--
-- PostgreSQL database dump
--

-- Dumped from database version 9.5.25
-- Dumped by pg_dump version 10.23 (Ubuntu 10.23-0ubuntu0.18.04.1)

-- Started on 2025-05-28 17:31:27 CEST

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

--
-- TOC entry 10 (class 2615 OID 36211)
-- Name: app; Type: SCHEMA; Schema: -; Owner: postgres
--

CREATE SCHEMA app;


ALTER SCHEMA app OWNER TO postgres;

--
-- TOC entry 12 (class 2615 OID 36320)
-- Name: fews; Type: SCHEMA; Schema: -; Owner: postgres
--

CREATE SCHEMA fews;


ALTER SCHEMA fews OWNER TO postgres;

--
-- TOC entry 11 (class 2615 OID 36321)
-- Name: monitoring; Type: SCHEMA; Schema: -; Owner: webapp
--

CREATE SCHEMA monitoring;


ALTER SCHEMA monitoring OWNER TO webapp;

--
-- TOC entry 13 (class 2615 OID 36322)
-- Name: ratingcurve; Type: SCHEMA; Schema: -; Owner: postgres
--

CREATE SCHEMA ratingcurve;


ALTER SCHEMA ratingcurve OWNER TO postgres;

--
-- TOC entry 1388 (class 1255 OID 36323)
-- Name: check_at_least_one_parameter_per_location(); Type: FUNCTION; Schema: fews; Owner: postgres
--

CREATE FUNCTION fews.check_at_least_one_parameter_per_location() RETURNS trigger
    LANGUAGE plpgsql
    AS $$
  DECLARE paramcount integer;
    BEGIN
    select count(*) from fews.locationparameters where fews.locationparameters.locationkey = NEW.locationkey into paramcount;
    IF paramcount > 0 THEN 
        RETURN NEW;
    END IF;
    RAISE EXCEPTION 'location must have parameters, please insert into locationparameters first';
  END;    
  $$;


ALTER FUNCTION fews.check_at_least_one_parameter_per_location() OWNER TO postgres;

--
-- TOC entry 1389 (class 1255 OID 36324)
-- Name: pivotcode(character varying, character varying, character varying, character varying, character varying); Type: FUNCTION; Schema: monitoring; Owner: postgres
--

CREATE FUNCTION monitoring.pivotcode(tablename character varying, rowc character varying, colc character varying, cellc character varying, celldatatype character varying) RETURNS character varying
    LANGUAGE plpgsql
    AS $$
  declare
      dynsql1 varchar;
      dynsql2 varchar;
      columnlist varchar;
  begin
      -- 1. retrieve list of column names.
      dynsql1 = 'select string_agg(distinct ''_''||'||colc||'||'' '||celldatatype||''','','' order by ''_''||'||colc||'||'' '||celldatatype||''') from '||tablename||';';
      execute dynsql1 into columnlist;
      -- 2. set up the crosstab query
      dynsql2 = 'select * from crosstab (
   ''select '||rowc||', '||colc||', '||cellc||' from '||tablename||' group by 1,2 order by 1,2'',
   ''select distinct '||colc||' from '||tablename||' order by 1''
   )
   as newtable (
   '||rowc||' varchar,'||columnlist||'
   );';
      return dynsql2;
  end
  $$;


ALTER FUNCTION monitoring.pivotcode(tablename character varying, rowc character varying, colc character varying, cellc character varying, celldatatype character varying) OWNER TO postgres;

--
-- TOC entry 205 (class 1259 OID 36212)
-- Name: navtree_itemid_seq; Type: SEQUENCE; Schema: app; Owner: postgres
--

CREATE SEQUENCE app.navtree_itemid_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE app.navtree_itemid_seq OWNER TO postgres;

SET default_with_oids = false;

--
-- TOC entry 206 (class 1259 OID 36214)
-- Name: navtree; Type: TABLE; Schema: app; Owner: postgres
--

CREATE TABLE app.navtree (
    itemid integer DEFAULT nextval('app.navtree_itemid_seq'::regclass) NOT NULL,
    text character varying(25) NOT NULL,
    title character varying NOT NULL,
    iconcls character varying(50) NOT NULL,
    classcolor character varying(25) DEFAULT 'plain'::character varying NOT NULL,
    viewtype character varying(100) DEFAULT 'panel'::character varying NOT NULL,
    route character varying(25),
    children boolean DEFAULT false NOT NULL,
    parentid integer DEFAULT 0 NOT NULL,
    "position" integer,
    modulename character varying(50)
);


ALTER TABLE app.navtree OWNER TO postgres;

--
-- TOC entry 207 (class 1259 OID 36225)
-- Name: preferences; Type: TABLE; Schema: app; Owner: postgres
--

CREATE TABLE app.preferences (
    type character varying(100) NOT NULL,
    name character varying(100) NOT NULL,
    data character varying(16384) NOT NULL,
    userid integer,
    roleid integer,
    gid integer
);


ALTER TABLE app.preferences OWNER TO postgres;

--
-- TOC entry 208 (class 1259 OID 36231)
-- Name: role_roleid_seq; Type: SEQUENCE; Schema: app; Owner: postgres
--

CREATE SEQUENCE app.role_roleid_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE app.role_roleid_seq OWNER TO postgres;

--
-- TOC entry 209 (class 1259 OID 36233)
-- Name: role; Type: TABLE; Schema: app; Owner: postgres
--

CREATE TABLE app.role (
    roleid integer DEFAULT nextval('app.role_roleid_seq'::regclass) NOT NULL,
    rolename character varying(100) NOT NULL,
    description character varying(150)
);


ALTER TABLE app.role OWNER TO postgres;

--
-- TOC entry 210 (class 1259 OID 36237)
-- Name: role_navtree; Type: TABLE; Schema: app; Owner: postgres
--

CREATE TABLE app.role_navtree (
    roleid integer NOT NULL,
    itemid integer NOT NULL,
    readwrite boolean DEFAULT false NOT NULL
);


ALTER TABLE app.role_navtree OWNER TO postgres;

--
-- TOC entry 211 (class 1259 OID 36241)
-- Name: spatialfilter; Type: TABLE; Schema: app; Owner: postgres
--

CREATE TABLE app.spatialfilter (
    gid integer NOT NULL,
    areatype character varying(50),
    areaname character varying(50),
    geom public.geometry(MultiPolygon,4326)
);


ALTER TABLE app.spatialfilter OWNER TO postgres;

--
-- TOC entry 212 (class 1259 OID 36247)
-- Name: spatialfilter_gid_seq; Type: SEQUENCE; Schema: app; Owner: postgres
--

CREATE SEQUENCE app.spatialfilter_gid_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE app.spatialfilter_gid_seq OWNER TO postgres;

--
-- TOC entry 3812 (class 0 OID 0)
-- Dependencies: 212
-- Name: spatialfilter_gid_seq; Type: SEQUENCE OWNED BY; Schema: app; Owner: postgres
--

ALTER SEQUENCE app.spatialfilter_gid_seq OWNED BY app.spatialfilter.gid;


--
-- TOC entry 213 (class 1259 OID 36249)
-- Name: userid_seq; Type: SEQUENCE; Schema: app; Owner: postgres
--

CREATE SEQUENCE app.userid_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE app.userid_seq OWNER TO postgres;

--
-- TOC entry 214 (class 1259 OID 36251)
-- Name: user; Type: TABLE; Schema: app; Owner: postgres
--

CREATE TABLE app."user" (
    userid integer DEFAULT nextval('app.userid_seq'::regclass) NOT NULL,
    username character varying(25) NOT NULL,
    fullname character varying(150) NOT NULL,
    passwd character varying(150) NOT NULL,
    roleid integer NOT NULL,
    email character varying(150)
);


ALTER TABLE app."user" OWNER TO postgres;

--
-- TOC entry 215 (class 1259 OID 36255)
-- Name: user_spatialfilter; Type: TABLE; Schema: app; Owner: postgres
--

CREATE TABLE app.user_spatialfilter (
    userid integer NOT NULL,
    gid integer NOT NULL
);


ALTER TABLE app.user_spatialfilter OWNER TO postgres;

--
-- TOC entry 216 (class 1259 OID 36325)
-- Name: AggregationPeriods_aggregationperiodkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."AggregationPeriods_aggregationperiodkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."AggregationPeriods_aggregationperiodkey_seq" OWNER TO postgres;

--
-- TOC entry 217 (class 1259 OID 36327)
-- Name: FeatureClass_featureclasskey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."FeatureClass_featureclasskey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."FeatureClass_featureclasskey_seq" OWNER TO postgres;

--
-- TOC entry 218 (class 1259 OID 36329)
-- Name: Filters_filterkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."Filters_filterkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."Filters_filterkey_seq" OWNER TO postgres;

--
-- TOC entry 219 (class 1259 OID 36331)
-- Name: Locations_locationkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."Locations_locationkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."Locations_locationkey_seq" OWNER TO postgres;

--
-- TOC entry 220 (class 1259 OID 36333)
-- Name: ModuleInstances_moduleinstancekey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."ModuleInstances_moduleinstancekey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."ModuleInstances_moduleinstancekey_seq" OWNER TO postgres;

--
-- TOC entry 221 (class 1259 OID 36335)
-- Name: ParameterGroups_groupkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."ParameterGroups_groupkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."ParameterGroups_groupkey_seq" OWNER TO postgres;

--
-- TOC entry 222 (class 1259 OID 36337)
-- Name: ParametersTable_parameterkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."ParametersTable_parameterkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."ParametersTable_parameterkey_seq" OWNER TO postgres;

--
-- TOC entry 223 (class 1259 OID 36339)
-- Name: QualifierSets_qualifiersetkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."QualifierSets_qualifiersetkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."QualifierSets_qualifiersetkey_seq" OWNER TO postgres;

--
-- TOC entry 224 (class 1259 OID 36341)
-- Name: Qualifiers_qualifierkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."Qualifiers_qualifierkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."Qualifiers_qualifierkey_seq" OWNER TO postgres;

--
-- TOC entry 225 (class 1259 OID 36343)
-- Name: TimeSeriesKeys_serieskey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."TimeSeriesKeys_serieskey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."TimeSeriesKeys_serieskey_seq" OWNER TO postgres;

--
-- TOC entry 226 (class 1259 OID 36345)
-- Name: TimeSteps_timestepkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."TimeSteps_timestepkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."TimeSteps_timestepkey_seq" OWNER TO postgres;

--
-- TOC entry 227 (class 1259 OID 36347)
-- Name: Users_userkey_seq; Type: SEQUENCE; Schema: fews; Owner: postgres
--

CREATE SEQUENCE fews."Users_userkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE fews."Users_userkey_seq" OWNER TO postgres;

--
-- TOC entry 228 (class 1259 OID 36349)
-- Name: aggregationperiods; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.aggregationperiods (
    aggregationperiodkey integer DEFAULT nextval('fews."AggregationPeriods_aggregationperiodkey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    description character varying(255)
);


ALTER TABLE fews.aggregationperiods OWNER TO postgres;

--
-- TOC entry 229 (class 1259 OID 36353)
-- Name: dual; Type: VIEW; Schema: fews; Owner: webapp
--

CREATE VIEW fews.dual AS
 SELECT ('now'::text)::date AS date;


ALTER TABLE fews.dual OWNER TO webapp;

--
-- TOC entry 230 (class 1259 OID 36357)
-- Name: featureclass; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.featureclass (
    featureclasskey integer DEFAULT nextval('fews."FeatureClass_featureclasskey_seq"'::regclass) NOT NULL,
    featureclassname text
);


ALTER TABLE fews.featureclass OWNER TO postgres;

--
-- TOC entry 231 (class 1259 OID 36364)
-- Name: filters; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.filters (
    filterkey integer DEFAULT nextval('fews."Filters_filterkey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    name character varying(64),
    description character varying(255),
    parentfilterid character varying(64),
    validationiconsvisible integer NOT NULL,
    mapextentid character varying(64),
    viewpermission character varying(64),
    editpermission character varying(64)
);


ALTER TABLE fews.filters OWNER TO postgres;

--
-- TOC entry 232 (class 1259 OID 36371)
-- Name: filtertimeserieskeys; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.filtertimeserieskeys (
    filterkey integer NOT NULL,
    serieskey integer NOT NULL
);


ALTER TABLE fews.filtertimeserieskeys OWNER TO postgres;

--
-- TOC entry 233 (class 1259 OID 36374)
-- Name: locations; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.locations (
    locationkey integer DEFAULT nextval('fews."Locations_locationkey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    name character varying(64),
    shortname character varying(64),
    description character varying(255),
    icon character varying(64),
    tooltip character varying(64),
    parentlocationid character varying(64),
    visibilitystarttime timestamp without time zone,
    visibilityendtime timestamp without time zone,
    x double precision NOT NULL,
    y double precision NOT NULL,
    z double precision,
    srid integer
);


ALTER TABLE fews.locations OWNER TO postgres;

--
-- TOC entry 3820 (class 0 OID 0)
-- Dependencies: 233
-- Name: COLUMN locations.x; Type: COMMENT; Schema: fews; Owner: postgres
--

COMMENT ON COLUMN fews.locations.x IS 'Coordinates are in local reference system';


--
-- TOC entry 3821 (class 0 OID 0)
-- Dependencies: 233
-- Name: COLUMN locations.y; Type: COMMENT; Schema: fews; Owner: postgres
--

COMMENT ON COLUMN fews.locations.y IS 'Coordinates are in local reference system';


--
-- TOC entry 3822 (class 0 OID 0)
-- Dependencies: 233
-- Name: COLUMN locations.srid; Type: COMMENT; Schema: fews; Owner: postgres
--

COMMENT ON COLUMN fews.locations.srid IS 'SRID code for the values in the ''x'' & ''y'' columns';


--
-- TOC entry 234 (class 1259 OID 36381)
-- Name: moduleinstances; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.moduleinstances (
    moduleinstancekey integer DEFAULT nextval('fews."ModuleInstances_moduleinstancekey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    name character varying(64),
    description character varying(255)
);


ALTER TABLE fews.moduleinstances OWNER TO postgres;

--
-- TOC entry 235 (class 1259 OID 36385)
-- Name: parametergroups; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.parametergroups (
    groupkey integer DEFAULT nextval('fews."ParameterGroups_groupkey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    name character varying(64),
    description character varying(255),
    parametertype character varying(64) NOT NULL,
    unit character varying(64),
    displayunit character varying(64)
);


ALTER TABLE fews.parametergroups OWNER TO postgres;

--
-- TOC entry 236 (class 1259 OID 36392)
-- Name: parameterstable; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.parameterstable (
    parameterkey integer DEFAULT nextval('fews."ParametersTable_parameterkey_seq"'::regclass) NOT NULL,
    groupkey integer NOT NULL,
    id character varying(64) NOT NULL,
    name character varying(64),
    shortname character varying(64),
    description character varying(255),
    valueresolution double precision,
    attributea character varying(64),
    attributeb double precision,
    featureclasskey integer NOT NULL
);


ALTER TABLE fews.parameterstable OWNER TO postgres;

--
-- TOC entry 237 (class 1259 OID 36399)
-- Name: qualifiers; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.qualifiers (
    qualifierkey integer DEFAULT nextval('fews."Qualifiers_qualifierkey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    name character varying(64),
    shortname character varying(64),
    description character varying(255)
);


ALTER TABLE fews.qualifiers OWNER TO postgres;

--
-- TOC entry 238 (class 1259 OID 36403)
-- Name: qualifiersets; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.qualifiersets (
    qualifiersetkey integer DEFAULT nextval('fews."QualifierSets_qualifiersetkey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    qualifierkey1 integer NOT NULL,
    qualifierkey2 integer,
    qualifierkey3 integer,
    qualifierkey4 integer
);


ALTER TABLE fews.qualifiersets OWNER TO postgres;

--
-- TOC entry 239 (class 1259 OID 36407)
-- Name: samples; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.samples (
    locationkey integer NOT NULL,
    datetime timestamp without time zone NOT NULL,
    id character varying(64) NOT NULL,
    description character varying(255)
);


ALTER TABLE fews.samples OWNER TO postgres;

--
-- TOC entry 240 (class 1259 OID 36410)
-- Name: stations; Type: VIEW; Schema: fews; Owner: postgres
--

CREATE VIEW fews.stations AS
 SELECT locations.locationkey AS stationkey,
    locations.id AS station_id,
    locations.name AS station_name,
    public.st_transform(public.st_setsrid(public.st_point(locations.x, locations.y), locations.srid), 4326) AS geom
   FROM fews.locations;


ALTER TABLE fews.stations OWNER TO postgres;

--
-- TOC entry 241 (class 1259 OID 36414)
-- Name: timeseriescomments; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.timeseriescomments (
    serieskey integer NOT NULL,
    datetime timestamp without time zone NOT NULL,
    commenttext character varying(64) NOT NULL
);


ALTER TABLE fews.timeseriescomments OWNER TO postgres;

--
-- TOC entry 242 (class 1259 OID 36417)
-- Name: timeserieskeys; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.timeserieskeys (
    serieskey integer DEFAULT nextval('fews."TimeSeriesKeys_serieskey_seq"'::regclass) NOT NULL,
    locationkey integer NOT NULL,
    parameterkey integer NOT NULL,
    qualifiersetkey integer,
    moduleinstancekey integer NOT NULL,
    timestepkey integer NOT NULL,
    aggregationperiodkey integer,
    valuetype integer DEFAULT 0 NOT NULL,
    modificationtime timestamp without time zone NOT NULL
);


ALTER TABLE fews.timeserieskeys OWNER TO postgres;

--
-- TOC entry 243 (class 1259 OID 36422)
-- Name: timeseriesmanualeditshistory; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.timeseriesmanualeditshistory (
    serieskey integer NOT NULL,
    editdatetime timestamp without time zone NOT NULL,
    datetime timestamp without time zone NOT NULL,
    userkey integer,
    scalarvalue double precision,
    flags integer NOT NULL,
    commenttext character varying(64),
    id integer
);


ALTER TABLE fews.timeseriesmanualeditshistory OWNER TO postgres;

--
-- TOC entry 244 (class 1259 OID 36425)
-- Name: timeseriesvaluesandflags; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.timeseriesvaluesandflags (
    serieskey integer NOT NULL,
    datetime timestamp without time zone NOT NULL,
    scalarvalue double precision,
    flags integer NOT NULL
);


ALTER TABLE fews.timeseriesvaluesandflags OWNER TO postgres;

--
-- TOC entry 245 (class 1259 OID 36428)
-- Name: timesteps; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.timesteps (
    timestepkey integer DEFAULT nextval('fews."TimeSteps_timestepkey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    label character varying(64)
);


ALTER TABLE fews.timesteps OWNER TO postgres;

--
-- TOC entry 246 (class 1259 OID 36432)
-- Name: users; Type: TABLE; Schema: fews; Owner: postgres
--

CREATE TABLE fews.users (
    userkey integer DEFAULT nextval('fews."Users_userkey_seq"'::regclass) NOT NULL,
    id character varying(64) NOT NULL,
    name character varying(64)
);


ALTER TABLE fews.users OWNER TO postgres;

--
-- TOC entry 247 (class 1259 OID 36436)
-- Name: wgslocations; Type: VIEW; Schema: fews; Owner: postgres
--

CREATE VIEW fews.wgslocations AS
 SELECT locations.locationkey,
    locations.id,
    locations.name,
    locations.shortname,
    locations.description,
    locations.icon,
    locations.tooltip,
    locations.parentlocationid,
    locations.visibilitystarttime,
    locations.visibilityendtime,
    public.st_x(public.st_transform(public.st_setsrid(public.st_point(locations.x, locations.y), locations.srid), 4326)) AS x,
    public.st_y(public.st_transform(public.st_setsrid(public.st_point(locations.x, locations.y), locations.srid), 4326)) AS y,
    locations.z
   FROM fews.locations;


ALTER TABLE fews.wgslocations OWNER TO postgres;

--
-- TOC entry 248 (class 1259 OID 36440)
-- Name: dump; Type: TABLE; Schema: monitoring; Owner: webapp
--

CREATE TABLE monitoring.dump (
    id integer NOT NULL,
    datetime timestamp without time zone,
    scalarvalue double precision,
    parameterid character varying(64),
    locationid character varying(64),
    flags integer,
    commenttext character varying(64)
);


ALTER TABLE monitoring.dump OWNER TO webapp;

--
-- TOC entry 249 (class 1259 OID 36443)
-- Name: dump_id_seq; Type: SEQUENCE; Schema: monitoring; Owner: webapp
--

CREATE SEQUENCE monitoring.dump_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE monitoring.dump_id_seq OWNER TO webapp;

--
-- TOC entry 3838 (class 0 OID 0)
-- Dependencies: 249
-- Name: dump_id_seq; Type: SEQUENCE OWNED BY; Schema: monitoring; Owner: webapp
--

ALTER SEQUENCE monitoring.dump_id_seq OWNED BY monitoring.dump.id;


--
-- TOC entry 250 (class 1259 OID 36445)
-- Name: Period_periodkey_seq; Type: SEQUENCE; Schema: ratingcurve; Owner: postgres
--

CREATE SEQUENCE ratingcurve."Period_periodkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE ratingcurve."Period_periodkey_seq" OWNER TO postgres;

--
-- TOC entry 251 (class 1259 OID 36447)
-- Name: Segment_segmentkey_seq; Type: SEQUENCE; Schema: ratingcurve; Owner: postgres
--

CREATE SEQUENCE ratingcurve."Segment_segmentkey_seq"
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE ratingcurve."Segment_segmentkey_seq" OWNER TO postgres;

--
-- TOC entry 252 (class 1259 OID 36449)
-- Name: period; Type: TABLE; Schema: ratingcurve; Owner: postgres
--

CREATE TABLE ratingcurve.period (
    periodkey integer DEFAULT nextval('ratingcurve."Period_periodkey_seq"'::regclass) NOT NULL,
    locationkey integer NOT NULL,
    start timestamp without time zone NOT NULL
);


ALTER TABLE ratingcurve.period OWNER TO postgres;

--
-- TOC entry 253 (class 1259 OID 36453)
-- Name: segment; Type: TABLE; Schema: ratingcurve; Owner: postgres
--

CREATE TABLE ratingcurve.segment (
    segmentkey integer DEFAULT nextval('ratingcurve."Segment_segmentkey_seq"'::regclass) NOT NULL,
    periodkey integer NOT NULL,
    low double precision NOT NULL,
    a_coef double precision NOT NULL,
    b_coef double precision NOT NULL,
    c_coef double precision NOT NULL
);


ALTER TABLE ratingcurve.segment OWNER TO postgres;

--
-- TOC entry 3840 (class 0 OID 0)
-- Dependencies: 253
-- Name: COLUMN segment.b_coef; Type: COMMENT; Schema: ratingcurve; Owner: postgres
--

COMMENT ON COLUMN ratingcurve.segment.b_coef IS 'h0 value';


--
-- TOC entry 3841 (class 0 OID 0)
-- Dependencies: 253
-- Name: COLUMN segment.c_coef; Type: COMMENT; Schema: ratingcurve; Owner: postgres
--

COMMENT ON COLUMN ratingcurve.segment.c_coef IS 'Also known as alfa';


--
-- TOC entry 3499 (class 2604 OID 36258)
-- Name: spatialfilter gid; Type: DEFAULT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.spatialfilter ALTER COLUMN gid SET DEFAULT nextval('app.spatialfilter_gid_seq'::regclass);


--
-- TOC entry 3514 (class 2604 OID 36457)
-- Name: dump id; Type: DEFAULT; Schema: monitoring; Owner: webapp
--

ALTER TABLE ONLY monitoring.dump ALTER COLUMN id SET DEFAULT nextval('monitoring.dump_id_seq'::regclass);


--
-- TOC entry 3754 (class 0 OID 36214)
-- Dependencies: 206
-- Data for Name: navtree; Type: TABLE DATA; Schema: app; Owner: postgres
--

INSERT INTO app.navtree VALUES (1, 'HOME', 'HOME', 'x-fa fa-home', 'blue', 'homeguest', 'home', false, 0, 0, 'homeguest');
INSERT INTO app.navtree VALUES (2, 'ABOUT', 'ABOUT', 'x-fa fa-info', 'blue', 'aboutcredits', 'about', false, 0, 200000, 'about');
INSERT INTO app.navtree VALUES (3, 'HOME', 'HOME', 'x-fa fa-home', 'blue', 'homehome', 'home', false, 0, 0, 'home');
INSERT INTO app.navtree VALUES (4, 'BASE DATA', 'DEFINITION OF TIME SERIES COMPONENTS', 'x-fa fa-database', 'blue', 'basedatadashboard', 'basedata', false, 0, 100, 'basedata');
INSERT INTO app.navtree VALUES (5, 'DATA ENTRY', 'MANUAL DATA ENTRY', 'x-fa fa-edit', 'blue', 'dataentry', 'dataentry', false, 0, 200, 'dataentry');
INSERT INTO app.navtree VALUES (6, 'TIME SERIES', 'TIME SERIES MANAGEMENT', 'x-fa fa-line-chart', 'blue', 'timeserieskeys', 'timeseries', false, 0, 300, 'timeseries');
INSERT INTO app.navtree VALUES (7, 'RATING CURVES', 'STAGE-DISCHARGE COEFICIENTS', 'x-fa fa-stack-overflow', 'blue', 'ratingcurveseditor', 'ratingcurves', false, 0, 400, 'raitingcurves');
INSERT INTO app.navtree VALUES (8, 'VISUALIZATION', 'VISUALIZATION', 'x-fa fa-desktop', 'blue', 'panel', NULL, true, 0, 500, 'visualization');
INSERT INTO app.navtree VALUES (9, 'ANALYSIS', 'FUNCTIONAL ANALYSIS OF TIME SERIES', 'x-fa fa-sliders', 'blue', 'visualizationanalysis', 'analysis', false, 8, 510, 'visualizationanalysis');
INSERT INTO app.navtree VALUES (10, 'CROSSTABS', 'AGGRGATED TIME SERIES DISPLAY', 'x-fa fa-table', 'blue', 'visualizationcrosstabs', 'crosstabs', false, 8, 520, 'visualizationcrosstabs');
INSERT INTO app.navtree VALUES (11, 'HELP', 'HELP', 'x-fa fa-question', 'blue', 'helpbase', 'help', false, 0, 190000, 'help');
INSERT INTO app.navtree VALUES (12, 'MANAGEMENT', 'USER ACCOUNTS AND USER ROLES', 'x-fa fa-user', 'blue', 'managementbase', 'management', false, 0, 10000, 'management');


--
-- TOC entry 3755 (class 0 OID 36225)
-- Dependencies: 207
-- Data for Name: preferences; Type: TABLE DATA; Schema: app; Owner: postgres
--



--
-- TOC entry 3757 (class 0 OID 36233)
-- Dependencies: 209
-- Data for Name: role; Type: TABLE DATA; Schema: app; Owner: postgres
--

INSERT INTO app.role VALUES (1, 'admin', 'User Administration');
INSERT INTO app.role VALUES (2, 'superuser', 'Read/Write access everywhere');
INSERT INTO app.role VALUES (3, 'readonly', 'Read-only access');
INSERT INTO app.role VALUES (4, 'demonstration', 'Only for demo purposes');


--
-- TOC entry 3758 (class 0 OID 36237)
-- Dependencies: 210
-- Data for Name: role_navtree; Type: TABLE DATA; Schema: app; Owner: postgres
--

INSERT INTO app.role_navtree VALUES (1, 12, false);
INSERT INTO app.role_navtree VALUES (2, 4, true);
INSERT INTO app.role_navtree VALUES (2, 5, true);
INSERT INTO app.role_navtree VALUES (2, 6, true);
INSERT INTO app.role_navtree VALUES (2, 7, true);
INSERT INTO app.role_navtree VALUES (2, 9, true);
INSERT INTO app.role_navtree VALUES (2, 8, false);
INSERT INTO app.role_navtree VALUES (2, 10, true);
INSERT INTO app.role_navtree VALUES (3, 4, false);
INSERT INTO app.role_navtree VALUES (3, 5, false);
INSERT INTO app.role_navtree VALUES (3, 6, false);
INSERT INTO app.role_navtree VALUES (3, 7, false);
INSERT INTO app.role_navtree VALUES (3, 9, false);
INSERT INTO app.role_navtree VALUES (3, 8, false);
INSERT INTO app.role_navtree VALUES (3, 10, false);
INSERT INTO app.role_navtree VALUES (4, 4, false);
INSERT INTO app.role_navtree VALUES (4, 6, false);
INSERT INTO app.role_navtree VALUES (4, 9, false);
INSERT INTO app.role_navtree VALUES (4, 8, false);


--
-- TOC entry 3759 (class 0 OID 36241)
-- Dependencies: 211
-- Data for Name: spatialfilter; Type: TABLE DATA; Schema: app; Owner: postgres
--

INSERT INTO app.spatialfilter VALUES (1, 'World', 'Everything', '0106000020E6100000010000000103000000010000000500000000000000008066C000000000000054C000000000008066C0000000000000544000000000008066400000000000005440000000000080664000000000000054C000000000008066C000000000000054C0');


--
-- TOC entry 3762 (class 0 OID 36251)
-- Dependencies: 214
-- Data for Name: user; Type: TABLE DATA; Schema: app; Owner: postgres
--

INSERT INTO app."user" VALUES (2, 'retsios', 'Bas Retsios', 'A9zFQjTur/1xhdBa/C8bLg==', 2, 'retsios@itc.nl');
INSERT INTO app."user" VALUES (3, 'bekzod', 'Bekzod Akramov', 'f3L3dyDmHAF0pq/Fk7klQw==', 2, 'bekzod.akramov@gmail.com');
INSERT INTO app."user" VALUES (6, 'pulatov', 'Yarash Pulatov', 'BGW0ijsjYgEBgzvdUtt53g==', 2, 'tj_water@mail.ru');
INSERT INTO app."user" VALUES (7, 'yarash', 'Yarash Pulatov', 'w4yG698opSXN6faCL5rq1g==', 2, 'tj_water@mail.ru');
INSERT INTO app."user" VALUES (5, 'nano', 'Tilyavi', 'R5lUAIvx+ucl94V+UqTRFQ==', 2, NULL);
INSERT INTO app."user" VALUES (8, 'janay', 'Janay Sagintayev', '4OWPKOqzrlWXd/YlXdNdPw==', 2, 'zhanay.sagintayev@nu.edu.kz');
INSERT INTO app."user" VALUES (9, 'zheenbek', 'Kulenbekov', 'qaXpU9mFeZDKiRbbFHBrkQ==', 2, 'kulenbekov@gmail.com');
INSERT INTO app."user" VALUES (10, 'demo', 'Demonstration user', '/gHOKn+6yPr67XyYKgTiKQ==', 4, NULL);
INSERT INTO app."user" VALUES (1, 'admin', 'User Administrator', 'KyrpowWNr84j/rmt032IQA==', 1, NULL);
INSERT INTO app."user" VALUES (11, 'demo_contributor', 'Demonstration superuser', '/gHOKn+6yPr67XyYKgTiKQ==', 2, NULL);
INSERT INTO app."user" VALUES (12, 'gijsbers', 'Peter Gijsbers', 'f9TotrbX6/1IHzr6faJnpg==', 2, 'Peter.Gijsbers@deltares.nl');
INSERT INTO app."user" VALUES (13, 'mvandijk', 'Marc van Dijk', 'LbNa775S4G3EwTf1t7afLA==', 2, 'Marc.vanDijk@deltares.nl');
INSERT INTO app."user" VALUES (4, 'zafar', 'Zafar Gafurov', 'DpCU7Q2F/2sUOyTbH6xQ8g==', 2, 'z.gafurov@cgiar.org');
INSERT INTO app."user" VALUES (14, 'haedes', 'Haedes Account', 'woBMd7i628S0095RGsREpw==', 3, 'ivan.rocabado@haedes.eu');


--
-- TOC entry 3763 (class 0 OID 36255)
-- Dependencies: 215
-- Data for Name: user_spatialfilter; Type: TABLE DATA; Schema: app; Owner: postgres
--

INSERT INTO app.user_spatialfilter VALUES (2, 1);
INSERT INTO app.user_spatialfilter VALUES (3, 1);
INSERT INTO app.user_spatialfilter VALUES (4, 1);
INSERT INTO app.user_spatialfilter VALUES (5, 1);
INSERT INTO app.user_spatialfilter VALUES (6, 1);
INSERT INTO app.user_spatialfilter VALUES (7, 1);
INSERT INTO app.user_spatialfilter VALUES (8, 1);
INSERT INTO app.user_spatialfilter VALUES (9, 1);
INSERT INTO app.user_spatialfilter VALUES (10, 1);
INSERT INTO app.user_spatialfilter VALUES (11, 1);
INSERT INTO app.user_spatialfilter VALUES (12, 1);
INSERT INTO app.user_spatialfilter VALUES (13, 1);
INSERT INTO app.user_spatialfilter VALUES (14, 1);


--
-- TOC entry 3776 (class 0 OID 36349)
-- Dependencies: 228
-- Data for Name: aggregationperiods; Type: TABLE DATA; Schema: fews; Owner: postgres
--



--
-- TOC entry 3777 (class 0 OID 36357)
-- Dependencies: 230
-- Data for Name: featureclass; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.featureclass VALUES (1, 'Surface Water');
INSERT INTO fews.featureclass VALUES (2, 'Water Quality');


--
-- TOC entry 3778 (class 0 OID 36364)
-- Dependencies: 231
-- Data for Name: filters; Type: TABLE DATA; Schema: fews; Owner: postgres
--



--
-- TOC entry 3779 (class 0 OID 36371)
-- Dependencies: 232
-- Data for Name: filtertimeserieskeys; Type: TABLE DATA; Schema: fews; Owner: postgres
--



--
-- TOC entry 3780 (class 0 OID 36374)
-- Dependencies: 233
-- Data for Name: locations; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.locations VALUES (1, 'Karatag', 'Karatag', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.0116666666666987, 38.3113888888888994, NULL, 4326);
INSERT INTO fews.locations VALUES (8, 'Denav', 'Denav meteostation in Surkhandarya province', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.9000000000000057, 38.2659999999999982, 520, 4326);
INSERT INTO fews.locations VALUES (2, 'Surhandarya_01', 'Surhandarya river kishlak Shurchi', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.875, 38, NULL, 4326);
INSERT INTO fews.locations VALUES (3, 'Surhandarya_02', 'Surhandarya river- below the South Surkhan reservoir', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.1083333333333343, 37.7833333333333314, NULL, 4326);
INSERT INTO fews.locations VALUES (4, 'Surhandarya_03', 'Surhandarya river- Galaba channel aqueduct', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.6666666666666714, 37.8333333333333286, NULL, 4326);
INSERT INTO fews.locations VALUES (18, 'Tupalang', 'river mouth', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.0041999999999973, 38.1841000000000008, NULL, 4006);
INSERT INTO fews.locations VALUES (20, 'ZARCHOB', 'TUPALANGDARYA', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.0090000000000003, 38.0026999999999973, 694, 4326);
INSERT INTO fews.locations VALUES (25, 'p373672', 'precipitation', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.1880000000000024, 37.3109999999999999, NULL, 4006);
INSERT INTO fews.locations VALUES (26, 'p373675', 'precipitation', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.5, 37.3109999999999999, NULL, 4006);
INSERT INTO fews.locations VALUES (36, 'p376675', 'precipitation', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.5, 37.6240000000000023, NULL, 4006);
INSERT INTO fews.locations VALUES (37, 'p389684', 'Precipitation', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.4380000000000024, 38.8729999999999976, NULL, 4006);
INSERT INTO fews.locations VALUES (39, 'p379672', 'precipitation', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.1880000000000024, 37.9359999999999999, NULL, 4006);
INSERT INTO fews.locations VALUES (40, 'p386678', 'precipitation', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.8130000000000024, 38.5600000000000023, NULL, 4006);
INSERT INTO fews.locations VALUES (42, 'w373666', 'wind speed', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 66.5630000000000024, 37.3109999999999999, NULL, 4006);
INSERT INTO fews.locations VALUES (43, 'w376678', 'wind speed', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.8130000000000024, 37.6240000000000023, NULL, 4006);
INSERT INTO fews.locations VALUES (45, 'w382684', 'wind speed', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.4380000000000024, 38.2479999999999976, NULL, 4006);
INSERT INTO fews.locations VALUES (46, 'w386678', 'wind speed', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.8130000000000024, 38.5600000000000023, NULL, 4006);
INSERT INTO fews.locations VALUES (44, 'w382672', 'wind speed', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.1880000000000024, 38.2479999999999976, NULL, 4006);
INSERT INTO fews.locations VALUES (47, 'w386688', 'wind speed', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.75, 38.5600000000000023, NULL, 4006);
INSERT INTO fews.locations VALUES (48, 'w389681', 'wind speed', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.125, 38.8729999999999976, NULL, 4006);
INSERT INTO fews.locations VALUES (52, 't379684', 'temperature (max)', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.4380000000000024, 37.9359999999999999, NULL, 4006);
INSERT INTO fews.locations VALUES (50, 't379675', 'temperature (max)', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.5, 37.9359999999999999, NULL, 4006);
INSERT INTO fews.locations VALUES (49, 't376669', 'temperature (max)', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 66.875, 37.6240000000000023, NULL, 4006);
INSERT INTO fews.locations VALUES (53, 't382688', 'temperature (max)', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.75, 38.2479999999999976, NULL, 4006);
INSERT INTO fews.locations VALUES (54, 't386681', 'temperature (max)', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 68.125, 38.5600000000000023, NULL, 4006);
INSERT INTO fews.locations VALUES (55, 't389675', 'temperature (max)', NULL, NULL, NULL, NULL, NULL, NULL, NULL, 67.5, 38.8729999999999976, NULL, 4006);


--
-- TOC entry 3781 (class 0 OID 36381)
-- Dependencies: 234
-- Data for Name: moduleinstances; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.moduleinstances VALUES (1, 'Import_From_DB', 'Import_From_DB', 'Import data from the temporary table in the database');
INSERT INTO fews.moduleinstances VALUES (2, 'Import_CSV', 'Import_CSV', 'Import Precipitation, Evaporation and Temperature from CSV');


--
-- TOC entry 3782 (class 0 OID 36385)
-- Dependencies: 235
-- Data for Name: parametergroups; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.parametergroups VALUES (1, 'Discharge', 'Discharge', NULL, '0', 'm3/sec', 'm3/sec');
INSERT INTO fews.parametergroups VALUES (2, 'Precipitation', 'Precipitation', NULL, '0', 'mm', 'mm');
INSERT INTO fews.parametergroups VALUES (3, 'Temperature', 'Temperature', NULL, '0', 'oC', 'oC');
INSERT INTO fews.parametergroups VALUES (5, 'Sulphate', 'Sulphate', NULL, '0', 'mg SO4/l', 'mg SO4/l');
INSERT INTO fews.parametergroups VALUES (4, 'Height (cm)', 'Height (cm)', NULL, '0', 'cm', 'cm');
INSERT INTO fews.parametergroups VALUES (6, 'Speed', 'Speed', NULL, '0', 'm/s', 'm/s');


--
-- TOC entry 3783 (class 0 OID 36392)
-- Dependencies: 236
-- Data for Name: parameterstable; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.parameterstable VALUES (1, 1, 'Q.calc', 'Discharge calculated', 'Q.calc', NULL, NULL, NULL, NULL, 1);
INSERT INTO fews.parameterstable VALUES (2, 3, 'T.obs', 'Temperature observed', 'T.obs', NULL, NULL, NULL, NULL, 2);
INSERT INTO fews.parameterstable VALUES (3, 5, 'S.obs', 'Sulphate observed', 'S.obs', NULL, NULL, NULL, NULL, 2);
INSERT INTO fews.parameterstable VALUES (4, 2, 'P.obs', 'Precipitation observed', 'P.obs', NULL, NULL, NULL, NULL, 1);
INSERT INTO fews.parameterstable VALUES (5, 4, 'H.obs', 'Water level observed', 'H.obs', NULL, NULL, NULL, NULL, 1);
INSERT INTO fews.parameterstable VALUES (6, 6, 'W.obs', 'Wind speed observed', 'W.obs', NULL, NULL, NULL, NULL, 1);


--
-- TOC entry 3784 (class 0 OID 36399)
-- Dependencies: 237
-- Data for Name: qualifiers; Type: TABLE DATA; Schema: fews; Owner: postgres
--



--
-- TOC entry 3785 (class 0 OID 36403)
-- Dependencies: 238
-- Data for Name: qualifiersets; Type: TABLE DATA; Schema: fews; Owner: postgres
--



--
-- TOC entry 3786 (class 0 OID 36407)
-- Dependencies: 239
-- Data for Name: samples; Type: TABLE DATA; Schema: fews; Owner: postgres
--



--
-- TOC entry 3787 (class 0 OID 36414)
-- Dependencies: 241
-- Data for Name: timeseriescomments; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.timeseriescomments VALUES (1, '2019-01-01 00:00:00', 'Imported from "Karatag - Copy - Levels.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '2019-01-01 00:00:00', 'Imported from "Karatag - Copy - Q.csv"');
INSERT INTO fews.timeseriescomments VALUES (4, '2019-01-01 00:00:00', 'Imported from "Surhandarya river- kishlak Shurchi - Q.csv"');
INSERT INTO fews.timeseriescomments VALUES (5, '2019-01-01 00:00:00', 'Imported from "Surhandarya river- below the South Surkhan reserv');
INSERT INTO fews.timeseriescomments VALUES (6, '2019-01-01 00:00:00', 'Imported from "Surhandarya river- Galaba channel aqueduct - Leve');
INSERT INTO fews.timeseriescomments VALUES (7, '2019-01-01 00:00:00', 'Imported from "Surhandarya river- below the South Surkhan reserv');
INSERT INTO fews.timeseriescomments VALUES (3, '2019-01-01 00:00:00', 'Imported from "Surhandarya river- kishlak Shurchi - Levels.csv"');
INSERT INTO fews.timeseriescomments VALUES (8, '2000-01-01 00:00:00', 'Imported from "Denau_2000-2017_temp_max_updated.csv"');
INSERT INTO fews.timeseriescomments VALUES (9, '2008-02-01 00:00:00', 'Imported from "tupalang1.csv"');
INSERT INTO fews.timeseriescomments VALUES (9, '2009-02-01 00:00:00', 'Imported from "tupalang2.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2010-01-01 00:00:00', 'Imported from "Karatag3.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2011-01-01 00:00:00', 'Imported from "Karatag4.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2008-01-01 00:00:00', 'Imported from "Karatag1.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2012-01-01 00:00:00', 'Imported from "Karatag5.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2009-01-01 00:00:00', 'Imported from "Karatag2.csv"');
INSERT INTO fews.timeseriescomments VALUES (3, '2008-01-05 00:00:00', 'Imported from "Surhshurci2008l.csv"');
INSERT INTO fews.timeseriescomments VALUES (3, '2009-01-05 00:00:00', 'Imported from "Surhshurci2009l.csv"');
INSERT INTO fews.timeseriescomments VALUES (3, '2010-01-05 00:00:00', 'Imported from "Surhshurci2010l.csv"');
INSERT INTO fews.timeseriescomments VALUES (3, '2011-01-05 00:00:00', 'Imported from "Surhshurci2011l.csv"');
INSERT INTO fews.timeseriescomments VALUES (3, '2012-01-05 00:00:00', 'Imported from "Surhshurci2012l.csv"');
INSERT INTO fews.timeseriescomments VALUES (7, '2008-01-05 00:00:00', 'Imported from "Surhyujno2008l.csv"');
INSERT INTO fews.timeseriescomments VALUES (7, '2009-01-05 00:00:00', 'Imported from "Surhyujno2009l.csv"');
INSERT INTO fews.timeseriescomments VALUES (7, '2010-01-05 00:00:00', 'Imported from "Surhyujno2010l.csv"');
INSERT INTO fews.timeseriescomments VALUES (7, '2011-01-05 00:00:00', 'Imported from "Surhyujno2011l.csv"');
INSERT INTO fews.timeseriescomments VALUES (7, '2012-01-05 00:00:00', 'Imported from "Surhyujno2012l.csv"');
INSERT INTO fews.timeseriescomments VALUES (6, '2008-01-05 00:00:00', 'Imported from "Surhgalaba2008l.csv"');
INSERT INTO fews.timeseriescomments VALUES (6, '2009-01-05 00:00:00', 'Imported from "Surhgalaba2009l.csv"');
INSERT INTO fews.timeseriescomments VALUES (6, '2010-01-05 00:00:00', 'Imported from "Surhgalaba2010l.csv"');
INSERT INTO fews.timeseriescomments VALUES (6, '2011-01-05 00:00:00', 'Imported from "Surhgalaba2011l.csv"');
INSERT INTO fews.timeseriescomments VALUES (6, '2012-01-05 00:00:00', 'Imported from "Surhgalaba2012l.csv"');
INSERT INTO fews.timeseriescomments VALUES (4, '2008-01-05 00:00:00', 'Imported from "SurhshurciQ2008.csv"');
INSERT INTO fews.timeseriescomments VALUES (4, '2009-01-05 00:00:00', 'Imported from "SurhshurciQ2009.csv"');
INSERT INTO fews.timeseriescomments VALUES (4, '2010-01-05 00:00:00', 'Imported from "SurhshurciQ2010.csv"');
INSERT INTO fews.timeseriescomments VALUES (4, '2011-01-05 00:00:00', 'Imported from "SurhshurciQ2011.csv"');
INSERT INTO fews.timeseriescomments VALUES (4, '2012-01-05 00:00:00', 'Imported from "SurhshurciQ2012.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2008-01-05 00:00:00', 'Imported from "KaratagWT2008.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2009-01-05 00:00:00', 'Imported from "KaratagWT2009.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2010-01-05 00:00:00', 'Imported from "KaratagWT2010.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2011-01-05 00:00:00', 'Imported from "KaratagWT2011.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2012-01-05 00:00:00', 'Imported from "KaratagWT2013.csv"');
INSERT INTO fews.timeseriescomments VALUES (11, '2008-01-05 00:00:00', 'Imported from "SurhyujnoWT2008.csv"');
INSERT INTO fews.timeseriescomments VALUES (11, '2009-01-05 00:00:00', 'Imported from "SurhyujnoWT2009.csv"');
INSERT INTO fews.timeseriescomments VALUES (11, '2010-01-05 00:00:00', 'Imported from "SurhyujnoWT2010.csv"');
INSERT INTO fews.timeseriescomments VALUES (11, '2011-01-05 00:00:00', 'Imported from "SurhyujnoWT2011.csv"');
INSERT INTO fews.timeseriescomments VALUES (11, '2012-01-05 00:00:00', 'Imported from "SurhyujnoWT2013.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2013-01-05 00:00:00', 'Imported from "KaratagWT2013.csv"');
INSERT INTO fews.timeseriescomments VALUES (11, '2013-01-05 00:00:00', 'Imported from "SurhyujnoWT2013.csv"');
INSERT INTO fews.timeseriescomments VALUES (5, '2008-01-05 00:00:00', 'Imported from "SurhyujnoQ2008.csv"');
INSERT INTO fews.timeseriescomments VALUES (5, '2009-01-05 00:00:00', 'Imported from "SurhyujnoQ2009.csv"');
INSERT INTO fews.timeseriescomments VALUES (5, '2010-01-05 00:00:00', 'Imported from "Surhyujno2010l.csv"');
INSERT INTO fews.timeseriescomments VALUES (5, '2011-01-05 00:00:00', 'Imported from "SurhyujnoQ2011.csv"');
INSERT INTO fews.timeseriescomments VALUES (5, '2012-01-05 00:00:00', 'Imported from "SurhyujnoQ2012.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '1979-01-01 00:00:00', 'Imported from "p373666.csv"');
INSERT INTO fews.timeseriescomments VALUES (16, '1979-01-01 00:00:00', 'Imported from "p373672.csv"');
INSERT INTO fews.timeseriescomments VALUES (17, '1979-01-01 00:00:00', 'Imported from "p373675.csv"');
INSERT INTO fews.timeseriescomments VALUES (25, '1979-01-01 00:00:00', 'Imported from "p376675.csv"');
INSERT INTO fews.timeseriescomments VALUES (26, '1979-01-01 00:00:00', 'Imported from "p389684.csv"');
INSERT INTO fews.timeseriescomments VALUES (27, '1979-01-01 00:00:00', 'Imported from "p379672.csv"');
INSERT INTO fews.timeseriescomments VALUES (28, '1979-01-01 00:00:00', 'Imported from "p386678_.csv"');
INSERT INTO fews.timeseriescomments VALUES (29, '1979-01-01 00:00:00', 'Imported from "w373666.csv"');
INSERT INTO fews.timeseriescomments VALUES (30, '1979-01-01 00:00:00', 'Imported from "w376678.csv"');
INSERT INTO fews.timeseriescomments VALUES (31, '1979-01-01 00:00:00', 'Imported from "w382672.csv"');
INSERT INTO fews.timeseriescomments VALUES (32, '1979-01-01 00:00:00', 'Imported from "w382684.csv"');
INSERT INTO fews.timeseriescomments VALUES (33, '1979-01-01 00:00:00', 'Imported from "w386678.csv"');
INSERT INTO fews.timeseriescomments VALUES (34, '1979-01-01 00:00:00', 'Imported from "w386688.csv"');
INSERT INTO fews.timeseriescomments VALUES (35, '1979-01-01 00:00:00', 'Imported from "w389681.csv"');
INSERT INTO fews.timeseriescomments VALUES (36, '1979-01-01 00:00:00', 'Imported from "t376669.csv"');
INSERT INTO fews.timeseriescomments VALUES (37, '1979-01-01 00:00:00', 'Imported from "t379675.csv"');
INSERT INTO fews.timeseriescomments VALUES (38, '1979-01-01 00:00:00', 'Imported from "t379684.csv"');
INSERT INTO fews.timeseriescomments VALUES (39, '1979-01-01 00:00:00', 'Imported from "t382688.csv"');
INSERT INTO fews.timeseriescomments VALUES (40, '1979-01-01 00:00:00', 'Imported from "t386681.csv"');
INSERT INTO fews.timeseriescomments VALUES (41, '1979-01-01 00:00:00', 'Imported from "t389675.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '2017-01-05 00:00:00', 'Imported from "2017kq.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '2018-01-05 00:00:00', 'Imported from "2018kq.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '2019-01-05 00:00:00', 'Imported from "2019kq.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2014-01-05 00:00:00', 'Imported from "2014kh.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2015-01-05 00:00:00', 'Imported from "2015kh.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2016-01-05 00:00:00', 'Imported from "2016kh.csv"');
INSERT INTO fews.timeseriescomments VALUES (1, '2013-01-05 00:00:00', 'Imported from "2013kh.csv"');
INSERT INTO fews.timeseriescomments VALUES (3, '2013-01-05 00:00:00', 'Imported from "Surhshurci2013l.csv"');
INSERT INTO fews.timeseriescomments VALUES (7, '2013-01-05 00:00:00', 'Imported from "Surhyujno2013l.csv"');
INSERT INTO fews.timeseriescomments VALUES (6, '2013-01-05 00:00:00', 'Imported from "Surhgalaba2013l.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '2013-01-05 00:00:00', 'Imported from "2013kq.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '2014-01-05 00:00:00', 'Imported from "2014kq.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '2015-01-05 00:00:00', 'Imported from "2015kq.csv"');
INSERT INTO fews.timeseriescomments VALUES (2, '2016-01-05 00:00:00', 'Imported from "2016kq.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2014-01-05 00:00:00', 'Imported from "KaratagWT2014.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2019-01-05 00:00:00', 'Imported from "KaratagWT2019.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2015-01-05 00:00:00', 'Imported from "KaratagWT2015.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2016-01-05 00:00:00', 'Imported from "KaratagWT2016.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2017-01-05 00:00:00', 'Imported from "KaratagWT2017.csv"');
INSERT INTO fews.timeseriescomments VALUES (10, '2018-01-05 00:00:00', 'Imported from "KaratagWT2018.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2014-01-05 00:00:00', 'Imported from "SurhyujnoWT2014.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2015-01-05 00:00:00', 'Imported from "SurhyujnoWT2015.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2017-01-05 00:00:00', 'Imported from "KaratagWT2017.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2018-01-05 00:00:00', 'Imported from "SurhyujnoWT2018.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2019-01-05 00:00:00', 'Imported from "SurhyujnoWT2019.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2016-01-05 00:00:00', 'Imported from "SurhyujnoWT2016.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2008-01-05 00:00:00', 'Imported from "SurhyujnoWT2008.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2009-01-05 00:00:00', 'Imported from "SurhyujnoWT2009.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2010-01-05 00:00:00', 'Imported from "SurhyujnoWT2010.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2011-01-05 00:00:00', 'Imported from "SurhyujnoWT2011.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2012-01-05 00:00:00', 'Imported from "SurhyujnoWT2012.csv"');
INSERT INTO fews.timeseriescomments VALUES (42, '2013-01-05 00:00:00', 'Imported from "SurhyujnoWT2013.csv"');


--
-- TOC entry 3788 (class 0 OID 36417)
-- Dependencies: 242
-- Data for Name: timeserieskeys; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.timeserieskeys VALUES (4, 2, 1, NULL, 1, 1, NULL, 0, '2021-09-28 13:19:42');
INSERT INTO fews.timeserieskeys VALUES (3, 2, 5, NULL, 1, 1, NULL, 0, '2022-01-24 09:22:50');
INSERT INTO fews.timeserieskeys VALUES (28, 40, 4, NULL, 1, 1, NULL, 0, '2021-11-27 15:54:06');
INSERT INTO fews.timeserieskeys VALUES (7, 3, 5, NULL, 1, 1, NULL, 0, '2022-01-24 11:40:18');
INSERT INTO fews.timeserieskeys VALUES (29, 42, 6, NULL, 1, 1, NULL, 0, '2021-11-27 16:07:05');
INSERT INTO fews.timeserieskeys VALUES (6, 4, 5, NULL, 1, 1, NULL, 0, '2022-01-24 11:40:46');
INSERT INTO fews.timeserieskeys VALUES (30, 43, 6, NULL, 1, 1, NULL, 0, '2021-11-27 16:09:21');
INSERT INTO fews.timeserieskeys VALUES (8, 8, 2, NULL, 1, 1, NULL, 0, '2020-09-23 10:48:27');
INSERT INTO fews.timeserieskeys VALUES (16, 25, 4, NULL, 1, 1, NULL, 0, '2021-11-26 13:46:17');
INSERT INTO fews.timeserieskeys VALUES (9, 18, 1, NULL, 1, 1, NULL, 0, '2021-03-17 18:27:01');
INSERT INTO fews.timeserieskeys VALUES (31, 44, 6, NULL, 1, 1, NULL, 0, '2021-11-27 16:11:45');
INSERT INTO fews.timeserieskeys VALUES (17, 26, 4, NULL, 1, 1, NULL, 0, '2021-11-26 13:53:45');
INSERT INTO fews.timeserieskeys VALUES (32, 45, 6, NULL, 1, 1, NULL, 0, '2021-11-27 16:13:22');
INSERT INTO fews.timeserieskeys VALUES (11, 3, 2, NULL, 1, 1, NULL, 0, '2021-10-07 16:22:23');
INSERT INTO fews.timeserieskeys VALUES (33, 46, 6, NULL, 1, 1, NULL, 0, '2021-11-27 16:22:12');
INSERT INTO fews.timeserieskeys VALUES (2, 1, 1, NULL, 1, 1, NULL, 0, '2022-01-31 12:10:55');
INSERT INTO fews.timeserieskeys VALUES (34, 47, 6, NULL, 1, 1, NULL, 0, '2021-11-27 16:24:07');
INSERT INTO fews.timeserieskeys VALUES (35, 48, 6, NULL, 1, 1, NULL, 0, '2021-11-27 16:25:35');
INSERT INTO fews.timeserieskeys VALUES (5, 3, 1, NULL, 1, 1, NULL, 0, '2021-10-09 16:08:39');
INSERT INTO fews.timeserieskeys VALUES (36, 49, 2, NULL, 1, 1, NULL, 0, '2021-11-29 08:50:35');
INSERT INTO fews.timeserieskeys VALUES (37, 50, 2, NULL, 1, 1, NULL, 0, '2021-11-29 08:56:19');
INSERT INTO fews.timeserieskeys VALUES (38, 52, 2, NULL, 1, 1, NULL, 0, '2021-11-29 09:05:55');
INSERT INTO fews.timeserieskeys VALUES (10, 1, 2, NULL, 1, 1, NULL, 0, '2022-03-25 09:55:20');
INSERT INTO fews.timeserieskeys VALUES (39, 53, 2, NULL, 1, 1, NULL, 0, '2021-11-29 09:12:04');
INSERT INTO fews.timeserieskeys VALUES (25, 36, 4, NULL, 1, 1, NULL, 0, '2021-11-27 08:56:41');
INSERT INTO fews.timeserieskeys VALUES (26, 37, 4, NULL, 1, 1, NULL, 0, '2021-11-27 14:43:23');
INSERT INTO fews.timeserieskeys VALUES (40, 54, 2, NULL, 1, 1, NULL, 0, '2021-11-29 09:19:41');
INSERT INTO fews.timeserieskeys VALUES (27, 39, 4, NULL, 1, 1, NULL, 0, '2021-11-27 15:49:24');
INSERT INTO fews.timeserieskeys VALUES (41, 55, 2, NULL, 1, 1, NULL, 0, '2021-11-29 09:30:17');
INSERT INTO fews.timeserieskeys VALUES (1, 1, 5, NULL, 1, 1, NULL, 0, '2022-01-24 09:12:40');
INSERT INTO fews.timeserieskeys VALUES (42, 4, 2, NULL, 1, 1, NULL, 0, '2022-04-22 11:27:43');


--
-- TOC entry 3789 (class 0 OID 36422)
-- Dependencies: 243
-- Data for Name: timeseriesmanualeditshistory; Type: TABLE DATA; Schema: fews; Owner: postgres
--



--
-- TOC entry 3790 (class 0 OID 36425)
-- Dependencies: 244
-- Data for Name: timeseriesvaluesandflags; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-01 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-02 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-03 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-04 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-05 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-06 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-07 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-08 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-09 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-10 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-11 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-12 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-13 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-14 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-15 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-16 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-17 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-18 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-19 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-20 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-21 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-22 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-23 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-24 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-25 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-26 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-27 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-28 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-29 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-30 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-01-31 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-01 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-02 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-03 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-04 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-05 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-06 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-07 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-08 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-09 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-10 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-11 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-12 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-13 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-14 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-15 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-16 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-17 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-18 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-19 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-20 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-21 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-22 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-23 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-24 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-25 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-26 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-27 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-02-28 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-01 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-02 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-03 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-04 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-05 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-06 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-07 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-08 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-09 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-10 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-11 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-12 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-13 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-14 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-15 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-16 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-17 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-18 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-19 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-20 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-21 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-22 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-23 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-24 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-25 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-26 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-27 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-28 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-29 00:00:00', 269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-30 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-03-31 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-01 00:00:00', 273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-02 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-03 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-04 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-05 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-06 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-07 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-08 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-09 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-10 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-11 00:00:00', 293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-12 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-13 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-14 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-15 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-16 00:00:00', 285, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-17 00:00:00', 285, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-18 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-19 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-20 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-21 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-22 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-23 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-24 00:00:00', 327, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-25 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-26 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-27 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-28 00:00:00', 323, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-29 00:00:00', 314, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-04-30 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-01 00:00:00', 295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-02 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-03 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-04 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-05 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-06 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-07 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-08 00:00:00', 299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-09 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-10 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-11 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-12 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-13 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-14 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-15 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-16 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-17 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-18 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-19 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-20 00:00:00', 288, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-21 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-22 00:00:00', 293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-23 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-24 00:00:00', 287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-25 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-26 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-27 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-28 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-29 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-30 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-05-31 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-01 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-02 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-03 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-04 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-05 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-06 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-07 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-08 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-09 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-10 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-11 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-12 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-13 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-14 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-15 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-16 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-17 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-18 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-19 00:00:00', 267, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-20 00:00:00', 269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-21 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-22 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-23 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-24 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-25 00:00:00', 297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-26 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-27 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-28 00:00:00', 287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-29 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-06-30 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-01 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-02 00:00:00', 237, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-03 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-04 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-05 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-06 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-07 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-08 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-09 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-10 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-11 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-12 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-13 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-14 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-15 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-16 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-17 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-18 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-19 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-20 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-21 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-22 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-23 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-24 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-25 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-26 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-27 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-28 00:00:00', 233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-29 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-30 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-07-31 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-01 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-02 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-03 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-04 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-05 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-06 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-07 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-08 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-09 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-10 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-11 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-12 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-13 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-14 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-15 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-16 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-17 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-18 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-19 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-20 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-21 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-22 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-23 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-24 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-25 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-26 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-27 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-28 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-29 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-30 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-08-31 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-01 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-02 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-03 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-04 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-05 00:00:00', 201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-06 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-07 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-08 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-09 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-10 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-11 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-12 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-13 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-14 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-15 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-16 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-17 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-18 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-19 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-20 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-21 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-22 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-23 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-24 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-25 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-26 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-27 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-28 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-29 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-09-30 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-01 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-02 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-03 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-04 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-05 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-06 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-07 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-08 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-09 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-10 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-11 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-12 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-13 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-14 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-15 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-16 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-17 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-18 00:00:00', 176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-19 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-20 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-21 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-22 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-23 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-24 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-25 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-26 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-27 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-28 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-29 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-30 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-10-31 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-01 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-02 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-03 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-04 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-05 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-06 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-07 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-08 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-09 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-10 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-11 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-12 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-13 00:00:00', 176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-14 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-15 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-16 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-17 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-18 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-19 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-20 00:00:00', 179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-21 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-22 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-23 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-24 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-25 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-26 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-27 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-28 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-29 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-11-30 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-01 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-02 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-03 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-04 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-05 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-06 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-07 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-08 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-09 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-10 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-11 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-12 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-13 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-14 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-15 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-16 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-17 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-18 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-19 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-20 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-21 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-22 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-23 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-24 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-25 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-26 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-27 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-28 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-29 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-30 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2019-12-31 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2020-01-01 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-01 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-02 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-03 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-04 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-06 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-07 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-08 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-09 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-10 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-11 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-12 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-13 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-14 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-16 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-17 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-18 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-19 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-20 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-21 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-22 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-23 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-24 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-26 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-27 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-28 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-29 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-30 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-31 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-01 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-02 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-03 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-04 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-06 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-07 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-08 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-09 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-10 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-11 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-12 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-13 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-14 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-16 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-17 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-18 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-19 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-20 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-21 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-22 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-23 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-24 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-26 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-27 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-28 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-01 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-02 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-03 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-04 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-05 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-06 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-07 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-08 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-09 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-10 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-11 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-12 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-13 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-14 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-16 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-17 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-18 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-19 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-20 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-21 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-22 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-23 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-24 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-26 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-27 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-28 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-29 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-30 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-31 00:00:00', 42.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-01 00:00:00', 44.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-02 00:00:00', 81.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-03 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-04 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-06 00:00:00', 90.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-07 00:00:00', 89, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-08 00:00:00', 84, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-09 00:00:00', 86.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-10 00:00:00', 87.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-11 00:00:00', 68, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-12 00:00:00', 49.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-13 00:00:00', 54.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-14 00:00:00', 57.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-16 00:00:00', 58.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-17 00:00:00', 58.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-18 00:00:00', 51.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-19 00:00:00', 52.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-20 00:00:00', 52.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-21 00:00:00', 52.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-22 00:00:00', 54.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-23 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-24 00:00:00', 112, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-26 00:00:00', 84, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-27 00:00:00', 87.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-28 00:00:00', 106, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-29 00:00:00', 94.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-30 00:00:00', 71.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-01 00:00:00', 70.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-02 00:00:00', 99.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-03 00:00:00', 96.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-04 00:00:00', 96.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-06 00:00:00', 71.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-07 00:00:00', 71.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-08 00:00:00', 75.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-09 00:00:00', 76.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-10 00:00:00', 84, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-11 00:00:00', 90.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-12 00:00:00', 69.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-13 00:00:00', 47, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-14 00:00:00', 45.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-16 00:00:00', 42.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-17 00:00:00', 42.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-18 00:00:00', 48.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-19 00:00:00', 57.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-20 00:00:00', 61.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-21 00:00:00', 66.6999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-22 00:00:00', 68, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-23 00:00:00', 66.6999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-24 00:00:00', 60.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-26 00:00:00', 58.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-27 00:00:00', 66.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-28 00:00:00', 48.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-29 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-30 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-31 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-01 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-02 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-03 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-04 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-06 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-07 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-08 00:00:00', 48.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-09 00:00:00', 61.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-10 00:00:00', 61.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-11 00:00:00', 60.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-12 00:00:00', 59.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-13 00:00:00', 59.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-14 00:00:00', 60.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-16 00:00:00', 54.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-17 00:00:00', 52.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-18 00:00:00', 52.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-19 00:00:00', 50.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-20 00:00:00', 51.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-21 00:00:00', 53.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-22 00:00:00', 53.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-23 00:00:00', 60.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-24 00:00:00', 69.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-26 00:00:00', 81.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-27 00:00:00', 72.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-28 00:00:00', 73.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-29 00:00:00', 48.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-30 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-01 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-02 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-03 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-04 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-06 00:00:00', 63.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-07 00:00:00', 62.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-08 00:00:00', 60.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-09 00:00:00', 59.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-10 00:00:00', 58.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-11 00:00:00', 54.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-12 00:00:00', 57, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-13 00:00:00', 58.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-14 00:00:00', 47.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-16 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-17 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-18 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-19 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-20 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-21 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-22 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-23 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-24 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-25 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-26 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-27 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-28 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-29 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-30 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-31 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-01 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-02 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-03 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-04 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-06 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-07 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-08 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-09 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-10 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-11 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-12 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-13 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-14 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-16 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-17 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-18 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-19 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-20 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-21 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-22 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-23 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-24 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-26 00:00:00', 4.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-27 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-28 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-29 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-30 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-31 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-01 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-02 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-03 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-04 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-06 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-07 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-08 00:00:00', 6.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-09 00:00:00', 8.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-10 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-11 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-12 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-13 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-14 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-16 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-17 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-18 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-19 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-20 00:00:00', 8.72999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-21 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-22 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-23 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-24 00:00:00', 8.72999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-26 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-27 00:00:00', 8.72999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-28 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-29 00:00:00', 8.72999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-30 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-01 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-02 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-03 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-04 00:00:00', 8.27999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-06 00:00:00', 8.72999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-07 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-08 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-09 00:00:00', 8.72999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-10 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-11 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-12 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-13 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-14 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-16 00:00:00', 8.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-17 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-18 00:00:00', 7.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-19 00:00:00', 7.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-20 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-21 00:00:00', 6.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-22 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-23 00:00:00', 6.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-24 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-26 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-27 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-28 00:00:00', 5.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-29 00:00:00', 5.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-30 00:00:00', 5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-31 00:00:00', 5.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-01 00:00:00', 5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-02 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-03 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-04 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-06 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-07 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-08 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-09 00:00:00', 6.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-10 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-11 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-12 00:00:00', 7.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-13 00:00:00', 7.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-14 00:00:00', 7.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-16 00:00:00', 7.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-17 00:00:00', 7.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-18 00:00:00', 7.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-19 00:00:00', 7.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-20 00:00:00', 7.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-21 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-22 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-23 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-24 00:00:00', 7.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-26 00:00:00', 6.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-27 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-28 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-29 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-30 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-01 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-02 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-03 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-04 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-06 00:00:00', 5.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-07 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-08 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-09 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-10 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-11 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-12 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-13 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-14 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-16 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-17 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-18 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-19 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-20 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-21 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-22 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-23 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-24 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-26 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-27 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-28 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-29 00:00:00', 6.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-30 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-31 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2020-01-01 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-15 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-02 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-03 00:00:00', 179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-04 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-05 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-06 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-07 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-08 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-09 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-10 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-11 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-12 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-13 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-14 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-15 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-16 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-17 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-18 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-19 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-20 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-21 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-22 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-23 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-24 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-25 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-26 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-27 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-28 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-29 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-30 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-31 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-01 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-02 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-03 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-04 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-05 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-06 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-07 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-08 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-09 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-10 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-11 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-12 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-13 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-14 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-15 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-16 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-17 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-18 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-19 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-20 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-21 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-22 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-23 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-24 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-25 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-26 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-27 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-02-28 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-01 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-02 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-03 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-04 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-05 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-06 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-07 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-08 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-09 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-10 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-11 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-12 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-13 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-14 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-15 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-16 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-17 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-18 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-19 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-20 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-21 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-22 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-23 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-24 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-25 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-26 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-27 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-28 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-29 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-30 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-03-31 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-01 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-02 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-03 00:00:00', 211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-04 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-05 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-06 00:00:00', 201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-07 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-08 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-09 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-10 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-11 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-12 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-13 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-14 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-15 00:00:00', 201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-16 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-17 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-18 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-19 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-20 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-21 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-22 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-23 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-24 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-25 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-26 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-27 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-28 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-29 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-04-30 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-01 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-02 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-03 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-04 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-05 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-06 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-07 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-08 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-09 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-10 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-11 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-12 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-13 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-14 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-15 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-16 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-17 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-18 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-19 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-20 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-21 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-22 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-23 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-24 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-25 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-26 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-27 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-28 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-29 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-30 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-05-31 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-01 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-02 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-03 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-04 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-05 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-06 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-07 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-08 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-09 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-10 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-11 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-12 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-13 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-14 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-15 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-16 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-17 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-18 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-19 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-20 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-21 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-22 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-23 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-24 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-25 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-26 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-27 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-28 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-29 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-06-30 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-01 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-02 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-03 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-04 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-05 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-06 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-07 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-08 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-09 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-10 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-11 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-12 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-13 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-14 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-15 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-16 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-17 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-18 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-19 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-20 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-21 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-22 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-23 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-24 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-25 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-26 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-27 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-28 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-29 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-30 00:00:00', 179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-07-31 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-01 00:00:00', 177, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-02 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-03 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-04 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-05 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-06 00:00:00', 173, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-07 00:00:00', 173, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-08 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-09 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-10 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-11 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-12 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-13 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-14 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-15 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-16 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-17 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-18 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-19 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-20 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-21 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-22 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-23 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-24 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-25 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-26 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-27 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-28 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-29 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-30 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-08-31 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-01 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-02 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-03 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-04 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-05 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-06 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-07 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-08 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-09 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-10 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-11 00:00:00', 162, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-12 00:00:00', 161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-13 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-14 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-15 00:00:00', 159, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-16 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-17 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-18 00:00:00', 161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-19 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-20 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-21 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-22 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-23 00:00:00', 158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-24 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-25 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-26 00:00:00', 161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-27 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-28 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-29 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-09-30 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-01 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-02 00:00:00', 159, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-03 00:00:00', 159, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-04 00:00:00', 159, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-05 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-06 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-07 00:00:00', 161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-08 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-09 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-10 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-11 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-12 00:00:00', 162, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-13 00:00:00', 161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-14 00:00:00', 162, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-15 00:00:00', 161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-16 00:00:00', 161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-17 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-18 00:00:00', 159, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-19 00:00:00', 158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-20 00:00:00', 156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-21 00:00:00', 156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-22 00:00:00', 155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-23 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-24 00:00:00', 155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-25 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-26 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-27 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-28 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-29 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-30 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-10-31 00:00:00', 149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-01 00:00:00', 148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-02 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-03 00:00:00', 148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-04 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-05 00:00:00', 146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-06 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-07 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-08 00:00:00', 143, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-09 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-10 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-11 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-12 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-13 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-14 00:00:00', 143, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-15 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-16 00:00:00', 145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-17 00:00:00', 146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-18 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-19 00:00:00', 146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-20 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-21 00:00:00', 149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-22 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-23 00:00:00', 149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-24 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-25 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-26 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-27 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-28 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-29 00:00:00', 156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-11-30 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-01 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-02 00:00:00', 158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-03 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-04 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-05 00:00:00', 156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-06 00:00:00', 155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-07 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-08 00:00:00', 153, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-09 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-10 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-11 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-12 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-13 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-14 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-15 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-16 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-17 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-18 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-19 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-20 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-21 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-22 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-23 00:00:00', 155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-24 00:00:00', 155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-25 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-26 00:00:00', 153, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-27 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-28 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-29 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-30 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-12-31 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2020-01-01 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-01 00:00:00', 44.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-02 00:00:00', 44.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-03 00:00:00', 45.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-04 00:00:00', 47.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-05 00:00:00', 48.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-06 00:00:00', 49.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-07 00:00:00', 50.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-08 00:00:00', 50.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-09 00:00:00', 51.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-10 00:00:00', 51.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-11 00:00:00', 52.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-12 00:00:00', 55, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-13 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-14 00:00:00', 59.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-15 00:00:00', 59.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-16 00:00:00', 58, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-17 00:00:00', 59.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-18 00:00:00', 58, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-19 00:00:00', 58, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-20 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-21 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-22 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-23 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-24 00:00:00', 55, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-25 00:00:00', 55, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-26 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-27 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-28 00:00:00', 55, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-29 00:00:00', 53.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-30 00:00:00', 55, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-01-31 00:00:00', 58, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-01 00:00:00', 58, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-02 00:00:00', 58.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-03 00:00:00', 58.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-04 00:00:00', 58.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-05 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-06 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-07 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-08 00:00:00', 55.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-09 00:00:00', 55.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-10 00:00:00', 54.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-11 00:00:00', 53.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-12 00:00:00', 55.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-13 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-14 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-15 00:00:00', 58.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-16 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-17 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-18 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-19 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-20 00:00:00', 61.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-21 00:00:00', 64.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-22 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-23 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-24 00:00:00', 58.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-25 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-26 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-27 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-02-28 00:00:00', 58.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-01 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-02 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-03 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-04 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-05 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-06 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-07 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-08 00:00:00', 61.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-09 00:00:00', 61.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-10 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-11 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-12 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-13 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-14 00:00:00', 55.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-15 00:00:00', 55.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-16 00:00:00', 54.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-17 00:00:00', 55.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-18 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-19 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-20 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-21 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-22 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-23 00:00:00', 65.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-24 00:00:00', 65.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-25 00:00:00', 64.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-26 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-27 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-28 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-29 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-30 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-03-31 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-01 00:00:00', 64.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-02 00:00:00', 77.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-03 00:00:00', 87.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-04 00:00:00', 90.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-05 00:00:00', 70.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-06 00:00:00', 69.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-07 00:00:00', 67.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-08 00:00:00', 70.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-09 00:00:00', 70.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-10 00:00:00', 67.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-11 00:00:00', 72.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-12 00:00:00', 75.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-13 00:00:00', 75.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-14 00:00:00', 75.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-15 00:00:00', 69.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-16 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-17 00:00:00', 61.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-18 00:00:00', 61.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-19 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-20 00:00:00', 64.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-21 00:00:00', 65.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-22 00:00:00', 65.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-23 00:00:00', 90.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-24 00:00:00', 99.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-25 00:00:00', 84.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-26 00:00:00', 80.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-27 00:00:00', 77.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-28 00:00:00', 79, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-29 00:00:00', 77.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-04-30 00:00:00', 80.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-01 00:00:00', 82.6999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-02 00:00:00', 82.6999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-03 00:00:00', 80.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-04 00:00:00', 75.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-05 00:00:00', 67.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-06 00:00:00', 64.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-07 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-08 00:00:00', 59.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-09 00:00:00', 58.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-10 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-11 00:00:00', 57.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-12 00:00:00', 90.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-13 00:00:00', 123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-14 00:00:00', 123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-15 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-16 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-17 00:00:00', 121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-18 00:00:00', 121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-19 00:00:00', 120, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-20 00:00:00', 120, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-21 00:00:00', 119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-22 00:00:00', 119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-23 00:00:00', 118, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-24 00:00:00', 118, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-25 00:00:00', 117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-26 00:00:00', 117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-27 00:00:00', 121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-28 00:00:00', 125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-29 00:00:00', 130, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-30 00:00:00', 134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-05-31 00:00:00', 138, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-01 00:00:00', 142, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-02 00:00:00', 139, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-03 00:00:00', 135, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-04 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-05 00:00:00', 128, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-06 00:00:00', 125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-07 00:00:00', 127, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-08 00:00:00', 128, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-09 00:00:00', 130, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-10 00:00:00', 131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-11 00:00:00', 133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-12 00:00:00', 134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-13 00:00:00', 136, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-14 00:00:00', 137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-15 00:00:00', 139, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-16 00:00:00', 140, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-17 00:00:00', 142, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-18 00:00:00', 145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-19 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-20 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-21 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-22 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-23 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-24 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-25 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-26 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-27 00:00:00', 148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-28 00:00:00', 148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-29 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-06-30 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-01 00:00:00', 146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-02 00:00:00', 145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-03 00:00:00', 145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-04 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-05 00:00:00', 144, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-06 00:00:00', 143, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-07 00:00:00', 142, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-08 00:00:00', 141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-09 00:00:00', 140, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-10 00:00:00', 138, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-11 00:00:00', 137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-12 00:00:00', 136, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-13 00:00:00', 135, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-14 00:00:00', 134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-15 00:00:00', 133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-16 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-17 00:00:00', 130, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-18 00:00:00', 129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-19 00:00:00', 128, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-20 00:00:00', 129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-21 00:00:00', 130, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-22 00:00:00', 130, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-23 00:00:00', 131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-24 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-25 00:00:00', 133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-26 00:00:00', 134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-27 00:00:00', 135, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-28 00:00:00', 135, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-29 00:00:00', 136, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-30 00:00:00', 137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-07-31 00:00:00', 138, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-01 00:00:00', 136, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-02 00:00:00', 135, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-03 00:00:00', 133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-04 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-05 00:00:00', 130, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-06 00:00:00', 129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-07 00:00:00', 127, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-08 00:00:00', 126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-09 00:00:00', 124, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-10 00:00:00', 124, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-11 00:00:00', 114, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-12 00:00:00', 95.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-13 00:00:00', 86.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-14 00:00:00', 81.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-15 00:00:00', 81.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-16 00:00:00', 86.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-17 00:00:00', 95.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-18 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-19 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-20 00:00:00', 95.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-21 00:00:00', 114, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-22 00:00:00', 95.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-23 00:00:00', 95.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-24 00:00:00', 81.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-25 00:00:00', 95.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-26 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-27 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-28 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-29 00:00:00', 95.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-30 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-08-31 00:00:00', 95.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-01 00:00:00', 114, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-02 00:00:00', 114, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-03 00:00:00', 124, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-04 00:00:00', 124, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-05 00:00:00', 124, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-06 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-07 00:00:00', 86.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-08 00:00:00', 81.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-09 00:00:00', 81.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-10 00:00:00', 75.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-11 00:00:00', 70.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-12 00:00:00', 65.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-13 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-14 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-15 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-16 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-17 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-18 00:00:00', 65.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-19 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-20 00:00:00', 49.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-21 00:00:00', 49.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-22 00:00:00', 49.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-23 00:00:00', 52.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-24 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-25 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-26 00:00:00', 65.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-27 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-28 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-29 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-09-30 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-01 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-02 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-03 00:00:00', 56, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-04 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-05 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-06 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-07 00:00:00', 65.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-08 00:00:00', 75.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-09 00:00:00', 75.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-10 00:00:00', 81.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-11 00:00:00', 75.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-12 00:00:00', 70.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-13 00:00:00', 65.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-14 00:00:00', 70.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-15 00:00:00', 65.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-16 00:00:00', 65.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-17 00:00:00', 60, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-18 00:00:00', 56.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-19 00:00:00', 52.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-20 00:00:00', 45.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-21 00:00:00', 45.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-22 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-23 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-24 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-25 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-26 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-27 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-28 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-29 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-30 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-10-31 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-01 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-02 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-03 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-04 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-05 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-06 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-07 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-08 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-09 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-10 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-11 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-12 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-13 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-14 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-15 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-16 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-17 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-18 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-19 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-20 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-21 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-22 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-23 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-24 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-25 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-26 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-27 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-28 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-29 00:00:00', 45.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-11-30 00:00:00', 49.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-01 00:00:00', 49.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-02 00:00:00', 52.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-03 00:00:00', 49.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-04 00:00:00', 49.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-05 00:00:00', 45.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-06 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-07 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-08 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-09 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-10 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-11 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-12 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-13 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-14 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-15 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-16 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-17 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-18 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-19 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-20 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-21 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-22 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-23 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-24 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-25 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-26 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-27 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-28 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-29 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-30 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2019-12-31 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2020-01-01 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-01 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-02 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-03 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-04 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-05 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-06 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-07 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-08 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-09 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-10 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-11 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-12 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-13 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-14 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-15 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-16 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-17 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-18 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-19 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-20 00:00:00', 47.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-21 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-22 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-23 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-24 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-25 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-26 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-27 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-28 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-29 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-30 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-01-31 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-01 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-02 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-03 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-04 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-05 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-06 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-07 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-08 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-09 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-10 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-11 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-12 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-13 00:00:00', 48.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-14 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-15 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-16 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-17 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-18 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-19 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-20 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-21 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-22 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-23 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-24 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-25 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-26 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-27 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-02-28 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-01 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-02 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-03 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-04 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-05 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-06 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-07 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-08 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-09 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-10 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-11 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-12 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-13 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-14 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-15 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-16 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-17 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-18 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-19 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-20 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-21 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-22 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-23 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-24 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-25 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-26 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-27 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-28 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-29 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-30 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-03-31 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-01 00:00:00', 48.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-02 00:00:00', 58.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-03 00:00:00', 58.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-04 00:00:00', 58.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-05 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-06 00:00:00', 158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-07 00:00:00', 158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-08 00:00:00', 139, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-09 00:00:00', 139, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-10 00:00:00', 139, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-11 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-12 00:00:00', 104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-13 00:00:00', 84.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-14 00:00:00', 84.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-15 00:00:00', 84.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-16 00:00:00', 84.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-17 00:00:00', 84.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-18 00:00:00', 90.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-19 00:00:00', 97.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-20 00:00:00', 97.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-21 00:00:00', 97.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-22 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-23 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-24 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-25 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-26 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-27 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-28 00:00:00', 287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-29 00:00:00', 370, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-04-30 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-01 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-02 00:00:00', 143, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-03 00:00:00', 143, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-04 00:00:00', 111, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-05 00:00:00', 111, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-06 00:00:00', 68.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-07 00:00:00', 68.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-08 00:00:00', 68.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-09 00:00:00', 50.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-10 00:00:00', 50.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-11 00:00:00', 50.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-12 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-13 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-14 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-15 00:00:00', 111, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-16 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-17 00:00:00', 82.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-18 00:00:00', 80.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-19 00:00:00', 78.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-20 00:00:00', 78.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-21 00:00:00', 78.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-22 00:00:00', 126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-23 00:00:00', 125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-24 00:00:00', 123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-25 00:00:00', 114, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-26 00:00:00', 80.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-27 00:00:00', 58.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-28 00:00:00', 58.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-29 00:00:00', 90.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-30 00:00:00', 69.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-05-31 00:00:00', 69.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-01 00:00:00', 69.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-02 00:00:00', 137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-03 00:00:00', 137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-04 00:00:00', 162, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-05 00:00:00', 162, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-06 00:00:00', 123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-07 00:00:00', 123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-08 00:00:00', 123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-09 00:00:00', 123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-10 00:00:00', 123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-11 00:00:00', 96, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-12 00:00:00', 96, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-13 00:00:00', 96, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-14 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-15 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-16 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-17 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-18 00:00:00', 49.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-19 00:00:00', 62.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-20 00:00:00', 74.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-21 00:00:00', 74.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-22 00:00:00', 84.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-23 00:00:00', 84.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-24 00:00:00', 92.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-25 00:00:00', 100, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-26 00:00:00', 100, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-27 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-28 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-29 00:00:00', 87.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-06-30 00:00:00', 65, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-01 00:00:00', 65, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-02 00:00:00', 65, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-03 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-04 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-05 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-06 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-07 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-08 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-09 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-10 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-11 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-12 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-13 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-14 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-15 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-16 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-17 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-18 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-19 00:00:00', 7.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-20 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-21 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-22 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-23 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-24 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-25 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-26 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-27 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-28 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-29 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-30 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-07-31 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-01 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-02 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-03 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-04 00:00:00', 5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-05 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-06 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-07 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-08 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-09 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-10 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-11 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-12 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-13 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-14 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-15 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-16 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-17 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-18 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-19 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-20 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-21 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-22 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-23 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-24 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-25 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-26 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-27 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-28 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-29 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-30 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-08-31 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-01 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-02 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-03 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-04 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-05 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-06 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-07 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-08 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-09 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-10 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-11 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-12 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-13 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-14 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-15 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-16 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-17 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-18 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-19 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-20 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-21 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-22 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-23 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-24 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-25 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-26 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-27 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-28 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-29 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-09-30 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-01 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-02 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-03 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-04 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-05 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-06 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-07 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-08 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-09 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-10 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-11 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-12 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-13 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-14 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-15 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-16 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-17 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-18 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-19 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-20 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-21 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-22 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-23 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-24 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-25 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-26 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-27 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-28 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-29 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-30 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-10-31 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-01 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-02 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-03 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-04 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-05 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-06 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-07 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-08 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-09 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-10 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-11 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-12 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-13 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-14 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-15 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-16 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-17 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-18 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-19 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-20 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-21 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-22 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-23 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-24 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-25 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-26 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-27 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-28 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-29 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-11-30 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-01 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-02 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-03 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-04 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-05 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-06 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-07 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-08 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-09 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-10 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-11 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-12 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-13 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-14 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-15 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-16 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-17 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-18 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-19 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-20 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-21 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-22 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-23 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-24 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-25 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-26 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-27 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-28 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-29 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-30 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2019-12-31 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2020-01-01 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-01 00:00:00', 335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-02 00:00:00', 331, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-03 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-04 00:00:00', 333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-05 00:00:00', 337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-06 00:00:00', 343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-07 00:00:00', 344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-08 00:00:00', 344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-09 00:00:00', 346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-10 00:00:00', 346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-11 00:00:00', 348, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-12 00:00:00', 348, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-13 00:00:00', 348, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-14 00:00:00', 348, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-15 00:00:00', 349, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-16 00:00:00', 344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-17 00:00:00', 342, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-18 00:00:00', 355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-19 00:00:00', 380, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-20 00:00:00', 379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-21 00:00:00', 377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-22 00:00:00', 377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-23 00:00:00', 375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-24 00:00:00', 392, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-25 00:00:00', 390, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-26 00:00:00', 384, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-27 00:00:00', 394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-28 00:00:00', 396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-29 00:00:00', 392, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-30 00:00:00', 394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-01-31 00:00:00', 393, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-01 00:00:00', 392, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-02 00:00:00', 392, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-03 00:00:00', 397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-04 00:00:00', 410, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-05 00:00:00', 414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-06 00:00:00', 415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-07 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-08 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-09 00:00:00', 409, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-10 00:00:00', 407, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-11 00:00:00', 409, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-12 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-13 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-14 00:00:00', 411, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-15 00:00:00', 413, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-16 00:00:00', 414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-17 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-18 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-19 00:00:00', 409, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-20 00:00:00', 409, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-21 00:00:00', 407, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-22 00:00:00', 407, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-23 00:00:00', 407, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-24 00:00:00', 398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-25 00:00:00', 365, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-26 00:00:00', 353, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-27 00:00:00', 356, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-02-28 00:00:00', 364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-01 00:00:00', 374, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-02 00:00:00', 392, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-03 00:00:00', 403, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-04 00:00:00', 404, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-05 00:00:00', 403, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-06 00:00:00', 399, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-07 00:00:00', 394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-08 00:00:00', 352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-09 00:00:00', 348, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-10 00:00:00', 343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-11 00:00:00', 344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-12 00:00:00', 347, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-13 00:00:00', 348, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-14 00:00:00', 347, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-15 00:00:00', 344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-16 00:00:00', 342, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-17 00:00:00', 342, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-18 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-19 00:00:00', 341, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-20 00:00:00', 344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-21 00:00:00', 343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-22 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-23 00:00:00', 336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-24 00:00:00', 336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-25 00:00:00', 346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-26 00:00:00', 351, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-27 00:00:00', 351, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-28 00:00:00', 350, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-29 00:00:00', 341, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-30 00:00:00', 332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-03-31 00:00:00', 317, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-01 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-02 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-03 00:00:00', 317, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-04 00:00:00', 384, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-05 00:00:00', 420, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-06 00:00:00', 445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-07 00:00:00', 433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-08 00:00:00', 432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-09 00:00:00', 431, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-10 00:00:00', 431, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-11 00:00:00', 432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-12 00:00:00', 429, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-13 00:00:00', 423, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-14 00:00:00', 415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-15 00:00:00', 405, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-16 00:00:00', 410, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-17 00:00:00', 409, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-18 00:00:00', 408, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-19 00:00:00', 404, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-20 00:00:00', 405, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-21 00:00:00', 409, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-22 00:00:00', 410, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-23 00:00:00', 417, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-24 00:00:00', 437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-25 00:00:00', 457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-26 00:00:00', 472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-27 00:00:00', 477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-28 00:00:00', 481, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-29 00:00:00', 496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-04-30 00:00:00', 484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-01 00:00:00', 481, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-02 00:00:00', 475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-03 00:00:00', 441, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-04 00:00:00', 414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-05 00:00:00', 416, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-06 00:00:00', 422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-07 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-08 00:00:00', 413, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-09 00:00:00', 413, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-10 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-11 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-12 00:00:00', 396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-13 00:00:00', 406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-14 00:00:00', 403, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-15 00:00:00', 385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-16 00:00:00', 419, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-17 00:00:00', 416, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-18 00:00:00', 416, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-19 00:00:00', 419, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-20 00:00:00', 423, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-21 00:00:00', 474, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-22 00:00:00', 470, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-23 00:00:00', 452, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-24 00:00:00', 447, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-25 00:00:00', 441, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-26 00:00:00', 423, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-27 00:00:00', 414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-28 00:00:00', 458, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-29 00:00:00', 437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-30 00:00:00', 418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-05-31 00:00:00', 418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-01 00:00:00', 417, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-02 00:00:00', 435, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-03 00:00:00', 443, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-04 00:00:00', 443, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-05 00:00:00', 454, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-06 00:00:00', 453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-07 00:00:00', 454, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-08 00:00:00', 456, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-09 00:00:00', 456, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-10 00:00:00', 456, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-11 00:00:00', 450, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-12 00:00:00', 444, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-13 00:00:00', 440, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-14 00:00:00', 433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-15 00:00:00', 412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-16 00:00:00', 411, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-17 00:00:00', 410, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-18 00:00:00', 403, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-19 00:00:00', 427, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-20 00:00:00', 413, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-21 00:00:00', 416, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-22 00:00:00', 424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-23 00:00:00', 436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-24 00:00:00', 440, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-25 00:00:00', 436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-26 00:00:00', 442, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-27 00:00:00', 448, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-28 00:00:00', 450, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-29 00:00:00', 445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-06-30 00:00:00', 430, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-01 00:00:00', 419, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-02 00:00:00', 415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-03 00:00:00', 396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-04 00:00:00', 371, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-05 00:00:00', 354, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-06 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-07 00:00:00', 332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-08 00:00:00', 327, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-09 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-10 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-11 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-12 00:00:00', 329, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-13 00:00:00', 323, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-14 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-15 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-16 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-17 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-18 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-19 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-20 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-21 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-22 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-23 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-24 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-25 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-26 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-27 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-28 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-29 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-30 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-07-31 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-01 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-02 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-03 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-04 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-05 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-06 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-07 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-08 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-09 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-10 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-11 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-12 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-13 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-14 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-15 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-16 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-17 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-18 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-19 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-20 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-21 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-22 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-23 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-24 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-25 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-26 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-27 00:00:00', 342, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-28 00:00:00', 341, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-29 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-30 00:00:00', 339, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-08-31 00:00:00', 337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-01 00:00:00', 335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-02 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-03 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-04 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-05 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-06 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-07 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-08 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-09 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-10 00:00:00', 315, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-11 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-12 00:00:00', 325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-13 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-14 00:00:00', 321, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-15 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-16 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-17 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-18 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-19 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-20 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-21 00:00:00', 314, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-22 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-23 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-24 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-25 00:00:00', 314, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-26 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-27 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-28 00:00:00', 317, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-29 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-09-30 00:00:00', 324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-01 00:00:00', 324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-02 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-03 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-04 00:00:00', 323, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-05 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-06 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-07 00:00:00', 325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-08 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-09 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-10 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-11 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-12 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-13 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-14 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-15 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-16 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-17 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-18 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-19 00:00:00', 323, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-20 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-21 00:00:00', 319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-22 00:00:00', 324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-23 00:00:00', 325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-24 00:00:00', 325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-25 00:00:00', 326, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-26 00:00:00', 326, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-27 00:00:00', 326, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-28 00:00:00', 326, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-29 00:00:00', 326, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-30 00:00:00', 321, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-10-31 00:00:00', 317, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-01 00:00:00', 315, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-02 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-03 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-04 00:00:00', 324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-05 00:00:00', 327, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-06 00:00:00', 329, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-07 00:00:00', 331, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-08 00:00:00', 332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-09 00:00:00', 331, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-10 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-11 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-12 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-13 00:00:00', 329, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-14 00:00:00', 329, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-15 00:00:00', 329, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-16 00:00:00', 331, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-17 00:00:00', 333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-18 00:00:00', 338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-19 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-20 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-21 00:00:00', 341, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-22 00:00:00', 342, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-23 00:00:00', 341, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-24 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-25 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-26 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-27 00:00:00', 338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-28 00:00:00', 338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-29 00:00:00', 339, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-11-30 00:00:00', 338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-01 00:00:00', 338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-02 00:00:00', 336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-03 00:00:00', 336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-04 00:00:00', 337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-05 00:00:00', 339, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-06 00:00:00', 336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-07 00:00:00', 332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-08 00:00:00', 333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-09 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-10 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-11 00:00:00', 336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-12 00:00:00', 336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-13 00:00:00', 335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-14 00:00:00', 335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-15 00:00:00', 335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-16 00:00:00', 338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-17 00:00:00', 337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-18 00:00:00', 336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-19 00:00:00', 337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-20 00:00:00', 335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-21 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-22 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-23 00:00:00', 333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-24 00:00:00', 332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-25 00:00:00', 331, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-26 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-27 00:00:00', 332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-28 00:00:00', 333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-29 00:00:00', 335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-30 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2019-12-31 00:00:00', 333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2020-01-01 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-01 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-02 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-03 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-04 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-05 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-06 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-07 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-08 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-09 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-10 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-11 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-12 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-13 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-14 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-15 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-16 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-17 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-18 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-19 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-20 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-21 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-22 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-23 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-24 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-25 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-26 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-27 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-28 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-29 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-30 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-01-31 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-01 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-02 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-03 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-04 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-05 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-06 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-07 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-08 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-09 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-10 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-11 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-12 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-13 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-14 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-15 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-16 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-17 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-18 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-19 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-20 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-21 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-22 00:00:00', 176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-23 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-24 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-25 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-26 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-27 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-02-28 00:00:00', 177, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-01 00:00:00', 177, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-02 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-03 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-04 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-05 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-06 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-07 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-08 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-09 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-10 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-11 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-12 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-13 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-14 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-15 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-16 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-17 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-18 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-19 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-20 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-21 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-22 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-23 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-24 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-25 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-26 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-27 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-28 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-29 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-30 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-03-31 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-01 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-02 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-03 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-04 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-05 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-06 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-07 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-08 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-09 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-10 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-11 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-12 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-13 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-14 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-15 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-16 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-17 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-18 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-19 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-20 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-21 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-22 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-23 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-24 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-25 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-26 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-27 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-28 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-29 00:00:00', 342, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-04-30 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-01 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-02 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-03 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-04 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-05 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-06 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-07 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-08 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-09 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-10 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-11 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-12 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-13 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-14 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-15 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-16 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-17 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-18 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-19 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-20 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-21 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-22 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-23 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-24 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-25 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-26 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-27 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-28 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-29 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-30 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-05-31 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-01 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-02 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-03 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-04 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-05 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-06 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-07 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-08 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-09 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-10 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-11 00:00:00', 211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-12 00:00:00', 211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-13 00:00:00', 211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-14 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-15 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-16 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-17 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-18 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-19 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-20 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-21 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-22 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-23 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-24 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-25 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-26 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-27 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-28 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-29 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-06-30 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-01 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-02 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-03 00:00:00', 112, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-04 00:00:00', 112, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-05 00:00:00', 112, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-06 00:00:00', 112, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-07 00:00:00', 112, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-08 00:00:00', 112, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-09 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-10 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-11 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-12 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-13 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-14 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-15 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-16 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-17 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-18 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-19 00:00:00', 114, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-20 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-21 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-22 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-23 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-24 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-25 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-26 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-27 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-28 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-29 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-30 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-07-31 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-01 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-02 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-03 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-04 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-05 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-06 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-07 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-08 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-09 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-10 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-11 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-12 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-13 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-14 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-15 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-16 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-17 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-18 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-19 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-20 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-21 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-22 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-23 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-24 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-25 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-26 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-27 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-28 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-29 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-30 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-08-31 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-01 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-02 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-03 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-04 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-05 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-06 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-07 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-08 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-09 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-10 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-11 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-12 00:00:00', 104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-13 00:00:00', 108, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-14 00:00:00', 108, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-15 00:00:00', 108, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-16 00:00:00', 108, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-17 00:00:00', 108, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-18 00:00:00', 108, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-19 00:00:00', 108, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-20 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-21 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-22 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-23 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-24 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-25 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-26 00:00:00', 106, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-27 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-28 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-29 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-09-30 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-01 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-02 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-03 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-04 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-05 00:00:00', 105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-06 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-07 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-08 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-09 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-10 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-11 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-12 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-13 00:00:00', 101, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-14 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-15 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-16 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-17 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-18 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-19 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-20 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-21 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-22 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-23 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-24 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-25 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-26 00:00:00', 100, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-27 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-28 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-29 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-30 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-10-31 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-01 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-02 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-03 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-04 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-05 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-06 00:00:00', 97, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-07 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-08 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-09 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-10 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-11 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-12 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-13 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-14 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-15 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-16 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-17 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-18 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-19 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-20 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-21 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-22 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-23 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-24 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-25 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-26 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-27 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-28 00:00:00', 95, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-29 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-11-30 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-01 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-02 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-03 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-04 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-05 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-06 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-07 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-08 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-09 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-10 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-11 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-12 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-13 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-14 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-15 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-16 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-17 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-18 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-19 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-20 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-21 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-22 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-23 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-24 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-25 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-26 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-27 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-28 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-29 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-30 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2019-12-31 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2020-01-01 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2019-01-01 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-01 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-02 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-03 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-04 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-05 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-06 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-07 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-08 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-09 00:00:00', 6.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-10 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-11 00:00:00', 6.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-12 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-13 00:00:00', -1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-14 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-15 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-16 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-17 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-18 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-19 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-20 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-21 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-22 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-23 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-24 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-25 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-26 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-27 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-28 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-29 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-30 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-01-31 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-01 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-02 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-03 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-04 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-06 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-07 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-08 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-09 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-10 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-11 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-12 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-13 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-14 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-15 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-16 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-17 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-18 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-19 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-20 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-21 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-22 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-23 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-24 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-25 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-26 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-27 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-28 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-02-29 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-01 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-02 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-03 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-04 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-06 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-07 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-08 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-09 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-10 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-11 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-12 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-13 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-14 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-15 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-16 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-17 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-18 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-19 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-20 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-21 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-22 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-23 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-24 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-25 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-26 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-27 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-28 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-29 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-30 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-03-31 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-01 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-02 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-03 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-04 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-05 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-06 00:00:00', 25.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-07 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-08 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-09 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-10 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-11 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-12 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-13 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-14 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-15 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-16 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-17 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-18 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-19 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-20 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-21 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-22 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-23 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-24 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-25 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-26 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-27 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-28 00:00:00', 25.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-29 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-04-30 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-01 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-02 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-03 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-04 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-05 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-06 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-07 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-08 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-09 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-10 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-11 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-12 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-13 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-14 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-15 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-16 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-17 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-18 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-19 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-20 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-21 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-22 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-23 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-24 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-25 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-26 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-27 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-28 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-29 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-30 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-05-31 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-01 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-02 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-03 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-04 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-05 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-06 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-07 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-08 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-09 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-10 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-11 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-12 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-13 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-14 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-15 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-16 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-17 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-18 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-19 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-20 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-21 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-22 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-23 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-24 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-25 00:00:00', 40.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-26 00:00:00', 40.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-27 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-28 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-29 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-06-30 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-01 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-02 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-03 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-04 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-05 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-06 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-07 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-08 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-09 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-10 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-11 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-12 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-13 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-14 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-15 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-16 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-17 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-18 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-19 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-20 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-21 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-22 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-23 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-24 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-25 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-26 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-27 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-28 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-29 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-30 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-07-31 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-01 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-02 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-03 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-04 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-05 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-06 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-07 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-08 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-09 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-10 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-11 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-12 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-13 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-14 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-15 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-16 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-17 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-18 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-19 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-20 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-21 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-22 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-23 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-24 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-25 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-26 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-27 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-28 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-29 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-30 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-08-31 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-01 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-02 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-03 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-04 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-05 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-06 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-07 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-08 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-09 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-10 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-11 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-12 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-13 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-14 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-15 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-16 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-17 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-18 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-19 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-20 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-21 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-22 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-23 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-24 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-25 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-26 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-27 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-28 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-29 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-09-30 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-01 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-02 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-03 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-04 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-05 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-06 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-07 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-08 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-09 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-10 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-11 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-12 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-13 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-14 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-15 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-16 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-17 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-18 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-19 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-20 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-21 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-22 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-23 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-24 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-25 00:00:00', 25.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-26 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-27 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-28 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-29 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-30 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-10-31 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-01 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-02 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-03 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-04 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-05 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-06 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-07 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-08 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-09 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-10 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-11 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-12 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-13 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-14 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-15 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-16 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-17 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-18 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-19 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-20 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-21 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-22 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-23 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-24 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-25 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-26 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-27 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-28 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-29 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-11-30 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-01 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-02 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-03 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-04 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-06 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-07 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-08 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-09 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-10 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-11 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-12 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-13 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-14 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-15 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-16 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-17 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-18 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-19 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-20 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-21 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-22 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-23 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-24 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-25 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-26 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-27 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-28 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-29 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-30 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2000-12-31 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-01 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-02 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-03 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-04 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-05 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-06 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-07 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-08 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-09 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-10 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-11 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-12 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-13 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-14 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-15 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-16 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-17 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-18 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-19 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-20 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-21 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-22 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-23 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-24 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-25 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-26 00:00:00', -2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-27 00:00:00', -2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-28 00:00:00', -0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-29 00:00:00', -0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-30 00:00:00', -3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-01-31 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-01 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-02 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-03 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-04 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-05 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-06 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-07 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-08 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-09 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-10 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-11 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-12 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-13 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-14 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-16 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-17 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-18 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-19 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-20 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-21 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-22 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-23 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-24 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-25 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-26 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-27 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-02-28 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-01 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-02 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-03 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-04 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-05 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-06 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-07 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-08 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-09 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-10 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-11 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-12 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-13 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-14 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-16 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-17 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-18 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-19 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-20 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-21 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-22 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-23 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-24 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-25 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-26 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-27 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-28 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-29 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-30 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-03-31 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-01 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-02 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-03 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-04 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-05 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-06 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-07 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-08 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-09 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-10 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-11 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-12 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-13 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-14 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-15 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-16 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-17 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-18 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-19 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-20 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-21 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-22 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-23 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-24 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-25 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-26 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-27 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-28 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-29 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-04-30 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-01 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-02 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-03 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-04 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-05 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-06 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-07 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-08 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-09 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-10 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-11 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-12 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-13 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-14 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-15 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-16 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-17 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-18 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-19 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-20 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-21 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-22 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-23 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-24 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-25 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-26 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-27 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-28 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-29 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-30 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-05-31 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-01 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-02 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-03 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-04 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-05 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-06 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-07 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-08 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-09 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-10 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-11 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-12 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-13 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-14 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-15 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-16 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-17 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-18 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-19 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-20 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-21 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-22 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-23 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-24 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-25 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-26 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-27 00:00:00', 41.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-28 00:00:00', 52.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-29 00:00:00', 42.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-06-30 00:00:00', 42.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-01 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-02 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-03 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-04 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-05 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-06 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-07 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-08 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-09 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-10 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-11 00:00:00', 39.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-12 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-13 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-14 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-15 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-16 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-17 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-18 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-19 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-20 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-21 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-22 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-23 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-24 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-25 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-26 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-27 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-28 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-29 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-30 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-07-31 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-01 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-02 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-03 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-04 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-05 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-06 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-07 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-08 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-09 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-10 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-11 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-12 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-13 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-14 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-15 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-16 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-17 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-18 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-19 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-20 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-21 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-22 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-23 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-24 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-25 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-26 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-27 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-28 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-29 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-30 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-08-31 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-01 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-02 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-03 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-04 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-05 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-06 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-07 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-08 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-09 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-10 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-11 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-12 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-13 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-14 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-15 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-16 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-17 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-18 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-19 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-20 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-21 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-22 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-23 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-24 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-25 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-26 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-27 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-28 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-29 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-09-30 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-01 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-02 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-03 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-04 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-05 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-06 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-07 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-08 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-09 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-10 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-11 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-12 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-13 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-14 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-15 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-16 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-17 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-18 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-19 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-20 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-21 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-22 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-23 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-24 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-25 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-26 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-27 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-28 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-29 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-30 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-10-31 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-01 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-02 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-03 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-04 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-05 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-06 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-07 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-08 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-09 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-10 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-11 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-12 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-13 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-14 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-15 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-16 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-17 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-18 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-19 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-20 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-21 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-22 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-23 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-24 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-25 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-26 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-27 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-28 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-29 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-11-30 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-01 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-02 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-03 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-04 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-05 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-06 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-07 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-08 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-09 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-10 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-11 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-12 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-13 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-14 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-15 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-16 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-17 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-18 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-19 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-20 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-21 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-22 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-23 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-24 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-25 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-26 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-27 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-28 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-29 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-30 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2001-12-31 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-01 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-02 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-03 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-04 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-05 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-06 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-07 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-08 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-09 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-10 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-11 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-12 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-13 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-14 00:00:00', -0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-15 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-16 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-17 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-18 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-19 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-20 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-21 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-22 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-23 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-24 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-25 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-26 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-27 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-28 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-29 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-30 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-01-31 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-01 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-02 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-03 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-04 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-05 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-06 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-07 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-08 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-09 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-10 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-11 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-12 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-13 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-14 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-15 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-16 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-17 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-18 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-19 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-20 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-21 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-22 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-23 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-24 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-26 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-27 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-02-28 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-01 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-02 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-03 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-04 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-05 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-06 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-07 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-08 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-09 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-10 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-11 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-12 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-13 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-14 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-15 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-16 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-17 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-18 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-19 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-20 00:00:00', 25.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-21 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-22 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-23 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-24 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-25 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-26 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-27 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-28 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-29 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-30 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-03-31 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-01 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-02 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-03 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-04 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-05 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-06 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-07 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-08 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-09 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-10 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-11 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-12 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-13 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-14 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-15 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-16 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-17 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-18 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-19 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-20 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-21 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-22 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-23 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-24 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-25 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-26 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-27 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-28 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-29 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-04-30 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-01 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-02 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-03 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-04 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-05 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-06 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-07 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-08 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-09 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-10 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-11 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-12 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-13 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-14 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-15 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-16 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-17 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-18 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-19 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-20 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-21 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-22 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-23 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-24 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-25 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-26 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-27 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-28 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-29 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-30 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-05-31 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-01 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-02 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-03 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-04 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-05 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-06 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-07 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-08 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-09 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-10 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-11 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-12 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-13 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-14 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-15 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-16 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-17 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-18 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-19 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-20 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-21 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-22 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-23 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-24 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-25 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-26 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-27 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-28 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-29 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-06-30 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-01 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-02 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-03 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-04 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-05 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-06 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-07 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-08 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-09 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-10 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-11 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-12 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-13 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-14 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-15 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-16 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-17 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-18 00:00:00', 39.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-19 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-20 00:00:00', 41.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-21 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-22 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-23 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-24 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-25 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-26 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-27 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-28 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-29 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-30 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-07-31 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-01 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-02 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-03 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-04 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-05 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-06 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-07 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-08 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-09 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-10 00:00:00', 39.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-11 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-12 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-13 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-14 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-15 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-16 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-17 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-18 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-19 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-20 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-21 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-22 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-23 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-24 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-25 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-26 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-27 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-28 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-29 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-30 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-08-31 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-01 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-02 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-03 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-04 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-05 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-06 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-07 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-08 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-09 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-10 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-11 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-12 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-13 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-14 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-15 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-16 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-17 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-18 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-19 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-20 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-21 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-22 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-23 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-24 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-25 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-26 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-27 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-28 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-29 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-09-30 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-01 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-02 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-03 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-04 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-05 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-06 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-07 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-08 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-09 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-10 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-11 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-12 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-13 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-14 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-15 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-16 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-17 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-18 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-19 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-20 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-21 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-22 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-23 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-24 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-25 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-26 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-27 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-28 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-29 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-30 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-10-31 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-01 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-02 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-03 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-04 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-05 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-06 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-07 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-08 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-09 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-10 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-11 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-12 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-13 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-14 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-15 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-16 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-17 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-18 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-19 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-20 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-21 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-22 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-23 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-24 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-25 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-26 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-27 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-28 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-29 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-11-30 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-01 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-02 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-03 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-04 00:00:00', -6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-05 00:00:00', -1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-06 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-07 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-08 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-09 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-10 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-11 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-12 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-13 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-14 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-15 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-16 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-17 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-18 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-19 00:00:00', -0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-20 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-21 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-22 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-23 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-24 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-25 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-26 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-27 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-28 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-29 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-30 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2002-12-31 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-01 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-02 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-03 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-04 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-05 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-06 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-07 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-08 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-09 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-10 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-11 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-12 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-13 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-14 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-15 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-16 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-17 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-18 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-19 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-20 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-21 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-22 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-23 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-24 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-25 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-26 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-27 00:00:00', 6.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-28 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-29 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-30 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-01-31 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-01 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-02 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-03 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-04 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-05 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-06 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-07 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-08 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-09 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-10 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-11 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-12 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-13 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-14 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-15 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-16 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-17 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-18 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-19 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-20 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-21 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-22 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-23 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-24 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-25 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-26 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-27 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-02-28 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-01 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-02 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-03 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-04 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-05 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-06 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-07 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-08 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-09 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-10 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-11 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-12 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-13 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-14 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-15 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-16 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-17 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-18 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-19 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-20 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-21 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-22 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-23 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-24 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-25 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-26 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-27 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-28 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-29 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-30 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-03-31 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-01 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-02 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-03 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-04 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-05 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-06 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-07 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-08 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-09 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-10 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-11 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-12 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-13 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-14 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-15 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-16 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-17 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-18 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-19 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-20 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-21 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-22 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-23 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-24 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-25 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-26 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-27 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-28 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-29 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-04-30 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-01 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-02 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-03 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-04 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-05 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-06 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-07 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-08 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-09 00:00:00', 25.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-10 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-11 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-12 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-13 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-14 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-15 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-16 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-17 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-18 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-19 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-20 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-21 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-22 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-23 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-24 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-25 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-26 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-27 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-28 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-29 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-30 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-05-31 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-01 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-02 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-03 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-04 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-05 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-06 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-07 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-08 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-09 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-10 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-11 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-12 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-13 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-14 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-15 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-16 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-17 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-18 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-19 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-20 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-21 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-22 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-23 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-24 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-25 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-26 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-27 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-28 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-29 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-06-30 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-01 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-02 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-03 00:00:00', 41.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-04 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-05 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-06 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-07 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-08 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-09 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-10 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-11 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-12 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-13 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-14 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-15 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-16 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-17 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-18 00:00:00', 41.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-19 00:00:00', 42, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-20 00:00:00', 41.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-21 00:00:00', 40.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-22 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-23 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-24 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-25 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-26 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-27 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-28 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-29 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-30 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-07-31 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-01 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-02 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-03 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-04 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-05 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-06 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-07 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-08 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-09 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-10 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-11 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-12 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-13 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-14 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-15 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-16 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-17 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-18 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-19 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-20 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-21 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-22 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-23 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-24 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-25 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-26 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-27 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-28 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-29 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-30 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-08-31 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-01 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-02 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-03 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-04 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-05 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-06 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-07 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-08 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-09 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-10 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-11 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-12 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-13 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-14 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-15 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-16 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-17 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-18 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-19 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-20 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-21 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-22 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-23 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-24 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-25 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-26 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-27 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-28 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-29 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-09-30 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-01 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-02 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-03 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-04 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-05 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-06 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-07 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-08 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-09 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-10 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-11 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-12 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-13 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-14 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-15 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-16 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-17 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-18 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-19 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-20 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-21 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-22 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-23 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-24 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-25 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-26 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-27 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-28 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-29 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-30 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-10-31 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-01 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-02 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-03 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-04 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-05 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-06 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-07 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-08 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-09 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-10 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-11 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-12 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-13 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-14 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-15 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-16 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-17 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-18 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-19 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-20 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-21 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-22 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-23 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-24 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-25 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-26 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-27 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-28 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-29 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-11-30 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-01 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-02 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-03 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-04 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-06 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-07 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-08 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-09 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-10 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-11 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-12 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-13 00:00:00', -3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-14 00:00:00', -1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-15 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-16 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-17 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-18 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-19 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-20 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-21 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-22 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-23 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-24 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-25 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-26 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-27 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-28 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-29 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-30 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2003-12-31 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-01 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-02 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-03 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-04 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-05 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-06 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-07 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-08 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-09 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-10 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-11 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-12 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-13 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-14 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-15 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-16 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-17 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-18 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-19 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-20 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-21 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-22 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-23 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-24 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-25 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-26 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-27 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-28 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-29 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-30 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-01-31 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-01 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-02 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-03 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-04 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-05 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-06 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-07 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-08 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-09 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-10 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-11 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-12 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-13 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-14 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-15 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-16 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-17 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-18 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-19 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-20 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-21 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-22 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-23 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-24 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-25 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-26 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-27 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-28 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-02-29 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-01 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-02 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-03 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-04 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-05 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-06 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-07 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-08 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-09 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-10 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-11 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-12 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-13 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-14 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-15 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-16 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-17 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-18 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-19 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-20 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-21 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-22 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-23 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-24 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-25 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-26 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-27 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-28 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-29 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-30 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-03-31 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-01 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-02 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-03 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-04 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-05 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-06 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-07 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-08 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-09 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-10 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-11 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-12 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-13 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-14 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-15 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-16 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-17 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-18 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-19 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-20 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-21 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-22 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-23 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-24 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-25 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-26 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-27 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-28 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-29 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-04-30 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-01 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-02 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-03 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-04 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-05 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-06 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-07 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-08 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-09 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-10 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-11 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-12 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-13 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-14 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-15 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-16 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-17 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-18 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-19 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-20 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-21 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-22 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-23 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-24 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-25 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-26 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-27 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-28 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-29 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-30 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-05-31 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-01 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-02 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-03 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-04 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-05 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-06 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-07 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-08 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-09 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-10 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-11 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-12 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-13 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-14 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-15 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-16 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-17 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-18 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-19 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-20 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-21 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-22 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-23 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-24 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-25 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-26 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-27 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-28 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-29 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-06-30 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-01 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-02 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-03 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-04 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-05 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-06 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-07 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-08 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-09 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-10 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-11 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-12 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-13 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-14 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-15 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-16 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-17 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-18 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-19 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-20 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-21 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-22 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-23 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-24 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-25 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-26 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-27 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-28 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-29 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-30 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-07-31 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-01 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-02 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-03 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-04 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-05 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-06 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-07 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-08 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-09 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-10 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-11 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-12 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-13 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-14 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-15 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-16 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-17 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-18 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-19 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-20 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-21 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-22 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-23 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-24 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-25 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-26 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-27 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-28 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-29 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-30 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-08-31 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-01 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-02 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-03 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-04 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-05 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-06 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-07 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-08 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-09 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-10 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-11 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-12 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-13 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-14 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-15 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-16 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-17 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-18 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-19 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-20 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-21 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-22 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-23 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-24 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-25 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-26 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-27 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-28 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-29 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-09-30 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-01 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-02 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-03 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-04 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-05 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-06 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-07 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-08 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-09 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-10 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-11 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-12 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-13 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-14 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-15 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-16 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-17 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-18 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-19 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-20 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-21 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-22 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-23 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-24 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-25 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-26 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-27 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-28 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-29 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-30 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-10-31 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-01 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-02 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-03 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-04 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-05 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-06 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-07 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-08 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-09 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-10 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-11 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-12 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-13 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-14 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-15 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-16 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-17 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-18 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-19 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-20 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-21 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-22 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-23 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-24 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-25 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-26 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-27 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-28 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-29 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-11-30 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-01 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-02 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-03 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-04 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-05 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-06 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-07 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-08 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-09 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-10 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-11 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-12 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-13 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-14 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-15 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-16 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-17 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-18 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-19 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-20 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-21 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-22 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-23 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-24 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-25 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-26 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-27 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-28 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-29 00:00:00', -0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-30 00:00:00', -0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2004-12-31 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-01 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-02 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-03 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-04 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-05 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-06 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-07 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-08 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-09 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-10 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-11 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-12 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-13 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-14 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-15 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-16 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-17 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-18 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-19 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-20 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-21 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-22 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-23 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-24 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-25 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-26 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-27 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-28 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-29 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-30 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-01-31 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-01 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-02 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-03 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-04 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-05 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-06 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-07 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-08 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-09 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-10 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-11 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-12 00:00:00', -0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-13 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-14 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-15 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-16 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-17 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-18 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-19 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-20 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-21 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-22 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-23 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-24 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-26 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-27 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-02-28 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-01 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-02 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-03 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-04 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-05 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-06 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-07 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-08 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-09 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-10 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-11 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-12 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-13 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-14 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-15 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-16 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-17 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-18 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-19 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-20 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-21 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-22 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-23 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-24 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-25 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-26 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-27 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-28 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-29 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-30 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-03-31 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-01 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-02 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-03 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-04 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-05 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-06 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-07 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-08 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-09 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-10 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-11 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-12 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-13 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-14 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-15 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-16 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-17 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-18 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-19 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-20 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-21 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-22 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-23 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-24 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-25 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-26 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-27 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-28 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-29 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-04-30 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-01 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-02 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-03 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-04 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-05 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-06 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-07 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-08 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-09 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-10 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-11 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-12 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-13 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-14 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-15 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-16 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-17 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-18 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-19 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-20 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-21 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-22 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-23 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-24 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-25 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-26 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-27 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-28 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-29 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-30 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-05-31 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-01 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-02 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-03 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-04 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-05 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-06 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-07 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-08 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-09 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-10 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-11 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-12 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-13 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-14 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-15 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-16 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-17 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-18 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-19 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-20 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-21 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-22 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-23 00:00:00', 43.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-24 00:00:00', 47.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-25 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-26 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-27 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-28 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-29 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-06-30 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-01 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-02 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-03 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-04 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-05 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-06 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-07 00:00:00', 41.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-08 00:00:00', 41.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-09 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-10 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-11 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-12 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-13 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-14 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-15 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-16 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-17 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-18 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-19 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-20 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-21 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-22 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-23 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-24 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-25 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-26 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-27 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-28 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-29 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-30 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-07-31 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-01 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-02 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-03 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-04 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-05 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-06 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-07 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-08 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-09 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-10 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-11 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-12 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-13 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-14 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-15 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-16 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-17 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-18 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-19 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-20 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-21 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-22 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-23 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-24 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-25 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-26 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-27 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-28 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-29 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-30 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-08-31 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-01 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-02 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-03 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-04 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-05 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-06 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-07 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-08 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-09 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-10 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-11 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-12 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-13 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-14 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-15 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-16 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-17 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-18 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-19 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-20 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-21 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-22 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-23 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-24 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-25 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-26 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-27 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-28 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-29 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-09-30 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-01 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-02 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-03 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-04 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-05 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-06 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-07 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-08 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-09 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-10 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-11 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-12 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-13 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-14 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-15 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-16 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-17 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-18 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-19 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-20 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-21 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-22 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-23 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-24 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-25 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-26 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-27 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-28 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-29 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-30 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-10-31 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-01 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-02 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-03 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-04 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-05 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-06 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-07 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-08 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-09 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-10 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-11 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-12 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-13 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-14 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-15 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-16 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-17 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-18 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-19 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-20 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-21 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-22 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-23 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-24 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-25 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-26 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-27 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-28 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-29 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-11-30 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-01 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-02 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-03 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-04 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-05 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-06 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-07 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-08 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-09 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-10 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-11 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-12 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-13 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-14 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-15 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-16 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-17 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-18 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-19 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-20 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-21 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-22 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-23 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-24 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-26 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-27 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-28 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-29 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-30 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2005-12-31 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-01 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-02 00:00:00', -1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-03 00:00:00', -1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-04 00:00:00', -0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-05 00:00:00', -2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-06 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-07 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-08 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-09 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-10 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-11 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-12 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-13 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-14 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-15 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-16 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-17 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-18 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-19 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-20 00:00:00', 4.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-21 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-22 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-23 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-24 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-25 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-26 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-27 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-28 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-29 00:00:00', -0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-30 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-01-31 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-01 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-02 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-03 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-04 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-05 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-06 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-07 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-08 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-09 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-10 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-11 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-12 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-13 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-14 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-15 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-16 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-17 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-18 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-19 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-20 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-21 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-22 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-23 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-24 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-25 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-26 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-27 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-02-28 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-01 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-02 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-03 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-04 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-05 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-06 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-07 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-08 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-09 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-10 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-11 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-12 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-13 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-14 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-15 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-16 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-17 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-18 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-19 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-20 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-21 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-22 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-23 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-24 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-25 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-26 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-27 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-28 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-29 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-30 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-03-31 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-01 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-02 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-03 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-04 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-05 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-06 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-07 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-08 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-09 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-10 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-11 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-12 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-13 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-14 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-15 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-16 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-17 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-18 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-19 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-20 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-21 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-22 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-23 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-24 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-25 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-26 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-27 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-28 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-29 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-04-30 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-01 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-02 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-03 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-04 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-05 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-06 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-07 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-08 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-09 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-10 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-11 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-12 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-13 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-14 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-15 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-16 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-17 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-18 00:00:00', 35.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-19 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-20 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-21 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-22 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-23 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-24 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-25 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-26 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-27 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-28 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-29 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-30 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-05-31 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-01 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-02 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-03 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-04 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-05 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-06 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-07 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-08 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-09 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-10 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-11 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-12 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-13 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-14 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-15 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-16 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-17 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-18 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-19 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-20 00:00:00', 39.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-21 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-22 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-23 00:00:00', 40.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-24 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-25 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-26 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-27 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-28 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-29 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-06-30 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-01 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-02 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-03 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-04 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-05 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-06 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-07 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-08 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-09 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-10 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-11 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-12 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-13 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-14 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-15 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-16 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-17 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-18 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-19 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-20 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-21 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-22 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-23 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-24 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-25 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-26 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-27 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-28 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-29 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-30 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-07-31 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-01 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-02 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-03 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-04 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-05 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-06 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-07 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-08 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-09 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-10 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-11 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-12 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-13 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-14 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-15 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-16 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-17 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-18 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-19 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-20 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-21 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-22 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-23 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-24 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-25 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-26 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-27 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-28 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-29 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-30 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-08-31 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-01 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-02 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-03 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-04 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-05 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-06 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-07 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-08 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-09 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-10 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-11 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-12 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-13 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-14 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-15 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-16 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-17 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-18 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-19 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-20 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-21 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-22 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-23 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-24 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-25 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-26 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-27 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-28 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-29 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-09-30 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-01 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-02 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-03 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-04 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-05 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-06 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-07 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-08 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-09 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-10 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-11 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-12 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-13 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-14 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-15 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-16 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-17 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-18 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-19 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-20 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-21 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-22 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-23 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-24 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-25 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-26 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-27 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-28 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-29 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-30 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-10-31 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-01 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-02 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-03 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-04 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-05 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-06 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-07 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-08 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-09 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-10 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-11 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-12 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-13 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-14 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-15 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-16 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-17 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-18 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-19 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-20 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-21 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-22 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-23 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-24 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-25 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-26 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-27 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-28 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-29 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-11-30 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-01 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-02 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-03 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-04 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-05 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-06 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-07 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-08 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-09 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-10 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-11 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-12 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-13 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-14 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-15 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-16 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-17 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-18 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-19 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-20 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-21 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-22 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-23 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-24 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-25 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-26 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-27 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-28 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-29 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-30 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2006-12-31 00:00:00', -1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-01 00:00:00', -0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-02 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-03 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-04 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-05 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-06 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-07 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-08 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-09 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-10 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-11 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-12 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-13 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-14 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-15 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-16 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-17 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-18 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-19 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-20 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-21 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-22 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-23 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-24 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-26 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-27 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-28 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-29 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-30 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-01-31 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-01 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-02 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-03 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-04 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-05 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-06 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-07 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-08 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-09 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-10 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-11 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-12 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-13 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-14 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-16 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-17 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-18 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-19 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-20 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-21 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-22 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-23 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-24 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-25 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-26 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-27 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-02-28 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-01 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-02 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-03 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-04 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-05 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-06 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-07 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-08 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-09 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-10 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-11 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-12 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-13 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-14 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-15 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-16 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-17 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-18 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-19 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-20 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-21 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-22 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-23 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-24 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-25 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-26 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-27 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-28 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-29 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-30 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-03-31 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-01 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-02 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-03 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-04 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-05 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-06 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-07 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-08 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-09 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-10 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-11 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-12 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-13 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-14 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-15 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-16 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-17 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-18 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-19 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-20 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-21 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-22 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-23 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-24 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-25 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-26 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-27 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-28 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-29 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-04-30 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-01 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-02 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-03 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-04 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-05 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-06 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-07 00:00:00', 28.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-08 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-09 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-10 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-11 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-12 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-13 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-14 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-15 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-16 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-17 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-18 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-19 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-20 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-21 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-22 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-23 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-24 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-25 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-26 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-27 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-28 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-29 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-30 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-05-31 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-01 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-02 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-03 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-04 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-05 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-06 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-07 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-08 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-09 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-10 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-11 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-12 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-13 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-14 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-15 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-16 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-17 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-18 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-19 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-20 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-21 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-22 00:00:00', 42.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-23 00:00:00', 42.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-24 00:00:00', 39.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-25 00:00:00', 40.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-26 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-27 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-28 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-29 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-06-30 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-01 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-02 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-03 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-04 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-05 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-06 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-07 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-08 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-09 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-10 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-11 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-12 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-13 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-14 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-15 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-16 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-17 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-18 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-19 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-20 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-21 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-22 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-23 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-24 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-25 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-26 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-27 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-28 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-29 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-30 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-07-31 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-01 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-02 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-03 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-04 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-05 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-06 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-07 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-08 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-09 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-10 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-11 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-12 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-13 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-14 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-15 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-16 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-17 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-18 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-19 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-20 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-21 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-22 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-23 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-24 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-25 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-26 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-27 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-28 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-29 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-30 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-08-31 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-01 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-02 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-03 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-04 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-05 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-06 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-07 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-08 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-09 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-10 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-11 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-12 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-13 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-14 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-15 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-16 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-17 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-18 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-19 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-20 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-21 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-22 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-23 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-24 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-25 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-26 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-27 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-28 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-29 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-09-30 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-01 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-02 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-03 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-04 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-05 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-06 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-07 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-08 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-09 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-10 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-11 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-12 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-13 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-14 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-15 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-16 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-17 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-18 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-19 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-20 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-21 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-22 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-23 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-24 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-25 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-26 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-27 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-28 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-29 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-30 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-10-31 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-01 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-02 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-03 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-04 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-06 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-07 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-08 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-09 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-10 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-11 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-12 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-13 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-14 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-15 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-16 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-17 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-18 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-19 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-20 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-21 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-22 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-23 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-24 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-25 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-26 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-27 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-28 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-29 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-11-30 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-01 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-02 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-03 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-04 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-05 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-06 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-07 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-08 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-09 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-10 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-11 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-12 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-13 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-14 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-15 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-16 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-17 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-18 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-19 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-20 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-21 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-22 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-23 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-24 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-25 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-26 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-27 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-28 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-29 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-30 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2007-12-31 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-01 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-02 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-03 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-04 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-05 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-06 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-07 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-08 00:00:00', -6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-09 00:00:00', -6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-10 00:00:00', -6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-11 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-12 00:00:00', -1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-13 00:00:00', -2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-14 00:00:00', -5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-15 00:00:00', -6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-16 00:00:00', -5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-17 00:00:00', -4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-18 00:00:00', -1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-19 00:00:00', -5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-20 00:00:00', -6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-21 00:00:00', -6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-22 00:00:00', -6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-23 00:00:00', -7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-24 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-25 00:00:00', -8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-26 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-27 00:00:00', -1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-28 00:00:00', -1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-29 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-30 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-01-31 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-01 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-02 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-03 00:00:00', -1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-04 00:00:00', -2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-05 00:00:00', -3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-06 00:00:00', -2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-07 00:00:00', -3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-08 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-09 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-10 00:00:00', -2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-11 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-12 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-13 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-14 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-15 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-16 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-17 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-18 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-19 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-20 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-21 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-22 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-23 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-24 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-25 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-26 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-27 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-28 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-02-29 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-01 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-02 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-03 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-04 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-06 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-07 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-08 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-09 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-10 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-11 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-12 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-13 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-14 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-15 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-16 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-17 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-18 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-19 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-20 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-21 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-22 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-23 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-24 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-25 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-26 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-27 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-28 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-29 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-30 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-03-31 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-01 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-02 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-03 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-04 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-05 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-06 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-07 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-08 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-09 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-10 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-11 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-12 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-13 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-14 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-15 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-16 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-17 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-18 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-19 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-20 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-21 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-22 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-23 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-24 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-25 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-26 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-27 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-28 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-29 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-04-30 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-01 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-02 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-03 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-04 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-05 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-06 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-07 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-08 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-09 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-10 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-11 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-12 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-13 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-14 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-15 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-16 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-17 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-18 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-19 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-20 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-21 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-22 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-23 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-24 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-25 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-26 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-27 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-28 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-29 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-30 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-05-31 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-01 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-02 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-03 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-04 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-05 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-06 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-07 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-08 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-09 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-10 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-11 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-12 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-13 00:00:00', 41.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-14 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-15 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-16 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-17 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-18 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-19 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-20 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-21 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-22 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-23 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-24 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-25 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-26 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-27 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-28 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-29 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-06-30 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-01 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-02 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-03 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-04 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-05 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-06 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-07 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-08 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-09 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-10 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-11 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-12 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-13 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-14 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-15 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-16 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-17 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-18 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-19 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-20 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-21 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-22 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-23 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-24 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-25 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-26 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-27 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-28 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-29 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-30 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-07-31 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-01 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-02 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-03 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-04 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-05 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-06 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-07 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-08 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-09 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-10 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-11 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-12 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-13 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-14 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-15 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-16 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-17 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-18 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-19 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-20 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-21 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-22 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-23 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-24 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-25 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-26 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-27 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-28 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-29 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-30 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-08-31 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-01 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-02 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-03 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-04 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-05 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-06 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-07 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-08 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-09 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-10 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-11 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-12 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-13 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-14 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-15 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-16 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-17 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-18 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-19 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-20 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-21 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-22 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-23 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-24 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-25 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-26 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-27 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-28 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-29 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-09-30 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-01 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-02 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-03 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-04 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-05 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-06 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-07 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-08 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-09 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-10 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-11 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-12 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-13 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-14 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-15 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-16 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-17 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-18 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-19 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-20 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-21 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-22 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-23 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-24 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-25 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-26 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-27 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-28 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-29 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-30 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-10-31 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-01 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-02 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-03 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-04 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-05 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-06 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-07 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-08 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-09 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-10 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-11 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-12 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-13 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-14 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-15 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-16 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-17 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-18 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-19 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-20 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-21 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-22 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-23 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-24 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-25 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-26 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-27 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-28 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-29 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-11-30 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-01 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-02 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-03 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-04 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-05 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-06 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-07 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-08 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-09 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-10 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-11 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-12 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-13 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-14 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-15 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-16 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-17 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-18 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-19 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-20 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-21 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-22 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-23 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-24 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-25 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-26 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-27 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-28 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-29 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-30 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2008-12-31 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-01 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-02 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-03 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-04 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-05 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-06 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-07 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-08 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-09 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-10 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-11 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-12 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-13 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-14 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-15 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-16 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-17 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-18 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-19 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-20 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-21 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-22 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-23 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-24 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-25 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-26 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-27 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-28 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-29 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-30 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-01-31 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-01 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-02 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-03 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-04 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-05 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-06 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-07 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-08 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-09 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-10 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-11 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-12 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-13 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-14 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-15 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-16 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-17 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-18 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-19 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-20 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-21 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-22 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-23 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-24 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-25 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-26 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-27 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-02-28 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-01 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-02 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-03 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-04 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-05 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-06 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-07 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-08 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-09 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-10 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-11 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-12 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-13 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-14 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-15 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-16 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-17 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-18 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-19 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-20 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-21 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-22 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-23 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-24 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-25 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-26 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-27 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-28 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-29 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-30 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-03-31 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-01 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-02 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-03 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-04 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-05 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-06 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-07 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-08 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-09 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-10 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-11 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-12 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-13 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-14 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-15 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-16 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-17 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-18 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-19 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-20 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-21 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-22 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-23 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-24 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-25 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-26 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-27 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-28 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-29 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-04-30 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-01 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-02 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-03 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-04 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-05 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-06 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-07 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-08 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-09 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-10 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-11 00:00:00', 28.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-12 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-13 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-14 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-15 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-16 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-17 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-18 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-19 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-20 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-21 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-22 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-23 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-24 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-25 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-26 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-27 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-28 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-29 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-30 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-05-31 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-01 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-02 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-03 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-04 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-05 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-06 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-07 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-08 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-09 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-10 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-11 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-12 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-13 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-14 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-15 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-16 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-17 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-18 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-19 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-20 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-21 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-22 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-23 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-24 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-25 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-26 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-27 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-28 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-29 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-06-30 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-01 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-02 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-03 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-04 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-05 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-06 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-07 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-08 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-09 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-10 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-11 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-12 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-13 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-14 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-15 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-16 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-17 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-18 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-19 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-20 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-21 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-22 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-23 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-24 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-25 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-26 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-27 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-28 00:00:00', 39.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-29 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-30 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-07-31 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-01 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-02 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-03 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-04 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-05 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-06 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-07 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-08 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-09 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-10 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-11 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-12 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-13 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-14 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-15 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-16 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-17 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-18 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-19 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-20 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-21 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-22 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-23 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-24 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-25 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-26 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-27 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-28 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-29 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-30 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-08-31 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-01 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-02 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-03 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-04 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-05 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-06 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-07 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-08 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-09 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-10 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-11 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-12 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-13 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-14 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-15 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-16 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-17 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-18 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-19 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-20 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-21 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-22 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-23 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-24 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-25 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-26 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-27 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-28 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-29 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-09-30 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-01 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-02 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-03 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-04 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-05 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-06 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-07 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-08 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-09 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-10 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-11 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-12 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-13 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-14 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-15 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-16 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-17 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-18 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-19 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-20 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-21 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-22 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-23 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-24 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-25 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-26 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-27 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-28 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-29 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-30 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-10-31 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-01 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-02 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-03 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-04 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-05 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-06 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-07 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-08 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-09 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-10 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-11 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-12 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-13 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-14 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-15 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-16 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-17 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-18 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-19 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-20 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-21 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-22 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-23 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-24 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-25 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-26 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-27 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-28 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-29 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-11-30 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-01 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-02 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-03 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-04 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-05 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-06 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-07 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-08 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-09 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-10 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-11 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-12 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-13 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-14 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-16 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-17 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-18 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-19 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-20 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-21 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-22 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-23 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-24 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-26 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-27 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-28 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-29 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-30 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2009-12-31 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-01 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-02 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-03 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-04 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-05 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-06 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-07 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-08 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-09 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-10 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-11 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-12 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-13 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-14 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-15 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-16 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-17 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-18 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-19 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-20 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-21 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-22 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-23 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-24 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-26 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-27 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-28 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-29 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-30 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-01-31 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-01 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-02 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-03 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-04 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-05 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-06 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-07 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-08 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-09 00:00:00', -1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-10 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-11 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-12 00:00:00', 4.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-13 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-14 00:00:00', -1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-15 00:00:00', -1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-16 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-17 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-18 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-19 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-20 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-21 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-22 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-23 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-24 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-25 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-26 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-27 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-02-28 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-01 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-02 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-03 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-04 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-05 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-06 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-07 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-08 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-09 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-10 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-11 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-12 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-13 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-14 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-15 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-16 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-17 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-18 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-19 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-20 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-21 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-22 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-23 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-24 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-25 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-26 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-27 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-28 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-29 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-30 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-03-31 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-01 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-02 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-03 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-04 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-05 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-06 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-07 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-08 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-09 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-10 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-11 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-12 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-13 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-14 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-15 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-16 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-17 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-18 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-19 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-20 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-21 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-22 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-23 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-24 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-25 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-26 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-27 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-28 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-29 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-04-30 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-01 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-02 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-03 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-04 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-05 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-06 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-07 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-08 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-09 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-10 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-11 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-12 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-13 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-14 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-15 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-16 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-17 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-18 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-19 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-20 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-21 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-22 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-23 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-24 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-25 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-26 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-27 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-28 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-29 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-30 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-05-31 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-01 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-02 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-03 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-04 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-05 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-06 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-07 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-08 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-09 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-10 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-11 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-12 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-13 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-14 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-15 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-16 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-17 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-18 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-19 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-20 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-21 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-22 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-23 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-24 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-25 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-26 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-27 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-28 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-29 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-06-30 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-01 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-02 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-03 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-04 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-05 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-06 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-07 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-08 00:00:00', 41.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-09 00:00:00', 41.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-10 00:00:00', 41.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-11 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-12 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-13 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-14 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-15 00:00:00', 42.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-16 00:00:00', 43.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-17 00:00:00', 42.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-18 00:00:00', 42.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-19 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-20 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-21 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-22 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-23 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-24 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-25 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-26 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-27 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-28 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-29 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-30 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-07-31 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-01 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-02 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-03 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-04 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-05 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-06 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-07 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-08 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-09 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-10 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-11 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-12 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-13 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-14 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-15 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-16 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-17 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-18 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-19 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-20 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-21 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-22 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-23 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-24 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-25 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-26 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-27 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-28 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-29 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-30 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-08-31 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-01 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-02 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-03 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-04 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-05 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-06 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-07 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-08 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-09 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-10 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-11 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-12 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-13 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-14 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-15 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-16 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-17 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-18 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-19 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-20 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-21 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-22 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-23 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-24 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-25 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-26 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-27 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-28 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-29 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-09-30 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-01 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-02 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-03 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-04 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-05 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-06 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-07 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-08 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-09 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-10 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-11 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-12 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-13 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-14 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-15 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-16 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-17 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-18 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-19 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-20 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-21 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-22 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-23 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-24 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-25 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-26 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-27 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-28 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-29 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-30 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-10-31 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-01 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-02 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-03 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-04 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-05 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-06 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-07 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-08 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-09 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-10 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-11 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-12 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-13 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-14 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-16 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-17 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-18 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-19 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-20 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-21 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-22 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-23 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-24 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-25 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-26 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-27 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-28 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-29 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-11-30 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-01 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-02 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-03 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-04 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-05 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-06 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-07 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-08 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-09 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-10 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-11 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-12 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-13 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-14 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-15 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-16 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-17 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-18 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-19 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-20 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-21 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-22 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-23 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-24 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-25 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-26 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-27 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-28 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-29 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-30 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2010-12-31 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-01 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-02 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-03 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-04 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-05 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-06 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-07 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-08 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-09 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-10 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-11 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-12 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-13 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-14 00:00:00', 0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-15 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-16 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-17 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-18 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-19 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-20 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-21 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-22 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-23 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-24 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-25 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-26 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-27 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-28 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-29 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-30 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-01-31 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-01 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-02 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-03 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-04 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-05 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-06 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-07 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-08 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-09 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-10 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-11 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-12 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-13 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-14 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-15 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-16 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-17 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-18 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-19 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-20 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-21 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-22 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-23 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-24 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-25 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-26 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-27 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-02-28 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-01 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-02 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-03 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-04 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-05 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-06 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-07 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-08 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-09 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-10 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-11 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-12 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-13 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-14 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-15 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-16 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-17 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-18 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-19 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-20 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-21 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-22 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-23 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-24 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-25 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-26 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-27 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-28 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-29 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-30 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-03-31 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-01 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-02 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-03 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-04 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-05 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-06 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-07 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-08 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-09 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-10 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-11 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-12 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-13 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-14 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-15 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-16 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-17 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-18 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-19 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-20 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-21 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-22 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-23 00:00:00', 35.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-24 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-25 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-26 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-27 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-28 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-29 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-04-30 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-01 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-02 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-03 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-04 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-05 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-06 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-07 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-08 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-09 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-10 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-11 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-12 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-13 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-14 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-15 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-16 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-17 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-18 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-19 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-20 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-21 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-22 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-23 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-24 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-25 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-26 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-27 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-28 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-29 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-30 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-05-31 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-01 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-02 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-03 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-04 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-05 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-06 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-07 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-08 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-09 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-10 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-11 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-12 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-13 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-14 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-15 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-16 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-17 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-18 00:00:00', 39.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-19 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-20 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-21 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-22 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-23 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-24 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-25 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-26 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-27 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-28 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-29 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-06-30 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-01 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-02 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-03 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-04 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-05 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-06 00:00:00', 41.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-07 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-08 00:00:00', 41.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-09 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-10 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-11 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-12 00:00:00', 41.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-13 00:00:00', 42.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-14 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-15 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-16 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-17 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-18 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-19 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-20 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-21 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-22 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-23 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-24 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-25 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-26 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-27 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-28 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-29 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-30 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-07-31 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-01 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-02 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-03 00:00:00', 42.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-04 00:00:00', 42.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-05 00:00:00', 41.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-06 00:00:00', 42, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-07 00:00:00', 42.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-08 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-09 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-10 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-11 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-12 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-13 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-14 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-15 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-16 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-17 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-18 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-19 00:00:00', 39.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-20 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-21 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-22 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-23 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-24 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-25 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-26 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-27 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-28 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-29 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-30 00:00:00', 30.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-08-31 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-01 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-02 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-03 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-04 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-05 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-06 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-07 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-08 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-09 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-10 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-11 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-12 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-13 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-14 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-15 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-16 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-17 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-18 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-19 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-20 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-21 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-22 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-23 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-24 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-25 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-26 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-27 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-28 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-29 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-09-30 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-01 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-02 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-03 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-04 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-05 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-06 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-07 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-08 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-09 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-10 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-11 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-12 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-13 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-14 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-15 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-16 00:00:00', 30.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-17 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-18 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-19 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-20 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-21 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-22 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-23 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-24 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-25 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-26 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-27 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-28 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-29 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-30 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-10-31 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-01 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-02 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-03 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-04 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-05 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-06 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-07 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-08 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-09 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-10 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-11 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-12 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-13 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-14 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-15 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-16 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-17 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-18 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-19 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-20 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-21 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-22 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-23 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-24 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-25 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-26 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-27 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-28 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-29 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-11-30 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-01 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-02 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-03 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-04 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-05 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-06 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-07 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-08 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-09 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-10 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-11 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-12 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-13 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-14 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-15 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-16 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-17 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-18 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-19 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-20 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-21 00:00:00', -2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-22 00:00:00', -3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-23 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-24 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-25 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-26 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-27 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-28 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-29 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-30 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2011-12-31 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-01 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-02 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-03 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-04 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-05 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-06 00:00:00', -1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-07 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-08 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-09 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-10 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-11 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-12 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-13 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-14 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-15 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-16 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-17 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-18 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-19 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-20 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-21 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-22 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-23 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-24 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-25 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-26 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-27 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-28 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-29 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-30 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-01-31 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-01 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-02 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-03 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-04 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-05 00:00:00', -4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-06 00:00:00', -2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-07 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-08 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-09 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-10 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-11 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-12 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-13 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-14 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-15 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-16 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-17 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-18 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-19 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-20 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-21 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-22 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-23 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-24 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-25 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-26 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-27 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-28 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-02-29 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-01 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-02 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-03 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-04 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-05 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-06 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-07 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-08 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-09 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-10 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-11 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-12 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-13 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-14 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-15 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-16 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-17 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-18 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-19 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-20 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-21 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-22 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-23 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-24 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-25 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-26 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-27 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-28 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-29 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-30 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-03-31 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-01 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-02 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-03 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-04 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-05 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-06 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-07 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-08 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-09 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-10 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-11 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-12 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-13 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-14 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-15 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-16 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-17 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-18 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-19 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-20 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-21 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-22 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-23 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-24 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-25 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-26 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-27 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-28 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-29 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-04-30 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-01 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-02 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-03 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-04 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-05 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-06 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-07 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-08 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-09 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-10 00:00:00', 25.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-11 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-12 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-13 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-14 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-15 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-16 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-17 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-18 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-19 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-20 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-21 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-22 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-23 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-24 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-25 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-26 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-27 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-28 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-29 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-30 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-05-31 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-01 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-02 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-03 00:00:00', 38.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-04 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-05 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-06 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-07 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-08 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-09 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-10 00:00:00', 36.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-11 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-12 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-13 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-14 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-15 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-16 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-17 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-18 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-19 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-20 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-21 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-22 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-23 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-24 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-25 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-26 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-27 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-28 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-29 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-06-30 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-01 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-02 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-03 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-04 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-05 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-06 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-07 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-08 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-09 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-10 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-11 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-12 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-13 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-14 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-15 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-16 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-17 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-18 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-19 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-20 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-21 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-22 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-23 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-24 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-25 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-26 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-27 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-28 00:00:00', 34.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-29 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-30 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-07-31 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-01 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-02 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-03 00:00:00', 34.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-04 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-05 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-06 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-07 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-08 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-09 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-10 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-11 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-12 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-13 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-14 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-15 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-16 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-17 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-18 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-19 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-20 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-21 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-22 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-23 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-24 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-25 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-26 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-27 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-28 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-29 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-30 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-08-31 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-01 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-02 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-03 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-04 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-05 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-06 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-07 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-08 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-09 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-10 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-11 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-12 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-13 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-14 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-15 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-16 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-17 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-18 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-19 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-20 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-21 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-22 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-23 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-24 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-25 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-26 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-27 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-28 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-29 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-09-30 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-01 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-02 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-03 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-04 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-05 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-06 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-07 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-08 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-09 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-10 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-11 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-12 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-13 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-14 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-15 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-16 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-17 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-18 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-19 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-20 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-21 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-22 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-23 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-24 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-25 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-26 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-27 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-28 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-29 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-30 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-10-31 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-01 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-02 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-03 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-04 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-05 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-06 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-07 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-08 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-09 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-10 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-11 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-12 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-13 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-14 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-15 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-16 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-17 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-18 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-19 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-20 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-21 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-22 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-23 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-24 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-25 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-26 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-27 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-28 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-29 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-11-30 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-01 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-02 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-03 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-04 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-05 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-06 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-07 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-08 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-09 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-10 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-11 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-12 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-13 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-14 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-15 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-16 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-17 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-18 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-19 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-20 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-21 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-22 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-23 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-24 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-25 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-26 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-27 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-28 00:00:00', -6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-29 00:00:00', -2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-30 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2012-12-31 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-01 00:00:00', -1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-02 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-03 00:00:00', 0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-04 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-05 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-06 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-07 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-08 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-09 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-10 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-11 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-12 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-13 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-14 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-15 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-16 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-17 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-18 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-19 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-20 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-21 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-22 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-23 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-24 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-25 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-26 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-27 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-28 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-29 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-30 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-01-31 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-01 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-02 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-03 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-04 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-05 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-06 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-07 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-08 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-09 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-10 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-11 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-12 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-13 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-14 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-15 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-16 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-17 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-18 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-19 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-20 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-21 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-22 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-23 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-24 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-25 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-26 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-27 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-02-28 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-01 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-02 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-03 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-04 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-05 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-06 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-07 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-08 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-09 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-10 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-11 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-12 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-13 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-14 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-15 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-16 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-17 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-18 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-19 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-20 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-21 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-22 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-23 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-24 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-25 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-26 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-27 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-28 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-29 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-30 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-03-31 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-01 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-02 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-03 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-04 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-05 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-06 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-07 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-08 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-09 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-10 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-11 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-12 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-13 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-14 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-15 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-16 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-17 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-18 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-19 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-20 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-21 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-22 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-23 00:00:00', 25.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-24 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-25 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-26 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-27 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-28 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-29 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-04-30 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-01 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-02 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-03 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-04 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-05 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-06 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-07 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-08 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-09 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-10 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-11 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-12 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-13 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-14 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-15 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-16 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-17 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-18 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-19 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-20 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-21 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-22 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-23 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-24 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-25 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-26 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-27 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-28 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-29 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-30 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-05-31 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-01 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-02 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-03 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-04 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-05 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-06 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-07 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-08 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-09 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-10 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-11 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-12 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-13 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-14 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-15 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-16 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-17 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-18 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-19 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-20 00:00:00', 39.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-21 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-22 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-23 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-24 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-25 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-26 00:00:00', 39.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-27 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-28 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-29 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-06-30 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-01 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-02 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-03 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-04 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-05 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-06 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-07 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-08 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-09 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-10 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-11 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-12 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-13 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-14 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-15 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-16 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-17 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-18 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-19 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-20 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-21 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-22 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-23 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-24 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-25 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-26 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-27 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-28 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-29 00:00:00', 41.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-30 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-07-31 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-01 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-02 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-03 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-04 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-05 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-06 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-07 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-08 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-09 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-10 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-11 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-12 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-13 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-14 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-15 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-16 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-17 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-18 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-19 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-20 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-21 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-22 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-23 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-24 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-25 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-26 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-27 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-28 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-29 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-30 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-08-31 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-01 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-02 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-03 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-04 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-05 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-06 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-07 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-08 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-09 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-10 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-11 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-12 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-13 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-14 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-15 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-16 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-17 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-18 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-19 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-20 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-21 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-22 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-23 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-24 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-25 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-26 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-27 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-28 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-29 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-09-30 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-01 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-02 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-03 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-04 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-05 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-06 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-07 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-08 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-09 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-10 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-11 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-12 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-13 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-14 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-15 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-16 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-17 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-18 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-19 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-20 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-21 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-22 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-23 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-24 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-25 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-26 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-27 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-28 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-29 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-30 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-10-31 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-01 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-02 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-03 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-04 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-05 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-06 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-07 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-08 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-09 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-10 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-11 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-12 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-13 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-14 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-15 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-16 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-17 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-18 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-19 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-20 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-21 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-22 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-23 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-24 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-25 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-26 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-27 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-28 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-29 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-11-30 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-01 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-02 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-03 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-04 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-05 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-06 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-07 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-08 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-09 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-10 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-11 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-12 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-13 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-14 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-15 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-16 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-17 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-18 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-19 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-20 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-21 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-22 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-23 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-24 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-25 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-26 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-27 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-28 00:00:00', 0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-29 00:00:00', -2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-30 00:00:00', -2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2013-12-31 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-01 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-02 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-03 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-04 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-05 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-06 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-07 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-08 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-09 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-10 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-11 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-12 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-13 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-14 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-15 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-16 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-17 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-18 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-19 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-20 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-21 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-22 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-23 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-24 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-25 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-26 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-27 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-28 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-29 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-30 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-01-31 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-01 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-02 00:00:00', -7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-03 00:00:00', -11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-04 00:00:00', -10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-05 00:00:00', -4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-06 00:00:00', -9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-07 00:00:00', -2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-08 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-09 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-10 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-11 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-12 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-13 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-14 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-15 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-16 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-17 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-18 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-19 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-20 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-21 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-22 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-23 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-24 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-25 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-26 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-27 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-02-28 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-01 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-02 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-03 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-04 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-06 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-07 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-08 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-09 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-10 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-11 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-12 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-13 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-14 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-15 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-16 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-17 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-18 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-19 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-20 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-21 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-22 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-23 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-24 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-25 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-26 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-27 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-28 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-29 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-30 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-03-31 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-01 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-02 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-03 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-04 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-05 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-06 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-07 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-08 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-09 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-10 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-11 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-12 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-13 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-14 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-15 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-16 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-17 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-18 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-19 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-20 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-21 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-22 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-23 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-24 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-25 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-26 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-27 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-28 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-29 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-04-30 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-01 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-02 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-03 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-04 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-05 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-06 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-07 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-08 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-09 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-10 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-11 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-12 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-13 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-14 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-15 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-16 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-17 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-18 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-19 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-20 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-21 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-22 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-23 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-24 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-25 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-26 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-27 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-28 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-29 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-30 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-05-31 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-01 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-02 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-03 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-04 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-05 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-06 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-07 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-08 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-09 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-10 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-11 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-12 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-13 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-14 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-15 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-16 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-17 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-18 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-19 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-20 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-21 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-22 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-23 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-24 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-25 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-26 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-27 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-28 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-29 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-06-30 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-01 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-02 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-03 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-04 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-05 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-06 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-07 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-08 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-09 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-10 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-11 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-12 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-13 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-14 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-15 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-16 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-17 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-18 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-19 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-20 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-21 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-22 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-23 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-24 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-25 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-26 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-27 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-28 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-29 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-30 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-07-31 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-01 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-02 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-03 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-04 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-05 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-06 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-07 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-08 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-09 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-10 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-11 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-12 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-13 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-14 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-15 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-16 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-17 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-18 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-19 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-20 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-21 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-22 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-23 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-24 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-25 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-26 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-27 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-28 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-29 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-30 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-08-31 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-01 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-02 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-03 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-04 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-05 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-06 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-07 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-08 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-09 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-10 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-11 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-12 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-13 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-14 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-15 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-16 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-17 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-18 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-19 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-20 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-21 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-22 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-23 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-24 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-25 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-26 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-27 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-28 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-29 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-09-30 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-01 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-02 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-03 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-04 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-05 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-06 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-07 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-08 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-09 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-10 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-11 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-12 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-13 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-14 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-15 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-16 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-17 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-18 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-19 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-20 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-21 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-22 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-23 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-24 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-25 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-26 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-27 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-28 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-29 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-30 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-10-31 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-01 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-02 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-03 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-04 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-06 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-07 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-08 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-09 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-10 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-11 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-12 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-13 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-14 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-15 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-16 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-17 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-18 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-19 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-20 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-21 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-22 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-23 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-24 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-25 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-26 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-27 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-28 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-29 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-11-30 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-01 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-02 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-03 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-04 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-05 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-06 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-07 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-08 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-09 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-10 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-11 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-12 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-13 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-14 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-15 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-16 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-17 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-18 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-19 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-20 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-21 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-22 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-23 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-24 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-25 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-26 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-27 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-28 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-29 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-30 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2014-12-31 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-01 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-02 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-03 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-04 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-05 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-06 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-07 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-08 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-09 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-10 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-11 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-12 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-13 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-14 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-15 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-16 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-17 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-18 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-19 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-20 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-21 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-22 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-23 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-24 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-25 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-26 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-27 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-28 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-29 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-30 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-01-31 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-01 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-02 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-03 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-04 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-06 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-07 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-08 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-09 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-10 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-11 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-12 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-13 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-14 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-15 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-16 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-17 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-18 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-19 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-20 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-21 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-22 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-23 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-24 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-25 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-26 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-27 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-02-28 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-01 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-02 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-03 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-04 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-06 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-07 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-08 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-09 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-10 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-11 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-12 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-13 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-14 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-15 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-16 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-17 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-18 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-19 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-20 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-21 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-22 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-23 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-24 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-25 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-26 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-27 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-28 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-29 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-30 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-03-31 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-01 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-02 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-03 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-04 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-05 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-06 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-07 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-08 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-09 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-10 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-11 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-12 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-13 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-14 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-15 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-16 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-17 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-18 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-19 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-20 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-21 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-22 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-23 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-24 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-25 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-26 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-27 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-28 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-29 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-04-30 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-01 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-02 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-03 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-04 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-05 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-06 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-07 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-08 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-09 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-10 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-11 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-12 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-13 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-14 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-15 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-16 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-17 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-18 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-19 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-20 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-21 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-22 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-23 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-24 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-25 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-26 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-27 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-28 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-29 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-30 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-05-31 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-01 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-02 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-03 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-04 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-05 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-06 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-07 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-08 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-09 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-10 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-11 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-12 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-13 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-14 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-15 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-16 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-17 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-18 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-19 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-20 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-21 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-22 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-23 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-24 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-25 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-26 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-27 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-28 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-29 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-06-30 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-01 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-02 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-03 00:00:00', 42, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-04 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-05 00:00:00', 41.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-06 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-07 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-08 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-09 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-10 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-11 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-12 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-13 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-14 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-15 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-16 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-17 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-18 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-19 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-20 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-21 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-22 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-23 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-24 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-25 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-26 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-27 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-28 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-29 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-30 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-07-31 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-01 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-02 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-03 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-04 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-05 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-06 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-07 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-08 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-09 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-10 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-11 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-12 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-13 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-14 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-15 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-16 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-17 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-18 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-19 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-20 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-21 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-22 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-23 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-24 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-25 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-26 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-27 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-28 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-29 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-30 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-08-31 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-01 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-02 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-03 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-04 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-05 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-06 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-07 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-08 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-09 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-10 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-11 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-12 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-13 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-14 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-15 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-16 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-17 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-18 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-19 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-20 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-21 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-22 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-23 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-24 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-25 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-26 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-27 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-28 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-29 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-09-30 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-01 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-02 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-03 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-04 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-05 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-06 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-07 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-08 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-09 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-10 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-11 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-12 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-13 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-14 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-15 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-16 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-17 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-18 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-19 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-20 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-21 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-22 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-23 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-24 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-25 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-26 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-27 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-28 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-29 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-30 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-10-31 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-01 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-02 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-03 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-04 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-05 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-06 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-07 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-08 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-09 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-10 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-11 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-12 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-13 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-14 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-15 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-16 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-17 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-18 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-19 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-20 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-21 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-22 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-23 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-24 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-25 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-26 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-27 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-28 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-29 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-11-30 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-01 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-02 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-03 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-04 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-05 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-06 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-07 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-08 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-09 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-10 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-11 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-12 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-13 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-14 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-15 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-16 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-17 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-18 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-19 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-20 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-21 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-22 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-23 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-24 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-25 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-26 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-27 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-28 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-29 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-30 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2015-12-31 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-01 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-02 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-03 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-04 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-05 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-06 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-07 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-08 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-09 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-10 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-11 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-12 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-13 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-14 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-15 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-16 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-17 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-18 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-19 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-20 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-21 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-22 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-23 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-24 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-25 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-26 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-27 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-28 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-29 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-30 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-01-31 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-01 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-02 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-03 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-04 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-05 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-06 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-07 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-08 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-09 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-10 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-11 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-12 00:00:00', -1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-13 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-14 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-15 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-16 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-17 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-18 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-19 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-20 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-21 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-22 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-23 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-24 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-25 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-26 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-27 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-28 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-02-29 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-01 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-02 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-03 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-04 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-05 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-06 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-07 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-08 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-09 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-10 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-11 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-12 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-13 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-14 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-15 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-16 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-17 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-18 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-19 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-20 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-21 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-22 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-23 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-24 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-25 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-26 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-27 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-28 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-29 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-30 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-03-31 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-01 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-02 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-03 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-04 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-06 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-07 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-08 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-09 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-10 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-11 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-12 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-13 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-14 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-15 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-16 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-17 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-18 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-19 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-20 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-21 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-22 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-23 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-24 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-25 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-26 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-27 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-28 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-29 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-04-30 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-01 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-02 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-03 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-04 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-05 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-06 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-07 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-08 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-09 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-10 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-11 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-12 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-13 00:00:00', 30.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-14 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-15 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-16 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-17 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-18 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-19 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-20 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-21 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-22 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-23 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-24 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-25 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-26 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-27 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-28 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-29 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-30 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-05-31 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-01 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-02 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-03 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-04 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-05 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-06 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-07 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-08 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-09 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-10 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-11 00:00:00', 39.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-12 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-13 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-14 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-15 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-16 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-17 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-18 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-19 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-20 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-21 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-22 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-23 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-24 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-25 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-26 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-27 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-28 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-29 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-06-30 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-01 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-02 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-03 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-04 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-05 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-06 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-07 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-08 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-09 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-10 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-11 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-12 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-13 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-14 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-15 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-16 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-17 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-18 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-19 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-20 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-21 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-22 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-23 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-24 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-25 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-26 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-27 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-28 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-29 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-30 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-07-31 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-01 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-02 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-03 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-04 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-05 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-06 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-07 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-08 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-09 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-10 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-11 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-12 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-13 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-14 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-15 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-16 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-17 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-18 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-19 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-20 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-21 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-22 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-23 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-24 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-25 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-26 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-27 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-28 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-29 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-30 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-08-31 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-01 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-02 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-03 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-04 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-05 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-06 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-07 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-08 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-09 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-10 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-11 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-12 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-13 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-14 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-15 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-16 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-17 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-18 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-19 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-20 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-21 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-22 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-23 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-24 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-25 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-26 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-27 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-28 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-29 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-09-30 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-01 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-02 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-03 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-04 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-05 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-06 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-07 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-08 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-09 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-10 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-11 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-12 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-13 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-14 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-15 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-16 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-17 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-18 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-19 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-20 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-21 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-22 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-23 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-24 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-25 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-26 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-27 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-28 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-29 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-30 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-10-31 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-01 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-02 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-03 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-04 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-05 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-06 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-07 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-08 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-09 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-10 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-11 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-12 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-13 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-14 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-15 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-16 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-17 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-18 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-19 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-20 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-21 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-22 00:00:00', -4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-23 00:00:00', -1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-24 00:00:00', -2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-25 00:00:00', -2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-26 00:00:00', -2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-27 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-28 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-29 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-11-30 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-01 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-02 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-03 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-04 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-05 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-06 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-07 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-08 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-09 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-10 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-11 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-12 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-13 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-14 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-15 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-16 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-17 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-18 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-19 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-20 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-21 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-22 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-23 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-24 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-25 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-26 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-27 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-28 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-29 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-30 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2016-12-31 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-01 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-02 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-03 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-04 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-05 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-06 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-07 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-08 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-09 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-10 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-11 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-12 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-13 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-14 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-15 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-16 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-17 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-18 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-19 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-20 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-21 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-22 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-23 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-24 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-25 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-26 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-27 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-28 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-29 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-30 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-01-31 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-01 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-02 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-03 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-04 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-05 00:00:00', -0.200000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-06 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-07 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-08 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-09 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-10 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-11 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-12 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-13 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-14 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-15 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-16 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-17 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-18 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-19 00:00:00', -0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-20 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-21 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-22 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-23 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-24 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-25 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-26 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-27 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-02-28 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-01 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-02 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-03 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-04 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-05 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-06 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-07 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-08 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-09 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-10 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-11 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-12 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-13 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-14 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-15 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-16 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-17 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-18 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-19 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-20 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-21 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-22 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-23 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-24 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-25 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-26 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-27 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-28 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-29 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-30 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-03-31 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-01 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-02 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-03 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-04 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-05 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-06 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-07 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-08 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-09 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-10 00:00:00', 24.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-11 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-12 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-13 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-14 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-15 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-16 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-17 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-18 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-19 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-20 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-21 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-22 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-23 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-24 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-25 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-26 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-27 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-28 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-29 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-04-30 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-01 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-02 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-03 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-04 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-05 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-06 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-07 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-08 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-09 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-10 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-11 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-12 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-13 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-14 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-15 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-16 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-17 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-18 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-19 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-20 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-21 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-22 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-23 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-24 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-25 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-26 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-27 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-28 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-29 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-30 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-05-31 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-01 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-02 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-03 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-04 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-05 00:00:00', 34, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-06 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-07 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-08 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-09 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-10 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-11 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-12 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-13 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-14 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-15 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-16 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-17 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-18 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-19 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-20 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-21 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-22 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-23 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-24 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-25 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-26 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-27 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-28 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-29 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-06-30 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-01 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-02 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-03 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-04 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-05 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-06 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-07 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-08 00:00:00', 41.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-09 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-10 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-11 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-12 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-13 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-14 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-15 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-16 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-17 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-18 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-19 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-20 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-21 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-22 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-23 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-24 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-25 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-26 00:00:00', 40.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-27 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-28 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-29 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-30 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-07-31 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-01 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-02 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-03 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-04 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-05 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-06 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-07 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-08 00:00:00', 38.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-09 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-10 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-11 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-12 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-13 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-14 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-15 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-16 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-17 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-18 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-19 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-20 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-21 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-22 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-23 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-24 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-25 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-26 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-27 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-28 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-29 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-30 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-08-31 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-01 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-02 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-03 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-04 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-05 00:00:00', 34.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-06 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-07 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-08 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-09 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-10 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-11 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-12 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-13 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-14 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-15 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-16 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-17 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-18 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-19 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-20 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-21 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-22 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-23 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-24 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-25 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-26 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-27 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-28 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-29 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-09-30 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-01 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-02 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-03 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-04 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-05 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-06 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-07 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-08 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-09 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-10 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-11 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-12 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-13 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-14 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-15 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-16 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-17 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-18 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-19 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-20 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-21 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-22 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-23 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-24 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-25 00:00:00', 27.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-26 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-27 00:00:00', 27.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-28 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-29 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-30 00:00:00', 30.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-10-31 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-01 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-02 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-03 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-04 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-05 00:00:00', 26.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-06 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-07 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-08 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-09 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-10 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-11 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-12 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-13 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-14 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-15 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-16 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-17 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-18 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-19 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-20 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-21 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-22 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-23 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-24 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-25 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-26 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-27 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-28 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-29 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-11-30 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-01 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-02 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-03 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-04 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-05 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-06 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-07 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-08 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-09 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-10 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-11 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-12 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-13 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-14 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-15 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-16 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-17 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-18 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-19 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-20 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-21 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-22 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-23 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-24 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-25 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-26 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-27 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-28 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-29 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-30 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (8, '2017-12-31 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (9, '2008-02-01 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (9, '2008-06-01 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (9, '2009-02-01 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (9, '2009-06-01 00:00:00', 112, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (9, '2009-08-01 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-01 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-02 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-03 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-04 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-05 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-06 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-07 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-08 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-09 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-10 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-11 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-12 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-13 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-14 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-15 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-16 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-17 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-18 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-19 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-20 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-21 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-22 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-23 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-24 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-25 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-26 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-27 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-28 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-29 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-30 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-01-31 00:00:00', 233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-01 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-02 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-03 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-04 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-05 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-06 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-07 00:00:00', 233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-08 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-09 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-10 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-11 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-12 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-13 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-14 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-15 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-16 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-17 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-18 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-19 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-20 00:00:00', 344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-21 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-22 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-23 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-24 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-25 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-26 00:00:00', 273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-27 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-02-28 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-01 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-02 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-03 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-04 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-05 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-06 00:00:00', 287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-07 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-08 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-09 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-10 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-11 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-12 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-13 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-14 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-15 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-16 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-17 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-18 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-19 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-20 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-21 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-22 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-23 00:00:00', 285, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-24 00:00:00', 273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-25 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-26 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-27 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-28 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-29 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-30 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-03-31 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-01 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-02 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-03 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-04 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-05 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-06 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-07 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-08 00:00:00', 269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-09 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-10 00:00:00', 269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-11 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-12 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-13 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-14 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-15 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-16 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-17 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-18 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-19 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-20 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-21 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-22 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-23 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-24 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-25 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-26 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-27 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-28 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-29 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-04-30 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-01 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-02 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-03 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-04 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-05 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-06 00:00:00', 324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-07 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-08 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-09 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-10 00:00:00', 314, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-11 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-12 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-13 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-14 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-15 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-16 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-17 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-18 00:00:00', 330, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-19 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-20 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-21 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-22 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-23 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-24 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-25 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-26 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-27 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-28 00:00:00', 273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-29 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-30 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-05-31 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-01 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-02 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-03 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-04 00:00:00', 329, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-05 00:00:00', 305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-06 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-07 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-08 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-09 00:00:00', 285, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-10 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-11 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-12 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-13 00:00:00', 288, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-14 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-15 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-16 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-17 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-18 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-19 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-20 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-21 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-22 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-23 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-24 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-25 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-26 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-27 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-28 00:00:00', 314, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-29 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-06-30 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-01 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-02 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-03 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-04 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-05 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-06 00:00:00', 258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-07 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-08 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-09 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-10 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-11 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-12 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-13 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-14 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-15 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-16 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-17 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-18 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-19 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-20 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-21 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-22 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-23 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-24 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-25 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-26 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-27 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-28 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-29 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-30 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-07-31 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-01 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-02 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-03 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-04 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-05 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-06 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-07 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-08 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-09 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-10 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-11 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-12 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-13 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-14 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-15 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-16 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-17 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-18 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-19 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-20 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-21 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-22 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-23 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-24 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-25 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-26 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-27 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-28 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-29 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-30 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-08-31 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-01 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-02 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-03 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-04 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-05 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-06 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-07 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-08 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-09 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-10 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-11 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-12 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-13 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-14 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-15 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-16 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-17 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-18 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-19 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-20 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-21 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-22 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-23 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-24 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-25 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-26 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-27 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-28 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-29 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-09-30 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-01 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-02 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-03 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-04 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-05 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-06 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-07 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-08 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-09 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-10 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-11 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-12 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-13 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-14 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-15 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-16 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-17 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-18 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-19 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-20 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-21 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-22 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-23 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-24 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-25 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-26 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-27 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-28 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-29 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-30 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-10-31 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-01 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-02 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-03 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-04 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-05 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-06 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-07 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-08 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-09 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-10 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-11 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-12 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-13 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-14 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-15 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-16 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-17 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-18 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-19 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-20 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-21 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-22 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-23 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-24 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-25 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-26 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-27 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-28 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-29 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-11-30 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-01 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-02 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-03 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-04 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-05 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-06 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-07 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-08 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-09 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-10 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-11 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-12 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-13 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-14 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-15 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-16 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-17 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-18 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-19 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-20 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-21 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-22 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-23 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-24 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-25 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-26 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-27 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-28 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-29 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-30 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2010-12-31 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-01 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-02 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-03 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-04 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-05 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-06 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-07 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-08 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-09 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-10 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-11 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-12 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-13 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-14 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-15 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-16 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-17 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-18 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-19 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-20 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-21 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-22 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-23 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-24 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-25 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-26 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-27 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-28 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-29 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-30 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-01-31 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-01 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-02 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-03 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-04 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-05 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-06 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-07 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-08 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-09 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-10 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-11 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-12 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-13 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-14 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-15 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-16 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-17 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-18 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-19 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-20 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-21 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-22 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-23 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-24 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-25 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-26 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-27 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-02-28 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-01 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-02 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-03 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-04 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-05 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-06 00:00:00', 281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-07 00:00:00', 281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-08 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-09 00:00:00', 258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-10 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-11 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-12 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-13 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-14 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-15 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-16 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-17 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-18 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-19 00:00:00', 289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-20 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-21 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-22 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-23 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-24 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-25 00:00:00', 267, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-26 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-27 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-28 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-29 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-30 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-03-31 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-01 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-02 00:00:00', 299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-03 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-04 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-05 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-06 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-07 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-08 00:00:00', 297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-09 00:00:00', 297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-10 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-11 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-12 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-13 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-14 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-15 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-16 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-17 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-18 00:00:00', 297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-19 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-20 00:00:00', 305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-21 00:00:00', 317, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-22 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-23 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-24 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-25 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-26 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-27 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-28 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-29 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-04-30 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-01 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-02 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-03 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-04 00:00:00', 324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-05 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-06 00:00:00', 324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-07 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-08 00:00:00', 340, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-09 00:00:00', 355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-10 00:00:00', 347, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-11 00:00:00', 338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-12 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-13 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-14 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-15 00:00:00', 295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-16 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-17 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-18 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-19 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-20 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-21 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-22 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-23 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-24 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-25 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-26 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-27 00:00:00', 301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-28 00:00:00', 302, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-29 00:00:00', 301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-30 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-05-31 00:00:00', 297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-01 00:00:00', 299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-02 00:00:00', 295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-03 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-04 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-05 00:00:00', 288, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-06 00:00:00', 287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-07 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-08 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-09 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-10 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-11 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-12 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-13 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-14 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-15 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-16 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-17 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-18 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-19 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-20 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-21 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-22 00:00:00', 291, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-23 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-24 00:00:00', 293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-25 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-26 00:00:00', 295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-27 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-28 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-29 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-06-30 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-01 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-02 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-03 00:00:00', 299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-04 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-05 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-06 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-07 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-08 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-09 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-10 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-11 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-12 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-13 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-14 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-15 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-16 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-17 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-18 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-19 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-20 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-21 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-22 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-23 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-24 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-25 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-26 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-27 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-28 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-29 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-30 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-07-31 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-01 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-02 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-03 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-04 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-05 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-06 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-07 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-08 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-09 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-10 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-11 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-12 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-13 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-14 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-15 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-16 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-17 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-18 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-19 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-20 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-21 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-22 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-23 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-24 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-25 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-26 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-27 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-28 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-29 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-30 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-08-31 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-01 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-02 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-03 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-04 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-05 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-06 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-07 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-08 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-09 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-10 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-11 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-12 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-13 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-14 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-15 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-16 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-17 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-18 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-19 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-20 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-21 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-22 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-23 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-24 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-25 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-26 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-27 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-28 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-29 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-09-30 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-01 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-02 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-03 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-04 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-05 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-06 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-07 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-08 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-09 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-10 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-11 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-12 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-13 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-14 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-15 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-16 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-17 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-18 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-19 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-20 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-21 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-22 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-23 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-24 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-25 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-26 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-27 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-28 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-29 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-30 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-10-31 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-01 00:00:00', 233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-02 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-03 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-04 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-05 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-06 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-07 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-08 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-09 00:00:00', 237, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-10 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-11 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-12 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-13 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-14 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-15 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-16 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-17 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-18 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-19 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-20 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-21 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-22 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-23 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-24 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-25 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-26 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-27 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-28 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-29 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-11-30 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-01 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-02 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-03 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-04 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-05 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-06 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-07 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-08 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-09 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-10 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-11 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-12 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-13 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-14 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-15 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-16 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-17 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-18 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-19 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-20 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-21 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-22 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-23 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-24 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-25 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-26 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-27 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-28 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-29 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-30 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2011-12-31 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-01 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-02 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-03 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-04 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-05 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-06 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-07 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-08 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-09 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-10 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-11 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-12 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-13 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-14 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-15 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-16 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-17 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-18 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-19 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-20 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-21 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-22 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-23 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-24 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-25 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-26 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-27 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-28 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-29 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-30 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-01-31 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-01 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-02 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-03 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-04 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-05 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-06 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-07 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-08 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-09 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-10 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-11 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-12 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-13 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-14 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-15 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-16 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-17 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-18 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-19 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-20 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-21 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-22 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-23 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-24 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-25 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-26 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-27 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-28 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-02-29 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-01 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-02 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-03 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-04 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-05 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-06 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-07 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-08 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-09 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-10 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-11 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-12 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-13 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-14 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-15 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-16 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-17 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-18 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-19 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-20 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-21 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-22 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-23 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-24 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-25 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-26 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-27 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-28 00:00:00', 269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-29 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-30 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-03-31 00:00:00', 273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-01 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-02 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-03 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-04 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-05 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-06 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-07 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-08 00:00:00', 308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-09 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-10 00:00:00', 293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-11 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-12 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-13 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-14 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-15 00:00:00', 285, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-16 00:00:00', 285, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-17 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-18 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-19 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-20 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-21 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-22 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-23 00:00:00', 327, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-24 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-25 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-26 00:00:00', 309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-27 00:00:00', 323, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-28 00:00:00', 314, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-29 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-04-30 00:00:00', 295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-01 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-02 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-03 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-04 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-05 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-06 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-07 00:00:00', 299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-08 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-09 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-10 00:00:00', 311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-11 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-12 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-13 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-14 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-15 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-16 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-17 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-18 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-19 00:00:00', 288, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-20 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-21 00:00:00', 293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-22 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-23 00:00:00', 287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-24 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-25 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-26 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-27 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-28 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-29 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-30 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-05-31 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-01 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-02 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-03 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-04 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-05 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-06 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-07 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-08 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-09 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-10 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-11 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-12 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-13 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-14 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-15 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-16 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-17 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-18 00:00:00', 267, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-19 00:00:00', 269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-20 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-21 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-22 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-23 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-24 00:00:00', 297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-25 00:00:00', 292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-26 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-27 00:00:00', 287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-28 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-29 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-06-30 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-01 00:00:00', 237, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-02 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-03 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-04 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-05 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-06 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-07 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-08 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-09 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-10 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-11 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-12 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-13 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-14 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-15 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-16 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-17 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-18 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-19 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-20 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-21 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-22 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-23 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-24 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-25 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-26 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-27 00:00:00', 233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-28 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-29 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-30 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-07-31 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-01 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-02 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-03 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-04 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-05 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-06 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-07 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-08 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-09 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-10 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-11 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-12 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-13 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-14 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-15 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-16 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-17 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-18 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-19 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-20 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-21 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-22 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-23 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-24 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-25 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-26 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-27 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-28 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-29 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-30 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-08-31 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-01 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-02 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-03 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-04 00:00:00', 201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-05 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-06 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-07 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-08 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-09 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-10 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-11 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-12 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-13 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-14 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-15 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-16 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-17 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-18 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-19 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-20 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-21 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-22 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-23 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-24 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-25 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-26 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-27 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-28 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-29 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-09-30 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-01 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-02 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-03 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-04 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-05 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-06 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-07 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-08 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-09 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-10 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-11 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-12 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-13 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-14 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-15 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-16 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-17 00:00:00', 176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-18 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-19 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-20 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-21 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-22 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-23 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-24 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-25 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-26 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-27 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-28 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-29 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-30 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-10-31 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-01 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-02 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-03 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-04 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-05 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-06 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-07 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-08 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-09 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-10 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-11 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-12 00:00:00', 176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-13 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-14 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-15 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-16 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-17 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-18 00:00:00', 178, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-19 00:00:00', 179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-20 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-21 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-22 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-23 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-24 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-25 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-26 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-27 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-28 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-29 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-11-30 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-01 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-02 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-03 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-04 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-05 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-06 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-07 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-08 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-09 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-10 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-11 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-12 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-13 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-14 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-15 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-16 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-17 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-18 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-19 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-20 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-21 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-22 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-23 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-24 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-25 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-26 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-27 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-28 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-29 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-30 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2008-12-31 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-01 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-02 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-03 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-04 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-05 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-06 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-07 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-08 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-09 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-10 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-11 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-12 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-13 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-14 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-15 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-16 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-17 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-18 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-19 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-20 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-21 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-22 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-23 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-24 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-25 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-26 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-27 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-28 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-29 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-30 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-01-31 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-01 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-02 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-03 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-04 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-05 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-06 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-07 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-08 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-09 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-10 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-11 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-12 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-13 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-14 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-15 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-16 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-17 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-18 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-19 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-20 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-21 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-22 00:00:00', 259, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-23 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-24 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-25 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-26 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-27 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-28 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-02-29 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-01 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-02 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-03 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-04 00:00:00', 237, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-05 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-06 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-07 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-08 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-09 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-10 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-11 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-12 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-13 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-14 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-15 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-16 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-17 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-18 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-19 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-20 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-21 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-22 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-23 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-24 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-25 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-26 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-27 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-28 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-29 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-30 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-03-31 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-01 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-02 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-03 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-04 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-05 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-06 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-07 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-08 00:00:00', 258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-09 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-10 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-11 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-12 00:00:00', 259, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-13 00:00:00', 258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-14 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-15 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-16 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-17 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-18 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-19 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-20 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-21 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-22 00:00:00', 258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-23 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-24 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-25 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-26 00:00:00', 259, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-27 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-28 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-29 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-04-30 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-01 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-02 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-03 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-04 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-05 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-06 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-07 00:00:00', 258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-08 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-09 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-10 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-11 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-12 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-13 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-14 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-15 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-16 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-17 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-18 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-19 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-20 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-21 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-22 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-23 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-24 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-25 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-26 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-27 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-28 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-29 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-30 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-05-31 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-01 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-02 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-03 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-04 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-05 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-06 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-07 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-08 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-09 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-10 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-11 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-12 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-13 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-14 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-15 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-16 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-17 00:00:00', 260, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-18 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-19 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-20 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-21 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-22 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-23 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-24 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-25 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-26 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-27 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-28 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-29 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-06-30 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-01 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-02 00:00:00', 199, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-03 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-04 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-05 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-06 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-07 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-08 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-09 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-10 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-11 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-12 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-13 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-14 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-15 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-16 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-17 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-18 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-19 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-20 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-21 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-22 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-23 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-24 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-25 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-26 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-27 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-28 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-29 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-30 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-07-31 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-01 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-02 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-03 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-04 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-05 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-06 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-07 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-08 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-09 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-10 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-11 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-12 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-13 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-14 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-15 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-16 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-17 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-18 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-19 00:00:00', 183, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-20 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-21 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-22 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-23 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-24 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-25 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-26 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-27 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-28 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-29 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-30 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-08-31 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-01 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-02 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-03 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-04 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-05 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-06 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-07 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-08 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-09 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-10 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-11 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-12 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-13 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-14 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-15 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-16 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-17 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-18 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-19 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-20 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-21 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-22 00:00:00', 179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-23 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-24 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-25 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-26 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-27 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-28 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-29 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-09-30 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-01 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-02 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-03 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-04 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-05 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-06 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-07 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-08 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-09 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-10 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-11 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-12 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-13 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-14 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-15 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-16 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-17 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-18 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-19 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-20 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-21 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-22 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-23 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-24 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-25 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-26 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-27 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-28 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-29 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-30 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-10-31 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-01 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-02 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-03 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-04 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-05 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-06 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-07 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-08 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-09 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-10 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-11 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-12 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-13 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-14 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-15 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-16 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-17 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-18 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-19 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-20 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-21 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-22 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-23 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-24 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-25 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-26 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-27 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-28 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-29 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-11-30 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-01 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-02 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-03 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-04 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-05 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-06 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-07 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-08 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-09 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-10 00:00:00', 233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-11 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-12 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-13 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-14 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-15 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-16 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-17 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-18 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-19 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-20 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-21 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-22 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-23 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-24 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-25 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-26 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-27 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-28 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-29 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-30 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2012-12-31 00:00:00', 249, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-01 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-02 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-03 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-04 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-05 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-06 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-07 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-08 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-09 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-10 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-11 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-12 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-13 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-14 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-15 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-16 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-17 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-18 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-19 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-20 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-21 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-22 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-23 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-24 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-25 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-26 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-27 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-28 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-29 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-30 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-01-31 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-01 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-02 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-03 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-04 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-05 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-06 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-07 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-08 00:00:00', 209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-09 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-10 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-11 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-12 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-13 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-14 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-15 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-16 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-17 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-18 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-19 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-20 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-21 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-22 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-23 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-24 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-25 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-26 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-27 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-02-28 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-01 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-02 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-03 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-04 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-05 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-06 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-07 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-08 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-09 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-10 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-11 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-12 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-13 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-14 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-15 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-16 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-17 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-18 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-19 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-20 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-21 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-22 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-23 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-24 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-25 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-26 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-27 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-28 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-29 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-30 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-03-31 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-01 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-02 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-03 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-04 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-05 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-06 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-07 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-08 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-09 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-10 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-11 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-12 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-13 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-14 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-15 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-16 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-17 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-18 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-19 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-20 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-21 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-22 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-23 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-24 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-25 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-26 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-27 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-28 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-29 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-04-30 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-01 00:00:00', 290, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-02 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-03 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-04 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-05 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-06 00:00:00', 349, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-07 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-08 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-09 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-10 00:00:00', 294, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-11 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-12 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-13 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-14 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-15 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-16 00:00:00', 283, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-17 00:00:00', 295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-18 00:00:00', 295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-19 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-20 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-21 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-22 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-23 00:00:00', 251, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-24 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-25 00:00:00', 236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-26 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-27 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-28 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-29 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-30 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-05-31 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-01 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-02 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-03 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-04 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-05 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-06 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-07 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-08 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-09 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-10 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-11 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-12 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-13 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-14 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-15 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-16 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-17 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-18 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-19 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-20 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-21 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-22 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-23 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-24 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-25 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-26 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-27 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-28 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-29 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-06-30 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-01 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-02 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-03 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-04 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-05 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-06 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-07 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-08 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-09 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-10 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-11 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-12 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-13 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-14 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-15 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-16 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-17 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-18 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-19 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-20 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-21 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-22 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-23 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-24 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-25 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-26 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-27 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-28 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-29 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-30 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-07-31 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-01 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-02 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-03 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-04 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-05 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-06 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-07 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-08 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-09 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-10 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-11 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-12 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-13 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-14 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-15 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-16 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-17 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-18 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-19 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-20 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-21 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-22 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-23 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-24 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-25 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-26 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-27 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-28 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-29 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-30 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-08-31 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-01 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-02 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-03 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-04 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-05 00:00:00', 191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-06 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-07 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-08 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-09 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-10 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-11 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-12 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-13 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-14 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-15 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-16 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-17 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-18 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-19 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-20 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-21 00:00:00', 189, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-22 00:00:00', 188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-23 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-24 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-25 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-26 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-27 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-28 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-29 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-09-30 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-01 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-02 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-03 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-04 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-05 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-06 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-07 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-08 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-09 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-10 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-11 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-12 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-13 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-14 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-15 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-16 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-17 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-18 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-19 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-20 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-21 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-22 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-23 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-24 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-25 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-26 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-27 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-28 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-29 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-30 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-10-31 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-01 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-02 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-03 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-04 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-05 00:00:00', 233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-06 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-07 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-08 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-09 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-10 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-11 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-12 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-13 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-14 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-15 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-16 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-17 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-18 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-19 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-20 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-21 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-22 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-23 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-24 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-25 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-26 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-27 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-28 00:00:00', 281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-29 00:00:00', 280, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-11-30 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-01 00:00:00', 274, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-02 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-03 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-04 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-05 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-06 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-07 00:00:00', 271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-08 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-09 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-10 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-11 00:00:00', 261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-12 00:00:00', 259, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-13 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-14 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-15 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-16 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-17 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-18 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-19 00:00:00', 237, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-20 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-21 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-22 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-23 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-24 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-25 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-26 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-27 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-28 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-29 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-30 00:00:00', 248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2009-12-31 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-07 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-08 00:00:00', 18.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-10 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-11 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-12 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-13 00:00:00', 0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-14 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-15 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-16 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-17 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-18 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-23 00:00:00', 4.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-24 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-25 00:00:00', 25.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-26 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-30 00:00:00', 0.107000000774860382, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-04 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-05 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-06 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-08 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-09 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-10 00:00:00', 7.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-12 00:00:00', 14.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-13 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-17 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-18 00:00:00', 12.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-19 00:00:00', 5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-21 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-22 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-23 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-24 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-25 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-27 00:00:00', 15.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-02-28 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-01 00:00:00', 7.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-02 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-03 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-04 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-05 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-06 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-10 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-11 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-13 00:00:00', 7.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-14 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-16 00:00:00', 5.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-21 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-22 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-23 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-24 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-25 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-26 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-28 00:00:00', 8.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-29 00:00:00', 4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-30 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-03-31 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-01 00:00:00', 13.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-02 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-03 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-04 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-05 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-06 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-07 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-12 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-13 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-14 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-15 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-16 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-17 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-18 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-20 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-22 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-27 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-29 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-04-30 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-01 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-04 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-05 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-06 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-07 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-11 00:00:00', 9.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-12 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-13 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-14 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-15 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-16 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-17 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-18 00:00:00', 7.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-19 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-20 00:00:00', 5.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-24 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-05-31 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-01-05 00:00:00', 181.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-01-15 00:00:00', 189.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-01-25 00:00:00', 188.550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-02-05 00:00:00', 191.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-02-15 00:00:00', 194.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-02-25 00:00:00', 194.55999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-03-05 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-03-15 00:00:00', 192.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-03-25 00:00:00', 197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-04-05 00:00:00', 203.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-04-15 00:00:00', 199.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-04-25 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-05-05 00:00:00', 199.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-05-15 00:00:00', 195.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-05-25 00:00:00', 196.360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-06-05 00:00:00', 194.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-06-15 00:00:00', 194.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-06-25 00:00:00', 197.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-07-05 00:00:00', 192.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-07-15 00:00:00', 187.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-07-25 00:00:00', 181.729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-08-05 00:00:00', 172.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-08-15 00:00:00', 165.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-08-25 00:00:00', 166.360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-09-05 00:00:00', 165.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-09-15 00:00:00', 159.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-09-25 00:00:00', 159.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-10-05 00:00:00', 161.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-10-15 00:00:00', 159.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-10-25 00:00:00', 151.910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-11-05 00:00:00', 145.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-11-15 00:00:00', 145.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-11-25 00:00:00', 153.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-12-05 00:00:00', 154.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-12-15 00:00:00', 151.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2008-12-25 00:00:00', 152.639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-01-05 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-01-15 00:00:00', 145.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-01-25 00:00:00', 147.82000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-02-05 00:00:00', 150.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-02-15 00:00:00', 158.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-03-05 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-03-15 00:00:00', 166.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-03-25 00:00:00', 171.360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-04-05 00:00:00', 164.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-04-15 00:00:00', 173.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-04-25 00:00:00', 194.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-05-05 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-05-15 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-05-25 00:00:00', 187.17999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-06-05 00:00:00', 168.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-06-15 00:00:00', 173.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-06-25 00:00:00', 161.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-07-05 00:00:00', 146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-07-15 00:00:00', 138.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-07-25 00:00:00', 135.17999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-08-05 00:00:00', 140.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-08-15 00:00:00', 135.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-08-25 00:00:00', 142.270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-09-05 00:00:00', 145.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-09-15 00:00:00', 142.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-09-25 00:00:00', 148.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-10-05 00:00:00', 150, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-10-15 00:00:00', 151.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-10-25 00:00:00', 154.449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-11-05 00:00:00', 166.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-11-15 00:00:00', 173.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-11-25 00:00:00', 178.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-12-05 00:00:00', 185.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-12-15 00:00:00', 178.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-12-25 00:00:00', 174.360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2009-02-25 00:00:00', 166.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-01-05 00:00:00', 160.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-01-15 00:00:00', 160.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-01-25 00:00:00', 160, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-02-05 00:00:00', 171.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-02-15 00:00:00', 168.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-02-25 00:00:00', 180.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-03-05 00:00:00', 184.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-03-15 00:00:00', 175.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-03-25 00:00:00', 193.17999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-04-05 00:00:00', 178.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-04-15 00:00:00', 232.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-04-25 00:00:00', 206.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-05-05 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-05-15 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-05-25 00:00:00', 233.360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-06-05 00:00:00', 227.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-06-15 00:00:00', 221.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-06-25 00:00:00', 223.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-07-05 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-07-15 00:00:00', 190.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-07-25 00:00:00', 187.089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-04 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-05 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-08-05 00:00:00', 164.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-08-15 00:00:00', 155.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-08-25 00:00:00', 149.089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-09-05 00:00:00', 149.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-09-15 00:00:00', 154.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-09-25 00:00:00', 161.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-10-05 00:00:00', 167.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-10-15 00:00:00', 163.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-10-25 00:00:00', 163.639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-11-05 00:00:00', 165.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-11-15 00:00:00', 163.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-11-25 00:00:00', 165.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-12-05 00:00:00', 157.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-12-15 00:00:00', 155.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2010-12-25 00:00:00', 152.910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-01-05 00:00:00', 142.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-01-15 00:00:00', 138.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-01-25 00:00:00', 137.449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-02-05 00:00:00', 144.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-02-15 00:00:00', 149.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-02-25 00:00:00', 160.6300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-03-05 00:00:00', 168.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-03-15 00:00:00', 162.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-03-25 00:00:00', 168.729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-04-05 00:00:00', 197.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-04-15 00:00:00', 216.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-04-25 00:00:00', 215.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-05-05 00:00:00', 231.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-05-15 00:00:00', 217.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-05-25 00:00:00', 227.82000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-06-05 00:00:00', 222.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-06-15 00:00:00', 218.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-06-25 00:00:00', 223.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-07-05 00:00:00', 192.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-07-15 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-07-25 00:00:00', 180.270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-08-05 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-08-15 00:00:00', 136.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-08-25 00:00:00', 127.730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-09-05 00:00:00', 124.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-09-15 00:00:00', 141.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-09-25 00:00:00', 141.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-10-05 00:00:00', 146.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-10-15 00:00:00', 149.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-10-25 00:00:00', 151.910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-11-05 00:00:00', 153.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-11-15 00:00:00', 154.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-11-25 00:00:00', 152.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-12-05 00:00:00', 164.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-12-15 00:00:00', 164.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2011-12-25 00:00:00', 162.089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-01-05 00:00:00', 172.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-01-15 00:00:00', 168.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-01-25 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-02-05 00:00:00', 162.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-02-15 00:00:00', 167.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-02-25 00:00:00', 167.55999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-03-05 00:00:00', 173.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-03-15 00:00:00', 170.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-03-25 00:00:00', 156.449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-04-05 00:00:00', 151.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-04-15 00:00:00', 163.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-04-25 00:00:00', 162.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-05-05 00:00:00', 189.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-05-15 00:00:00', 181, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-05-25 00:00:00', 182.639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-06-05 00:00:00', 180.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-06-15 00:00:00', 185.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-06-25 00:00:00', 152.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-07-05 00:00:00', 136.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-07-15 00:00:00', 133.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-07-25 00:00:00', 140.729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-08-05 00:00:00', 136.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-08-15 00:00:00', 139.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-08-25 00:00:00', 138.270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-09-05 00:00:00', 126.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-09-15 00:00:00', 129.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-09-25 00:00:00', 120.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-10-05 00:00:00', 124.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-10-15 00:00:00', 123.900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-10-25 00:00:00', 134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-11-05 00:00:00', 139, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-11-15 00:00:00', 141.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-11-25 00:00:00', 139.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-12-05 00:00:00', 140, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-12-15 00:00:00', 141.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2012-12-25 00:00:00', 142.82000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-01-05 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-01-15 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-01-25 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-02-05 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-02-15 00:00:00', 162, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-02-25 00:00:00', 203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-03-05 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-03-15 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-03-25 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-04-05 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-04-15 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-04-25 00:00:00', 173, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-05-05 00:00:00', 177, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-05-15 00:00:00', 177, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-05-25 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-06-05 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-06-15 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-06-25 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-07-05 00:00:00', 185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-07-15 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-07-25 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-08-05 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-08-15 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-08-25 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-09-05 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-09-15 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-09-25 00:00:00', 165, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-10-05 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-10-15 00:00:00', 180, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-10-25 00:00:00', 176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-11-05 00:00:00', 173, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-11-15 00:00:00', 176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-11-25 00:00:00', 174, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-12-05 00:00:00', 167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-12-15 00:00:00', 173, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2008-12-25 00:00:00', 171, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-01-05 00:00:00', 166.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-01-15 00:00:00', 168, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-01-25 00:00:00', 171.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-02-05 00:00:00', 172.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-02-15 00:00:00', 171.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-02-25 00:00:00', 172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-03-05 00:00:00', 170.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-03-15 00:00:00', 180.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-03-25 00:00:00', 184.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-04-05 00:00:00', 185.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-04-15 00:00:00', 231, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-04-25 00:00:00', 277.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-05-05 00:00:00', 329, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-05-15 00:00:00', 300.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-05-25 00:00:00', 305.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-06-05 00:00:00', 325.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-06-15 00:00:00', 297.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-06-25 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-07-05 00:00:00', 205.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-07-15 00:00:00', 136, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-07-25 00:00:00', 136, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-08-05 00:00:00', 137.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-08-15 00:00:00', 133.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-08-25 00:00:00', 136, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-09-05 00:00:00', 133.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-09-15 00:00:00', 134.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-09-25 00:00:00', 138, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-10-05 00:00:00', 133.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-10-15 00:00:00', 129.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-10-25 00:00:00', 136.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-11-05 00:00:00', 132.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-11-15 00:00:00', 137.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-11-25 00:00:00', 135.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-12-05 00:00:00', 127, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-12-15 00:00:00', 126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2009-12-25 00:00:00', 127.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-01-05 00:00:00', 128, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-01-15 00:00:00', 127.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-01-25 00:00:00', 127.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-02-05 00:00:00', 123.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-02-15 00:00:00', 120.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-02-25 00:00:00', 123.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-03-05 00:00:00', 203.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-03-15 00:00:00', 201.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-03-25 00:00:00', 190.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-04-05 00:00:00', 199.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-04-15 00:00:00', 236.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-04-25 00:00:00', 225.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-05-05 00:00:00', 257.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-05-15 00:00:00', 280.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-05-25 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-06-05 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-06-15 00:00:00', 179.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-06-25 00:00:00', 195.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-07-05 00:00:00', 145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-07-15 00:00:00', 133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-07-25 00:00:00', 136.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-08-05 00:00:00', 141.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-08-15 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-08-25 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-09-05 00:00:00', 153, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-09-15 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-09-25 00:00:00', 148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-10-05 00:00:00', 134.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-10-15 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-10-25 00:00:00', 124.099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-11-05 00:00:00', 122.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-11-15 00:00:00', 131.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-11-25 00:00:00', 119.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-12-05 00:00:00', 120.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-12-15 00:00:00', 123.099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2010-12-25 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-01-05 00:00:00', 116.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-01-15 00:00:00', 116, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-01-25 00:00:00', 120.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-02-05 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-02-15 00:00:00', 129.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-02-25 00:00:00', 130, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-03-05 00:00:00', 130, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-03-15 00:00:00', 122.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-03-25 00:00:00', 117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-04-05 00:00:00', 111.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-04-15 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-04-25 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-05-05 00:00:00', 106.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-05-15 00:00:00', 112.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-05-25 00:00:00', 113.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-06-05 00:00:00', 102.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-06-15 00:00:00', 119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-06-25 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-07-05 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-07-15 00:00:00', 121.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-07-25 00:00:00', 120, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-08-05 00:00:00', 120, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-08-15 00:00:00', 113.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-08-25 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-09-05 00:00:00', 120.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-09-15 00:00:00', 120, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-09-25 00:00:00', 117.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-10-05 00:00:00', 115.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-10-15 00:00:00', 119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-10-25 00:00:00', 121.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-11-05 00:00:00', 127.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-11-15 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-11-25 00:00:00', 135.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-12-05 00:00:00', 136, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-12-15 00:00:00', 167.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2011-12-25 00:00:00', 174.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-01-05 00:00:00', 175, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-01-15 00:00:00', 180.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-01-25 00:00:00', 212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-02-05 00:00:00', 191.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-02-15 00:00:00', 190, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-02-25 00:00:00', 174.669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-03-05 00:00:00', 179.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-03-15 00:00:00', 167.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-03-25 00:00:00', 167.82000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-04-05 00:00:00', 224.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-04-15 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-04-25 00:00:00', 277.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-05-05 00:00:00', 201.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-05-15 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-05-25 00:00:00', 204.82000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-06-05 00:00:00', 234.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-06-15 00:00:00', 182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-06-25 00:00:00', 205.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-07-05 00:00:00', 125.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-07-15 00:00:00', 108.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-07-25 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-08-05 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-08-15 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-08-25 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-09-05 00:00:00', 99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-09-15 00:00:00', 106.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-09-25 00:00:00', 106.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-10-05 00:00:00', 102.900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-10-15 00:00:00', 101.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-10-25 00:00:00', 99.089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-11-05 00:00:00', 99.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-11-15 00:00:00', 96.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-11-25 00:00:00', 93.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-12-05 00:00:00', 87.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-12-15 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2012-12-25 00:00:00', 81, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-01-05 00:00:00', 338.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-01-15 00:00:00', 354.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-01-25 00:00:00', 387.6400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-02-05 00:00:00', 406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-02-15 00:00:00', 411.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-02-25 00:00:00', 381.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-03-05 00:00:00', 378.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-03-15 00:00:00', 343.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-03-25 00:00:00', 337.45001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-04-05 00:00:00', 403.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-04-15 00:00:00', 411.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-04-25 00:00:00', 461.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-05-05 00:00:00', 423, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-05-15 00:00:00', 415.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-05-25 00:00:00', 435.910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-06-05 00:00:00', 450, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-06-15 00:00:00', 420.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-06-25 00:00:00', 437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-07-05 00:00:00', 350.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-07-15 00:00:00', 315.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-07-25 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-08-05 00:00:00', 310.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-08-15 00:00:00', 310.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-08-25 00:00:00', 330.269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-09-05 00:00:00', 316.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-09-15 00:00:00', 316.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-09-25 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-10-05 00:00:00', 324.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-10-15 00:00:00', 325.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-10-25 00:00:00', 323.3599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-11-05 00:00:00', 327.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-11-15 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-11-25 00:00:00', 339.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-12-05 00:00:00', 335.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-12-15 00:00:00', 335.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2008-12-25 00:00:00', 333.17999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-01-05 00:00:00', 367.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-01-15 00:00:00', 364.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-01-25 00:00:00', 362.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-02-05 00:00:00', 358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-02-15 00:00:00', 347.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-02-25 00:00:00', 347.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-03-05 00:00:00', 336.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-03-15 00:00:00', 325.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-03-25 00:00:00', 328.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-04-05 00:00:00', 353.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-04-15 00:00:00', 363.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-04-25 00:00:00', 384.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-05-05 00:00:00', 443.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-05-15 00:00:00', 428.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-05-25 00:00:00', 437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-06-05 00:00:00', 442.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-06-15 00:00:00', 437.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-06-25 00:00:00', 443.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-07-05 00:00:00', 427.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-07-15 00:00:00', 345.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-07-25 00:00:00', 337.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-08-05 00:00:00', 337.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-08-15 00:00:00', 338.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-08-25 00:00:00', 341.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-09-05 00:00:00', 337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-09-15 00:00:00', 329.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-09-25 00:00:00', 332.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-10-05 00:00:00', 337.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-10-15 00:00:00', 350.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-10-25 00:00:00', 350.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-11-05 00:00:00', 342.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-11-15 00:00:00', 350.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-11-25 00:00:00', 361.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-12-05 00:00:00', 363.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-12-15 00:00:00', 360.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2009-12-25 00:00:00', 358.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-01-05 00:00:00', 362.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-01-15 00:00:00', 377.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-01-25 00:00:00', 365.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-02-05 00:00:00', 364.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-02-15 00:00:00', 383.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-02-25 00:00:00', 384.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-03-05 00:00:00', 412.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-03-15 00:00:00', 358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-03-25 00:00:00', 343.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-04-05 00:00:00', 330.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-04-15 00:00:00', 378.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-04-25 00:00:00', 401.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-05-05 00:00:00', 440.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-05-15 00:00:00', 462, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-05-25 00:00:00', 470.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-06-05 00:00:00', 470.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-06-15 00:00:00', 369.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-06-25 00:00:00', 381.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-07-05 00:00:00', 336.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-07-15 00:00:00', 329.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-07-25 00:00:00', 323.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-08-05 00:00:00', 331.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-08-15 00:00:00', 335.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-08-25 00:00:00', 332.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-09-05 00:00:00', 333.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-09-15 00:00:00', 337.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-09-25 00:00:00', 344.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-10-05 00:00:00', 344.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-10-15 00:00:00', 337.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-10-25 00:00:00', 343.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-11-05 00:00:00', 355.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-11-15 00:00:00', 354.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-11-25 00:00:00', 360.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-12-05 00:00:00', 351.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-12-15 00:00:00', 352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2010-12-25 00:00:00', 358.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-01-05 00:00:00', 358.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-01-15 00:00:00', 363.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-01-25 00:00:00', 377.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-02-05 00:00:00', 378.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-02-15 00:00:00', 366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-02-25 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-03-05 00:00:00', 334.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-03-15 00:00:00', 347.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-03-25 00:00:00', 349.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-04-05 00:00:00', 348.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-04-15 00:00:00', 338.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-04-25 00:00:00', 336.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-05-05 00:00:00', 340.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-05-15 00:00:00', 344.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-05-25 00:00:00', 336.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-06-05 00:00:00', 333.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-06-15 00:00:00', 336.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-06-25 00:00:00', 341.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-07-05 00:00:00', 332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-07-15 00:00:00', 337.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-07-25 00:00:00', 340.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-08-05 00:00:00', 340.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-08-15 00:00:00', 341.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-08-25 00:00:00', 340.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-09-05 00:00:00', 339.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-09-15 00:00:00', 338.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-09-25 00:00:00', 342.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-10-05 00:00:00', 344.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-10-15 00:00:00', 351.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-10-25 00:00:00', 353.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-11-05 00:00:00', 354, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-11-15 00:00:00', 358.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-11-25 00:00:00', 365, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-12-05 00:00:00', 356, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-12-15 00:00:00', 352.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2011-12-25 00:00:00', 343.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-01-05 00:00:00', 338.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-01-15 00:00:00', 354.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-01-25 00:00:00', 387.6400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-02-05 00:00:00', 406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-02-15 00:00:00', 411.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-02-25 00:00:00', 381.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-03-05 00:00:00', 378.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-03-15 00:00:00', 343.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-03-25 00:00:00', 337.45001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-04-05 00:00:00', 403.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-04-15 00:00:00', 411.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-04-25 00:00:00', 461.20001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-05-05 00:00:00', 423, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-05-15 00:00:00', 415.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-05-25 00:00:00', 435.910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-06-05 00:00:00', 450, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-06-15 00:00:00', 420.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-06-25 00:00:00', 437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-07-05 00:00:00', 350.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-07-15 00:00:00', 315.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-07-25 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-08-05 00:00:00', 310.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-08-15 00:00:00', 310.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-08-25 00:00:00', 330.269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-09-05 00:00:00', 316.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-09-15 00:00:00', 316.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-09-25 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-10-05 00:00:00', 324.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-10-15 00:00:00', 325.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-10-25 00:00:00', 323.3599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-11-05 00:00:00', 327.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-11-15 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-11-25 00:00:00', 339.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-12-05 00:00:00', 335.29998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-12-15 00:00:00', 335.79998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2012-12-25 00:00:00', 333.17999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-01-05 00:00:00', 41.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-01-15 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-01-25 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-02-05 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-02-15 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-02-25 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-03-05 00:00:00', 43.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-03-15 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-03-25 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-04-05 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-04-15 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-04-25 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-05-05 00:00:00', 91.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-05-15 00:00:00', 75.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-05-25 00:00:00', 86.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-06-05 00:00:00', 69.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-06-15 00:00:00', 80.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-06-25 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-07-05 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-07-15 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-07-25 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-08-05 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-08-15 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-08-25 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-09-05 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-09-15 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-09-25 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-10-05 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-10-15 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-10-25 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-11-05 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-11-15 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-11-25 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-12-05 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-12-15 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2008-12-25 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-01-05 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-01-15 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-01-25 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-02-05 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-02-15 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-02-25 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-03-05 00:00:00', 43.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-03-15 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-03-25 00:00:00', 48.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-04-05 00:00:00', 88.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-04-15 00:00:00', 151.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-04-25 00:00:00', 152.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-05-05 00:00:00', 211.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-05-15 00:00:00', 157.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-05-25 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-06-05 00:00:00', 162.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-06-15 00:00:00', 159.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-06-25 00:00:00', 175.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-07-05 00:00:00', 103.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-07-15 00:00:00', 70.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-07-25 00:00:00', 69.6999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-08-05 00:00:00', 47.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-08-15 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-08-25 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-09-05 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-09-15 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-09-25 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-10-05 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-10-15 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-10-25 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-11-05 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-11-15 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-11-25 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-12-05 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-12-15 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2009-12-25 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-01-05 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-01-15 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-01-25 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-02-05 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-02-15 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-02-25 00:00:00', 64, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-03-05 00:00:00', 59.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-03-15 00:00:00', 56.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-03-25 00:00:00', 93.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-04-05 00:00:00', 66.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-04-15 00:00:00', 198.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-04-25 00:00:00', 121.900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-05-05 00:00:00', 190.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-05-15 00:00:00', 251.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-05-25 00:00:00', 205.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-06-05 00:00:00', 190.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-06-15 00:00:00', 158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-06-25 00:00:00', 161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-07-05 00:00:00', 130.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-07-15 00:00:00', 89.3000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-07-25 00:00:00', 73.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-08-05 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-08-15 00:00:00', 26.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-08-25 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-09-05 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-09-15 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-09-25 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-10-05 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-10-15 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-10-25 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-11-05 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-11-15 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-11-25 00:00:00', 33.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-12-05 00:00:00', 25.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-12-15 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2010-12-25 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-01-05 00:00:00', 48.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-01-15 00:00:00', 57.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-01-25 00:00:00', 55.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-02-05 00:00:00', 56.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-02-15 00:00:00', 58.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-02-25 00:00:00', 59.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-03-05 00:00:00', 58.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-03-15 00:00:00', 57, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-03-25 00:00:00', 62.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-04-05 00:00:00', 74.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-04-15 00:00:00', 67.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-04-25 00:00:00', 81.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-05-05 00:00:00', 66.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-05-15 00:00:00', 118.129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-05-25 00:00:00', 125.360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-06-05 00:00:00', 130.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-06-15 00:00:00', 142.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-06-25 00:00:00', 148.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-07-05 00:00:00', 141.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-07-15 00:00:00', 131.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-07-25 00:00:00', 134.270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-08-05 00:00:00', 127.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-08-15 00:00:00', 94.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-08-25 00:00:00', 99.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-09-05 00:00:00', 98.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-09-15 00:00:00', 58.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-09-25 00:00:00', 58.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-10-05 00:00:00', 66.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-10-15 00:00:00', 59.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-10-25 00:00:00', 36.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-11-05 00:00:00', 25.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-11-15 00:00:00', 26.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-11-25 00:00:00', 40.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-12-05 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-12-15 00:00:00', 34.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2012-12-25 00:00:00', 37.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-01-05 00:00:00', 19.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-01-15 00:00:00', 15.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-01-25 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-02-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-02-15 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-02-25 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-03-05 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-03-15 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-03-25 00:00:00', 45.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-04-05 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-04-15 00:00:00', 50.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-04-25 00:00:00', 95.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-05-05 00:00:00', 208.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-05-15 00:00:00', 140.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-05-25 00:00:00', 77.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-06-05 00:00:00', 41.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-06-15 00:00:00', 50.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-06-25 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-07-05 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-07-15 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-07-25 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-08-05 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-08-15 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-08-25 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-09-05 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-09-15 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-09-25 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-10-05 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-10-15 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-10-25 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-11-05 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-11-15 00:00:00', 40.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-11-25 00:00:00', 49.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-12-05 00:00:00', 52.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-12-15 00:00:00', 46.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (4, '2011-12-25 00:00:00', 42.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-01-05 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-01-15 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-01-25 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-02-05 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-02-15 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-02-25 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-03-05 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-03-15 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-03-25 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-04-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-04-15 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-04-25 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-05-05 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-05-15 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-05-25 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-06-05 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-06-15 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-06-25 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-07-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-07-15 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-07-25 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-08-05 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-08-15 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-08-25 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-09-05 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-09-15 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-09-25 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-10-05 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-10-15 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-10-25 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-11-05 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-11-15 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-11-25 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-12-05 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-12-15 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2008-12-25 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-01-05 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-01-15 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-01-25 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-02-05 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-02-15 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-02-25 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-03-05 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-03-15 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-03-25 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-04-05 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-04-15 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-04-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-05-05 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-05-15 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-05-25 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-06-05 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-06-15 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-06-25 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-07-05 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-07-15 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-07-25 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-08-05 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-08-15 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-08-25 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-09-05 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-09-15 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-09-25 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-10-05 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-10-15 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-10-25 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-11-05 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-11-15 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-11-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-12-05 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-12-15 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2009-12-25 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-01-05 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-01-15 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-01-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-02-05 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-02-15 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-02-25 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-03-05 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-03-15 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-03-25 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-04-05 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-04-15 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-04-25 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-05-05 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-05-15 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-05-25 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-06-05 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-06-15 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-06-25 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-07-05 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-07-15 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-07-25 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-08-05 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-08-15 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-08-25 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-09-05 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-09-15 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-09-25 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-10-05 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-10-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-10-25 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-11-05 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-11-15 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-11-25 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-12-05 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-12-15 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2010-12-25 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-01-05 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-01-15 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-01-25 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-02-05 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-02-15 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-02-25 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-03-05 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-03-15 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-03-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-04-05 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-04-15 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-04-25 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-05-05 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-05-15 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-05-25 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-06-05 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-06-15 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-06-25 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-07-05 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-07-15 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-07-25 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-08-05 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-08-15 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-08-25 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-09-05 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-09-15 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-09-25 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-10-05 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-10-15 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-10-25 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-11-05 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-11-15 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-11-25 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-12-05 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-12-15 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2011-12-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-04-05 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-01-05 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-01-15 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-01-25 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-02-05 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-02-15 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-02-25 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-03-05 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-03-15 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-03-25 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-04-15 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-04-25 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-05-05 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-05-15 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-05-25 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-06-05 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-06-15 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-06-25 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-07-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-07-15 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-07-25 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-08-05 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-08-15 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-08-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-09-05 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-09-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-09-25 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-10-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-10-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-10-25 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-11-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-11-15 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-11-25 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-12-05 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-12-15 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2012-12-25 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-01-05 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-01-15 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-01-25 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-02-05 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-02-15 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-02-25 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-03-05 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-03-15 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-03-25 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-04-05 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-04-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-04-25 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-05-05 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-05-15 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-05-25 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-06-05 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-06-15 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-06-25 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-07-05 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-07-15 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-07-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-08-05 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-08-15 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-08-25 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-09-05 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-09-15 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-09-25 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-10-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-10-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-10-25 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-11-05 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-11-15 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-11-25 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-12-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-12-15 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2008-12-25 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-01-05 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-01-15 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-01-25 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-02-05 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-02-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-02-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-03-05 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-03-15 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-03-25 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-04-05 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-04-15 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-04-25 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-05-05 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-05-15 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-05-25 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-06-05 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-06-15 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-06-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-07-05 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-07-15 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-07-25 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-08-05 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-08-15 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-08-25 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-09-05 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-09-15 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-09-25 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-10-05 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-10-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-10-25 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-11-05 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-11-15 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-11-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-12-05 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-12-15 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-13 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2009-12-25 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-01-05 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-01-15 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-01-25 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-02-05 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-02-15 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-02-25 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-03-05 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-03-15 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-03-25 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-04-05 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-04-15 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-04-25 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-05-05 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-05-15 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-05-25 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-06-05 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-06-15 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-06-25 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-07-05 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-07-15 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-07-25 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-08-05 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-08-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-08-25 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-09-05 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-09-15 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-09-25 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-10-05 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-10-15 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-10-25 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-11-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-11-15 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-11-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-12-05 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-12-15 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2010-12-25 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-01-05 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-01-15 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-01-25 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-02-05 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-02-15 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-02-25 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-03-05 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-03-15 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-03-25 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-04-05 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-04-15 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-04-25 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-05-05 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-05-15 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-05-25 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-06-05 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-06-15 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-06-25 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-07-05 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-07-15 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-07-25 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-08-05 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-08-15 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-08-25 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-09-05 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-09-15 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-09-25 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-10-05 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-10-15 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-10-25 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-11-05 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-11-15 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-11-25 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-12-05 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-12-15 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2011-12-25 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-20 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-21 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-01-05 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-01-15 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-01-25 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-02-05 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-02-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-02-25 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-03-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-03-15 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-03-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-04-05 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-04-15 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-04-25 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-05-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-05-15 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-05-25 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-06-05 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-06-15 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-06-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-07-05 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-07-15 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-07-25 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-08-05 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-08-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-08-25 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-09-05 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-09-15 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-09-25 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-28 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-29 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-30 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-10-31 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-04 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-05 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-06 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-07 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-11 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-12 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-13 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-10-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-10-15 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-10-25 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-11-05 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-11-15 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-11-25 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-12-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-12-15 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2012-12-25 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-01-05 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-01-15 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-01-25 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-02-05 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-02-15 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-02-25 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-03-05 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-03-15 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-03-25 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-04-15 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-04-25 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-05-05 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-05-15 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-05-25 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-06-05 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-06-15 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-06-25 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-07-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-07-15 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-07-25 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-08-05 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-08-15 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-08-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-09-05 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-09-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-09-25 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-10-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-10-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-10-25 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-11-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-11-15 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-11-25 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-12-05 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-12-15 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2013-12-25 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-01-05 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-01-15 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-01-25 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-02-05 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-02-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-02-25 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-03-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-03-15 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-03-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-04-05 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-04-15 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-04-25 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-05-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-05-15 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-05-25 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-06-05 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-06-15 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-06-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-07-05 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-07-15 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-07-25 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-08-05 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-08-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-08-25 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-09-05 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-09-15 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-09-25 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-10-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-10-15 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-10-25 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-11-05 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-11-15 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-11-25 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-12-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-12-15 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (11, '2013-12-25 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-01-05 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-01-15 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-01-25 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-02-05 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-02-15 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-02-25 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-03-05 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-03-15 00:00:00', 42.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-03-25 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-04-05 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-04-15 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-04-25 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-05-05 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-05-15 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-05-25 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-06-05 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-06-15 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-06-25 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-07-05 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-07-15 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-07-25 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-08-05 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-08-15 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-08-25 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-09-05 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-09-15 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-09-25 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-10-05 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-10-15 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-10-25 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-11-05 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-11-15 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-11-25 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-12-05 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-12-15 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2008-12-25 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-01-05 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-01-15 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-01-25 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-02-05 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-02-15 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-02-25 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-03-05 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-03-15 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-03-25 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-04-05 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-04-15 00:00:00', 64.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-04-25 00:00:00', 117.900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-05-05 00:00:00', 207.199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-05-15 00:00:00', 194.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-05-25 00:00:00', 158.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-06-05 00:00:00', 193, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-06-15 00:00:00', 144.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-06-25 00:00:00', 112.900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-07-05 00:00:00', 42.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-07-15 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-07-25 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-08-05 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-08-15 00:00:00', 6.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-08-25 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-09-05 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-09-15 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-09-25 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-10-05 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-10-15 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-10-25 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-11-05 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-11-15 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-11-25 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-12-05 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-12-15 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2009-12-25 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-01-05 00:00:00', 128, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-01-15 00:00:00', 127.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-01-25 00:00:00', 127.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-02-05 00:00:00', 123.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-02-15 00:00:00', 120.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-02-25 00:00:00', 123.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-03-05 00:00:00', 203.100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-03-15 00:00:00', 201.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-03-25 00:00:00', 190.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-04-05 00:00:00', 199.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-04-15 00:00:00', 236.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-04-25 00:00:00', 225.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-05-05 00:00:00', 257.70001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-05-15 00:00:00', 280.600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-05-25 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-06-05 00:00:00', 272, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-06-15 00:00:00', 179.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-06-25 00:00:00', 195.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-07-05 00:00:00', 145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-07-15 00:00:00', 133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-07-25 00:00:00', 136.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-08-05 00:00:00', 141.699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-08-15 00:00:00', 147, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-08-25 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-09-05 00:00:00', 153, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-09-15 00:00:00', 154, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-09-25 00:00:00', 148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-10-05 00:00:00', 134.399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-10-15 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-10-25 00:00:00', 124.099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-11-05 00:00:00', 122.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-11-15 00:00:00', 131.300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-11-25 00:00:00', 119.599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-12-05 00:00:00', 120.400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-12-15 00:00:00', 123.099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2010-12-25 00:00:00', 122, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-01-05 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-01-15 00:00:00', 8.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-01-25 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-02-05 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-02-15 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-02-25 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-03-05 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-03-15 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-03-25 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-04-05 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-04-15 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-04-25 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-05-05 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-05-15 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-05-25 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-06-05 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-06-15 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-06-25 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-07-05 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-07-15 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-07-25 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-08-05 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-08-15 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-08-25 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-09-05 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-09-15 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-09-25 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-10-05 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-10-15 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-10-25 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-11-05 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-11-15 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-11-25 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-12-05 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-12-15 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2011-12-25 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-11-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-01 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-02 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-03 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-04 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-08 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-09 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-10 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-13 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-01-05 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-01-15 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-01-25 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-02-05 00:00:00', 41.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-02-15 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-02-25 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-03-05 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-03-15 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-03-25 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-04-05 00:00:00', 120.800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-04-15 00:00:00', 91, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-04-25 00:00:00', 221.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-14 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-17 00:00:00', 6.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-18 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-19 00:00:00', 0.455000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-21 00:00:00', 5.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-22 00:00:00', 8.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-23 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-05-05 00:00:00', 86.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-05-15 00:00:00', 85.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-05-25 00:00:00', 89.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-06-05 00:00:00', 130.899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-06-15 00:00:00', 62.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-06-25 00:00:00', 79.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-07-05 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-07-15 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-07-25 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-08-05 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-08-15 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-08-25 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-09-05 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-09-15 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-09-25 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-10-05 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-10-15 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-10-25 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-11-05 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-11-15 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-11-25 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-12-05 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-12-15 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (5, '2012-12-25 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-28 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-29 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-30 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-12-31 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-05 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-08 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-09 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-10 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-14 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-15 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-18 00:00:00', 8.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-20 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-21 00:00:00', 5.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-22 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-23 00:00:00', 13.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-24 00:00:00', 13.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-25 00:00:00', 7.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-27 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-28 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-30 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-01-31 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-01 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-02 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-03 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-04 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-07 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-08 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-09 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-10 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-12 00:00:00', 5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-13 00:00:00', 20.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-16 00:00:00', 0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-17 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-19 00:00:00', 6.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-20 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-21 00:00:00', 11.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-22 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-23 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-24 00:00:00', 6.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-25 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-26 00:00:00', 8.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-27 00:00:00', 4.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-28 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-02-29 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-01 00:00:00', 0.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-02 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-03 00:00:00', 9.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-04 00:00:00', 20.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-05 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-08 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-11 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-12 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-13 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-14 00:00:00', 19.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-15 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-16 00:00:00', 6.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-17 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-20 00:00:00', 10.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-22 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-23 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-24 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-27 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-28 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-01 00:00:00', 5.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-02 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-05 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-06 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-13 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-17 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-18 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-20 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-25 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-26 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-27 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-28 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-11 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-13 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-15 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-16 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-17 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-19 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-20 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-21 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-22 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-29 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-04 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-18 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-19 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-21 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-22 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-24 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-25 00:00:00', 7.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-26 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-01 00:00:00', 0.582000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-02 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-03 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-11 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-12 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-13 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-14 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-19 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-20 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-26 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-27 00:00:00', 10.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-28 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-29 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-30 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1980-12-31 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-01 00:00:00', 19.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-02 00:00:00', 14.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-03 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-04 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-09 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-12 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-13 00:00:00', 4.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-14 00:00:00', 5.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-15 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-16 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-18 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-20 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-22 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-23 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-25 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-26 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-27 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-28 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-30 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-01 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-02 00:00:00', 4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-03 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-04 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-08 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-10 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-11 00:00:00', 8.73900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-12 00:00:00', 8.51799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-13 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-17 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-18 00:00:00', 6.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-19 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-20 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-21 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-22 00:00:00', 14.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-23 00:00:00', 8.72000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-24 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-25 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-26 00:00:00', 5.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-27 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-02-28 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-02 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-03 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-04 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-05 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-09 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-11 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-13 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-14 00:00:00', 0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-15 00:00:00', 11.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-16 00:00:00', 18.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-17 00:00:00', 5.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-18 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-20 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-24 00:00:00', 6.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-26 00:00:00', 11.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-28 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-29 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-30 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-02 00:00:00', 9.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-03 00:00:00', 14.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-06 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-07 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-10 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-11 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-12 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-13 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-14 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-18 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-19 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-20 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-25 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-26 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-27 00:00:00', 22.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-28 00:00:00', 10.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-29 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-04-30 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-04 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-06 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-07 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-08 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-09 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-12 00:00:00', 0.456000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-13 00:00:00', 0.150000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-14 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-18 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-05-31 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-06 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-23 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-18 00:00:00', 4.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-19 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-21 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-22 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-23 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-11-30 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-01 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-02 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-04 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-05 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-06 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-07 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-08 00:00:00', 5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-09 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-10 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-16 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-21 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-25 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-26 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-27 00:00:00', 9.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-28 00:00:00', 0.705999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-29 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-30 00:00:00', 10.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1981-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-01 00:00:00', 4.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-02 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-03 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-08 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-12 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-13 00:00:00', 10.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-15 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-16 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-17 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-18 00:00:00', 10.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-19 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-20 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-21 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-22 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-27 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-28 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-29 00:00:00', 17.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-30 00:00:00', 6.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-01 00:00:00', 7.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-02 00:00:00', 14.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-06 00:00:00', 7.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-09 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-10 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-11 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-14 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-15 00:00:00', 10.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-16 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-18 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-19 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-20 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-22 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-23 00:00:00', 8.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-25 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-26 00:00:00', 6.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-27 00:00:00', 6.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-02-28 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-01 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-03 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-04 00:00:00', 10.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-08 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-09 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-11 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-12 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-13 00:00:00', 11.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-14 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-15 00:00:00', 7.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-16 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-19 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-20 00:00:00', 19.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-21 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-26 00:00:00', 5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-27 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-28 00:00:00', 4.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-29 00:00:00', 10.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-30 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-03-31 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-03 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-14 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-24 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-26 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-27 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-28 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-18 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-22 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-23 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-24 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-25 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-27 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-28 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-29 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-13 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-14 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-06-30 00:00:00', 0.569000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-01 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-05 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-06 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-14 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-09-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-02 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-03 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-04 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-06 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-07 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-09 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-10 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-11 00:00:00', 8.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-16 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-17 00:00:00', 0.874000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-18 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-23 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-24 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-25 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-01 00:00:00', 7.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-02 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-03 00:00:00', 8.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-04 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-08 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-10 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-11 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-13 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-14 00:00:00', 31.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-15 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-17 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-18 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-20 00:00:00', 0.898000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-23 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-27 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-28 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-29 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-11-30 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-01 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-06 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-07 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-08 00:00:00', 6.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-09 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-13 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-16 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-17 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-26 00:00:00', 0.874000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-27 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-28 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-29 00:00:00', 14.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-30 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1982-12-31 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-02 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-03 00:00:00', 9.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-04 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-05 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-06 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-07 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-10 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-11 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-13 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-14 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-16 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-22 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-25 00:00:00', 8.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-26 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-27 00:00:00', 5.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-05 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-06 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-07 00:00:00', 0.317000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-08 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-09 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-10 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-11 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-12 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-17 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-18 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-19 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-20 00:00:00', 7.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-21 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-22 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-23 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-27 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-02-28 00:00:00', 14.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-01 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-06 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-07 00:00:00', 13.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-08 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-10 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-14 00:00:00', 6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-16 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-17 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-18 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-19 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-23 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-24 00:00:00', 8.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-25 00:00:00', 10.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-26 00:00:00', 7.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-28 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-29 00:00:00', 8.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-30 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-03-31 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-01 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-02 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-03 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-05 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-06 00:00:00', 5.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-07 00:00:00', 16.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-09 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-11 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-12 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-13 00:00:00', 1.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-14 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-16 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-17 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-21 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-26 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-29 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-04-30 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-03 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-04 00:00:00', 6.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-05 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-07 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-08 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-09 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-10 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-11 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-13 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-15 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-27 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-30 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-05-31 00:00:00', 11.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-29 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-03 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-05 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-12 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-16 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-17 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-26 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-04 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-10 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-12 00:00:00', 1.01800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-13 00:00:00', 16.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-15 00:00:00', 5.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-16 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-17 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-28 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-29 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1983-12-31 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-03 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-04 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-09 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-10 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-11 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-12 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-15 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-16 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-17 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-18 00:00:00', 0.421000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-19 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-20 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-21 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-22 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-25 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-27 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-28 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-30 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-01-31 00:00:00', 8.61699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-01 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-05 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-06 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-08 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-09 00:00:00', 6.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-10 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-11 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-12 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-13 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-14 00:00:00', 11.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-15 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-16 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-17 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-18 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-19 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-20 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-25 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-26 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-27 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-28 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-02-29 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-01 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-02 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-03 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-04 00:00:00', 8.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-05 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-06 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-07 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-08 00:00:00', 5.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-09 00:00:00', 5.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-10 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-11 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-12 00:00:00', 7.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-13 00:00:00', 7.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-14 00:00:00', 12.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-15 00:00:00', 7.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-16 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-17 00:00:00', 8.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-19 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-20 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-21 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-22 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-24 00:00:00', 18.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-25 00:00:00', 18.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-26 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-27 00:00:00', 17.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-28 00:00:00', 12.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-30 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-03-31 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-04 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-05 00:00:00', 5.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-08 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-09 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-10 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-11 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-12 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-13 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-18 00:00:00', 5.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-19 00:00:00', 15.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-20 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-26 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-27 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-02 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-03 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-06 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-07 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-08 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-15 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-22 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-27 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-08 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-21 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-22 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-06 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-08 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-09 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-10 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-11 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-12 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-13 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-14 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-15 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-16 00:00:00', 12.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-17 00:00:00', 0.052000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-18 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-19 00:00:00', 7.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-20 00:00:00', 5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-21 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-22 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-23 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-27 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-11-30 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-01 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-02 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-03 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-04 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-05 00:00:00', 8.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-06 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-07 00:00:00', 11.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-08 00:00:00', 13.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-12 00:00:00', 6.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-13 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-14 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-15 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-16 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-22 00:00:00', 0.204999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-24 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-28 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-29 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1984-12-31 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-01 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-03 00:00:00', 13.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-04 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-05 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-06 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-10 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-11 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-12 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-13 00:00:00', 10.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-14 00:00:00', 13.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-15 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-16 00:00:00', 11.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-17 00:00:00', 9.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-18 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-19 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-20 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-23 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-24 00:00:00', 6.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-25 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-26 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-28 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-02 00:00:00', 8.12600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-03 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-04 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-07 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-17 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-18 00:00:00', 6.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-19 00:00:00', 12.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-23 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-24 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-27 00:00:00', 0.699000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-02-28 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-03 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-04 00:00:00', 11.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-08 00:00:00', 4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-09 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-10 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-11 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-14 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-15 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-17 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-21 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-22 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-23 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-25 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-26 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-27 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-28 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-29 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-30 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-03-31 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-01 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-02 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-04 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-05 00:00:00', 9.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-06 00:00:00', 5.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-07 00:00:00', 7.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-10 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-11 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-12 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-27 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-28 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-29 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-04-30 00:00:00', 10.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-01 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-02 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-03 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-04 00:00:00', 0.469000011682510376, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-05 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-06 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-07 00:00:00', 8.49699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-19 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-20 00:00:00', 0.229000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-23 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-25 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-12 00:00:00', 0.221000000834465027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-23 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-12 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-16 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-19 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-24 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-05 00:00:00', 0.841000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-06 00:00:00', 12.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-07 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-08 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-13 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-14 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-15 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-17 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-18 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-19 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-21 00:00:00', 12.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-22 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-23 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-24 00:00:00', 8.77000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-25 00:00:00', 6.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-26 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-28 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-29 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1985-12-31 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-01 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-05 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-06 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-15 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-16 00:00:00', 7.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-17 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-20 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-21 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-22 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-24 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-28 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-01-31 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-02 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-03 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-08 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-09 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-11 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-12 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-13 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-14 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-15 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-16 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-17 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-03 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-10 00:00:00', 6.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-11 00:00:00', 8.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-12 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-15 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-16 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-23 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-25 00:00:00', 7.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-26 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-27 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-29 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-30 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-09 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-11 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-12 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-13 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-15 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-21 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-22 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-07 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-15 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-16 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-17 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-25 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-29 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-30 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-03 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-12 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-13 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-14 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-15 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-06 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-08 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-09 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-11 00:00:00', 0.75700002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-12 00:00:00', 0.485000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-13 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-14 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-20 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-21 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-24 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-25 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-11-30 00:00:00', 0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-01 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-02 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-03 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-04 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-05 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-06 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-09 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-10 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-11 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-12 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-20 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-21 00:00:00', 12.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-22 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-23 00:00:00', 6.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-08 00:00:00', 6.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-12 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-18 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-19 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-20 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-21 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-01-31 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-01 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-02 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-05 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-06 00:00:00', 7.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-07 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-11 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-12 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-15 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-16 00:00:00', 0.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-17 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-20 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-21 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-22 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-23 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-02 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-03 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-04 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-05 00:00:00', 8.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-06 00:00:00', 6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-07 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-09 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-11 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-12 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-13 00:00:00', 8.17599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-14 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-15 00:00:00', 6.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-17 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-18 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-19 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-20 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-21 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-22 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-27 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-28 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-29 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-03-31 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-01 00:00:00', 12.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-02 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-05 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-06 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-07 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-08 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-14 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-15 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-16 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-20 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-21 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-28 00:00:00', 8.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-04 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-26 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-27 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-28 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-30 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-01 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-02 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-05 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-15 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-09-30 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-01 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-07 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-08 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-09 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-10 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-25 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-26 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-27 00:00:00', 12.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-28 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-04 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-29 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-11-30 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-01 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-10 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-11 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-14 00:00:00', 0.386000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-15 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-25 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-28 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-29 00:00:00', 16.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-30 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1987-12-31 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-01 00:00:00', 9.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-02 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-03 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-07 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-08 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-12 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-14 00:00:00', 15.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-15 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-17 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-18 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-19 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-20 00:00:00', 1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-21 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-25 00:00:00', 0.128000006079673767, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-26 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-27 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-28 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-29 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-30 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-04 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-06 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-07 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-13 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-14 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-15 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-16 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-18 00:00:00', 26.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-19 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-21 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-26 00:00:00', 9.22500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-27 00:00:00', 0.901000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-02 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-06 00:00:00', 11.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-08 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-09 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-10 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-11 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-13 00:00:00', 6.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-14 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-15 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-17 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-22 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-24 00:00:00', 12.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-25 00:00:00', 12.7030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-26 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-27 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-28 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-29 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-30 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-03-31 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-01 00:00:00', 0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-02 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-06 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-08 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-09 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-17 00:00:00', 6.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-28 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-29 00:00:00', 16.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-04-30 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-01 00:00:00', 4.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-02 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-13 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-24 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-16 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-22 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-29 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-15 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-21 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-22 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-02 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-15 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-16 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-18 00:00:00', 6.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-19 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-20 00:00:00', 6.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-21 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-23 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-26 00:00:00', 0.519999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-27 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-28 00:00:00', 14.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-29 00:00:00', 24.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1988-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-03 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-04 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-05 00:00:00', 7.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-07 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-15 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-16 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-18 00:00:00', 7.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-19 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-25 00:00:00', 4.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-26 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-27 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-28 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-29 00:00:00', 0.805000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-30 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-01 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-02 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-03 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-06 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-12 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-13 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-15 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-16 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-19 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-20 00:00:00', 6.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-21 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-23 00:00:00', 20.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-24 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-25 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-26 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-27 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-08 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-11 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-12 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-13 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-14 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-17 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-18 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-19 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-20 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-21 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-22 00:00:00', 9.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-29 00:00:00', 11.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-30 00:00:00', 8.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-03-31 00:00:00', 27.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-02 00:00:00', 4.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-05 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-08 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-15 00:00:00', 17.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-16 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-17 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-04-30 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-02 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-03 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-04 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-05 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-08 00:00:00', 5.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-09 00:00:00', 11.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-15 00:00:00', 0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-10-31 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-01 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-07 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-08 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-17 00:00:00', 17.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-18 00:00:00', 10.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-21 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-22 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-03 00:00:00', 0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-04 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-05 00:00:00', 5.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-06 00:00:00', 26.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-07 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-14 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-15 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-16 00:00:00', 11.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-17 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-18 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-24 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-28 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1989-12-31 00:00:00', 17.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-01 00:00:00', 13.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-02 00:00:00', 9.38599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-03 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-04 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-05 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-06 00:00:00', 10.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-07 00:00:00', 7.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-08 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-09 00:00:00', 11.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-10 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-11 00:00:00', 7.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-12 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-16 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-17 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-19 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-20 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-25 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-26 00:00:00', 8.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-27 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-30 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-01-31 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-03 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-04 00:00:00', 5.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-05 00:00:00', 4.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-06 00:00:00', 14.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-07 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-08 00:00:00', 0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-09 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-11 00:00:00', 17.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-12 00:00:00', 7.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-14 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-16 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-17 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-21 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-22 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-23 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-24 00:00:00', 0.638000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-25 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-26 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-07 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-08 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-09 00:00:00', 11.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-10 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-15 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-17 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-18 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-19 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-20 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-21 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-03-31 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-03 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-04 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-05 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-06 00:00:00', 8.97799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-07 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-08 00:00:00', 8.36699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-11 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-14 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-15 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-16 00:00:00', 7.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-17 00:00:00', 24.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-18 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-20 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-27 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-01 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-06 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-14 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-05 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-15 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-26 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-27 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-29 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-30 00:00:00', 10.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-01 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-02 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-14 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-07 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-08 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-09 00:00:00', 5.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-10 00:00:00', 8.51099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-11 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-12 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-13 00:00:00', 6.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-14 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-20 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-22 00:00:00', 4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-23 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-24 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-25 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-26 00:00:00', 12.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-27 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1990-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-04 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-05 00:00:00', 9.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-06 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-07 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-08 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-10 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-11 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-12 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-15 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-16 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-17 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-18 00:00:00', 10.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-19 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-20 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-23 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-24 00:00:00', 17.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-25 00:00:00', 11.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-26 00:00:00', 7.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-27 00:00:00', 14.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-28 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-29 00:00:00', 0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-02 00:00:00', 6.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-03 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-04 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-05 00:00:00', 17.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-06 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-07 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-08 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-09 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-10 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-11 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-12 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-13 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-14 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-23 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-24 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-25 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-26 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-02 00:00:00', 10.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-05 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-06 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-07 00:00:00', 9.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-08 00:00:00', 5.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-09 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-10 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-11 00:00:00', 14.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-12 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-15 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-16 00:00:00', 15.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-17 00:00:00', 13.9049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-18 00:00:00', 1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-20 00:00:00', 6.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-21 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-25 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-28 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-29 00:00:00', 8.93799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-05 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-06 00:00:00', 9.42800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-11 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-12 00:00:00', 6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-24 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-25 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-26 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-28 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-01 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-02 00:00:00', 9.74699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-08 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-12 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-15 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-16 00:00:00', 16.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-17 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-18 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-19 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-20 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-21 00:00:00', 16.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-25 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-25 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-27 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-28 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-29 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-02 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-13 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-16 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-17 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-19 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-20 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-21 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-23 00:00:00', 6.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-27 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-28 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-03 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-04 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-05 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-06 00:00:00', 9.04399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-08 00:00:00', 0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-09 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-10 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-11 00:00:00', 6.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-12 00:00:00', 6.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-13 00:00:00', 9.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-14 00:00:00', 10.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-15 00:00:00', 14.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-16 00:00:00', 24.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-17 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-20 00:00:00', 0.268999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-21 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-26 00:00:00', 0.361999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-27 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-29 00:00:00', 0.379999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-30 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1991-12-31 00:00:00', 0.254999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-01 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-02 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-03 00:00:00', 10.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-04 00:00:00', 19.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-05 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-06 00:00:00', 6.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-07 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-09 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-10 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-13 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-14 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-15 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-18 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-19 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-22 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-23 00:00:00', 5.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-24 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-25 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-26 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-27 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-28 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-29 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-01-31 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-01 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-02 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-03 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-04 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-05 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-06 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-07 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-11 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-12 00:00:00', 11.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-16 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-22 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-25 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-26 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-27 00:00:00', 5.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-28 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-01 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-02 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-03 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-04 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-07 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-08 00:00:00', 9.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-09 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-10 00:00:00', 11.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-11 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-12 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-16 00:00:00', 6.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-17 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-19 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-22 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-23 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-25 00:00:00', 7.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-26 00:00:00', 9.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-29 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-30 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-03-31 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-01 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-02 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-03 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-04 00:00:00', 7.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-06 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-11 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-12 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-16 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-20 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-23 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-24 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-27 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-28 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-29 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-04-30 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-02 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-05 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-06 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-07 00:00:00', 0.75700002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-10 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-11 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-12 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-13 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-15 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-18 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-20 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-16 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-17 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-18 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-19 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-20 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-21 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-27 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-05 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-07 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-08 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-10 00:00:00', 9.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-11 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-21 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-22 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-23 00:00:00', 23.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-24 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-28 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-29 00:00:00', 9.50300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-30 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1992-12-31 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-02 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-05 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-06 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-09 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-10 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-12 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-13 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-15 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-16 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-18 00:00:00', 0.893999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-19 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-24 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-01 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-02 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-04 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-05 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-06 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-07 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-08 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-10 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-11 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-12 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-13 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-14 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-15 00:00:00', 7.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-16 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-21 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-22 00:00:00', 19.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-23 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-24 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-25 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-02-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-01 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-02 00:00:00', 8.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-03 00:00:00', 0.42300000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-04 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-05 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-06 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-07 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-08 00:00:00', 0.328999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-09 00:00:00', 13.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-10 00:00:00', 14.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-11 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-12 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-13 00:00:00', 12.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-16 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-19 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-20 00:00:00', 14.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-22 00:00:00', 7.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-23 00:00:00', 10.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-24 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-05 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-06 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-14 00:00:00', 6.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-15 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-16 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-22 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-24 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-27 00:00:00', 9.96300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-28 00:00:00', 16.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-29 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-04-30 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-01 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-05 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-07 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-08 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-15 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-16 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-21 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-22 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-24 00:00:00', 6.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-25 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-30 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-02 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-23 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-07 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-08 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-28 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-29 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-30 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-02 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-03 00:00:00', 0.970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-04 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-05 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-08 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-17 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-21 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-22 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-26 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-27 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-28 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-29 00:00:00', 14.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-11-30 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-02 00:00:00', 0.893999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-03 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-04 00:00:00', 6.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-05 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-06 00:00:00', 5.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-07 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-09 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-12 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-13 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-17 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-26 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-27 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-29 00:00:00', 0.442000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1993-12-31 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-01 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-02 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-03 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-04 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-06 00:00:00', 8.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-07 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-09 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-10 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-17 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-18 00:00:00', 6.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-19 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-24 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-25 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-26 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-27 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-28 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-01-31 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-01 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-02 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-03 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-04 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-07 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-09 00:00:00', 6.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-10 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-12 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-13 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-14 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-15 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-16 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-23 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-24 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-25 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-02 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-03 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-06 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-09 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-10 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-11 00:00:00', 11.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-12 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-13 00:00:00', 23.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-16 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-17 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-24 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-25 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-28 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-30 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-02 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-03 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-04 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-05 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-06 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-13 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-15 00:00:00', 0.115999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-28 00:00:00', 11.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-01 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-02 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-06 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-07 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-08 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-18 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-21 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-17 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-20 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-24 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-25 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-26 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-01 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-10 00:00:00', 0.156000003218650818, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-11 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-16 00:00:00', 0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-18 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-25 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-26 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-27 00:00:00', 1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-01 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-05 00:00:00', 24.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-07 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-08 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-20 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-21 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-22 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-25 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-26 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-28 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1994-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-02 00:00:00', 0.300999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-03 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-06 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-07 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-08 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-11 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-12 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-14 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-15 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-18 00:00:00', 15.8970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-19 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-23 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-24 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-25 00:00:00', 8.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-06 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-07 00:00:00', 17.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-08 00:00:00', 9.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-09 00:00:00', 32.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-10 00:00:00', 16.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-17 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-25 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-26 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-27 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-02-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-03 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-05 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-06 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-07 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-08 00:00:00', 0.182999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-10 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-19 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-20 00:00:00', 6.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-21 00:00:00', 12.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-22 00:00:00', 12.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-23 00:00:00', 4.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-27 00:00:00', 10.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-28 00:00:00', 5.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-07 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-08 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-17 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-18 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-19 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-20 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-21 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-23 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-24 00:00:00', 0.953000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-25 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-26 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-27 00:00:00', 8.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-28 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-11 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-21 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-22 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-22 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-23 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-13 00:00:00', 0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-14 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-20 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-21 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-24 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-26 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-27 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-05 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-06 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-07 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-08 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-09 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-10 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-12 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-13 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-14 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-15 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-18 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-19 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-20 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-23 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-24 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-26 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-27 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-29 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1995-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-03 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-04 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-07 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-08 00:00:00', 0.582000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-09 00:00:00', 14.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-10 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-11 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-13 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-14 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-15 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-16 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-18 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-19 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-20 00:00:00', 10.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-21 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-24 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-25 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-26 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-27 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-28 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-30 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-01-31 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-01 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-02 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-03 00:00:00', 6.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-04 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-05 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-06 00:00:00', 15.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-07 00:00:00', 0.437000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-11 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-12 00:00:00', 6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-13 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-14 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-15 00:00:00', 0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-16 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-17 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-18 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-19 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-20 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-21 00:00:00', 11.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-22 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-23 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-26 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-27 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-28 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-02-29 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-01 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-02 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-03 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-04 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-05 00:00:00', 12.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-06 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-08 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-09 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-10 00:00:00', 0.990000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-11 00:00:00', 6.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-12 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-14 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-15 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-16 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-17 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-18 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-19 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-20 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-22 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-23 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-24 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-26 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-27 00:00:00', 9.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-01 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-02 00:00:00', 7.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-03 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-04 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-09 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-10 00:00:00', 0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-11 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-16 00:00:00', 7.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-17 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-18 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-19 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-20 00:00:00', 6.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-24 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-25 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-26 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-29 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-04-30 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-01 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-02 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-20 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-23 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-27 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-28 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-29 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-24 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-15 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-16 00:00:00', 5.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-12 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-13 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-17 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-18 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-11-30 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-01 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-02 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-12 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-16 00:00:00', 0.832000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-24 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-26 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-27 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1996-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-03 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-04 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-06 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-12 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-14 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-16 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-17 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-18 00:00:00', 15.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-19 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-23 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-24 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-26 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-27 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-29 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-30 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-01 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-07 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-08 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-20 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-21 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-22 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-23 00:00:00', 6.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-24 00:00:00', 6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-02-28 00:00:00', 12.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-01 00:00:00', 7.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-05 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-06 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-07 00:00:00', 5.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-08 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-09 00:00:00', 5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-10 00:00:00', 7.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-14 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-17 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-18 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-21 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-22 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-26 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-27 00:00:00', 7.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-28 00:00:00', 5.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-03-31 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-01 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-02 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-03 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-06 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-07 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-08 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-09 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-10 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-11 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-12 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-19 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-20 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-24 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-25 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-26 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-27 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-28 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-29 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-04-30 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-02 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-06 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-07 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-11 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-12 00:00:00', 13.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-16 00:00:00', 0.74299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-26 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-27 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-28 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-03 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-04 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-08 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-14 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-25 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-01 00:00:00', 0.446999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-02 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-06 00:00:00', 5.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-07 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-14 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-15 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-22 00:00:00', 0.759999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-24 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-28 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-02 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-05 00:00:00', 0.677999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-06 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-10 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-12 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-18 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-19 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-20 00:00:00', 8.38599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-21 00:00:00', 0.492000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-22 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-25 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-26 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-27 00:00:00', 4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-28 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1997-12-31 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-03 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-04 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-06 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-07 00:00:00', 27.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-10 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-11 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-12 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-14 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-15 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-17 00:00:00', 0.884000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-19 00:00:00', 0.0419999994337558746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-20 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-21 00:00:00', 0.111000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-22 00:00:00', 6.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-23 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-25 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-26 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-27 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-28 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-29 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-30 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-01-31 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-01 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-02 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-05 00:00:00', 7.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-08 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-09 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-10 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-11 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-12 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-13 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-14 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-15 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-16 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-17 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-22 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-23 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-27 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-02-28 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-01 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-02 00:00:00', 9.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-03 00:00:00', 0.182999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-04 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-06 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-14 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-15 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-16 00:00:00', 7.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-17 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-19 00:00:00', 10.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-20 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-21 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-22 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-26 00:00:00', 6.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-03 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-06 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-07 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-08 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-21 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-22 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-23 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-25 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-04-30 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-02 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-06 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-11 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-13 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-17 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-18 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-05-31 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-12 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-23 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-05 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-08 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-25 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-28 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-29 00:00:00', 15.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-11-30 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-01 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-02 00:00:00', 11.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-03 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-04 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-25 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-29 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1998-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-08 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-10 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-12 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-14 00:00:00', 9.08800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-18 00:00:00', 5.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-24 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-11 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-13 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-25 00:00:00', 1.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-27 00:00:00', 21.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-01 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-03 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-04 00:00:00', 14.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-05 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-06 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-07 00:00:00', 7.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-08 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-14 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-15 00:00:00', 8.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-16 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-18 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-19 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-21 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-22 00:00:00', 1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-23 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-24 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-27 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-29 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-30 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-03-31 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-03 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-04 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-07 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-09 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-10 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-22 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-24 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-11 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-12 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-28 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-29 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-02 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-03 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-04 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-05 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-09 00:00:00', 9.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-11 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-12 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-13 00:00:00', 0.898999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-20 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-21 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-24 00:00:00', 10.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-26 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-29 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-11-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-18 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-19 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1999-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-07 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-08 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-11 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-12 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-13 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-17 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-18 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-19 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-20 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-24 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-30 00:00:00', 5.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-01-31 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-03 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-08 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-09 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-15 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-16 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-22 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-26 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-27 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-03 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-04 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-09 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-10 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-26 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-27 00:00:00', 5.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-28 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-29 00:00:00', 8.99199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-17 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-04 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-05 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-15 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-16 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-18 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-19 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-06 00:00:00', 1.08700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-07 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-08 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-11 00:00:00', 5.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-23 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-29 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-02 00:00:00', 9.42099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-03 00:00:00', 7.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-07 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-10 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-12 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-13 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-16 00:00:00', 21.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-17 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-25 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-27 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-28 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2000-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-03 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-06 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-16 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-20 00:00:00', 0.994000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-21 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-22 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-24 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-25 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-26 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-28 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-29 00:00:00', 5.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-30 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-05 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-06 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-07 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-16 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-19 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-20 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-22 00:00:00', 8.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-23 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-11 00:00:00', 13.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-12 00:00:00', 12.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-13 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-17 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-18 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-19 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-27 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-28 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-23 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-02 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-03 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-20 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-28 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-29 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-11-30 00:00:00', 6.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-01 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-02 00:00:00', 8.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-03 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-06 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-10 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-13 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-16 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-17 00:00:00', 12.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-21 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-22 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2001-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-09 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-10 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-11 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-12 00:00:00', 20.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-13 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-15 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-23 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-24 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-01-31 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-01 00:00:00', 13.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-02 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-03 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-04 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-05 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-06 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-12 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-14 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-15 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-16 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-17 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-21 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-22 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-26 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-27 00:00:00', 0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-02-28 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-07 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-20 00:00:00', 0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-22 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-23 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-24 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-30 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-04 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-05 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-14 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-15 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-19 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-22 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-23 00:00:00', 9.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-26 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-29 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-01 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-02 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-05 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-06 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-13 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-14 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-14 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-16 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-17 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-18 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-22 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-29 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-11-30 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-02 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-03 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-08 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-10 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-11 00:00:00', 8.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-12 00:00:00', 20.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-13 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-14 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-15 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-17 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-18 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-19 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-20 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-23 00:00:00', 7.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-27 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-28 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-30 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2002-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-08 00:00:00', 9.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-11 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-19 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-20 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-21 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-23 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-29 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-30 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-01-31 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-06 00:00:00', 13.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-07 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-12 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-13 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-14 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-15 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-16 00:00:00', 9.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-17 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-19 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-20 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-21 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-22 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-23 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-24 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-26 00:00:00', 7.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-27 00:00:00', 10.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-02-28 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-01 00:00:00', 5.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-08 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-09 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-13 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-14 00:00:00', 8.90400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-15 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-16 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-18 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-21 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-22 00:00:00', 8.15699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-24 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-27 00:00:00', 8.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-28 00:00:00', 22.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-30 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-03-31 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-01 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-02 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-05 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-06 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-14 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-15 00:00:00', 10.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-18 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-19 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-23 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-24 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-27 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-04 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-05 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-06 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-14 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-15 00:00:00', 6.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-16 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-22 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-23 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-11-30 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-01 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-05 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-07 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-08 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-11 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-12 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-17 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-18 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-21 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-22 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-25 00:00:00', 0.437999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-26 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-28 00:00:00', 0.351000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-29 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-30 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2003-12-31 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-01 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-02 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-04 00:00:00', 6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-05 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-06 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-07 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-08 00:00:00', 9.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-09 00:00:00', 0.430999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-10 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-11 00:00:00', 5.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-12 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-15 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-16 00:00:00', 12.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-20 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-21 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-26 00:00:00', 0.247999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-27 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-28 00:00:00', 5.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-29 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-03 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-07 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-08 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-16 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-20 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-21 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-24 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-25 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-13 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-14 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-15 00:00:00', 5.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-16 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-17 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-20 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-21 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-01 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-02 00:00:00', 5.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-05 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-06 00:00:00', 0.156000003218650818, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-16 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-18 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-21 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-06 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-07 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-15 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-15 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-19 00:00:00', 7.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-20 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-21 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-25 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-28 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-29 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-03 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-10 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-13 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-14 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-16 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-17 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-18 00:00:00', 28.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-22 00:00:00', 0.386000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-23 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-27 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-28 00:00:00', 12.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-29 00:00:00', 7.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-30 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2004-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-04 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-05 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-07 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-08 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-09 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-10 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-11 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-12 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-13 00:00:00', 7.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-20 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-21 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-22 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-23 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-24 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-25 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-26 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-27 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-28 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-30 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-01-31 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-01 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-02 00:00:00', 9.59599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-03 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-04 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-06 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-07 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-09 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-10 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-11 00:00:00', 8.46300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-12 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-13 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-22 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-23 00:00:00', 6.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-03 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-04 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-07 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-08 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-09 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-13 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-14 00:00:00', 11.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-15 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-16 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-17 00:00:00', 6.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-18 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-19 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-24 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-25 00:00:00', 5.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-26 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-04 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-07 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-08 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-23 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-24 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-10 00:00:00', 0.836000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-06 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-07 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-09 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-10 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-11 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-21 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-03 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-04 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-05 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-07 00:00:00', 8.65499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-08 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-26 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-27 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-28 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-29 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2005-12-31 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-10 00:00:00', 7.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-11 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-12 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-13 00:00:00', 4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-14 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-15 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-22 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-23 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-24 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-25 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-26 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-27 00:00:00', 14.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-28 00:00:00', 8.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-29 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-30 00:00:00', 12.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-01-31 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-01 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-02 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-05 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-09 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-10 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-11 00:00:00', 0.312999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-14 00:00:00', 1.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-15 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-16 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-17 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-18 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-19 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-22 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-23 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-24 00:00:00', 8.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-01 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-03 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-04 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-12 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-13 00:00:00', 7.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-17 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-18 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-21 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-25 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-26 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-03-31 00:00:00', 5.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-05 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-08 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-09 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-16 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-20 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-23 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-25 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-02 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-05 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-09 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-14 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-15 00:00:00', 0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-16 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-17 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-20 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-21 00:00:00', 12.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-11-30 00:00:00', 0.344000011682510376, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-01 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-02 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-03 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-04 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-13 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-14 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-15 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-19 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-23 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-24 00:00:00', 8.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-25 00:00:00', 9.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-29 00:00:00', 0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-30 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2006-12-31 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-01 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-08 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-09 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-11 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-12 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-14 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-15 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-16 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-17 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-18 00:00:00', 9.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-23 00:00:00', 0.202000007033348083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-24 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-02 00:00:00', 6.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-03 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-04 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-05 00:00:00', 6.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-06 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-08 00:00:00', 0.317000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-09 00:00:00', 7.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-10 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-11 00:00:00', 6.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-17 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-18 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-19 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-20 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-21 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-24 00:00:00', 0.884000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-25 00:00:00', 6.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-26 00:00:00', 10.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-03 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-04 00:00:00', 1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-08 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-09 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-15 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-16 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-17 00:00:00', 18.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-18 00:00:00', 9.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-19 00:00:00', 4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-24 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-26 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-28 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-29 00:00:00', 21.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-30 00:00:00', 27.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-03-31 00:00:00', 9.24400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-01 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-02 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-03 00:00:00', 0.945999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-04 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-06 00:00:00', 0.739000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-07 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-08 00:00:00', 0.542999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-10 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-14 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-16 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-17 00:00:00', 0.418000012636184692, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-18 00:00:00', 0.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-04-30 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-01 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-02 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-07 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-16 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-17 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-18 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-19 00:00:00', 0.0680000036954879761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-20 00:00:00', 0.509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-24 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-28 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-11-30 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-01 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-06 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-07 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-08 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-09 00:00:00', 15.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-10 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-11 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-12 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-13 00:00:00', 0.842000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-17 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-18 00:00:00', 13.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-19 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-20 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-21 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-22 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-23 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-28 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2007-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-02 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-03 00:00:00', 6.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-04 00:00:00', 6.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-05 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-06 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-07 00:00:00', 16.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-08 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-10 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-12 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-13 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-14 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-15 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-16 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-17 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-18 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-19 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-28 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-29 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-02 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-03 00:00:00', 1.1390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-04 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-05 00:00:00', 0.829999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-13 00:00:00', 5.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-14 00:00:00', 5.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-15 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-16 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-17 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-20 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-21 00:00:00', 27.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-02-29 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-01 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-02 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-04 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-05 00:00:00', 6.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-06 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-13 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-26 00:00:00', 0.314999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-04 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-09 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-10 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-13 00:00:00', 0.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-14 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-19 00:00:00', 0.351999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-21 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-22 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-05 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-16 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-22 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-26 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-13 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-19 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-27 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-28 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-06 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-08 00:00:00', 0.455000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-12 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-13 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-17 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-21 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-23 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-24 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-06 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-07 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-08 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-09 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-15 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-16 00:00:00', 11.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-17 00:00:00', 13.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-18 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-19 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-20 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-21 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-22 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-23 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-27 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-28 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-29 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2008-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-02 00:00:00', 15.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-03 00:00:00', 14.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-11 00:00:00', 0.388999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-13 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-14 00:00:00', 0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-16 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-17 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-25 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-26 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-28 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-29 00:00:00', 19.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-01-31 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-01 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-02 00:00:00', 7.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-03 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-04 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-09 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-11 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-12 00:00:00', 11.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-13 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-14 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-17 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-18 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-19 00:00:00', 16.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-20 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-21 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-22 00:00:00', 7.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-23 00:00:00', 12.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-24 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-01 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-02 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-03 00:00:00', 4.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-04 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-05 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-06 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-18 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-22 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-23 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-26 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-01 00:00:00', 7.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-02 00:00:00', 14.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-05 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-06 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-07 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-09 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-10 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-11 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-14 00:00:00', 7.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-15 00:00:00', 10.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-19 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-20 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-21 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-25 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-26 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-27 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-28 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-01 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-02 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-03 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-04 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-08 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-09 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-13 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-14 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-18 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-19 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-05-31 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-01 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-04 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-13 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-14 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-18 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-19 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-26 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-29 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-30 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-01 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-02 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-07 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-22 00:00:00', 8.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-23 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-24 00:00:00', 8.35499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-25 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-28 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-11-30 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-01 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-02 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-03 00:00:00', 7.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-04 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-07 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-08 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-09 00:00:00', 6.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-10 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-11 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-12 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-16 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-19 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-20 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-21 00:00:00', 7.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-22 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-26 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-27 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-28 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2009-12-31 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-07 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-16 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-17 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-22 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-23 00:00:00', 6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-26 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-27 00:00:00', 7.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-28 00:00:00', 12.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-30 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-01-31 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-02 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-03 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-04 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-05 00:00:00', 23.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-06 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-07 00:00:00', 9.17099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-08 00:00:00', 0.307999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-11 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-12 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-13 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-17 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-18 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-19 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-20 00:00:00', 8.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-21 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-22 00:00:00', 0.705999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-23 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-24 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-25 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-26 00:00:00', 5.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-27 00:00:00', 7.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-02-28 00:00:00', 28.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-01 00:00:00', 5.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-03 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-04 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-05 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-06 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-08 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-12 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-21 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-22 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-29 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-30 00:00:00', 11.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-02 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-07 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-10 00:00:00', 20.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-11 00:00:00', 27.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-14 00:00:00', 0.279000014066696167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-15 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-20 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-29 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-04-30 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-01 00:00:00', 1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-02 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-03 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-04 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-05 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-06 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-10 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-16 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-21 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-22 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-23 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-02 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-13 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-14 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-24 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-16 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-29 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-03 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-04 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-05 00:00:00', 7.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-05 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-06 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-07 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-15 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2010-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-06 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-07 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-10 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-11 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-12 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-13 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-14 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-16 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-17 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-18 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-21 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-29 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-30 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-01-31 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-01 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-02 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-03 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-04 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-05 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-06 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-08 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-09 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-11 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-12 00:00:00', 8.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-13 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-17 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-18 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-19 00:00:00', 9.06200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-21 00:00:00', 0.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-22 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-23 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-27 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-02-28 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-01 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-02 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-03 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-04 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-06 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-07 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-11 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-14 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-15 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-16 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-17 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-24 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-25 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-26 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-27 00:00:00', 6.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-28 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-03-31 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-03 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-08 00:00:00', 0.421000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-09 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-10 00:00:00', 0.949000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-11 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-14 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-23 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-28 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-08 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-10 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-16 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-04 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-26 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-03 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-22 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-28 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-29 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-30 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-10-31 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-01 00:00:00', 0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-02 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-03 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-04 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-07 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-08 00:00:00', 11.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-09 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-14 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-17 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-18 00:00:00', 10.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-23 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-24 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-25 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-26 00:00:00', 12.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-27 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-28 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-02 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-03 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-05 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-26 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-27 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-28 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2011-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-02 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-03 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-04 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-05 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-06 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-12 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-13 00:00:00', 8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-14 00:00:00', 6.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-15 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-19 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-22 00:00:00', 0.846000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-23 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-25 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-26 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-30 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-02 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-03 00:00:00', 5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-04 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-09 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-11 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-12 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-13 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-17 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-19 00:00:00', 13.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-20 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-21 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-26 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-27 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-02-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-01 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-02 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-03 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-04 00:00:00', 4.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-06 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-10 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-11 00:00:00', 7.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-12 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-13 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-15 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-16 00:00:00', 4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-17 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-18 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-19 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-24 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-25 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-28 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-29 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-30 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-03-31 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-01 00:00:00', 10.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-09 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-19 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-20 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-21 00:00:00', 11.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-22 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-23 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-25 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-27 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-04-30 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-05 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-06 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-10 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-15 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-16 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-24 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-25 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-27 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-29 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-21 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-14 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-23 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-25 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-27 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-30 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-10-31 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-01 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-02 00:00:00', 0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-04 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-15 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-16 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-22 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-25 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-26 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-27 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-28 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-29 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-07 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-10 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-12 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-15 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-16 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-17 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-18 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-22 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-23 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-24 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-26 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-27 00:00:00', 13.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2012-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-01 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-03 00:00:00', 0.421000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-04 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-08 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-09 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-11 00:00:00', 8.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-12 00:00:00', 0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-16 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-21 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-22 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-26 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-27 00:00:00', 7.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-30 00:00:00', 15.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-31 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-01 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-02 00:00:00', 8.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-03 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-17 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-18 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-19 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-20 00:00:00', 0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-21 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-26 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-27 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-02 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-03 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-07 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-08 00:00:00', 18.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-12 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-19 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-20 00:00:00', 10.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-22 00:00:00', 6.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-23 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-24 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-26 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-31 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-12 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-22 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-23 00:00:00', 8.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-24 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-26 00:00:00', 14.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-29 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-30 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-19 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-21 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-24 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-24 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-27 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-09 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-22 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-23 00:00:00', 6.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-28 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-29 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-30 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-04 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-11 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-16 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-19 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-20 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-23 00:00:00', 0.925999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-24 00:00:00', 5.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-26 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-01 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-04 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-06 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-07 00:00:00', 6.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-10 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-11 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-16 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-18 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-21 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-27 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-28 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-29 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-03 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-13 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-20 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-21 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-22 00:00:00', 7.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-23 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-24 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-27 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-29 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-30 00:00:00', 5.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-31 00:00:00', 8.65499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-01 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-02 00:00:00', 9.21100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-03 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-06 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-18 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-19 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-20 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-23 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-24 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-03 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-05 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-15 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-01-25 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-05 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-15 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-02-25 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-06 00:00:00', 9.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-07 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-08 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-13 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-14 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-16 00:00:00', 11.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-17 00:00:00', 6.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-18 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-20 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-22 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-23 00:00:00', 14.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-24 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-26 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-01 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-03 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-04 00:00:00', 9.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-10 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-11 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-24 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-28 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-29 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-30 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-01 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-02 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-03 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-08 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-17 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-18 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-29 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-30 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-06 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '1979-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-08 00:00:00', 10.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-13 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-14 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-15 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-17 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-18 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-23 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-24 00:00:00', 0.162000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-25 00:00:00', 8.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-26 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-27 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-28 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-29 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-04 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-06 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-09 00:00:00', 0.180999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-10 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-12 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-13 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-18 00:00:00', 9.35700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-19 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-20 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-21 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-22 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-23 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-24 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-25 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-27 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-02-28 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-01 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-02 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-03 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-04 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-05 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-06 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-10 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-13 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-14 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-25 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-26 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-30 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-03-31 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-01 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-04 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-05 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-06 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-07 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-12 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-14 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-15 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-17 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-18 00:00:00', 8.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-19 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-21 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-27 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-04-30 00:00:00', 7.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-01 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-05 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-06 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-07 00:00:00', 4.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-09 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-11 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-12 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-13 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-14 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-15 00:00:00', 6.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-16 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-17 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-18 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-19 00:00:00', 7.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-20 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-22 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-23 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-24 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-07 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-20 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-21 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-28 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-30 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-10-31 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-05 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-06 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-07 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-12 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-01 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-02 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-03 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-04 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-09 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-10 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-17 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-18 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-21 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-22 00:00:00', 8.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-23 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-28 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-29 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-30 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1979-12-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-08 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-10 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-13 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-14 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-15 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-16 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-18 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-19 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-20 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-21 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-22 00:00:00', 4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-23 00:00:00', 8.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-24 00:00:00', 7.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-25 00:00:00', 10.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-27 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-28 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-01-31 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-01 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-02 00:00:00', 0.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-03 00:00:00', 0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-04 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-06 00:00:00', 0.0780000016093254089, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-07 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-08 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-12 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-13 00:00:00', 8.73200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-14 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-19 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-21 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-22 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-24 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-25 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-26 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-27 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-28 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-02-29 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-01 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-02 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-03 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-04 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-05 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-08 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-12 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-14 00:00:00', 10.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-15 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-16 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-17 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-20 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-21 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-22 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-24 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-25 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-27 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-28 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-01 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-02 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-05 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-17 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-18 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-21 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-25 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-26 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-27 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-08 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-11 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-12 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-13 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-15 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-16 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-17 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-21 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-18 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-19 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-24 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-25 00:00:00', 6.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-26 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-01 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-02 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-03 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-12 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-13 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-14 00:00:00', 0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-20 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-27 00:00:00', 11.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-28 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-29 00:00:00', 0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-30 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1980-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-01 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-02 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-03 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-04 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-13 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-14 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-15 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-16 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-18 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-20 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-23 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-26 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-27 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-28 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-29 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-01 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-02 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-03 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-04 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-08 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-10 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-11 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-12 00:00:00', 4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-13 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-17 00:00:00', 0.822000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-18 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-20 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-21 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-22 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-23 00:00:00', 9.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-24 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-26 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-27 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-02-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-03 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-04 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-05 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-06 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-09 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-11 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-13 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-14 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-15 00:00:00', 10.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-16 00:00:00', 13.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-17 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-18 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-20 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-24 00:00:00', 0.639999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-25 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-26 00:00:00', 6.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-28 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-29 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-30 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-02 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-03 00:00:00', 7.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-07 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-10 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-11 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-12 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-13 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-14 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-15 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-16 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-19 00:00:00', 7.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-20 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-27 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-28 00:00:00', 46.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-04-30 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-01 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-02 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-03 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-04 00:00:00', 11.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-07 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-08 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-09 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-10 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-18 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-19 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-05-31 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-01 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-06 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-23 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-14 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-18 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-19 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-21 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-22 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-23 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-01 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-02 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-04 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-08 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-16 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-21 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-27 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-28 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-29 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-30 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1981-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-01 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-03 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-13 00:00:00', 9.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-18 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-19 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-20 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-21 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-22 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-29 00:00:00', 5.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-30 00:00:00', 7.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-01 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-02 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-06 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-09 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-10 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-11 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-15 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-19 00:00:00', 4.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-22 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-23 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-25 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-26 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-27 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-02-28 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-01 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-03 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-04 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-08 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-09 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-11 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-12 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-13 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-14 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-15 00:00:00', 1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-16 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-20 00:00:00', 16.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-21 00:00:00', 5.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-26 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-27 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-28 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-29 00:00:00', 7.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-30 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-03-31 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-03 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-24 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-26 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-27 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-28 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-14 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-18 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-23 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-24 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-25 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-27 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-14 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-06-30 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-01 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-05 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-06 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-14 00:00:00', 0.953000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-17 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-09-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-03 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-04 00:00:00', 7.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-06 00:00:00', 5.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-07 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-09 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-10 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-11 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-16 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-19 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-24 00:00:00', 0.787999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-25 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-01 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-02 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-03 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-10 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-11 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-13 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-14 00:00:00', 26.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-15 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-16 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-20 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-29 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-11-30 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-01 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-06 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-07 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-08 00:00:00', 7.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-09 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-16 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-17 00:00:00', 1.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-27 00:00:00', 0.200000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-28 00:00:00', 0.361999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-29 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-30 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1982-12-31 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-03 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-04 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-06 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-07 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-10 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-11 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-13 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-14 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-22 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-25 00:00:00', 7.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-26 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-27 00:00:00', 8.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-28 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-07 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-09 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-10 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-11 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-12 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-17 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-19 00:00:00', 0.582000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-20 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-22 00:00:00', 0.925999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-23 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-27 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-02-28 00:00:00', 8.81299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-01 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-06 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-07 00:00:00', 10.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-08 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-10 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-14 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-16 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-17 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-18 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-19 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-23 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-24 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-25 00:00:00', 6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-26 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-28 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-29 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-30 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-03-31 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-05 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-06 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-07 00:00:00', 11.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-11 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-12 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-13 00:00:00', 0.324000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-22 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-26 00:00:00', 6.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-29 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-04-30 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-03 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-04 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-05 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-07 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-08 00:00:00', 6.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-10 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-11 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-30 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-05-31 00:00:00', 8.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-29 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-05 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-16 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-17 00:00:00', 0.221000000834465027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-26 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-04 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-05 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-10 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-13 00:00:00', 11.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-14 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-15 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-16 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-17 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-28 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1983-12-31 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-03 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-04 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-09 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-11 00:00:00', 0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-12 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-18 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-19 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-21 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-22 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-27 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-30 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-01-31 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-01 00:00:00', 4.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-03 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-06 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-08 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-09 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-10 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-11 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-13 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-14 00:00:00', 7.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-15 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-16 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-17 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-18 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-19 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-20 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-28 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-02-29 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-02 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-03 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-04 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-05 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-06 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-07 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-08 00:00:00', 6.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-09 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-10 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-12 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-13 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-14 00:00:00', 8.32199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-15 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-16 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-17 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-21 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-22 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-25 00:00:00', 5.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-26 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-27 00:00:00', 14.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-28 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-03-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-04 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-05 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-09 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-10 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-13 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-18 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-19 00:00:00', 13.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-21 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-27 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-03 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-07 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-08 00:00:00', 0.898000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-15 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-16 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-08 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-21 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-22 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-04 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-11 00:00:00', 6.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-12 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-13 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-14 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-15 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-16 00:00:00', 7.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-17 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-18 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-19 00:00:00', 0.785000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-20 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-22 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-27 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-11-30 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-01 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-02 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-04 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-05 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-06 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-07 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-08 00:00:00', 8.29599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-12 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-13 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-14 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-15 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-16 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-29 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1984-12-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-01 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-03 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-04 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-11 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-12 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-13 00:00:00', 7.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-14 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-15 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-16 00:00:00', 6.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-17 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-18 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-19 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-20 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-23 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-24 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-25 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-02 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-03 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-04 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-07 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-10 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-18 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-19 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-24 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-27 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-02-28 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-02 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-03 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-04 00:00:00', 15.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-05 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-06 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-08 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-09 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-10 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-11 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-14 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-15 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-21 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-22 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-23 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-25 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-26 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-27 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-29 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-30 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-02 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-03 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-05 00:00:00', 5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-06 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-07 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-21 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-28 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-04-30 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-01 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-02 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-03 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-06 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-07 00:00:00', 14.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-10 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-20 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-23 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-25 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-16 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-24 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-05 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-06 00:00:00', 7.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-07 00:00:00', 8.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-13 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-14 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-15 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-19 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-21 00:00:00', 7.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-22 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-24 00:00:00', 1.02100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-25 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-26 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-29 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1985-12-31 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-05 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-06 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-16 00:00:00', 7.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-17 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-22 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-24 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-28 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-02 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-03 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-09 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-12 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-13 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-17 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-03 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-10 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-11 00:00:00', 7.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-12 00:00:00', 7.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-15 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-16 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-23 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-25 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-26 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-27 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-30 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-12 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-13 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-15 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-16 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-22 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-15 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-16 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-17 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-30 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-03 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-11 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-12 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-13 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-14 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-16 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-20 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-21 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-25 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-11-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-01 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-02 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-03 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-04 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-05 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-06 00:00:00', 5.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-09 00:00:00', 0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-10 00:00:00', 7.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-11 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-20 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-21 00:00:00', 5.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-22 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-23 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-08 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-13 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-19 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-20 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-01-31 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-01 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-02 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-06 00:00:00', 6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-07 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-11 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-12 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-16 00:00:00', 0.186000004410743713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-17 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-22 00:00:00', 0.65700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-23 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-02 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-05 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-06 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-07 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-12 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-13 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-15 00:00:00', 12.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-18 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-20 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-21 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-22 00:00:00', 6.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-27 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-28 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-29 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-30 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-03-31 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-01 00:00:00', 10.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-02 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-05 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-06 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-07 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-08 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-14 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-15 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-16 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-20 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-21 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-28 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-27 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-28 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-30 00:00:00', 24.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-01 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-14 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-19 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-20 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-01 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-09 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-10 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-24 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-25 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-26 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-27 00:00:00', 10.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-28 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-04 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-26 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-28 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-29 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-11-30 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-14 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-15 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-28 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-29 00:00:00', 9.84099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-30 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1987-12-31 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-01 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-03 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-07 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-08 00:00:00', 7.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-14 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-15 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-17 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-18 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-20 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-21 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-26 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-30 00:00:00', 8.37399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-01 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-04 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-05 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-06 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-07 00:00:00', 6.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-15 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-16 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-18 00:00:00', 13.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-19 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-21 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-26 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-27 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-02 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-06 00:00:00', 13.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-09 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-10 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-11 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-13 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-15 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-17 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-22 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-24 00:00:00', 7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-25 00:00:00', 15.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-26 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-27 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-28 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-29 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-30 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-03-31 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-01 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-06 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-07 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-09 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-17 00:00:00', 18.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-29 00:00:00', 22.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-04-30 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-01 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-02 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-16 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-21 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-16 00:00:00', 1.16900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-22 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-29 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-15 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-21 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-22 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-23 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-16 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-18 00:00:00', 0.574999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-20 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-21 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-23 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-26 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-27 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-28 00:00:00', 7.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-29 00:00:00', 16.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-30 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1988-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-03 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-04 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-05 00:00:00', 7.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-07 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-13 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-15 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-16 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-18 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-19 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-22 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-25 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-27 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-29 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-30 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-01-31 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-02 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-03 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-06 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-12 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-13 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-15 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-16 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-20 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-21 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-23 00:00:00', 8.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-24 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-25 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-26 00:00:00', 10.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-27 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-08 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-11 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-13 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-14 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-17 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-20 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-22 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-29 00:00:00', 7.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-30 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-03-31 00:00:00', 14.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-02 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-05 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-08 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-15 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-16 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-17 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-04-30 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-03 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-04 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-05 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-08 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-09 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-22 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-10-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-01 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-07 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-08 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-17 00:00:00', 11.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-18 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-22 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-04 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-05 00:00:00', 0.535000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-06 00:00:00', 23.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-07 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-15 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-16 00:00:00', 7.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-17 00:00:00', 0.284000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-18 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1989-12-31 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-01 00:00:00', 10.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-02 00:00:00', 1.16900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-03 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-05 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-06 00:00:00', 5.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-07 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-08 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-09 00:00:00', 7.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-10 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-11 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-12 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-16 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-17 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-25 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-26 00:00:00', 6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-27 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-29 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-30 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-01-31 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-03 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-04 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-05 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-06 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-07 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-11 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-12 00:00:00', 7.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-13 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-14 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-16 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-17 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-22 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-23 00:00:00', 0.698000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-24 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-25 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-26 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-09 00:00:00', 10.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-15 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-17 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-18 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-19 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-20 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-21 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-04 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-06 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-07 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-08 00:00:00', 5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-14 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-15 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-16 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-17 00:00:00', 13.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-27 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-06 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-28 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-15 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-30 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-14 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-08 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-09 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-10 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-11 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-12 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-13 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-22 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-23 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-24 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-25 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-26 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-27 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1990-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-04 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-05 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-06 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-07 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-08 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-11 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-15 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-16 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-17 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-18 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-19 00:00:00', 0.221000000834465027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-20 00:00:00', 0.777000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-23 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-24 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-25 00:00:00', 6.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-26 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-27 00:00:00', 5.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-28 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-29 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-02 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-03 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-04 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-05 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-06 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-07 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-08 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-09 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-10 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-11 00:00:00', 1.28199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-12 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-13 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-14 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-23 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-24 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-25 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-26 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-02 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-06 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-07 00:00:00', 5.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-08 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-09 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-10 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-11 00:00:00', 6.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-12 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-16 00:00:00', 8.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-17 00:00:00', 11.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-18 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-20 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-21 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-22 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-23 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-25 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-29 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-02 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-06 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-09 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-11 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-12 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-13 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-15 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-16 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-24 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-26 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-29 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-01 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-02 00:00:00', 17.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-12 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-13 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-15 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-16 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-17 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-18 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-19 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-20 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-21 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-24 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-26 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-27 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-28 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-29 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-09-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-13 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-20 00:00:00', 6.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-21 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-23 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-28 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-03 00:00:00', 0.310000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-04 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-05 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-06 00:00:00', 7.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-07 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-09 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-10 00:00:00', 0.404000014066696167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-11 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-12 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-13 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-14 00:00:00', 5.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-15 00:00:00', 10.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-16 00:00:00', 17.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-17 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-20 00:00:00', 0.351000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-21 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-27 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-29 00:00:00', 0.236000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-30 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1991-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-01 00:00:00', 0.783999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-02 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-03 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-04 00:00:00', 20.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-06 00:00:00', 5.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-07 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-09 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-10 00:00:00', 0.296000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-14 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-18 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-22 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-23 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-24 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-25 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-26 00:00:00', 0.126000002026557922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-27 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-28 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-29 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-01-31 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-01 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-06 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-07 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-12 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-16 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-22 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-25 00:00:00', 5.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-27 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-28 00:00:00', 0.887000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-01 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-03 00:00:00', 0.755999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-04 00:00:00', 0.156000003218650818, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-07 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-08 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-09 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-10 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-11 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-12 00:00:00', 0.554000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-16 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-17 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-19 00:00:00', 0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-23 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-26 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-29 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-30 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-01 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-02 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-03 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-04 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-06 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-16 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-20 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-28 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-04-30 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-02 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-05 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-06 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-10 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-13 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-15 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-16 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-18 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-19 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-20 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-21 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-27 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-03 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-05 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-07 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-08 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-10 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-11 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-23 00:00:00', 8.17800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-24 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-29 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-30 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1992-12-31 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-03 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-05 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-06 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-09 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-10 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-15 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-16 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-18 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-19 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-02 00:00:00', 0.0659999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-04 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-05 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-06 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-07 00:00:00', 0.13099999725818634, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-08 00:00:00', 0.349000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-14 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-15 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-16 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-17 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-18 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-22 00:00:00', 5.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-23 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-24 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-25 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-01 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-02 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-03 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-04 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-05 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-06 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-07 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-09 00:00:00', 8.60499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-10 00:00:00', 25.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-11 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-12 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-13 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-20 00:00:00', 10.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-22 00:00:00', 8.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-23 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-24 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-07 00:00:00', 0.677999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-14 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-15 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-16 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-24 00:00:00', 0.846000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-27 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-28 00:00:00', 6.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-01 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-05 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-06 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-07 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-08 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-15 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-16 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-24 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-25 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-30 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-18 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-12 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-07 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-08 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-03 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-04 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-08 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-17 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-21 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-22 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-26 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-27 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-28 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-29 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-11-30 00:00:00', 8.49699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-02 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-03 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-04 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-06 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-07 00:00:00', 1.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-13 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-18 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-26 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-27 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-29 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1993-12-31 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-01 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-02 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-03 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-04 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-06 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-07 00:00:00', 5.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-09 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-17 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-18 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-19 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-24 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-26 00:00:00', 5.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-27 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-01-31 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-02 00:00:00', 6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-04 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-07 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-09 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-10 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-11 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-12 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-13 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-14 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-15 00:00:00', 1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-16 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-23 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-24 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-25 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-02 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-06 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-09 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-10 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-11 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-13 00:00:00', 7.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-17 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-25 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-30 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-03 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-05 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-13 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-15 00:00:00', 0.162000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-28 00:00:00', 15.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-02 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-07 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-25 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-26 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-01 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-02 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-11 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-17 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-18 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-19 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-24 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-25 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-27 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-01 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-02 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-05 00:00:00', 21.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-07 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-08 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-21 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-22 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-28 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1994-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-07 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-08 00:00:00', 0.14699999988079071, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-11 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-12 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-15 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-17 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-18 00:00:00', 7.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-19 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-23 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-24 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-25 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-06 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-07 00:00:00', 19.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-08 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-09 00:00:00', 10.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-10 00:00:00', 13.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-11 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-17 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-25 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-26 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-27 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-03 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-05 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-06 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-07 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-19 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-20 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-21 00:00:00', 8.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-22 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-23 00:00:00', 4.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-27 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-28 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-08 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-17 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-18 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-19 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-20 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-23 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-27 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-28 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-13 00:00:00', 0.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-14 00:00:00', 1.18299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-20 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-27 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-29 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-05 00:00:00', 0.554000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-06 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-07 00:00:00', 0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-08 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-09 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-10 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-13 00:00:00', 0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-14 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-15 00:00:00', 0.221000000834465027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-18 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-19 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-24 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1995-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-03 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-07 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-08 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-09 00:00:00', 6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-10 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-11 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-14 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-15 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-16 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-18 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-19 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-20 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-21 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-25 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-26 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-27 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-28 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-30 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-01-31 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-01 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-02 00:00:00', 0.529999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-03 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-04 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-05 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-06 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-07 00:00:00', 0.111000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-12 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-13 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-14 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-15 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-17 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-20 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-21 00:00:00', 9.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-23 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-24 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-26 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-27 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-28 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-02-29 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-01 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-03 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-04 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-05 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-06 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-08 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-09 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-10 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-11 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-12 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-15 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-17 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-18 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-19 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-20 00:00:00', 0.860000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-22 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-24 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-27 00:00:00', 5.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-02 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-03 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-04 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-10 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-16 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-17 00:00:00', 5.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-18 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-19 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-20 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-21 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-23 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-24 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-25 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-26 00:00:00', 0.314999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-04-30 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-01 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-02 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-20 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-27 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-29 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-16 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-12 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-13 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-17 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-20 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-02 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-27 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1996-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-04 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-12 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-14 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-17 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-18 00:00:00', 9.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-19 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-23 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-26 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-27 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-29 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-30 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-01 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-07 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-22 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-23 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-24 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-02-28 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-01 00:00:00', 10.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-07 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-09 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-10 00:00:00', 7.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-14 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-15 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-17 00:00:00', 1.12699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-18 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-21 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-22 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-27 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-28 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-03-31 00:00:00', 0.0970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-01 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-06 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-07 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-12 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-21 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-04-30 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-06 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-12 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-16 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-17 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-28 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-14 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-26 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-02 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-06 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-07 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-15 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-02 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-12 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-18 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-19 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-20 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-21 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-22 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-23 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-25 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-27 00:00:00', 0.901000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1997-12-31 00:00:00', 0.0659999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-03 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-04 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-06 00:00:00', 5.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-07 00:00:00', 19.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-08 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-11 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-12 00:00:00', 0.554000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-14 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-15 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-19 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-20 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-22 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-23 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-25 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-26 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-27 00:00:00', 0.156000003218650818, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-28 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-29 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-30 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-01-31 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-01 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-05 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-08 00:00:00', 6.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-09 00:00:00', 14.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-10 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-11 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-12 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-13 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-14 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-16 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-17 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-23 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-27 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-02-28 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-02 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-03 00:00:00', 0.728999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-04 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-06 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-15 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-16 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-17 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-19 00:00:00', 5.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-20 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-21 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-22 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-26 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-03-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-08 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-22 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-25 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-06 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-11 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-14 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-26 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-05 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-25 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-28 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-29 00:00:00', 8.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-11-30 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-02 00:00:00', 5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-03 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-29 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1998-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-10 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-12 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-14 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-18 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-24 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-11 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-13 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-27 00:00:00', 13.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-01 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-03 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-04 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-05 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-06 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-07 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-08 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-14 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-15 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-16 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-19 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-21 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-22 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-27 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-29 00:00:00', 0.822000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-03-31 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-04 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-07 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-09 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-10 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-22 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-11 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-12 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-24 00:00:00', 0.140000000596046448, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-28 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-29 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-28 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-30 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-02 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-03 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-04 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-05 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-09 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-11 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-12 00:00:00', 0.620000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-13 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-20 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-21 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-24 00:00:00', 6.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-29 00:00:00', 0.653999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-11-30 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-09 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-18 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '1999-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-08 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-11 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-12 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-13 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-18 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-19 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-20 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-24 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-30 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-01-31 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-03 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-08 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-09 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-15 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-04 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-16 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-27 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-28 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-29 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-05 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-16 00:00:00', 5.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-19 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-06 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-07 00:00:00', 9.09300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-08 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-11 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-12 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-17 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-29 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-02 00:00:00', 4.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-03 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-10 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-16 00:00:00', 9.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-17 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-27 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-28 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2000-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-16 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-17 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-20 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-21 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-22 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-24 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-25 00:00:00', 1.16900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-26 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-28 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-29 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-30 00:00:00', 0.811999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-05 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-06 00:00:00', 0.430000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-16 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-22 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-23 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-11 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-12 00:00:00', 9.16199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-13 00:00:00', 0.184000000357627869, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-19 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-27 00:00:00', 6.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-28 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-19 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-23 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-20 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-29 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-11-30 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-01 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-02 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-03 00:00:00', 6.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-06 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-10 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-13 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-16 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-17 00:00:00', 5.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-21 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-22 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2001-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-09 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-10 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-11 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-12 00:00:00', 8.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-13 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-01-31 00:00:00', 0.927999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-01 00:00:00', 8.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-02 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-04 00:00:00', 0.841000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-05 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-06 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-12 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-14 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-15 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-16 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-17 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-22 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-26 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-27 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-02-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-07 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-11 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-20 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-22 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-23 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-24 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-30 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-03 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-04 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-05 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-14 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-15 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-22 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-23 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-26 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-29 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-02 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-05 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-06 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-14 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-14 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-16 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-18 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-11-30 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-02 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-03 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-10 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-11 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-12 00:00:00', 9.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-13 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-14 00:00:00', 0.430999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-15 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-17 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-18 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-19 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-20 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-23 00:00:00', 9.67099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-24 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-27 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-28 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2002-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-08 00:00:00', 0.602999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-11 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-19 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-20 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-21 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-23 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-29 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-06 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-14 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-16 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-18 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-20 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-21 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-22 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-24 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-26 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-27 00:00:00', 9.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-01 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-02 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-09 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-14 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-15 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-16 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-22 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-24 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-27 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-28 00:00:00', 11.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-30 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-01 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-02 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-05 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-14 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-15 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-18 00:00:00', 6.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-19 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-23 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-24 00:00:00', 6.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-25 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-04 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-05 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-06 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-15 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-16 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-22 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-23 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-11-30 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-01 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-05 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-11 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-12 00:00:00', 8.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-21 00:00:00', 0.0680000036954879761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-22 00:00:00', 5.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-25 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-28 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-29 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2003-12-31 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-01 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-04 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-06 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-07 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-08 00:00:00', 9.36400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-09 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-10 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-11 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-12 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-15 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-16 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-21 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-26 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-28 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-29 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-07 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-08 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-09 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-16 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-21 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-25 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-13 00:00:00', 0.470999985933303833, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-14 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-15 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-17 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-20 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-21 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-02 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-21 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-22 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-07 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-22 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-15 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-19 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-20 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-28 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-29 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-03 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-14 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-16 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-17 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-18 00:00:00', 15.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-21 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-28 00:00:00', 8.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-29 00:00:00', 6.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-30 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2004-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-05 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-07 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-08 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-12 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-13 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-21 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-24 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-26 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-01-31 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-01 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-02 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-03 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-04 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-06 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-10 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-11 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-12 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-13 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-22 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-23 00:00:00', 5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-04 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-13 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-14 00:00:00', 13.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-15 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-16 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-17 00:00:00', 8.17099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-18 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-19 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-25 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-26 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-27 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-04 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-08 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-10 00:00:00', 9.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-07 00:00:00', 0.574999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-09 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-10 00:00:00', 7.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-14 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-04 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-05 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-07 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-26 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-27 00:00:00', 0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-28 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2005-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-10 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-11 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-12 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-13 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-14 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-15 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-23 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-25 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-26 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-27 00:00:00', 15.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-28 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-29 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-30 00:00:00', 7.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-01-31 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-10 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-11 00:00:00', 1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-15 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-17 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-18 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-19 00:00:00', 0.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-23 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-24 00:00:00', 6.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-25 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-04 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-13 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-17 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-18 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-21 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-25 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-26 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-03-31 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-08 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-09 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-28 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-01 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-16 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-20 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-23 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-09 00:00:00', 4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-16 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-17 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-20 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-21 00:00:00', 9.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-11-30 00:00:00', 0.0560000017285346985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-01 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-02 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-04 00:00:00', 7.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-19 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-24 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-25 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-30 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2006-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-11 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-12 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-14 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-15 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-16 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-17 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-18 00:00:00', 5.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-24 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-02 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-04 00:00:00', 0.819000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-05 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-06 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-09 00:00:00', 5.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-10 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-11 00:00:00', 4.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-12 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-18 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-19 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-20 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-21 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-25 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-26 00:00:00', 9.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-27 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-02-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-03 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-08 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-09 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-11 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-12 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-16 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-17 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-18 00:00:00', 0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-19 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-26 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-28 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-29 00:00:00', 13.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-30 00:00:00', 22.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-03-31 00:00:00', 11.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-01 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-04 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-06 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-08 00:00:00', 0.0970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-14 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-17 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-18 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-29 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-04-30 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-01 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-02 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-07 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-16 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-17 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-18 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-19 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-20 00:00:00', 0.505999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-24 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-28 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-11-30 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-01 00:00:00', 5.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-06 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-07 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-08 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-09 00:00:00', 10.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-10 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-12 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-16 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-17 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-18 00:00:00', 5.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-19 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-20 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-21 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-22 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-23 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-28 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2007-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-02 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-03 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-04 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-05 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-06 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-07 00:00:00', 8.62800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-08 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-10 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-13 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-15 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-16 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-17 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-20 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-28 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-02 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-03 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-05 00:00:00', 0.11900000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-10 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-13 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-14 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-15 00:00:00', 0.165999993681907654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-16 00:00:00', 5.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-17 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-20 00:00:00', 0.575999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-21 00:00:00', 27.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-02-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-01 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-02 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-05 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-06 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-04 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-09 00:00:00', 0.437999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-10 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-13 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-14 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-15 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-19 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-22 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-04 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-16 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-22 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-26 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-09-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-13 00:00:00', 0.65700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-19 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-27 00:00:00', 0.361999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-28 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-29 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-06 00:00:00', 0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-12 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-13 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-15 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-21 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-22 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-24 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-08 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-16 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-17 00:00:00', 15.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-18 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-19 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-20 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-22 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-23 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-27 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-28 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-29 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2008-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-02 00:00:00', 11.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-03 00:00:00', 15.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-11 00:00:00', 0.0900000035762786865, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-12 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-13 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-16 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-17 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-29 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-02 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-03 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-04 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-09 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-10 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-11 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-12 00:00:00', 9.38599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-13 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-17 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-18 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-19 00:00:00', 13.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-20 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-22 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-23 00:00:00', 6.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-24 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-01 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-02 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-03 00:00:00', 11.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-18 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-22 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-23 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-26 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-01 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-02 00:00:00', 5.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-05 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-10 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-11 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-15 00:00:00', 5.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-20 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-21 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-25 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-26 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-27 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-28 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-04-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-02 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-03 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-04 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-08 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-09 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-14 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-20 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-01 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-07 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-01 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-02 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-22 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-23 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-24 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-28 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-01 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-03 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-04 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-08 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-09 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-10 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-12 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-16 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-19 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-20 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-21 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-27 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-28 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2009-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-16 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-17 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-19 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-22 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-23 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-27 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-28 00:00:00', 10.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-01-31 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-02 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-03 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-04 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-05 00:00:00', 8.09599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-06 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-07 00:00:00', 7.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-08 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-11 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-12 00:00:00', 1.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-13 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-17 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-18 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-19 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-20 00:00:00', 6.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-22 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-23 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-24 00:00:00', 0.620000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-25 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-26 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-27 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-02-28 00:00:00', 11.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-01 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-03 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-08 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-21 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-22 00:00:00', 5.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-29 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-30 00:00:00', 9.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-03 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-07 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-10 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-11 00:00:00', 58.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-14 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-15 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-20 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-21 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-01 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-02 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-03 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-04 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-05 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-06 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-11 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-16 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-21 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-02 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-14 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-25 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-16 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-03 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-05 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-05 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-06 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-15 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2010-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-04 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-07 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-11 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-13 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-14 00:00:00', 1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-17 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-18 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-20 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-21 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-30 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-01-31 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-02 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-03 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-04 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-06 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-08 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-09 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-11 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-12 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-13 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-18 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-19 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-20 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-21 00:00:00', 0.592000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-22 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-23 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-02-28 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-02 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-04 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-06 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-07 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-11 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-14 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-15 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-16 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-17 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-24 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-25 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-27 00:00:00', 8.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-28 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-01 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-03 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-08 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-09 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-11 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-14 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-23 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-28 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-06 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-10 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-04 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-12 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-26 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-03 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-11 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-12 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-13 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-21 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-22 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-28 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-29 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-30 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-10-31 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-01 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-02 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-03 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-04 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-07 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-08 00:00:00', 12.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-09 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-10 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-14 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-17 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-18 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-23 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-24 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-25 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-26 00:00:00', 20.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-27 00:00:00', 6.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-28 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-01 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-02 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-03 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-05 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-27 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-28 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2011-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-02 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-03 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-04 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-05 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-13 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-14 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-15 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-19 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-22 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-25 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-26 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-30 00:00:00', 5.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-02 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-03 00:00:00', 5.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-04 00:00:00', 0.907999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-05 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-09 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-11 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-12 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-13 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-17 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-18 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-19 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-20 00:00:00', 6.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-22 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-26 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-27 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-02-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-02 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-04 00:00:00', 10.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-06 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-07 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-10 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-11 00:00:00', 6.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-12 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-13 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-14 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-15 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-16 00:00:00', 0.856999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-17 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-18 00:00:00', 0.994000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-19 00:00:00', 11.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-25 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-29 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-30 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-01 00:00:00', 5.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-09 00:00:00', 0.702000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-21 00:00:00', 6.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-22 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-23 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-24 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-25 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-27 00:00:00', 5.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-04-30 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-01 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-02 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-06 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-07 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-08 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-10 00:00:00', 0.386000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-11 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-12 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-15 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-16 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-18 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-19 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-21 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-22 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-25 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-26 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-27 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-22 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-23 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-14 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-15 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-24 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-25 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-30 00:00:00', 0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-10-31 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-01 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-13 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-15 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-16 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-22 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-27 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-28 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-29 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-07 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-16 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-17 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-18 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-23 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-24 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-26 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-27 00:00:00', 16.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2012-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-01 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-08 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-10 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-11 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-12 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-16 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-21 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-22 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-26 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-27 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-30 00:00:00', 10.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-01-31 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-01 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-02 00:00:00', 5.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-03 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-04 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-05 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-09 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-15 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-17 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-18 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-19 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-21 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-22 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-26 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-27 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-03 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-07 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-08 00:00:00', 13.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-09 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-12 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-19 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-20 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-21 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-22 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-23 00:00:00', 4.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-26 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-03-31 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-05 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-12 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-13 00:00:00', 0.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-15 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-21 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-22 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-23 00:00:00', 29.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-24 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-25 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-26 00:00:00', 11.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-29 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-04-30 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-04 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-19 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-26 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-02 00:00:00', 0.0320000015199184418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-03 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-04 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-24 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-27 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-09 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-23 00:00:00', 6.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-28 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-29 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-30 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-04 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-05 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-11 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-19 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-20 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-23 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-24 00:00:00', 1.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-26 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-01 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-05 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-06 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-07 00:00:00', 5.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-10 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-11 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-15 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-16 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-18 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-21 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-27 00:00:00', 0.880999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2013-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-13 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-20 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-21 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-22 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-23 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-24 00:00:00', 7.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-25 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-27 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-29 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-30 00:00:00', 6.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-01-31 00:00:00', 9.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-01 00:00:00', 6.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-02 00:00:00', 13.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-03 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-06 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-19 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-21 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-23 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-24 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-26 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-03 00:00:00', 0.184000000357627869, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-06 00:00:00', 12.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-08 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-13 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-14 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-15 00:00:00', 5.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-16 00:00:00', 4.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-17 00:00:00', 0.970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-18 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-21 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-22 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-23 00:00:00', 11.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-24 00:00:00', 6.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-26 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-27 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-01 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-03 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-04 00:00:00', 6.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-05 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-06 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-10 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-12 00:00:00', 0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-16 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-22 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-24 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-25 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-29 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-04-30 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-01 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-02 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-03 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-04 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-06 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-07 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-08 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-09 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-10 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-18 00:00:00', 4.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-19 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-20 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-29 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-30 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-04 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-06 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (25, '2014-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-08 00:00:00', 12.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-10 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-12 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-13 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-14 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-17 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-18 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-23 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-24 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-25 00:00:00', 8.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-26 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-27 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-04 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-05 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-06 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-09 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-10 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-12 00:00:00', 9.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-13 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-07 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-08 00:00:00', 26.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-09 00:00:00', 9.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-10 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-11 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-12 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-13 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-14 00:00:00', 5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-15 00:00:00', 7.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-16 00:00:00', 5.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-17 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-18 00:00:00', 5.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-19 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-22 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-23 00:00:00', 6.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-24 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-25 00:00:00', 23.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-26 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-27 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-28 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-29 00:00:00', 0.0590000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-04 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-05 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-06 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-07 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-08 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-09 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-10 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-11 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-12 00:00:00', 5.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-13 00:00:00', 14.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-14 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-17 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-18 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-19 00:00:00', 13.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-20 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-21 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-22 00:00:00', 1.17200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-23 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-24 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-25 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-26 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-27 00:00:00', 11.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-02-28 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-01 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-02 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-03 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-04 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-05 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-06 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-07 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-08 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-09 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-10 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-11 00:00:00', 14.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-12 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-13 00:00:00', 8.97299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-14 00:00:00', 9.39299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-15 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-16 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-17 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-18 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-19 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-20 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-21 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-22 00:00:00', 8.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-23 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-24 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-25 00:00:00', 10.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-26 00:00:00', 10.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-27 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-28 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-29 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-30 00:00:00', 5.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-03-31 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-01 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-02 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-03 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-04 00:00:00', 10.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-05 00:00:00', 9.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-06 00:00:00', 11.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-07 00:00:00', 19.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-08 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-09 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-10 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-11 00:00:00', 6.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-12 00:00:00', 10.3559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-13 00:00:00', 0.855000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-14 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-15 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-16 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-17 00:00:00', 6.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-18 00:00:00', 25.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-19 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-20 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-21 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-22 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-23 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-24 00:00:00', 8.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-25 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-26 00:00:00', 11.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-27 00:00:00', 19.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-28 00:00:00', 10.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-29 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-04-30 00:00:00', 7.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-01 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-02 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-03 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-04 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-05 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-06 00:00:00', 6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-07 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-08 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-09 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-10 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-11 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-12 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-13 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-14 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-15 00:00:00', 5.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-16 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-17 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-18 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-19 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-20 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-21 00:00:00', 7.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-22 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-23 00:00:00', 21.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-24 00:00:00', 13.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-25 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-26 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-27 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-28 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-29 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-30 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-05-31 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-01 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-02 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-03 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-04 00:00:00', 0.647000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-05 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-06 00:00:00', 0.437999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-07 00:00:00', 12.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-08 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-09 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-10 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-11 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-12 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-13 00:00:00', 0.767000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-14 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-15 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-16 00:00:00', 0.699000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-17 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-18 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-19 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-20 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-22 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-23 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-24 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-26 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-06-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-01 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-27 00:00:00', 0.953000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-28 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-04 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-05 00:00:00', 7.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-06 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-07 00:00:00', 6.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-08 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-16 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-17 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-28 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-13 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-15 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-23 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-24 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-01 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-06 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-07 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-08 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-09 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-10 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-12 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-15 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-16 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-20 00:00:00', 8.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-21 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-22 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-26 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-27 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-28 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-29 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-30 00:00:00', 28.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-10-31 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-01 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-05 00:00:00', 8.02000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-06 00:00:00', 20.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-07 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-08 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-11 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-13 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-14 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-22 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-23 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-11-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-01 00:00:00', 8.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-02 00:00:00', 7.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-03 00:00:00', 6.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-04 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-05 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-07 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-08 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-09 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-10 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-13 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-14 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-15 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-17 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-18 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-19 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-20 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-21 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-22 00:00:00', 9.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-23 00:00:00', 0.351000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-27 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-28 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-29 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-30 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1979-12-31 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-01 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-02 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-04 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-05 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-07 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-08 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-09 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-10 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-13 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-14 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-15 00:00:00', 16.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-16 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-17 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-18 00:00:00', 7.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-19 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-20 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-21 00:00:00', 8.28400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-22 00:00:00', 19.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-23 00:00:00', 14.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-24 00:00:00', 8.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-25 00:00:00', 12.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-26 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-27 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-28 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-01-31 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-01 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-02 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-03 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-04 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-05 00:00:00', 0.477999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-06 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-08 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-09 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-11 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-12 00:00:00', 12.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-13 00:00:00', 15.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-14 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-16 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-17 00:00:00', 7.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-18 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-19 00:00:00', 6.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-20 00:00:00', 7.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-21 00:00:00', 12.4420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-22 00:00:00', 11.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-23 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-24 00:00:00', 12.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-25 00:00:00', 6.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-26 00:00:00', 22.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-27 00:00:00', 10.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-28 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-02-29 00:00:00', 0.893999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-01 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-02 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-03 00:00:00', 20.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-04 00:00:00', 7.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-05 00:00:00', 14.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-06 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-08 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-09 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-10 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-11 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-12 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-13 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-14 00:00:00', 17.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-15 00:00:00', 18.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-16 00:00:00', 11.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-17 00:00:00', 18.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-18 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-19 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-20 00:00:00', 10.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-21 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-22 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-23 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-24 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-25 00:00:00', 0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-26 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-27 00:00:00', 10.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-28 00:00:00', 13.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-29 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-03-31 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-01 00:00:00', 20.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-02 00:00:00', 7.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-03 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-04 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-05 00:00:00', 7.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-06 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-07 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-08 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-09 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-10 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-11 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-13 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-14 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-15 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-16 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-17 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-18 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-19 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-20 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-21 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-22 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-23 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-24 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-25 00:00:00', 18.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-26 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-27 00:00:00', 8.33899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-28 00:00:00', 14.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-29 00:00:00', 6.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-04-30 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-01 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-02 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-03 00:00:00', 0.663999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-04 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-05 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-06 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-08 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-09 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-10 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-11 00:00:00', 16.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-12 00:00:00', 4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-14 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-15 00:00:00', 6.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-16 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-18 00:00:00', 1.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-20 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-21 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-22 00:00:00', 9.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-23 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-24 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-25 00:00:00', 6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-26 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-05-31 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-01 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-02 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-03 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-11 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-19 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-20 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-25 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-26 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-13 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-14 00:00:00', 6.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-15 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-16 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-17 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-18 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-08 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-11 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-12 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-16 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-17 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-18 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-04 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-10 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-24 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-29 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-09-30 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-01 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-05 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-06 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-07 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-09 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-10 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-11 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-12 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-13 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-14 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-15 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-16 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-17 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-19 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-20 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-21 00:00:00', 6.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-22 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-23 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-29 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-30 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-10-31 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-01 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-02 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-03 00:00:00', 5.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-04 00:00:00', 10.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-05 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-06 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-11 00:00:00', 0.388999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-12 00:00:00', 0.238000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-16 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-17 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-18 00:00:00', 7.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-19 00:00:00', 23.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-20 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-21 00:00:00', 4.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-22 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-23 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-24 00:00:00', 15.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-25 00:00:00', 15.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-26 00:00:00', 12.7030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-27 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-11-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-01 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-02 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-03 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-08 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-09 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-10 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-11 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-12 00:00:00', 4.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-13 00:00:00', 15.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-14 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-16 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-24 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-26 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-27 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-28 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-29 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-30 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1980-12-31 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-01 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-02 00:00:00', 6.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-03 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-04 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-05 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-06 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-07 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-09 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-10 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-12 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-13 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-14 00:00:00', 12.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-15 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-16 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-17 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-18 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-19 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-20 00:00:00', 17.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-21 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-22 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-23 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-24 00:00:00', 5.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-25 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-26 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-27 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-28 00:00:00', 8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-29 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-30 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-01-31 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-01 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-02 00:00:00', 8.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-03 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-04 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-08 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-10 00:00:00', 9.96300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-11 00:00:00', 14.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-12 00:00:00', 7.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-13 00:00:00', 6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-14 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-16 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-17 00:00:00', 11.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-18 00:00:00', 13.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-19 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-20 00:00:00', 9.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-21 00:00:00', 7.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-22 00:00:00', 22.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-23 00:00:00', 12.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-24 00:00:00', 7.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-25 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-26 00:00:00', 10.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-27 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-02-28 00:00:00', 8.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-01 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-03 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-04 00:00:00', 16.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-05 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-06 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-07 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-08 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-09 00:00:00', 6.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-10 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-11 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-14 00:00:00', 9.27499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-15 00:00:00', 9.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-16 00:00:00', 13.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-17 00:00:00', 11.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-18 00:00:00', 7.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-19 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-20 00:00:00', 11.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-21 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-22 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-23 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-24 00:00:00', 6.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-25 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-26 00:00:00', 21.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-27 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-28 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-29 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-30 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-03-31 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-02 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-03 00:00:00', 11.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-04 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-06 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-07 00:00:00', 33.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-08 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-09 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-10 00:00:00', 7.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-11 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-12 00:00:00', 7.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-13 00:00:00', 12.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-14 00:00:00', 17.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-15 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-16 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-18 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-19 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-20 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-21 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-22 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-23 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-24 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-25 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-26 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-27 00:00:00', 6.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-28 00:00:00', 6.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-04-30 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-01 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-02 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-04 00:00:00', 7.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-05 00:00:00', 0.945999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-07 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-08 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-09 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-10 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-11 00:00:00', 13.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-12 00:00:00', 11.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-13 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-14 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-18 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-19 00:00:00', 17.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-20 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-21 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-22 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-23 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-24 00:00:00', 6.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-25 00:00:00', 6.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-26 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-28 00:00:00', 1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-29 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-30 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-05-31 00:00:00', 5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-01 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-05 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-06 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-07 00:00:00', 9.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-08 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-09 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-13 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-14 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-16 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-17 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-18 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-20 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-21 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-22 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-23 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-24 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-25 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-26 00:00:00', 4.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-27 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-28 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-29 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-02 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-03 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-04 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-05 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-07 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-08 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-10 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-11 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-23 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-24 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-27 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-28 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-29 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-07-31 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-01 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-09 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-15 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-17 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-18 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-19 00:00:00', 5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-21 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-24 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-25 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-29 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-10 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-11 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-18 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-19 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-23 00:00:00', 10.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-24 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-09 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-10 00:00:00', 20.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-12 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-14 00:00:00', 11.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-15 00:00:00', 7.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-16 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-18 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-19 00:00:00', 24.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-20 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-24 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-25 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-26 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-27 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-28 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-29 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-30 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-05 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-06 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-07 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-08 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-14 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-15 00:00:00', 5.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-16 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-17 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-19 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-20 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-21 00:00:00', 8.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-22 00:00:00', 16.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-23 00:00:00', 33.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-24 00:00:00', 7.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-25 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-26 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-01 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-02 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-03 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-04 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-05 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-06 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-07 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-08 00:00:00', 8.93700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-09 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-10 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-12 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-13 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-15 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-16 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-17 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-19 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-20 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-21 00:00:00', 10.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-22 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-24 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-25 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-26 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-27 00:00:00', 10.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-28 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-29 00:00:00', 6.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-30 00:00:00', 16.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1981-12-31 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-01 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-02 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-03 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-05 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-06 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-08 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-09 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-10 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-11 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-12 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-13 00:00:00', 10.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-14 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-16 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-17 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-18 00:00:00', 18.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-19 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-20 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-21 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-22 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-26 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-27 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-28 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-29 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-30 00:00:00', 7.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-01-31 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-01 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-02 00:00:00', 8.35000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-03 00:00:00', 4.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-04 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-06 00:00:00', 8.48200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-07 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-09 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-10 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-11 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-12 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-15 00:00:00', 10.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-16 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-19 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-20 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-21 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-22 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-23 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-24 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-25 00:00:00', 0.767000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-26 00:00:00', 6.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-27 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-02-28 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-01 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-02 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-03 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-04 00:00:00', 8.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-05 00:00:00', 6.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-06 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-07 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-08 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-09 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-10 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-11 00:00:00', 8.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-12 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-13 00:00:00', 14.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-14 00:00:00', 11.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-15 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-16 00:00:00', 14.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-17 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-19 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-20 00:00:00', 11.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-21 00:00:00', 12.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-22 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-24 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-26 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-27 00:00:00', 5.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-28 00:00:00', 7.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-29 00:00:00', 8.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-30 00:00:00', 10.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-03-31 00:00:00', 6.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-03 00:00:00', 6.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-04 00:00:00', 7.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-05 00:00:00', 0.184000000357627869, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-11 00:00:00', 5.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-12 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-14 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-15 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-16 00:00:00', 5.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-17 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-21 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-22 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-23 00:00:00', 14.8809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-24 00:00:00', 7.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-25 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-26 00:00:00', 9.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-27 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-28 00:00:00', 12.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-29 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-04-30 00:00:00', 0.537000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-01 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-06 00:00:00', 17.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-07 00:00:00', 14.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-08 00:00:00', 11.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-09 00:00:00', 11.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-10 00:00:00', 8.05799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-12 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-13 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-14 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-15 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-17 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-18 00:00:00', 8.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-19 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-20 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-21 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-22 00:00:00', 14.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-23 00:00:00', 6.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-24 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-25 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-26 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-27 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-28 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-29 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-04 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-07 00:00:00', 0.554000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-13 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-14 00:00:00', 9.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-20 00:00:00', 0.602999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-26 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-27 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-28 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-29 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-06-30 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-01 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-02 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-03 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-04 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-05 00:00:00', 7.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-06 00:00:00', 10.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-07 00:00:00', 0.0780000016093254089, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-10 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-11 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-12 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-13 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-14 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-15 00:00:00', 0.718999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-16 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-11 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-12 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-20 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-23 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-25 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-26 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-27 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-30 00:00:00', 0.805000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-13 00:00:00', 0.930999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-14 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-15 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-17 00:00:00', 5.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-19 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-20 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-26 00:00:00', 0.898000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-27 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-29 00:00:00', 0.856999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-09-30 00:00:00', 11.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-01 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-02 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-03 00:00:00', 8.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-04 00:00:00', 23.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-05 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-06 00:00:00', 20.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-07 00:00:00', 11.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-08 00:00:00', 28.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-09 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-10 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-11 00:00:00', 14.6129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-12 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-14 00:00:00', 0.947000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-15 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-16 00:00:00', 5.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-18 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-19 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-20 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-21 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-22 00:00:00', 7.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-23 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-24 00:00:00', 9.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-25 00:00:00', 15.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-26 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-10-31 00:00:00', 0.259999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-01 00:00:00', 8.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-02 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-03 00:00:00', 8.81700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-04 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-05 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-07 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-08 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-09 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-10 00:00:00', 16.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-11 00:00:00', 16.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-12 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-13 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-14 00:00:00', 27.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-15 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-16 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-20 00:00:00', 8.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-21 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-27 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-28 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-29 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-11-30 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-01 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-02 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-04 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-06 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-07 00:00:00', 8.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-08 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-09 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-12 00:00:00', 0.120999999344348907, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-16 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-17 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-18 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-19 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-27 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-28 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-29 00:00:00', 6.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-30 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1982-12-31 00:00:00', 5.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-02 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-03 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-04 00:00:00', 6.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-05 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-06 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-07 00:00:00', 6.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-08 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-09 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-11 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-12 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-13 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-14 00:00:00', 8.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-15 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-16 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-17 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-20 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-21 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-22 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-23 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-25 00:00:00', 14.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-26 00:00:00', 5.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-27 00:00:00', 6.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-28 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-09 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-10 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-11 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-16 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-17 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-18 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-19 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-20 00:00:00', 5.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-21 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-22 00:00:00', 16.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-23 00:00:00', 9.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-24 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-26 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-27 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-02-28 00:00:00', 10.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-01 00:00:00', 10.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-02 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-03 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-04 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-05 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-06 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-07 00:00:00', 24.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-08 00:00:00', 6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-10 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-11 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-14 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-15 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-17 00:00:00', 12.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-18 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-19 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-20 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-23 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-24 00:00:00', 8.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-25 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-26 00:00:00', 7.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-27 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-28 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-29 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-30 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-03-31 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-03 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-04 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-05 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-06 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-07 00:00:00', 9.23900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-08 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-09 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-11 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-12 00:00:00', 6.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-13 00:00:00', 13.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-14 00:00:00', 0.970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-15 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-16 00:00:00', 9.21800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-17 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-18 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-19 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-20 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-21 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-22 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-23 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-24 00:00:00', 10.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-25 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-26 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-27 00:00:00', 7.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-28 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-29 00:00:00', 23.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-04-30 00:00:00', 32.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-01 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-02 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-03 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-04 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-05 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-06 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-08 00:00:00', 10.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-09 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-10 00:00:00', 11.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-11 00:00:00', 6.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-13 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-15 00:00:00', 5.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-16 00:00:00', 6.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-17 00:00:00', 15.2440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-18 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-19 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-20 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-21 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-23 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-26 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-27 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-28 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-29 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-30 00:00:00', 15.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-05-31 00:00:00', 13.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-01 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-03 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-06 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-07 00:00:00', 7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-08 00:00:00', 6.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-09 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-10 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-14 00:00:00', 14.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-15 00:00:00', 6.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-16 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-17 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-18 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-19 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-21 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-22 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-26 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-28 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-01 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-02 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-03 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-05 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-06 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-07 00:00:00', 12.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-08 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-09 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-10 00:00:00', 5.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-18 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-19 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-07 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-08 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-17 00:00:00', 0.976999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-19 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-03 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-09 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-11 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-23 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-27 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-29 00:00:00', 1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-02 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-03 00:00:00', 6.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-04 00:00:00', 1.08700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-05 00:00:00', 7.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-09 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-10 00:00:00', 0.0109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-12 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-13 00:00:00', 12.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-14 00:00:00', 13.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-15 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-16 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-17 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-19 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-20 00:00:00', 6.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-21 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-22 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-24 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-25 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-26 00:00:00', 11.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-27 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-28 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-29 00:00:00', 11.9940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-11-30 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-01 00:00:00', 7.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-02 00:00:00', 5.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-03 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-04 00:00:00', 9.41399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-05 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-06 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-08 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-09 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-10 00:00:00', 6.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-11 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-12 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-13 00:00:00', 4.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-14 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-15 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-16 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-17 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-18 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-28 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-29 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-30 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1983-12-31 00:00:00', 10.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-01 00:00:00', 0.907999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-03 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-04 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-05 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-09 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-10 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-11 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-12 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-13 00:00:00', 0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-15 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-16 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-17 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-18 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-19 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-21 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-22 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-25 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-26 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-27 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-28 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-30 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-01-31 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-01 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-03 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-04 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-05 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-06 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-07 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-08 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-09 00:00:00', 9.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-10 00:00:00', 6.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-11 00:00:00', 11.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-12 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-13 00:00:00', 14.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-14 00:00:00', 23.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-15 00:00:00', 11.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-16 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-17 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-18 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-19 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-20 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-21 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-22 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-23 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-24 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-26 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-27 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-28 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-02-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-01 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-02 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-03 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-04 00:00:00', 17.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-05 00:00:00', 0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-07 00:00:00', 6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-08 00:00:00', 27.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-09 00:00:00', 38.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-10 00:00:00', 11.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-11 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-13 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-14 00:00:00', 9.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-15 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-16 00:00:00', 17.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-17 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-18 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-19 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-20 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-21 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-22 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-24 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-25 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-26 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-27 00:00:00', 34.6570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-28 00:00:00', 38.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-29 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-03-31 00:00:00', 5.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-01 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-02 00:00:00', 0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-03 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-04 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-05 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-06 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-07 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-08 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-09 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-10 00:00:00', 6.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-11 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-12 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-13 00:00:00', 36.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-14 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-18 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-19 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-20 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-23 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-24 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-26 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-27 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-29 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-04-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-01 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-02 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-03 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-04 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-06 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-07 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-08 00:00:00', 8.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-09 00:00:00', 0.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-11 00:00:00', 0.995000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-12 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-13 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-14 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-15 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-16 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-17 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-18 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-19 00:00:00', 9.65900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-20 00:00:00', 7.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-21 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-22 00:00:00', 7.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-23 00:00:00', 6.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-24 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-25 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-27 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-28 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-29 00:00:00', 6.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-03 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-04 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-08 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-09 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-10 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-11 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-01 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-02 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-20 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-07 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-10 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-12 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-06 00:00:00', 0.370000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-07 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-08 00:00:00', 16.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-09 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-13 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-14 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-18 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-19 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-21 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-22 00:00:00', 10.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-29 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-02 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-03 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-04 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-06 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-07 00:00:00', 10.7100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-08 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-09 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-10 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-11 00:00:00', 6.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-13 00:00:00', 10.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-14 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-15 00:00:00', 14.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-16 00:00:00', 15.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-17 00:00:00', 11.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-18 00:00:00', 6.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-19 00:00:00', 17.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-20 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-21 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-22 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-23 00:00:00', 0.368999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-24 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-25 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-26 00:00:00', 0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-27 00:00:00', 8.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-28 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-11-30 00:00:00', 16.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-01 00:00:00', 12.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-02 00:00:00', 9.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-04 00:00:00', 0.291000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-05 00:00:00', 10.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-06 00:00:00', 6.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-07 00:00:00', 7.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-08 00:00:00', 19.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-09 00:00:00', 0.517000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-10 00:00:00', 1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-11 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-12 00:00:00', 6.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-13 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-15 00:00:00', 17.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-16 00:00:00', 8.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-21 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-22 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-25 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-28 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-29 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-30 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1984-12-31 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-01 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-02 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-03 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-04 00:00:00', 4.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-05 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-06 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-10 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-11 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-12 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-13 00:00:00', 11.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-14 00:00:00', 14.9709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-15 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-16 00:00:00', 13.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-17 00:00:00', 19.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-18 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-19 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-20 00:00:00', 10.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-21 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-22 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-23 00:00:00', 11.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-24 00:00:00', 6.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-25 00:00:00', 9.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-26 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-28 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-29 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-01 00:00:00', 11.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-02 00:00:00', 9.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-03 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-04 00:00:00', 14.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-05 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-07 00:00:00', 12.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-08 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-09 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-10 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-11 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-12 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-18 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-19 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-20 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-21 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-22 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-23 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-24 00:00:00', 12.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-25 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-26 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-27 00:00:00', 0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-02-28 00:00:00', 12.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-01 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-02 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-03 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-04 00:00:00', 23.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-05 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-06 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-07 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-08 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-09 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-10 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-11 00:00:00', 7.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-12 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-14 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-15 00:00:00', 11.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-16 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-17 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-20 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-21 00:00:00', 7.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-22 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-23 00:00:00', 7.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-24 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-25 00:00:00', 14.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-26 00:00:00', 17.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-27 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-28 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-29 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-30 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-03-31 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-01 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-02 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-03 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-04 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-05 00:00:00', 11.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-06 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-07 00:00:00', 28.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-08 00:00:00', 18.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-09 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-12 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-13 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-14 00:00:00', 6.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-15 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-16 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-17 00:00:00', 17.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-18 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-21 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-23 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-27 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-28 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-29 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-04-30 00:00:00', 9.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-01 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-02 00:00:00', 21.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-03 00:00:00', 17.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-04 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-05 00:00:00', 8.85299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-06 00:00:00', 10.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-07 00:00:00', 20.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-08 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-09 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-10 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-11 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-12 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-13 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-19 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-20 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-21 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-22 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-23 00:00:00', 7.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-24 00:00:00', 9.27999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-25 00:00:00', 4.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-26 00:00:00', 5.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-27 00:00:00', 11.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-28 00:00:00', 13.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-29 00:00:00', 7.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-30 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-05-31 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-01 00:00:00', 8.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-02 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-07 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-08 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-09 00:00:00', 0.319999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-10 00:00:00', 8.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-11 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-12 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-13 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-14 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-15 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-18 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-19 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-20 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-22 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-26 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-29 00:00:00', 0.521000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-06-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-01 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-18 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-07-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-14 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-19 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-29 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-30 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-05 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-11 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-12 00:00:00', 24.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-13 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-14 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-15 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-16 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-22 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-23 00:00:00', 14.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-24 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-26 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-27 00:00:00', 0.458999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-28 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-29 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-30 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-10-31 00:00:00', 7.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-01 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-03 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-04 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-09 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-11 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-12 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-15 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-16 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-17 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-18 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-19 00:00:00', 6.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-20 00:00:00', 8.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-21 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-23 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-24 00:00:00', 6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-25 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-01 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-02 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-03 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-04 00:00:00', 7.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-05 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-06 00:00:00', 16.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-07 00:00:00', 10.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-08 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-09 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-13 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-14 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-15 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-17 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-18 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-19 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-20 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-21 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-22 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-23 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-24 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-25 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-26 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-28 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-29 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-30 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1985-12-31 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-01 00:00:00', 0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-05 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-06 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-11 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-12 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-13 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-14 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-15 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-16 00:00:00', 26.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-17 00:00:00', 8.77499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-18 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-20 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-21 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-22 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-24 00:00:00', 5.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-25 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-27 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-28 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-29 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-01 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-02 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-03 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-04 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-06 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-08 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-09 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-12 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-13 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-14 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-15 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-16 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-17 00:00:00', 6.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-18 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-22 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-23 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-24 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-25 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-27 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-02-28 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-01 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-02 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-03 00:00:00', 13.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-04 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-05 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-10 00:00:00', 0.836000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-11 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-12 00:00:00', 16.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-13 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-14 00:00:00', 0.222000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-15 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-16 00:00:00', 5.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-17 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-18 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-20 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-21 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-23 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-24 00:00:00', 0.870999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-25 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-26 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-27 00:00:00', 9.76799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-28 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-29 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-30 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-03-31 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-01 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-04 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-05 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-06 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-07 00:00:00', 7.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-08 00:00:00', 13.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-09 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-10 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-11 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-12 00:00:00', 17.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-13 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-14 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-16 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-18 00:00:00', 7.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-19 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-21 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-22 00:00:00', 22.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-23 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-24 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-25 00:00:00', 6.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-26 00:00:00', 6.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-27 00:00:00', 12.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-28 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-29 00:00:00', 4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-04-30 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-02 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-06 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-07 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-08 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-09 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-12 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-13 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-14 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-15 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-16 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-17 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-18 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-19 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-21 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-22 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-24 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-25 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-26 00:00:00', 5.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-27 00:00:00', 7.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-28 00:00:00', 5.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-29 00:00:00', 13.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-30 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-01 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-02 00:00:00', 5.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-03 00:00:00', 6.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-04 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-05 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-06 00:00:00', 7.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-07 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-09 00:00:00', 9.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-10 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-11 00:00:00', 0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-14 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-15 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-20 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-21 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-24 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-13 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-22 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-24 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-08 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-27 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-09-30 00:00:00', 14.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-01 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-04 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-06 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-07 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-08 00:00:00', 15.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-09 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-10 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-12 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-13 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-14 00:00:00', 32.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-15 00:00:00', 6.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-16 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-19 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-22 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-23 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-24 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-29 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-06 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-08 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-09 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-10 00:00:00', 10.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-11 00:00:00', 10.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-12 00:00:00', 10.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-13 00:00:00', 11.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-14 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-15 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-16 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-17 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-18 00:00:00', 0.847000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-19 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-20 00:00:00', 9.68700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-21 00:00:00', 9.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-22 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-25 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-26 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-28 00:00:00', 0.222000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-29 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-11-30 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-01 00:00:00', 7.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-02 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-03 00:00:00', 12.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-04 00:00:00', 12.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-05 00:00:00', 6.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-06 00:00:00', 6.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-07 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-09 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-10 00:00:00', 18.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-11 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-12 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-13 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-18 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-20 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-21 00:00:00', 6.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-22 00:00:00', 5.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-23 00:00:00', 6.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-24 00:00:00', 0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-01 00:00:00', 7.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-02 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-04 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-05 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-08 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-12 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-13 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-15 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-16 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-18 00:00:00', 7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-19 00:00:00', 16.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-20 00:00:00', 8.02000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-21 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-22 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-25 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-26 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-27 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-28 00:00:00', 8.43000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-29 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-30 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-01-31 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-01 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-02 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-03 00:00:00', 7.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-06 00:00:00', 10.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-07 00:00:00', 9.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-08 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-10 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-11 00:00:00', 8.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-12 00:00:00', 7.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-14 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-15 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-16 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-17 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-20 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-21 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-22 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-23 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-02-28 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-01 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-02 00:00:00', 9.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-03 00:00:00', 12.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-04 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-05 00:00:00', 22.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-06 00:00:00', 31.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-07 00:00:00', 10.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-08 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-09 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-10 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-11 00:00:00', 22.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-12 00:00:00', 10.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-13 00:00:00', 22.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-14 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-15 00:00:00', 33.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-16 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-17 00:00:00', 16.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-18 00:00:00', 14.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-19 00:00:00', 7.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-20 00:00:00', 9.72799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-21 00:00:00', 5.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-22 00:00:00', 7.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-23 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-25 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-27 00:00:00', 5.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-28 00:00:00', 9.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-29 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-30 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-03-31 00:00:00', 0.428000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-01 00:00:00', 9.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-02 00:00:00', 9.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-03 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-04 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-05 00:00:00', 9.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-06 00:00:00', 32.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-07 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-08 00:00:00', 13.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-09 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-10 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-11 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-12 00:00:00', 0.822000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-13 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-14 00:00:00', 8.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-15 00:00:00', 14.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-16 00:00:00', 16.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-17 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-18 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-19 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-20 00:00:00', 15.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-21 00:00:00', 9.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-22 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-27 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-28 00:00:00', 20.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-29 00:00:00', 4.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-04-30 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-01 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-03 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-04 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-05 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-09 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-10 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-15 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-16 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-17 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-18 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-19 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-20 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-21 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-22 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-27 00:00:00', 6.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-28 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-29 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-30 00:00:00', 12.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-05-31 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-01 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-02 00:00:00', 6.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-03 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-04 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-06 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-07 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-08 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-13 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-15 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-16 00:00:00', 11.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-19 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-20 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-24 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-25 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-26 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-27 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-29 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-06-30 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-01 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-02 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-03 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-05 00:00:00', 11.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-08 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-11 00:00:00', 8.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-12 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-13 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-14 00:00:00', 16.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-15 00:00:00', 10.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-16 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-17 00:00:00', 9.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-18 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-19 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-20 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-21 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-24 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-25 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-26 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-27 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-29 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-30 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-07-31 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-01 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-03 00:00:00', 8.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-04 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-06 00:00:00', 0.592000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-07 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-11 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-12 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-08 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-16 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-20 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-21 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-24 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-09-30 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-01 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-02 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-07 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-08 00:00:00', 12.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-09 00:00:00', 13.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-10 00:00:00', 24.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-11 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-12 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-13 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-17 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-18 00:00:00', 0.851999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-19 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-21 00:00:00', 0.243000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-22 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-23 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-24 00:00:00', 11.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-25 00:00:00', 4.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-26 00:00:00', 31.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-27 00:00:00', 15.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-28 00:00:00', 10.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-29 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-10-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-03 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-04 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-05 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-08 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-09 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-10 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-15 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-16 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-22 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-23 00:00:00', 14.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-24 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-25 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-26 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-27 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-28 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-29 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-11-30 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-01 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-02 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-07 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-08 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-09 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-10 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-11 00:00:00', 6.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-12 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-14 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-15 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-16 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-17 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-21 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-22 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-24 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-25 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-26 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-27 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-28 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-29 00:00:00', 29.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-30 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1987-12-31 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-01 00:00:00', 8.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-02 00:00:00', 0.483000010251998901, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-03 00:00:00', 12.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-07 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-08 00:00:00', 10.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-09 00:00:00', 0.0900000035762786865, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-12 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-14 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-15 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-16 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-17 00:00:00', 9.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-18 00:00:00', 1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-19 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-20 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-21 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-22 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-24 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-25 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-26 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-27 00:00:00', 6.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-28 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-29 00:00:00', 6.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-30 00:00:00', 8.46300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-01-31 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-01 00:00:00', 7.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-02 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-03 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-04 00:00:00', 9.62199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-05 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-06 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-07 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-08 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-14 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-15 00:00:00', 0.546999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-16 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-18 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-19 00:00:00', 8.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-20 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-21 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-22 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-23 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-26 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-27 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-28 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-02-29 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-01 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-02 00:00:00', 16.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-03 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-06 00:00:00', 17.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-07 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-09 00:00:00', 9.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-10 00:00:00', 14.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-11 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-12 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-13 00:00:00', 14.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-14 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-15 00:00:00', 9.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-16 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-17 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-18 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-19 00:00:00', 1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-20 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-21 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-22 00:00:00', 21.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-23 00:00:00', 6.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-24 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-25 00:00:00', 16.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-26 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-27 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-28 00:00:00', 16.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-29 00:00:00', 15.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-30 00:00:00', 14.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-03-31 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-01 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-02 00:00:00', 16.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-03 00:00:00', 12.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-04 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-05 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-06 00:00:00', 0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-07 00:00:00', 1.08700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-08 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-09 00:00:00', 8.47000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-10 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-12 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-13 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-14 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-16 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-17 00:00:00', 8.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-18 00:00:00', 5.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-19 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-20 00:00:00', 0.126000002026557922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-22 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-23 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-24 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-25 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-26 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-27 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-28 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-29 00:00:00', 11.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-04-30 00:00:00', 6.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-01 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-02 00:00:00', 8.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-03 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-04 00:00:00', 9.07900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-05 00:00:00', 18.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-06 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-07 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-08 00:00:00', 8.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-09 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-10 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-11 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-12 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-13 00:00:00', 7.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-14 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-15 00:00:00', 6.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-16 00:00:00', 30.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-17 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-18 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-19 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-22 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-23 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-24 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-25 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-27 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-30 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-05-31 00:00:00', 9.50300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-01 00:00:00', 6.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-02 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-04 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-05 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-06 00:00:00', 5.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-07 00:00:00', 0.365000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-08 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-09 00:00:00', 12.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-10 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-11 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-13 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-14 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-15 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-16 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-20 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-21 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-22 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-28 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-29 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-02 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-06 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-07 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-08 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-09 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-10 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-12 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-13 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-14 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-18 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-21 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-22 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-23 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-07-31 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-01 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-26 00:00:00', 0.368999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-27 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-30 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-08-31 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-01 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-02 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-06 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-07 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-15 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-17 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-21 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-22 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-03 00:00:00', 0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-04 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-06 00:00:00', 1.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-07 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-08 00:00:00', 11.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-09 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-10 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-11 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-12 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-13 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-15 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-16 00:00:00', 11.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-17 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-21 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-22 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-23 00:00:00', 28.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-24 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-28 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-29 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-30 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-01 00:00:00', 0.883000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-02 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-03 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-05 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-06 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-08 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-09 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-15 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-16 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-20 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-21 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-22 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-23 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-24 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-26 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-29 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-11-30 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-01 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-02 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-05 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-06 00:00:00', 0.674000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-07 00:00:00', 6.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-13 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-14 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-15 00:00:00', 7.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-16 00:00:00', 13.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-17 00:00:00', 7.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-18 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-19 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-20 00:00:00', 11.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-21 00:00:00', 28.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-22 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-23 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-24 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-25 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-26 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-27 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-28 00:00:00', 22.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-29 00:00:00', 19.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-30 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1988-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-01 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-03 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-04 00:00:00', 10.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-05 00:00:00', 10.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-06 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-07 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-08 00:00:00', 0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-10 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-13 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-14 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-15 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-16 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-18 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-19 00:00:00', 6.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-22 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-25 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-26 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-27 00:00:00', 9.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-28 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-29 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-30 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-01-31 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-02 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-03 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-04 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-05 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-06 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-07 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-12 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-13 00:00:00', 8.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-14 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-15 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-16 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-17 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-18 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-19 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-20 00:00:00', 10.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-21 00:00:00', 7.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-22 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-23 00:00:00', 7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-24 00:00:00', 15.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-25 00:00:00', 5.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-26 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-27 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-02-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-01 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-02 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-03 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-05 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-06 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-07 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-08 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-09 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-12 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-13 00:00:00', 7.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-14 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-15 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-16 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-17 00:00:00', 9.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-18 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-19 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-20 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-21 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-22 00:00:00', 14.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-23 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-24 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-28 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-29 00:00:00', 7.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-30 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-03-31 00:00:00', 18.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-01 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-02 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-03 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-04 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-05 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-07 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-08 00:00:00', 6.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-09 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-10 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-11 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-12 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-15 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-16 00:00:00', 25.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-17 00:00:00', 15.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-18 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-21 00:00:00', 0.574999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-22 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-23 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-24 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-25 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-26 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-27 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-28 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-04-30 00:00:00', 17.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-01 00:00:00', 14.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-02 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-03 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-04 00:00:00', 1.02499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-05 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-06 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-08 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-09 00:00:00', 19.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-10 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-11 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-12 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-13 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-14 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-15 00:00:00', 16.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-16 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-17 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-18 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-20 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-21 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-22 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-23 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-24 00:00:00', 0.620000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-27 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-28 00:00:00', 0.801999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-29 00:00:00', 0.758000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-30 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-05-31 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-01 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-02 00:00:00', 9.47000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-03 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-04 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-07 00:00:00', 5.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-08 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-09 00:00:00', 0.460999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-12 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-14 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-15 00:00:00', 6.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-16 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-17 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-18 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-19 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-20 00:00:00', 0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-21 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-23 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-26 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-28 00:00:00', 0.691999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-06-30 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-01 00:00:00', 0.492000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-02 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-06 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-15 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-16 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-17 00:00:00', 0.957000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-18 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-19 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-20 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-21 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-22 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-23 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-07-31 00:00:00', 9.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-01 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-09 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-27 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-28 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-08-31 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-20 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-21 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-22 00:00:00', 18.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-23 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-28 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-29 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-09-30 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-10 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-11 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-12 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-13 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-14 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-18 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-23 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-24 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-29 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-30 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-10-31 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-01 00:00:00', 40.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-02 00:00:00', 4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-07 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-08 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-16 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-17 00:00:00', 7.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-18 00:00:00', 6.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-21 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-22 00:00:00', 21.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-23 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-25 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-26 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-03 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-04 00:00:00', 15.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-05 00:00:00', 18.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-06 00:00:00', 42.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-07 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-08 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-14 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-15 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-16 00:00:00', 15.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-17 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-18 00:00:00', 7.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-24 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-25 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-26 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-27 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-28 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-29 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-30 00:00:00', 0.759999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1989-12-31 00:00:00', 10.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-01 00:00:00', 12.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-02 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-03 00:00:00', 6.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-04 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-05 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-06 00:00:00', 12.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-07 00:00:00', 17.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-08 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-09 00:00:00', 6.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-10 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-11 00:00:00', 9.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-12 00:00:00', 7.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-13 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-16 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-17 00:00:00', 6.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-18 00:00:00', 0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-22 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-23 00:00:00', 0.740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-25 00:00:00', 1.02499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-26 00:00:00', 6.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-27 00:00:00', 5.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-28 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-01-31 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-01 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-02 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-03 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-04 00:00:00', 8.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-05 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-06 00:00:00', 8.48900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-07 00:00:00', 9.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-08 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-10 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-11 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-12 00:00:00', 16.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-13 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-14 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-15 00:00:00', 0.750999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-16 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-17 00:00:00', 13.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-18 00:00:00', 0.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-20 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-21 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-22 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-23 00:00:00', 0.575999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-24 00:00:00', 0.485000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-25 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-26 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-27 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-02-28 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-04 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-06 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-07 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-08 00:00:00', 16.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-09 00:00:00', 9.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-10 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-11 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-12 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-13 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-14 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-15 00:00:00', 20.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-16 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-17 00:00:00', 6.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-18 00:00:00', 9.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-19 00:00:00', 5.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-20 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-21 00:00:00', 9.56999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-22 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-23 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-24 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-26 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-27 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-28 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-29 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-30 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-03-31 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-01 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-03 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-04 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-05 00:00:00', 7.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-06 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-07 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-08 00:00:00', 13.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-09 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-10 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-11 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-12 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-13 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-14 00:00:00', 9.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-15 00:00:00', 8.62399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-16 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-17 00:00:00', 10.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-18 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-19 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-20 00:00:00', 9.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-21 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-23 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-24 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-25 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-26 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-27 00:00:00', 7.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-28 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-29 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-04-30 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-01 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-02 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-03 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-05 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-06 00:00:00', 11.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-07 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-08 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-09 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-10 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-14 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-15 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-23 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-24 00:00:00', 8.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-25 00:00:00', 10.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-26 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-27 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-28 00:00:00', 11.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-30 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-05-31 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-03 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-04 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-05 00:00:00', 21.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-06 00:00:00', 7.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-08 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-09 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-10 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-11 00:00:00', 7.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-12 00:00:00', 5.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-25 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-05 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-08 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-09 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-12 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-13 00:00:00', 0.345999985933303833, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-14 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-21 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-03 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-04 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-22 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-03 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-04 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-06 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-07 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-13 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-15 00:00:00', 5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-16 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-18 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-19 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-23 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-24 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-27 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-28 00:00:00', 6.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-29 00:00:00', 16.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-30 00:00:00', 17.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-10-31 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-01 00:00:00', 11.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-02 00:00:00', 11.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-03 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-10 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-12 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-14 00:00:00', 13.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-15 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-16 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-17 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-22 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-27 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-28 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-11-30 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-06 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-07 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-08 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-09 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-10 00:00:00', 5.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-11 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-12 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-13 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-14 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-18 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-19 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-20 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-21 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-22 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-23 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-24 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-25 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-26 00:00:00', 34.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-27 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-28 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-29 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1990-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-04 00:00:00', 1.18299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-05 00:00:00', 8.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-06 00:00:00', 10.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-07 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-08 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-10 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-11 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-12 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-15 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-16 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-17 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-18 00:00:00', 9.68299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-19 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-20 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-21 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-23 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-24 00:00:00', 12.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-25 00:00:00', 7.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-26 00:00:00', 12.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-27 00:00:00', 17.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-28 00:00:00', 11.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-29 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-01-31 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-01 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-02 00:00:00', 12.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-03 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-04 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-05 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-06 00:00:00', 6.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-07 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-08 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-09 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-10 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-11 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-12 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-13 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-14 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-15 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-19 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-24 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-25 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-26 00:00:00', 1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-27 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-01 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-02 00:00:00', 8.78600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-03 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-04 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-05 00:00:00', 10.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-06 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-07 00:00:00', 10.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-08 00:00:00', 18.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-09 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-10 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-11 00:00:00', 7.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-12 00:00:00', 17.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-13 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-15 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-16 00:00:00', 8.16399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-17 00:00:00', 19.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-18 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-19 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-20 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-21 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-22 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-23 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-24 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-25 00:00:00', 0.597999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-26 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-28 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-29 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-02 00:00:00', 8.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-03 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-06 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-07 00:00:00', 13.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-08 00:00:00', 7.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-09 00:00:00', 7.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-10 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-11 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-12 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-13 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-14 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-15 00:00:00', 14.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-16 00:00:00', 5.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-17 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-20 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-21 00:00:00', 9.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-22 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-23 00:00:00', 7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-24 00:00:00', 8.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-25 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-26 00:00:00', 7.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-27 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-28 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-29 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-04-30 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-01 00:00:00', 23.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-02 00:00:00', 11.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-03 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-04 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-05 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-08 00:00:00', 5.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-09 00:00:00', 11.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-10 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-12 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-13 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-15 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-16 00:00:00', 24.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-17 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-18 00:00:00', 6.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-19 00:00:00', 8.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-20 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-21 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-23 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-24 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-25 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-26 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-27 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-28 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-29 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-30 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-05-31 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-01 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-02 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-04 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-05 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-06 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-07 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-08 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-09 00:00:00', 7.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-10 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-11 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-15 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-16 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-17 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-18 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-19 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-20 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-21 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-22 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-24 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-25 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-29 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-06-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-03 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-04 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-05 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-06 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-07 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-12 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-13 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-15 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-26 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-27 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-07 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-08 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-09 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-13 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-14 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-23 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-25 00:00:00', 6.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-26 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-27 00:00:00', 9.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-28 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-29 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-09-30 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-01 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-02 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-03 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-05 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-06 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-07 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-11 00:00:00', 7.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-18 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-21 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-25 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-26 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-27 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-28 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-03 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-04 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-07 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-08 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-09 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-10 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-11 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-13 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-14 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-16 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-17 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-18 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-19 00:00:00', 9.09099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-20 00:00:00', 9.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-21 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-23 00:00:00', 10.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-24 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-27 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-28 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-29 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-02 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-03 00:00:00', 13.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-04 00:00:00', 8.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-05 00:00:00', 12.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-06 00:00:00', 11.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-07 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-08 00:00:00', 0.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-09 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-10 00:00:00', 6.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-11 00:00:00', 5.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-12 00:00:00', 7.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-13 00:00:00', 29.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-14 00:00:00', 33.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-15 00:00:00', 19.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-16 00:00:00', 34.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-17 00:00:00', 24.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-18 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-21 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-22 00:00:00', 0.851999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-26 00:00:00', 0.307999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-27 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-28 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-29 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-30 00:00:00', 0.976999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1991-12-31 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-01 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-02 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-03 00:00:00', 9.57699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-04 00:00:00', 23.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-05 00:00:00', 7.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-06 00:00:00', 5.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-07 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-08 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-09 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-10 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-11 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-12 00:00:00', 0.126000002026557922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-13 00:00:00', 0.976999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-14 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-15 00:00:00', 0.684000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-16 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-17 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-18 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-19 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-21 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-22 00:00:00', 0.703000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-23 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-24 00:00:00', 7.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-25 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-26 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-27 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-28 00:00:00', 0.107000000774860382, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-29 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-30 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-01-31 00:00:00', 0.970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-01 00:00:00', 10.0679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-02 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-03 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-04 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-05 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-06 00:00:00', 6.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-07 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-09 00:00:00', 7.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-10 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-11 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-12 00:00:00', 15.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-13 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-15 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-16 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-17 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-22 00:00:00', 6.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-23 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-24 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-25 00:00:00', 9.40400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-26 00:00:00', 15.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-27 00:00:00', 20.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-28 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-02-29 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-01 00:00:00', 0.990999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-02 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-03 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-04 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-05 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-07 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-08 00:00:00', 5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-09 00:00:00', 6.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-10 00:00:00', 7.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-11 00:00:00', 14.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-12 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-13 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-15 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-16 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-17 00:00:00', 12.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-18 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-19 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-20 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-21 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-22 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-23 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-24 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-25 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-26 00:00:00', 5.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-27 00:00:00', 0.107000000774860382, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-29 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-30 00:00:00', 7.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-03-31 00:00:00', 15.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-01 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-02 00:00:00', 6.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-03 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-04 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-05 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-06 00:00:00', 6.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-07 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-10 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-11 00:00:00', 0.811999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-12 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-15 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-16 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-17 00:00:00', 9.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-18 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-19 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-20 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-21 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-22 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-23 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-24 00:00:00', 12.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-25 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-26 00:00:00', 10.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-27 00:00:00', 7.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-28 00:00:00', 14.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-29 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-04-30 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-01 00:00:00', 18.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-02 00:00:00', 13.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-03 00:00:00', 8.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-04 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-05 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-06 00:00:00', 13.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-07 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-08 00:00:00', 6.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-09 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-10 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-11 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-12 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-13 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-14 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-15 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-16 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-17 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-18 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-19 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-20 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-21 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-22 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-23 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-24 00:00:00', 12.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-25 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-26 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-27 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-28 00:00:00', 0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-29 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-01 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-02 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-04 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-05 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-06 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-07 00:00:00', 5.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-08 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-09 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-10 00:00:00', 9.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-11 00:00:00', 0.356000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-12 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-13 00:00:00', 6.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-15 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-16 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-17 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-18 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-21 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-22 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-23 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-24 00:00:00', 0.575999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-28 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-29 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-06-30 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-01 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-02 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-09 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-12 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-15 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-08 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-27 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-30 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-08-31 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-06 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-07 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-17 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-18 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-19 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-24 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-09-30 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-06 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-07 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-08 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-09 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-16 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-17 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-21 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-25 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-26 00:00:00', 0.949000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-29 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-30 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-03 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-04 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-05 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-09 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-11 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-13 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-14 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-15 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-16 00:00:00', 19.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-17 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-18 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-19 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-20 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-27 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-28 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-29 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-01 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-02 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-03 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-04 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-05 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-06 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-07 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-08 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-09 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-10 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-11 00:00:00', 12.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-12 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-13 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-14 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-15 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-16 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-17 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-18 00:00:00', 18.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-19 00:00:00', 8.30500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-20 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-21 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-22 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-23 00:00:00', 18.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-24 00:00:00', 9.55099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-25 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-26 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-27 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-28 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-29 00:00:00', 14.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-30 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1992-12-31 00:00:00', 10.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-01 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-02 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-03 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-04 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-05 00:00:00', 4.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-06 00:00:00', 8.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-07 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-09 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-10 00:00:00', 15.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-11 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-12 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-13 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-14 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-15 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-16 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-18 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-19 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-20 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-24 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-26 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-30 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-01-31 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-01 00:00:00', 7.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-02 00:00:00', 7.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-03 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-04 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-05 00:00:00', 19.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-06 00:00:00', 21.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-07 00:00:00', 25.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-08 00:00:00', 11.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-11 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-12 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-13 00:00:00', 19.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-14 00:00:00', 12.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-15 00:00:00', 13.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-16 00:00:00', 17.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-17 00:00:00', 6.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-18 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-19 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-20 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-21 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-22 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-24 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-25 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-26 00:00:00', 0.781000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-02-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-01 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-02 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-03 00:00:00', 5.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-04 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-05 00:00:00', 17.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-06 00:00:00', 5.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-07 00:00:00', 27.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-08 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-09 00:00:00', 8.62899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-10 00:00:00', 29.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-11 00:00:00', 10.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-12 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-13 00:00:00', 18.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-14 00:00:00', 5.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-15 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-16 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-17 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-18 00:00:00', 0.460999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-19 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-20 00:00:00', 11.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-21 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-22 00:00:00', 14.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-23 00:00:00', 16.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-24 00:00:00', 10.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-25 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-26 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-27 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-29 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-30 00:00:00', 0.907999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-03-31 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-01 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-02 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-05 00:00:00', 9.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-06 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-07 00:00:00', 7.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-09 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-10 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-11 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-14 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-15 00:00:00', 12.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-16 00:00:00', 38.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-17 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-18 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-21 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-22 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-23 00:00:00', 12.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-24 00:00:00', 26.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-25 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-26 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-27 00:00:00', 9.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-28 00:00:00', 14.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-29 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-04-30 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-01 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-02 00:00:00', 5.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-03 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-04 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-05 00:00:00', 11.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-07 00:00:00', 31.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-08 00:00:00', 12.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-09 00:00:00', 23.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-10 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-11 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-12 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-14 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-15 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-16 00:00:00', 19.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-17 00:00:00', 7.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-18 00:00:00', 10.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-19 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-20 00:00:00', 11.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-21 00:00:00', 7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-22 00:00:00', 5.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-23 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-24 00:00:00', 62.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-25 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-26 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-28 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-29 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-30 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-05-31 00:00:00', 5.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-02 00:00:00', 6.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-03 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-06 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-12 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-14 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-17 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-18 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-20 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-22 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-23 00:00:00', 12.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-25 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-26 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-27 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-28 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-10 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-15 00:00:00', 5.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-22 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-23 00:00:00', 6.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-24 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-26 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-28 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-29 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-09 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-10 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-12 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-16 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-17 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-18 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-24 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-16 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-27 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-09-30 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-01 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-05 00:00:00', 13.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-06 00:00:00', 11.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-07 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-08 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-09 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-16 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-17 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-28 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-29 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-30 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-10-31 00:00:00', 8.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-01 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-02 00:00:00', 25.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-03 00:00:00', 18.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-04 00:00:00', 18.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-05 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-06 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-07 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-08 00:00:00', 8.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-09 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-10 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-11 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-12 00:00:00', 10.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-13 00:00:00', 6.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-14 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-15 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-17 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-18 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-21 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-22 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-23 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-24 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-25 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-26 00:00:00', 6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-27 00:00:00', 8.60700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-28 00:00:00', 13.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-29 00:00:00', 26.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-11-30 00:00:00', 17.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-01 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-02 00:00:00', 4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-03 00:00:00', 7.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-04 00:00:00', 5.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-05 00:00:00', 7.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-06 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-07 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-09 00:00:00', 0.620000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-10 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-11 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-12 00:00:00', 0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-13 00:00:00', 7.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-16 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-18 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-20 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-21 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-25 00:00:00', 0.455000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-26 00:00:00', 8.31499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-27 00:00:00', 8.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-28 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-29 00:00:00', 6.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-30 00:00:00', 6.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1993-12-31 00:00:00', 18.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-01 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-02 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-03 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-06 00:00:00', 10.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-07 00:00:00', 12.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-09 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-10 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-18 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-19 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-20 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-21 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-22 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-24 00:00:00', 6.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-25 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-26 00:00:00', 9.12600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-27 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-28 00:00:00', 7.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-01-31 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-01 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-02 00:00:00', 10.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-03 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-04 00:00:00', 18.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-05 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-07 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-08 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-09 00:00:00', 7.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-10 00:00:00', 7.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-11 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-13 00:00:00', 10.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-14 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-15 00:00:00', 10.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-16 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-17 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-18 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-19 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-20 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-21 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-22 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-23 00:00:00', 6.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-24 00:00:00', 16.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-25 00:00:00', 10.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-26 00:00:00', 6.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-27 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-02-28 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-01 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-02 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-03 00:00:00', 11.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-04 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-05 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-06 00:00:00', 0.80699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-07 00:00:00', 7.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-08 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-09 00:00:00', 29.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-10 00:00:00', 9.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-11 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-12 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-13 00:00:00', 15.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-14 00:00:00', 7.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-16 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-17 00:00:00', 12.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-18 00:00:00', 6.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-24 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-25 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-26 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-27 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-28 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-29 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-01 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-02 00:00:00', 7.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-03 00:00:00', 14.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-04 00:00:00', 10.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-05 00:00:00', 20.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-06 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-07 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-08 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-09 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-13 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-14 00:00:00', 4.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-15 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-16 00:00:00', 8.82900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-17 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-19 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-20 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-21 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-22 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-25 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-26 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-27 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-28 00:00:00', 22.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-29 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-04-30 00:00:00', 8.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-01 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-02 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-03 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-04 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-05 00:00:00', 0.509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-06 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-07 00:00:00', 11.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-08 00:00:00', 8.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-09 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-10 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-11 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-14 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-16 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-17 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-18 00:00:00', 6.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-19 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-21 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-22 00:00:00', 6.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-23 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-24 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-25 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-26 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-29 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-30 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-05-31 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-01 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-03 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-04 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-07 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-08 00:00:00', 6.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-09 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-10 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-11 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-12 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-13 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-15 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-21 00:00:00', 0.574999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-24 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-25 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-26 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-03 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-16 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-06 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-18 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-19 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-20 00:00:00', 0.550000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-21 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-22 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-23 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-01 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-02 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-04 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-05 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-06 00:00:00', 0.137999996542930603, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-10 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-11 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-12 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-14 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-16 00:00:00', 0.947000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-17 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-20 00:00:00', 5.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-21 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-23 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-24 00:00:00', 9.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-25 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-26 00:00:00', 5.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-01 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-02 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-05 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-06 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-07 00:00:00', 7.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-08 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-09 00:00:00', 20.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-10 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-11 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-16 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-17 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-18 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-19 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-21 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-22 00:00:00', 0.841000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-23 00:00:00', 7.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-24 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-25 00:00:00', 7.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-26 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-27 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-11-30 00:00:00', 0.469000011682510376, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-01 00:00:00', 10.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-02 00:00:00', 24.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-03 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-04 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-05 00:00:00', 35.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-06 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-07 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-08 00:00:00', 4.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-09 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-13 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-14 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-15 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-18 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-19 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-20 00:00:00', 7.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-21 00:00:00', 22.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-22 00:00:00', 7.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-23 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-24 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-26 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-27 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-28 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-29 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1994-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-03 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-04 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-06 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-07 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-08 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-11 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-12 00:00:00', 9.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-13 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-14 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-15 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-16 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-18 00:00:00', 13.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-19 00:00:00', 9.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-20 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-21 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-23 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-24 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-25 00:00:00', 9.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-26 00:00:00', 0.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-27 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-28 00:00:00', 6.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-29 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-01 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-02 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-05 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-06 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-07 00:00:00', 17.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-08 00:00:00', 7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-09 00:00:00', 10.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-10 00:00:00', 18.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-11 00:00:00', 8.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-12 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-14 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-16 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-17 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-18 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-19 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-25 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-26 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-27 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-02-28 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-03 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-04 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-07 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-09 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-10 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-11 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-12 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-16 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-17 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-18 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-19 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-20 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-21 00:00:00', 11.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-22 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-23 00:00:00', 6.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-24 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-25 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-26 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-27 00:00:00', 7.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-28 00:00:00', 9.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-29 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-30 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-03-31 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-02 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-03 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-06 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-07 00:00:00', 7.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-08 00:00:00', 8.02999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-09 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-17 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-18 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-19 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-20 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-21 00:00:00', 12.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-22 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-23 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-25 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-26 00:00:00', 9.33800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-27 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-28 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-29 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-04-30 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-02 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-04 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-09 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-10 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-11 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-12 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-13 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-14 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-15 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-16 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-17 00:00:00', 19.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-18 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-19 00:00:00', 8.78600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-20 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-22 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-23 00:00:00', 8.17800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-25 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-26 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-28 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-29 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-02 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-03 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-06 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-07 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-08 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-09 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-10 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-11 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-12 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-13 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-17 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-18 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-19 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-20 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-21 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-22 00:00:00', 0.883000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-23 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-24 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-25 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-26 00:00:00', 0.976999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-27 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-29 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-06-30 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-02 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-04 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-05 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-07 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-08 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-09 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-10 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-11 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-19 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-24 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-25 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-05 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-07 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-11 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-29 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-30 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-08-31 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-01 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-02 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-03 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-23 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-28 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-01 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-02 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-03 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-04 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-08 00:00:00', 0.372000008821487427, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-09 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-10 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-11 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-12 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-13 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-14 00:00:00', 8.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-15 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-16 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-17 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-18 00:00:00', 9.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-24 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-01 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-02 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-06 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-27 00:00:00', 8.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-28 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-03 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-04 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-05 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-06 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-07 00:00:00', 7.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-08 00:00:00', 6.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-09 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-10 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-11 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-13 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-14 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-15 00:00:00', 1.12699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-17 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-18 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-19 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-20 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-23 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-24 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-28 00:00:00', 0.381999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-29 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1995-12-31 00:00:00', 0.221000000834465027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-03 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-06 00:00:00', 6.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-07 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-08 00:00:00', 8.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-09 00:00:00', 13.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-10 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-11 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-14 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-15 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-16 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-18 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-19 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-20 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-21 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-22 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-24 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-25 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-26 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-27 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-28 00:00:00', 8.00100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-29 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-30 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-01-31 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-01 00:00:00', 6.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-02 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-03 00:00:00', 19.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-04 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-06 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-07 00:00:00', 6.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-08 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-09 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-10 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-11 00:00:00', 11.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-12 00:00:00', 12.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-13 00:00:00', 9.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-14 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-15 00:00:00', 1.02100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-17 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-18 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-19 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-20 00:00:00', 7.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-21 00:00:00', 13.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-22 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-23 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-24 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-25 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-26 00:00:00', 7.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-27 00:00:00', 9.41199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-02-29 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-01 00:00:00', 9.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-02 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-03 00:00:00', 24.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-04 00:00:00', 20.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-05 00:00:00', 13.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-06 00:00:00', 9.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-07 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-09 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-10 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-11 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-12 00:00:00', 24.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-13 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-14 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-15 00:00:00', 7.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-16 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-17 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-18 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-19 00:00:00', 8.29800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-20 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-21 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-22 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-23 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-24 00:00:00', 12.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-25 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-26 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-27 00:00:00', 13.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-28 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-29 00:00:00', 7.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-30 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-03-31 00:00:00', 0.788999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-01 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-02 00:00:00', 4.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-03 00:00:00', 5.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-04 00:00:00', 10.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-05 00:00:00', 7.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-06 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-07 00:00:00', 0.647000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-08 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-09 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-10 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-11 00:00:00', 27.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-12 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-13 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-14 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-15 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-16 00:00:00', 10.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-17 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-18 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-19 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-20 00:00:00', 5.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-21 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-22 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-23 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-24 00:00:00', 10.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-25 00:00:00', 0.587999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-26 00:00:00', 11.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-27 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-28 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-29 00:00:00', 5.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-04-30 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-01 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-02 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-05 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-06 00:00:00', 0.509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-07 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-08 00:00:00', 10.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-09 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-10 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-11 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-12 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-14 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-15 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-16 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-17 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-19 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-20 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-21 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-22 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-23 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-24 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-27 00:00:00', 5.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-28 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-03 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-04 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-07 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-08 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-12 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-13 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-14 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-26 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-28 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-29 00:00:00', 7.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-06-30 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-02 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-13 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-15 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-16 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-19 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-21 00:00:00', 0.382999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-22 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-23 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-07-31 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-02 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-18 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-24 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-25 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-02 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-08 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-10 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-11 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-13 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-14 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-15 00:00:00', 9.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-16 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-17 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-18 00:00:00', 5.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-19 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-10-31 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-01 00:00:00', 5.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-04 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-05 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-07 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-08 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-09 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-10 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-11 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-12 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-13 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-14 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-18 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-19 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-11-30 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-01 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-02 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-03 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-04 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-05 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-06 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-07 00:00:00', 0.143000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-12 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-13 00:00:00', 0.388999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-14 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-16 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-17 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-18 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-19 00:00:00', 0.246000006794929504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-24 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-27 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-28 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-29 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1996-12-31 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-03 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-04 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-05 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-06 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-08 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-09 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-10 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-11 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-12 00:00:00', 23.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-13 00:00:00', 9.40400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-14 00:00:00', 6.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-15 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-16 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-17 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-18 00:00:00', 21.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-19 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-23 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-24 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-26 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-27 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-28 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-29 00:00:00', 11.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-30 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-01-31 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-01 00:00:00', 5.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-02 00:00:00', 8.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-06 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-07 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-08 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-09 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-11 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-13 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-14 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-20 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-21 00:00:00', 7.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-22 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-23 00:00:00', 23.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-24 00:00:00', 22.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-25 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-02-28 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-01 00:00:00', 28.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-02 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-03 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-05 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-06 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-07 00:00:00', 12.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-08 00:00:00', 0.0320000015199184418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-09 00:00:00', 6.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-10 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-11 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-14 00:00:00', 6.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-15 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-17 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-18 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-19 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-20 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-22 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-23 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-24 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-25 00:00:00', 0.29800000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-26 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-27 00:00:00', 9.28699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-28 00:00:00', 11.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-29 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-30 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-03-31 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-01 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-02 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-05 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-06 00:00:00', 8.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-07 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-08 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-09 00:00:00', 6.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-10 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-11 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-12 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-13 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-14 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-15 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-18 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-20 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-21 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-24 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-25 00:00:00', 6.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-26 00:00:00', 0.10899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-27 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-28 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-29 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-04-30 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-01 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-02 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-04 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-06 00:00:00', 5.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-07 00:00:00', 24.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-08 00:00:00', 5.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-09 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-10 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-11 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-12 00:00:00', 7.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-13 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-15 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-16 00:00:00', 6.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-17 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-19 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-24 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-25 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-26 00:00:00', 9.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-27 00:00:00', 7.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-28 00:00:00', 9.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-29 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-02 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-03 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-04 00:00:00', 6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-06 00:00:00', 8.77000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-07 00:00:00', 7.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-08 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-09 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-10 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-11 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-12 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-13 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-18 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-19 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-20 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-21 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-22 00:00:00', 0.32699999213218689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-25 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-27 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-28 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-01 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-09 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-05 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-08 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-15 00:00:00', 6.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-16 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-18 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-22 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-25 00:00:00', 1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-26 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-28 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-10-31 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-01 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-02 00:00:00', 7.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-04 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-05 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-06 00:00:00', 12.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-07 00:00:00', 9.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-08 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-09 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-14 00:00:00', 0.938000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-15 00:00:00', 5.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-16 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-17 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-18 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-20 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-21 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-22 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-23 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-24 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-25 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-26 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-28 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-29 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-02 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-03 00:00:00', 0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-04 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-05 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-06 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-08 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-09 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-10 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-11 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-12 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-13 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-14 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-17 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-18 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-19 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-20 00:00:00', 5.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-21 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-22 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-23 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-24 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-25 00:00:00', 5.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-26 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-27 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-28 00:00:00', 0.404000014066696167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1997-12-31 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-01 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-02 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-03 00:00:00', 5.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-04 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-06 00:00:00', 7.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-07 00:00:00', 23.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-08 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-09 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-10 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-11 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-12 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-13 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-14 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-15 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-17 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-18 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-19 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-20 00:00:00', 5.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-21 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-22 00:00:00', 6.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-23 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-24 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-25 00:00:00', 9.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-26 00:00:00', 7.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-27 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-28 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-29 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-30 00:00:00', 7.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-01-31 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-01 00:00:00', 4.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-02 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-03 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-05 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-06 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-07 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-08 00:00:00', 11.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-09 00:00:00', 24.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-10 00:00:00', 35.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-11 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-12 00:00:00', 5.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-13 00:00:00', 10.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-14 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-15 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-16 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-17 00:00:00', 7.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-18 00:00:00', 0.819000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-21 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-22 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-23 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-24 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-25 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-27 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-02-28 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-01 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-02 00:00:00', 15.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-03 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-04 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-06 00:00:00', 6.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-07 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-08 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-11 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-12 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-14 00:00:00', 21.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-15 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-16 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-17 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-18 00:00:00', 6.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-19 00:00:00', 21.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-20 00:00:00', 9.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-21 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-22 00:00:00', 6.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-23 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-26 00:00:00', 9.37100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-27 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-30 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-03-31 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-01 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-02 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-03 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-04 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-05 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-06 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-07 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-08 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-09 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-10 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-11 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-12 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-19 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-20 00:00:00', 8.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-21 00:00:00', 28.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-22 00:00:00', 8.75800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-23 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-24 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-25 00:00:00', 13.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-26 00:00:00', 9.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-27 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-29 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-04-30 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-01 00:00:00', 11.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-02 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-03 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-04 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-05 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-06 00:00:00', 7.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-07 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-09 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-10 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-11 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-12 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-13 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-14 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-15 00:00:00', 8.07199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-16 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-17 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-18 00:00:00', 12.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-19 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-21 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-22 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-23 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-24 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-25 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-26 00:00:00', 9.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-27 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-28 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-29 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-05-31 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-01 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-02 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-03 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-04 00:00:00', 0.144999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-05 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-07 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-10 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-12 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-13 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-14 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-15 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-16 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-17 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-20 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-21 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-22 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-23 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-25 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-26 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-27 00:00:00', 0.537000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-28 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-06-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-25 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-26 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-29 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-04 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-05 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-08 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-30 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-12 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-13 00:00:00', 7.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-14 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-15 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-16 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-17 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-18 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-19 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-20 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-21 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-22 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-28 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-03 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-04 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-09 00:00:00', 9.89299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-10 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-21 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-24 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-25 00:00:00', 5.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-26 00:00:00', 6.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-29 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-12 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-17 00:00:00', 12.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-18 00:00:00', 0.291000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-21 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-24 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-28 00:00:00', 19.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-29 00:00:00', 12.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-11-30 00:00:00', 8.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-01 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-02 00:00:00', 25.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-03 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-04 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-07 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-14 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-22 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-25 00:00:00', 7.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-27 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-29 00:00:00', 9.86699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-30 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1998-12-31 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-02 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-08 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-10 00:00:00', 14.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-12 00:00:00', 11.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-14 00:00:00', 12.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-16 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-18 00:00:00', 13.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-20 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-24 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-28 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-03 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-09 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-11 00:00:00', 19.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-13 00:00:00', 33.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-15 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-17 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-19 00:00:00', 0.437999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-25 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-27 00:00:00', 15.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-01 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-03 00:00:00', 27.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-04 00:00:00', 6.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-05 00:00:00', 6.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-06 00:00:00', 0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-07 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-08 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-09 00:00:00', 0.393000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-13 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-14 00:00:00', 7.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-15 00:00:00', 7.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-16 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-17 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-18 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-19 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-20 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-21 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-22 00:00:00', 17.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-23 00:00:00', 11.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-24 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-25 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-27 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-28 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-29 00:00:00', 25.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-30 00:00:00', 12.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-03-31 00:00:00', 24.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-01 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-03 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-04 00:00:00', 9.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-05 00:00:00', 9.08600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-06 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-07 00:00:00', 17.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-08 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-09 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-10 00:00:00', 14.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-11 00:00:00', 12.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-12 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-16 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-17 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-19 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-22 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-23 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-27 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-28 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-04 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-06 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-09 00:00:00', 0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-11 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-12 00:00:00', 16.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-13 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-15 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-22 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-01 00:00:00', 6.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-02 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-04 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-07 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-11 00:00:00', 0.168999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-16 00:00:00', 0.351999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-23 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-24 00:00:00', 5.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-06 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-07 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-11 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-12 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-30 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-18 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-27 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-28 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-29 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-09-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-14 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-15 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-24 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-26 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-27 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-28 00:00:00', 13.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-30 00:00:00', 0.856999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-10-31 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-02 00:00:00', 8.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-03 00:00:00', 13.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-05 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-06 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-09 00:00:00', 13.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-10 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-11 00:00:00', 11.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-12 00:00:00', 6.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-13 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-14 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-17 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-18 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-19 00:00:00', 5.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-20 00:00:00', 12.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-21 00:00:00', 8.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-22 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-23 00:00:00', 0.787999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-24 00:00:00', 12.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-25 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-26 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-27 00:00:00', 5.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-28 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-29 00:00:00', 17.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-11-30 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-01 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-04 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-05 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-06 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-09 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-10 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-11 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-15 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-18 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-19 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-25 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-26 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-28 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-29 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '1999-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-06 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-07 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-08 00:00:00', 16.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-09 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-11 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-12 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-13 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-14 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-17 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-18 00:00:00', 9.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-19 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-20 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-21 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-23 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-24 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-25 00:00:00', 0.970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-27 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-28 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-29 00:00:00', 4.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-30 00:00:00', 8.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-01-31 00:00:00', 9.74699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-01 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-03 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-04 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-08 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-09 00:00:00', 7.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-10 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-11 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-12 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-14 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-15 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-16 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-26 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-27 00:00:00', 8.65200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-28 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-02-29 00:00:00', 6.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-01 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-02 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-03 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-04 00:00:00', 7.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-05 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-09 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-10 00:00:00', 7.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-11 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-13 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-15 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-16 00:00:00', 12.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-17 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-24 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-26 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-27 00:00:00', 15.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-28 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-29 00:00:00', 8.61200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-30 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-02 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-03 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-04 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-08 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-09 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-11 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-14 00:00:00', 0.0489999987185001373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-15 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-17 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-18 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-19 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-20 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-24 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-25 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-26 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-27 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-28 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-29 00:00:00', 4.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-04-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-02 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-03 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-04 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-05 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-08 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-09 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-10 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-22 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-28 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-29 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-02 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-09 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-19 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-20 00:00:00', 0.517000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-21 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-20 00:00:00', 1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-21 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-25 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-02 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-03 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-04 00:00:00', 5.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-05 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-06 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-07 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-13 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-14 00:00:00', 0.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-15 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-16 00:00:00', 10.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-18 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-19 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-21 00:00:00', 0.0799999982118606567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-22 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-23 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-24 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-25 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-04 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-05 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-06 00:00:00', 0.236000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-07 00:00:00', 17.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-08 00:00:00', 9.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-09 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-10 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-11 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-12 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-14 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-15 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-16 00:00:00', 0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-17 00:00:00', 1.07700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-18 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-22 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-23 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-24 00:00:00', 0.949000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-25 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-29 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-11-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-02 00:00:00', 9.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-03 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-04 00:00:00', 7.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-05 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-09 00:00:00', 0.647000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-10 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-12 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-13 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-14 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-15 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-16 00:00:00', 11.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-17 00:00:00', 9.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-18 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-25 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-26 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-27 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-28 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2000-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-03 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-16 00:00:00', 7.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-17 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-19 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-20 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-21 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-22 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-23 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-24 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-25 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-26 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-27 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-28 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-29 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-30 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-01-31 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-04 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-05 00:00:00', 6.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-06 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-07 00:00:00', 0.13099999725818634, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-09 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-10 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-16 00:00:00', 9.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-17 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-18 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-19 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-20 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-21 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-22 00:00:00', 8.24699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-23 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-25 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-02-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-03 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-05 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-06 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-10 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-11 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-12 00:00:00', 9.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-13 00:00:00', 0.386000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-17 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-18 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-19 00:00:00', 10.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-20 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-21 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-25 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-26 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-27 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-28 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-29 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-03-31 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-01 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-02 00:00:00', 8.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-03 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-05 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-08 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-09 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-10 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-12 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-17 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-18 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-19 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-21 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-22 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-23 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-24 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-26 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-04-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-01 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-07 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-09 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-18 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-19 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-20 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-28 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-29 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-14 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-15 00:00:00', 0.184000000357627869, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-16 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-17 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-21 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-22 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-19 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-28 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-14 00:00:00', 0.767000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-15 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-26 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-28 00:00:00', 8.09500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-02 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-06 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-07 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-22 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-09 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-14 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-17 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-18 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-19 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-20 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-21 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-22 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-23 00:00:00', 7.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-24 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-27 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-28 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-30 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-10-31 00:00:00', 6.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-01 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-02 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-03 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-05 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-08 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-09 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-10 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-15 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-20 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-28 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-29 00:00:00', 9.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-11-30 00:00:00', 6.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-01 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-02 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-03 00:00:00', 4.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-04 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-06 00:00:00', 9.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-07 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-09 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-10 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-11 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-12 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-13 00:00:00', 14.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-14 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-16 00:00:00', 5.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-17 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-18 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-20 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-21 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-22 00:00:00', 12.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-23 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-24 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-25 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-28 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-29 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-30 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2001-12-31 00:00:00', 6.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-02 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-05 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-06 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-08 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-09 00:00:00', 7.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-10 00:00:00', 8.06999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-11 00:00:00', 9.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-12 00:00:00', 15.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-13 00:00:00', 9.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-14 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-15 00:00:00', 0.307999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-23 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-24 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-25 00:00:00', 0.853999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-26 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-27 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-30 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-01-31 00:00:00', 0.731999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-01 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-02 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-03 00:00:00', 6.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-04 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-05 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-06 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-11 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-12 00:00:00', 4.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-13 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-14 00:00:00', 6.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-15 00:00:00', 13.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-16 00:00:00', 0.953000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-17 00:00:00', 6.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-18 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-19 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-22 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-23 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-25 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-26 00:00:00', 7.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-27 00:00:00', 10.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-02-28 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-01 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-02 00:00:00', 0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-07 00:00:00', 7.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-08 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-11 00:00:00', 7.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-12 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-13 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-14 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-15 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-16 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-17 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-18 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-19 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-20 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-21 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-22 00:00:00', 17.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-23 00:00:00', 6.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-24 00:00:00', 22.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-25 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-26 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-29 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-30 00:00:00', 8.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-03-31 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-01 00:00:00', 6.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-03 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-04 00:00:00', 7.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-05 00:00:00', 16.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-06 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-09 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-11 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-12 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-13 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-14 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-15 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-16 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-17 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-19 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-22 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-23 00:00:00', 12.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-24 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-25 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-26 00:00:00', 9.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-27 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-28 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-29 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-04-30 00:00:00', 6.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-01 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-02 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-03 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-04 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-05 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-06 00:00:00', 13.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-09 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-12 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-13 00:00:00', 6.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-14 00:00:00', 14.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-15 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-17 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-18 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-21 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-22 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-23 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-26 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-27 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-04 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-05 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-15 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-22 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-23 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-01 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-30 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-07-31 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-27 00:00:00', 0.647000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-28 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-09-30 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-18 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-24 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-25 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-29 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-03 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-04 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-05 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-06 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-10 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-12 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-13 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-14 00:00:00', 14.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-15 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-16 00:00:00', 7.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-17 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-18 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-27 00:00:00', 6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-28 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-29 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-11-30 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-02 00:00:00', 9.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-03 00:00:00', 11.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-04 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-08 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-09 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-10 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-11 00:00:00', 9.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-12 00:00:00', 13.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-13 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-14 00:00:00', 21.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-15 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-16 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-17 00:00:00', 6.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-18 00:00:00', 6.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-19 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-20 00:00:00', 12.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-21 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-22 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-23 00:00:00', 9.89500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-24 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-26 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-27 00:00:00', 5.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-28 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2002-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-05 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-06 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-07 00:00:00', 9.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-08 00:00:00', 10.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-09 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-11 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-12 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-13 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-15 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-16 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-17 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-19 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-21 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-22 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-23 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-29 00:00:00', 6.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-30 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-01-31 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-01 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-05 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-06 00:00:00', 7.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-07 00:00:00', 8.12600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-12 00:00:00', 7.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-13 00:00:00', 6.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-14 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-15 00:00:00', 10.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-16 00:00:00', 9.87399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-17 00:00:00', 7.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-18 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-19 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-20 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-21 00:00:00', 14.800999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-22 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-23 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-24 00:00:00', 6.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-25 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-26 00:00:00', 9.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-27 00:00:00', 9.60299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-02-28 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-01 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-02 00:00:00', 9.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-03 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-06 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-07 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-08 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-09 00:00:00', 5.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-10 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-12 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-13 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-14 00:00:00', 27.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-15 00:00:00', 11.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-16 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-18 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-19 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-20 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-21 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-22 00:00:00', 21.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-23 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-24 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-27 00:00:00', 8.48700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-28 00:00:00', 10.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-29 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-30 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-03-31 00:00:00', 9.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-01 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-02 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-03 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-05 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-06 00:00:00', 13.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-07 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-09 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-10 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-13 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-14 00:00:00', 6.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-15 00:00:00', 16.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-16 00:00:00', 17.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-17 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-18 00:00:00', 9.74699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-19 00:00:00', 6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-20 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-21 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-22 00:00:00', 0.550999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-23 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-24 00:00:00', 12.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-25 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-01 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-02 00:00:00', 6.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-03 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-05 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-09 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-10 00:00:00', 1.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-12 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-14 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-15 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-16 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-18 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-19 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-20 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-21 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-22 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-23 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-25 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-26 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-27 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-05-31 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-01 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-08 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-11 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-15 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-19 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-20 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-21 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-22 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-04 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-05 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-23 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-24 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-03 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-04 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-05 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-06 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-07 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-08 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-09 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-21 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-29 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-01 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-02 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-03 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-04 00:00:00', 12.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-05 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-06 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-07 00:00:00', 0.860000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-08 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-10 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-12 00:00:00', 7.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-13 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-14 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-15 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-16 00:00:00', 11.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-17 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-22 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-23 00:00:00', 10.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-24 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-29 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-11-30 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-01 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-02 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-04 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-05 00:00:00', 6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-06 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-07 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-08 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-11 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-12 00:00:00', 14.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-13 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-14 00:00:00', 0.0109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-18 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-19 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-20 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-21 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-22 00:00:00', 6.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-23 00:00:00', 1.17200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-25 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-26 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-27 00:00:00', 0.0179999992251396179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-28 00:00:00', 4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-29 00:00:00', 10.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-30 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2003-12-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-04 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-05 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-06 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-07 00:00:00', 16.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-08 00:00:00', 10.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-09 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-10 00:00:00', 12.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-11 00:00:00', 6.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-12 00:00:00', 5.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-14 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-15 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-16 00:00:00', 9.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-17 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-21 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-22 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-24 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-25 00:00:00', 10.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-26 00:00:00', 9.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-27 00:00:00', 10.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-28 00:00:00', 6.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-29 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-30 00:00:00', 0.65700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-01-31 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-01 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-03 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-04 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-05 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-07 00:00:00', 7.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-08 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-09 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-13 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-14 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-15 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-16 00:00:00', 6.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-17 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-18 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-19 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-20 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-21 00:00:00', 14.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-22 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-24 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-25 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-27 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-02-29 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-01 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-03 00:00:00', 6.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-04 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-05 00:00:00', 0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-10 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-11 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-12 00:00:00', 0.465999990701675415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-13 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-14 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-15 00:00:00', 9.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-16 00:00:00', 8.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-17 00:00:00', 19.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-18 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-20 00:00:00', 5.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-21 00:00:00', 15.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-22 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-23 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-24 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-01 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-02 00:00:00', 8.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-03 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-06 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-07 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-08 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-09 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-12 00:00:00', 0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-13 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-16 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-17 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-18 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-21 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-22 00:00:00', 11.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-23 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-25 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-26 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-27 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-28 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-29 00:00:00', 12.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-04-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-01 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-06 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-07 00:00:00', 19.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-08 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-11 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-16 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-19 00:00:00', 8.33600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-21 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-22 00:00:00', 7.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-23 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-24 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-25 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-27 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-30 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-05-31 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-01 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-02 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-05 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-06 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-14 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-21 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-13 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-17 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-18 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-19 00:00:00', 13.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-20 00:00:00', 0.526000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-22 00:00:00', 1.13699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-27 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-29 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-30 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-07 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-08 00:00:00', 0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-12 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-13 00:00:00', 0.296000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-14 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-15 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-17 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-18 00:00:00', 4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-19 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-23 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-24 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-25 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-27 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-28 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-03 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-05 00:00:00', 5.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-08 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-09 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-11 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-15 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-16 00:00:00', 0.501999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-18 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-19 00:00:00', 20.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-20 00:00:00', 14.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-21 00:00:00', 1.00800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-22 00:00:00', 6.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-24 00:00:00', 0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-25 00:00:00', 5.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-28 00:00:00', 11.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-29 00:00:00', 15.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-11-30 00:00:00', 0.193000003695487976, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-01 00:00:00', 0.0109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-02 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-03 00:00:00', 8.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-04 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-08 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-09 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-10 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-11 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-12 00:00:00', 6.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-13 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-14 00:00:00', 18.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-15 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-16 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-17 00:00:00', 14.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-18 00:00:00', 20.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-19 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-21 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-22 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-23 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-25 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-27 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-28 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-29 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-30 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2004-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-01 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-02 00:00:00', 0.393000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-03 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-04 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-05 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-07 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-08 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-09 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-10 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-11 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-12 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-13 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-14 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-15 00:00:00', 0.382999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-20 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-21 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-22 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-23 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-24 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-25 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-26 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-27 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-28 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-29 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-30 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-01-31 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-01 00:00:00', 12.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-02 00:00:00', 12.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-03 00:00:00', 13.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-04 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-05 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-06 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-07 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-10 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-11 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-12 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-13 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-14 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-15 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-16 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-17 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-18 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-19 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-22 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-23 00:00:00', 7.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-24 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-26 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-27 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-03 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-04 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-06 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-07 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-08 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-09 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-10 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-11 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-12 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-13 00:00:00', 10.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-14 00:00:00', 12.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-15 00:00:00', 7.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-16 00:00:00', 10.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-17 00:00:00', 10.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-18 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-19 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-20 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-21 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-22 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-23 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-24 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-25 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-26 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-27 00:00:00', 12.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-03-31 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-01 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-03 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-04 00:00:00', 12.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-05 00:00:00', 17.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-06 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-07 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-08 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-09 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-10 00:00:00', 0.437999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-11 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-12 00:00:00', 6.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-13 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-14 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-19 00:00:00', 0.970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-23 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-25 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-26 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-27 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-29 00:00:00', 6.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-04-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-01 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-02 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-07 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-08 00:00:00', 19.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-09 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-10 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-11 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-12 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-13 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-15 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-16 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-18 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-19 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-20 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-23 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-24 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-25 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-26 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-27 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-28 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-30 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-05-31 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-01 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-03 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-05 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-06 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-09 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-10 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-11 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-12 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-13 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-15 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-02 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-04 00:00:00', 0.259999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-05 00:00:00', 0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-11 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-13 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-23 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-24 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-30 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-02 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-09 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-12 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-14 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-23 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-24 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-25 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-10-31 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-07 00:00:00', 18.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-08 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-09 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-10 00:00:00', 10.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-11 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-13 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-14 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-15 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-16 00:00:00', 1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-19 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-20 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-21 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-22 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-23 00:00:00', 0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-24 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-25 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-03 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-04 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-05 00:00:00', 10.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-06 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-07 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-08 00:00:00', 6.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-09 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-14 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-21 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-22 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-24 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-25 00:00:00', 14.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-26 00:00:00', 13.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-27 00:00:00', 10.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-28 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-29 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2005-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-01 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-02 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-03 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-08 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-09 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-10 00:00:00', 8.35000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-11 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-12 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-13 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-14 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-15 00:00:00', 10.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-16 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-17 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-19 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-20 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-22 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-23 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-24 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-25 00:00:00', 5.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-26 00:00:00', 7.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-27 00:00:00', 23.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-28 00:00:00', 13.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-29 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-30 00:00:00', 7.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-01-31 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-01 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-02 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-05 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-06 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-09 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-10 00:00:00', 20.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-11 00:00:00', 10.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-12 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-13 00:00:00', 9.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-14 00:00:00', 7.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-15 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-16 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-17 00:00:00', 13.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-18 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-19 00:00:00', 7.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-20 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-21 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-22 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-23 00:00:00', 8.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-24 00:00:00', 6.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-25 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-26 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-27 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-01 00:00:00', 6.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-02 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-03 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-04 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-05 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-06 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-13 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-14 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-15 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-16 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-17 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-18 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-19 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-21 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-22 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-26 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-27 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-28 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-29 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-30 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-03-31 00:00:00', 9.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-01 00:00:00', 5.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-05 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-08 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-09 00:00:00', 35.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-10 00:00:00', 9.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-12 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-13 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-15 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-16 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-17 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-19 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-20 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-21 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-24 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-25 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-28 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-29 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-04-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-01 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-02 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-04 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-05 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-06 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-07 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-16 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-21 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-22 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-23 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-30 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-03 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-11 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-06-30 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-01 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-02 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-05 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-18 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-19 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-28 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-29 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-05 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-10 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-13 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-14 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-15 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-16 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-17 00:00:00', 8.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-18 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-20 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-21 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-23 00:00:00', 8.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-24 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-25 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-26 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-28 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-29 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-30 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-01 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-02 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-03 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-05 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-09 00:00:00', 8.51500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-10 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-13 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-14 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-15 00:00:00', 11.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-16 00:00:00', 12.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-17 00:00:00', 7.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-19 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-20 00:00:00', 0.505999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-21 00:00:00', 13.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-22 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-27 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-29 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-11-30 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-01 00:00:00', 6.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-02 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-04 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-05 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-06 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-13 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-14 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-15 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-16 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-19 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-20 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-23 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-24 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-25 00:00:00', 7.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-26 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-29 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-30 00:00:00', 9.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2006-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-01 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-02 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-08 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-09 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-10 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-11 00:00:00', 4.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-12 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-13 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-14 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-15 00:00:00', 10.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-16 00:00:00', 6.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-17 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-18 00:00:00', 9.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-19 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-23 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-24 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-01 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-02 00:00:00', 14.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-03 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-04 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-05 00:00:00', 5.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-06 00:00:00', 12.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-07 00:00:00', 0.273999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-08 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-09 00:00:00', 7.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-10 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-11 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-12 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-13 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-16 00:00:00', 0.537000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-17 00:00:00', 7.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-18 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-19 00:00:00', 13.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-20 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-21 00:00:00', 5.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-22 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-23 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-24 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-25 00:00:00', 14.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-26 00:00:00', 14.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-27 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-02-28 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-01 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-02 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-04 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-05 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-06 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-07 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-08 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-09 00:00:00', 6.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-10 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-11 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-12 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-13 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-14 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-16 00:00:00', 9.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-17 00:00:00', 21.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-18 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-19 00:00:00', 9.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-20 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-24 00:00:00', 12.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-25 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-26 00:00:00', 8.60499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-27 00:00:00', 7.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-28 00:00:00', 17.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-29 00:00:00', 10.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-30 00:00:00', 15.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-03-31 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-01 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-02 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-03 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-04 00:00:00', 11.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-05 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-06 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-08 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-09 00:00:00', 13.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-10 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-11 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-12 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-14 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-17 00:00:00', 11.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-19 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-20 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-21 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-22 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-29 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-04-30 00:00:00', 7.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-01 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-02 00:00:00', 7.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-03 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-06 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-07 00:00:00', 12.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-13 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-16 00:00:00', 11.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-17 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-18 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-19 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-22 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-24 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-25 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-26 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-29 00:00:00', 5.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-30 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-02 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-03 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-04 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-05 00:00:00', 14.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-07 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-10 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-11 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-12 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-15 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-16 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-17 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-26 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-28 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-06 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-07 00:00:00', 5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-12 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-21 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-23 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-02 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-01 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-19 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-23 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-24 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-25 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-13 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-19 00:00:00', 0.819000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-20 00:00:00', 10.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-22 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-23 00:00:00', 5.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-24 00:00:00', 6.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-25 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-26 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-27 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-28 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-11-30 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-01 00:00:00', 6.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-03 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-04 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-05 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-06 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-07 00:00:00', 11.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-08 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-09 00:00:00', 10.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-10 00:00:00', 7.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-11 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-12 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-13 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-14 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-15 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-16 00:00:00', 6.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-17 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-18 00:00:00', 14.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-19 00:00:00', 8.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-20 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-21 00:00:00', 11.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-22 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-23 00:00:00', 9.59099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-24 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-26 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-27 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2007-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-02 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-03 00:00:00', 11.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-04 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-05 00:00:00', 0.787999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-06 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-07 00:00:00', 8.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-08 00:00:00', 6.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-10 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-11 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-12 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-13 00:00:00', 4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-14 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-15 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-16 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-17 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-18 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-19 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-23 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-28 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-29 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-01 00:00:00', 0.566999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-02 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-03 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-04 00:00:00', 0.580999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-05 00:00:00', 0.908999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-06 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-07 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-08 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-09 00:00:00', 0.870000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-10 00:00:00', 0.870000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-11 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-13 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-14 00:00:00', 8.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-15 00:00:00', 8.11900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-16 00:00:00', 19.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-17 00:00:00', 6.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-20 00:00:00', 6.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-21 00:00:00', 12.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-22 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-23 00:00:00', 0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-26 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-27 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-28 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-02-29 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-01 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-02 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-03 00:00:00', 19.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-04 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-05 00:00:00', 14.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-06 00:00:00', 6.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-07 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-12 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-13 00:00:00', 7.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-14 00:00:00', 0.574999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-15 00:00:00', 0.602999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-23 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-24 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-25 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-26 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-27 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-28 00:00:00', 0.787999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-29 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-30 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-04 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-05 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-06 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-07 00:00:00', 6.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-08 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-09 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-10 00:00:00', 12.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-11 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-12 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-13 00:00:00', 5.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-14 00:00:00', 8.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-15 00:00:00', 23.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-16 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-17 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-18 00:00:00', 8.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-19 00:00:00', 29.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-20 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-22 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-23 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-24 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-29 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-02 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-04 00:00:00', 6.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-05 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-09 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-12 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-13 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-15 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-16 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-21 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-22 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-23 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-24 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-25 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-27 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-07 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-15 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-22 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-25 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-26 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-02 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-18 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-19 00:00:00', 0.221000000834465027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-21 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-22 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-27 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-05 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-13 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-26 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-27 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-28 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-29 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-09-30 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-01 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-08 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-10 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-11 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-12 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-13 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-14 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-18 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-19 00:00:00', 6.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-23 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-24 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-25 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-27 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-28 00:00:00', 17.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-29 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-30 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-02 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-05 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-06 00:00:00', 7.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-07 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-08 00:00:00', 18.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-09 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-10 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-11 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-12 00:00:00', 0.361999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-13 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-17 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-19 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-21 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-22 00:00:00', 11.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-23 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-24 00:00:00', 15.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-25 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-29 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-11-30 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-03 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-04 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-05 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-06 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-08 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-09 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-10 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-11 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-13 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-14 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-15 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-16 00:00:00', 7.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-17 00:00:00', 15.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-18 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-19 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-20 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-22 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-23 00:00:00', 9.73700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-24 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-25 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-27 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-28 00:00:00', 8.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-29 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2008-12-31 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-01 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-02 00:00:00', 14.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-03 00:00:00', 18.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-04 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-09 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-10 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-11 00:00:00', 0.184000000357627869, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-13 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-14 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-21 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-25 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-26 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-27 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-28 00:00:00', 8.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-29 00:00:00', 6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-30 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-01-31 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-01 00:00:00', 20.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-02 00:00:00', 6.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-03 00:00:00', 15.0819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-04 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-05 00:00:00', 6.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-09 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-10 00:00:00', 7.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-11 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-12 00:00:00', 12.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-13 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-14 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-15 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-16 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-17 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-18 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-19 00:00:00', 6.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-20 00:00:00', 9.73700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-21 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-22 00:00:00', 10.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-23 00:00:00', 20.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-24 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-25 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-26 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-01 00:00:00', 5.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-02 00:00:00', 5.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-03 00:00:00', 14.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-04 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-05 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-06 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-07 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-08 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-09 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-16 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-17 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-18 00:00:00', 10.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-19 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-21 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-22 00:00:00', 6.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-23 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-24 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-26 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-27 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-29 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-01 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-02 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-03 00:00:00', 0.801999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-05 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-06 00:00:00', 11.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-07 00:00:00', 11.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-09 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-10 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-11 00:00:00', 12.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-12 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-14 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-15 00:00:00', 15.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-16 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-17 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-18 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-19 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-20 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-21 00:00:00', 24.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-22 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-25 00:00:00', 8.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-26 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-27 00:00:00', 7.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-28 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-04-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-01 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-02 00:00:00', 14.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-03 00:00:00', 8.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-04 00:00:00', 31.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-05 00:00:00', 13.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-06 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-07 00:00:00', 6.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-08 00:00:00', 6.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-09 00:00:00', 8.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-10 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-11 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-12 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-13 00:00:00', 6.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-14 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-15 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-18 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-19 00:00:00', 12.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-20 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-24 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-30 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-05-31 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-01 00:00:00', 12.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-02 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-04 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-07 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-08 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-09 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-11 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-12 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-13 00:00:00', 7.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-14 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-15 00:00:00', 4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-18 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-19 00:00:00', 0.173999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-27 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-29 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-02 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-03 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-09 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-14 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-22 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-23 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-01 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-02 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-25 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-02 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-03 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-16 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-17 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-19 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-20 00:00:00', 6.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-21 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-22 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-23 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-25 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-26 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-01 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-27 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-30 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-10-31 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-01 00:00:00', 8.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-02 00:00:00', 20.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-03 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-04 00:00:00', 1.02499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-05 00:00:00', 5.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-06 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-07 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-08 00:00:00', 8.44900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-09 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-10 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-14 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-16 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-20 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-21 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-22 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-23 00:00:00', 18.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-24 00:00:00', 4.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-25 00:00:00', 7.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-26 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-27 00:00:00', 5.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-28 00:00:00', 8.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-29 00:00:00', 0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-11-30 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-01 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-02 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-03 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-04 00:00:00', 6.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-05 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-07 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-08 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-09 00:00:00', 12.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-10 00:00:00', 9.69900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-11 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-12 00:00:00', 10.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-13 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-14 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-15 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-16 00:00:00', 12.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-17 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-19 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-20 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-21 00:00:00', 15.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-22 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-26 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-27 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-28 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-29 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2009-12-31 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-03 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-05 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-06 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-07 00:00:00', 8.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-08 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-14 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-15 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-16 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-17 00:00:00', 13.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-18 00:00:00', 9.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-19 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-20 00:00:00', 6.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-21 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-22 00:00:00', 19.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-23 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-24 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-26 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-27 00:00:00', 14.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-28 00:00:00', 5.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-29 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-30 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-01-31 00:00:00', 12.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-01 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-02 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-03 00:00:00', 10.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-04 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-05 00:00:00', 21.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-06 00:00:00', 16.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-07 00:00:00', 9.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-08 00:00:00', 9.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-09 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-11 00:00:00', 4.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-12 00:00:00', 6.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-13 00:00:00', 6.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-14 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-17 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-18 00:00:00', 10.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-19 00:00:00', 21.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-20 00:00:00', 21.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-21 00:00:00', 14.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-22 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-23 00:00:00', 5.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-24 00:00:00', 9.27999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-25 00:00:00', 7.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-26 00:00:00', 17.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-27 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-02-28 00:00:00', 13.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-01 00:00:00', 13.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-02 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-03 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-04 00:00:00', 9.07199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-05 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-06 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-07 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-08 00:00:00', 7.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-09 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-11 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-12 00:00:00', 7.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-13 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-14 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-15 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-16 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-18 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-20 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-21 00:00:00', 7.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-22 00:00:00', 15.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-23 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-25 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-26 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-27 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-28 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-29 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-30 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-03-31 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-02 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-03 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-07 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-08 00:00:00', 0.32699999213218689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-09 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-10 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-11 00:00:00', 12.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-12 00:00:00', 12.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-14 00:00:00', 1.07700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-15 00:00:00', 16.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-16 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-17 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-21 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-22 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-23 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-24 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-25 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-26 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-27 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-29 00:00:00', 5.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-01 00:00:00', 9.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-02 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-03 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-04 00:00:00', 18.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-05 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-06 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-07 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-08 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-09 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-10 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-11 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-12 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-13 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-14 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-15 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-16 00:00:00', 14.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-17 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-18 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-19 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-21 00:00:00', 6.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-22 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-23 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-25 00:00:00', 0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-26 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-28 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-05-31 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-02 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-03 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-06 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-07 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-08 00:00:00', 11.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-09 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-10 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-11 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-12 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-13 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-14 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-15 00:00:00', 6.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-16 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-17 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-21 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-25 00:00:00', 0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-13 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-21 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-22 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-30 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-03 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-04 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-07 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-08 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-23 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-24 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-25 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-06 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-12 00:00:00', 8.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-13 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-15 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-16 00:00:00', 16.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-17 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-08 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-09 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-13 00:00:00', 7.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-14 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-15 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-26 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-28 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-29 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-30 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-01 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-02 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-03 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-04 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-05 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-20 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-03 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-04 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-05 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-06 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-15 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-16 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2010-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-03 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-04 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-06 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-07 00:00:00', 6.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-08 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-09 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-11 00:00:00', 7.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-12 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-13 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-14 00:00:00', 0.451000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-15 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-16 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-17 00:00:00', 13.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-18 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-20 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-21 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-22 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-23 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-27 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-28 00:00:00', 16.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-29 00:00:00', 5.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-30 00:00:00', 7.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-01-31 00:00:00', 23.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-01 00:00:00', 20.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-02 00:00:00', 13.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-03 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-04 00:00:00', 11.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-05 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-06 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-07 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-08 00:00:00', 9.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-09 00:00:00', 8.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-10 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-11 00:00:00', 9.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-12 00:00:00', 11.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-13 00:00:00', 7.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-14 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-16 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-17 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-18 00:00:00', 10.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-19 00:00:00', 9.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-20 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-21 00:00:00', 12.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-22 00:00:00', 16.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-23 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-24 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-25 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-26 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-27 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-02-28 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-01 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-02 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-03 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-04 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-05 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-06 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-07 00:00:00', 1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-10 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-11 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-12 00:00:00', 11.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-13 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-14 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-15 00:00:00', 13.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-16 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-17 00:00:00', 14.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-18 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-19 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-20 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-23 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-24 00:00:00', 14.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-25 00:00:00', 10.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-26 00:00:00', 12.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-27 00:00:00', 20.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-28 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-29 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-30 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-03-31 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-01 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-02 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-03 00:00:00', 15.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-04 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-05 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-08 00:00:00', 13.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-09 00:00:00', 15.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-10 00:00:00', 7.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-11 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-12 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-13 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-14 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-15 00:00:00', 6.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-16 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-17 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-19 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-20 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-23 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-25 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-26 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-27 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-28 00:00:00', 25.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-29 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-04-30 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-04 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-05 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-06 00:00:00', 7.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-07 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-08 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-09 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-10 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-11 00:00:00', 7.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-12 00:00:00', 7.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-13 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-14 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-15 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-16 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-17 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-18 00:00:00', 11.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-19 00:00:00', 6.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-20 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-21 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-22 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-23 00:00:00', 11.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-24 00:00:00', 8.75599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-25 00:00:00', 14.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-26 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-27 00:00:00', 7.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-28 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-29 00:00:00', 9.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-05-31 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-01 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-02 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-03 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-04 00:00:00', 9.24199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-05 00:00:00', 9.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-06 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-07 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-08 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-09 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-10 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-11 00:00:00', 25.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-12 00:00:00', 15.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-13 00:00:00', 9.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-14 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-16 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-17 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-18 00:00:00', 6.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-19 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-20 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-22 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-25 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-26 00:00:00', 10.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-27 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-28 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-29 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-06-30 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-02 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-08 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-10 00:00:00', 0.80699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-15 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-16 00:00:00', 5.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-28 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-29 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-30 00:00:00', 7.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-07-31 00:00:00', 8.49400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-09 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-26 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-27 00:00:00', 6.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-28 00:00:00', 6.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-29 00:00:00', 7.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-30 00:00:00', 7.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-09 00:00:00', 0.718999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-10 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-14 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-15 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-16 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-18 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-19 00:00:00', 9.82900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-21 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-23 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-27 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-28 00:00:00', 11.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-29 00:00:00', 15.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-09-30 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-03 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-05 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-07 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-10 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-11 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-12 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-13 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-14 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-15 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-16 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-17 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-19 00:00:00', 10.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-20 00:00:00', 18.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-21 00:00:00', 17.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-22 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-23 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-24 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-27 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-28 00:00:00', 17.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-29 00:00:00', 11.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-30 00:00:00', 12.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-10-31 00:00:00', 13.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-01 00:00:00', 20.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-02 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-03 00:00:00', 7.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-04 00:00:00', 8.37899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-05 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-06 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-07 00:00:00', 11.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-08 00:00:00', 29.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-09 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-10 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-13 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-14 00:00:00', 29.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-15 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-16 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-17 00:00:00', 10.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-18 00:00:00', 20.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-19 00:00:00', 6.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-20 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-21 00:00:00', 24.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-22 00:00:00', 14.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-23 00:00:00', 7.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-24 00:00:00', 12.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-25 00:00:00', 7.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-26 00:00:00', 20.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-27 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-28 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-01 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-02 00:00:00', 8.75800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-03 00:00:00', 0.855000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-04 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-05 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-06 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-12 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-13 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-18 00:00:00', 10.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-19 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-20 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-24 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-25 00:00:00', 15.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-26 00:00:00', 16.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-27 00:00:00', 7.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-28 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-29 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-30 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2011-12-31 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-02 00:00:00', 5.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-03 00:00:00', 6.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-04 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-05 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-06 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-07 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-10 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-11 00:00:00', 5.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-12 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-13 00:00:00', 24.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-14 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-15 00:00:00', 10.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-16 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-19 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-21 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-22 00:00:00', 6.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-23 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-24 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-25 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-26 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-27 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-28 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-29 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-30 00:00:00', 13.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-01-31 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-01 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-02 00:00:00', 7.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-03 00:00:00', 20.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-04 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-05 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-06 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-07 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-09 00:00:00', 8.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-10 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-11 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-12 00:00:00', 9.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-13 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-14 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-15 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-16 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-17 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-18 00:00:00', 9.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-19 00:00:00', 25.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-20 00:00:00', 19.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-21 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-22 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-23 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-25 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-26 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-27 00:00:00', 17.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-28 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-02-29 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-01 00:00:00', 4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-02 00:00:00', 20.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-03 00:00:00', 6.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-04 00:00:00', 13.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-05 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-06 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-07 00:00:00', 5.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-08 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-09 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-10 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-11 00:00:00', 12.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-12 00:00:00', 10.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-13 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-14 00:00:00', 7.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-15 00:00:00', 12.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-16 00:00:00', 55.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-17 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-18 00:00:00', 13.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-19 00:00:00', 30.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-20 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-21 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-23 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-24 00:00:00', 7.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-25 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-26 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-29 00:00:00', 32.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-30 00:00:00', 16.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-03-31 00:00:00', 8.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-01 00:00:00', 11.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-02 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-03 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-05 00:00:00', 5.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-06 00:00:00', 10.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-07 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-08 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-09 00:00:00', 19.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-10 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-11 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-12 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-13 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-17 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-19 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-20 00:00:00', 10.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-21 00:00:00', 11.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-22 00:00:00', 8.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-23 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-24 00:00:00', 7.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-25 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-26 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-27 00:00:00', 12.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-28 00:00:00', 11.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-29 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-04-30 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-01 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-02 00:00:00', 9.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-03 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-04 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-05 00:00:00', 10.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-06 00:00:00', 6.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-07 00:00:00', 17.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-08 00:00:00', 6.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-09 00:00:00', 12.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-10 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-11 00:00:00', 16.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-12 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-13 00:00:00', 7.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-14 00:00:00', 8.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-15 00:00:00', 9.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-16 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-17 00:00:00', 5.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-18 00:00:00', 9.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-19 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-20 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-21 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-22 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-23 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-24 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-25 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-26 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-27 00:00:00', 7.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-28 00:00:00', 7.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-29 00:00:00', 6.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-30 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-05-31 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-01 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-02 00:00:00', 0.759999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-04 00:00:00', 7.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-05 00:00:00', 8.32199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-07 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-08 00:00:00', 12.3629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-09 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-10 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-11 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-12 00:00:00', 9.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-14 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-15 00:00:00', 6.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-16 00:00:00', 6.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-17 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-18 00:00:00', 6.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-19 00:00:00', 13.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-20 00:00:00', 8.17800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-21 00:00:00', 12.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-22 00:00:00', 16.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-23 00:00:00', 10.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-24 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-25 00:00:00', 8.93000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-26 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-27 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-28 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-29 00:00:00', 5.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-06-30 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-01 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-02 00:00:00', 0.699000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-03 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-04 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-05 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-06 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-07 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-08 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-09 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-10 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-15 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-16 00:00:00', 6.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-17 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-18 00:00:00', 9.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-19 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-20 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-23 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-24 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-25 00:00:00', 5.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-26 00:00:00', 11.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-27 00:00:00', 0.80699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-03 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-04 00:00:00', 6.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-06 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-07 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-08 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-09 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-12 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-13 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-14 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-16 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-24 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-25 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-26 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-30 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-02 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-04 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-05 00:00:00', 6.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-14 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-17 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-18 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-19 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-21 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-25 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-29 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-09-30 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-12 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-14 00:00:00', 11.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-15 00:00:00', 11.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-17 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-20 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-21 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-24 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-25 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-26 00:00:00', 16.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-27 00:00:00', 24.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-28 00:00:00', 23.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-29 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-30 00:00:00', 9.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-10-31 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-01 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-02 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-03 00:00:00', 6.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-04 00:00:00', 26.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-09 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-12 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-13 00:00:00', 6.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-15 00:00:00', 11.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-16 00:00:00', 12.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-17 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-18 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-19 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-20 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-22 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-26 00:00:00', 6.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-27 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-28 00:00:00', 23.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-29 00:00:00', 6.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-11-30 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-06 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-07 00:00:00', 7.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-08 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-10 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-11 00:00:00', 8.36699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-12 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-13 00:00:00', 0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-15 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-16 00:00:00', 6.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-17 00:00:00', 11.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-18 00:00:00', 9.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-19 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-22 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-23 00:00:00', 28.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-24 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-25 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-26 00:00:00', 7.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-27 00:00:00', 13.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-28 00:00:00', 0.716000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2012-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-01 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-03 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-04 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-06 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-07 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-08 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-09 00:00:00', 9.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-10 00:00:00', 6.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-11 00:00:00', 22.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-12 00:00:00', 23.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-15 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-16 00:00:00', 1.21599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-17 00:00:00', 0.0680000036954879761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-18 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-19 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-20 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-21 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-22 00:00:00', 15.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-23 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-24 00:00:00', 1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-25 00:00:00', 10.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-26 00:00:00', 6.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-27 00:00:00', 13.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-28 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-29 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-30 00:00:00', 5.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-01-31 00:00:00', 7.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-01 00:00:00', 9.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-02 00:00:00', 13.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-03 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-04 00:00:00', 6.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-05 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-09 00:00:00', 13.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-10 00:00:00', 5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-12 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-13 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-14 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-15 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-16 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-18 00:00:00', 8.77900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-19 00:00:00', 5.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-20 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-21 00:00:00', 11.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-22 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-23 00:00:00', 0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-24 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-25 00:00:00', 7.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-26 00:00:00', 8.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-27 00:00:00', 6.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-02-28 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-01 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-02 00:00:00', 13.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-03 00:00:00', 21.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-04 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-05 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-06 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-07 00:00:00', 9.41399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-08 00:00:00', 23.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-09 00:00:00', 10.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-10 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-11 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-12 00:00:00', 10.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-13 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-15 00:00:00', 5.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-16 00:00:00', 12.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-17 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-18 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-19 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-20 00:00:00', 8.33899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-21 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-22 00:00:00', 6.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-23 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-24 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-25 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-26 00:00:00', 8.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-29 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-30 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-03-31 00:00:00', 9.67099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-01 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-02 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-05 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-06 00:00:00', 9.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-09 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-10 00:00:00', 12.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-11 00:00:00', 14.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-12 00:00:00', 30.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-13 00:00:00', 7.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-14 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-15 00:00:00', 20.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-16 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-17 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-18 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-19 00:00:00', 17.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-20 00:00:00', 8.50399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-21 00:00:00', 7.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-22 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-23 00:00:00', 18.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-24 00:00:00', 9.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-25 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-26 00:00:00', 13.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-27 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-28 00:00:00', 7.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-29 00:00:00', 6.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-04-30 00:00:00', 7.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-01 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-03 00:00:00', 10.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-04 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-05 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-06 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-07 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-08 00:00:00', 7.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-09 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-10 00:00:00', 10.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-11 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-12 00:00:00', 24.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-13 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-14 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-15 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-16 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-17 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-18 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-19 00:00:00', 11.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-20 00:00:00', 9.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-21 00:00:00', 16.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-22 00:00:00', 13.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-23 00:00:00', 7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-24 00:00:00', 17.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-25 00:00:00', 20.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-26 00:00:00', 6.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-27 00:00:00', 6.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-28 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-30 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-05-31 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-01 00:00:00', 10.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-02 00:00:00', 23.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-03 00:00:00', 9.22299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-04 00:00:00', 9.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-05 00:00:00', 4.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-11 00:00:00', 0.168999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-13 00:00:00', 8.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-14 00:00:00', 6.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-15 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-16 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-17 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-22 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-23 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-25 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-26 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-27 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-28 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-29 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-06-30 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-01 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-02 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-03 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-05 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-06 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-07 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-08 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-09 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-10 00:00:00', 10.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-11 00:00:00', 6.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-12 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-13 00:00:00', 0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-14 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-15 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-16 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-17 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-21 00:00:00', 1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-27 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-01 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-02 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-03 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-07 00:00:00', 11.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-08 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-10 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-11 00:00:00', 8.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-12 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-13 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-15 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-16 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-17 00:00:00', 7.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-19 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-20 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-21 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-22 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-23 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-24 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-27 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-28 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-29 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-30 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-08-31 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-01 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-04 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-09 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-14 00:00:00', 11.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-15 00:00:00', 8.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-27 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-28 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-10 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-11 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-13 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-14 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-16 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-17 00:00:00', 6.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-23 00:00:00', 7.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-25 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-26 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-27 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-28 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-29 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-30 00:00:00', 8.37399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-10-31 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-01 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-04 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-05 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-06 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-07 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-10 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-11 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-15 00:00:00', 0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-16 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-17 00:00:00', 0.866999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-18 00:00:00', 8.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-19 00:00:00', 16.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-20 00:00:00', 13.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-21 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-22 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-23 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-24 00:00:00', 6.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-25 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-26 00:00:00', 5.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-29 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-11-30 00:00:00', 14.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-01 00:00:00', 21.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-02 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-04 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-05 00:00:00', 17.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-06 00:00:00', 20.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-07 00:00:00', 21.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-08 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-09 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-10 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-11 00:00:00', 6.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-12 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-13 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-14 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-15 00:00:00', 10.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-16 00:00:00', 19.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-17 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-18 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-19 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-21 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-22 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-24 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-26 00:00:00', 0.550999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-27 00:00:00', 5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-28 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-29 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-30 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2013-12-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-03 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-04 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-05 00:00:00', 0.907999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-06 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-07 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-08 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-09 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-12 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-13 00:00:00', 5.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-15 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-16 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-20 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-21 00:00:00', 15.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-22 00:00:00', 12.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-23 00:00:00', 9.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-24 00:00:00', 32.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-25 00:00:00', 13.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-26 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-27 00:00:00', 20.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-28 00:00:00', 6.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-29 00:00:00', 9.14299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-30 00:00:00', 14.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-01-31 00:00:00', 12.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-01 00:00:00', 8.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-02 00:00:00', 9.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-03 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-04 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-06 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-07 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-08 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-10 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-11 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-12 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-13 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-14 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-15 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-18 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-19 00:00:00', 10.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-20 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-21 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-22 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-23 00:00:00', 12.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-24 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-25 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-26 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-27 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-02-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-02 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-03 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-04 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-05 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-06 00:00:00', 9.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-07 00:00:00', 15.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-08 00:00:00', 20.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-09 00:00:00', 8.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-10 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-11 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-13 00:00:00', 10.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-14 00:00:00', 16.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-15 00:00:00', 10.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-16 00:00:00', 9.51299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-17 00:00:00', 8.65499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-18 00:00:00', 9.28699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-19 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-20 00:00:00', 21.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-21 00:00:00', 14.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-22 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-23 00:00:00', 19.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-24 00:00:00', 10.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-25 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-26 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-27 00:00:00', 5.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-29 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-30 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-03-31 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-01 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-02 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-03 00:00:00', 7.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-04 00:00:00', 23.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-05 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-06 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-07 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-08 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-10 00:00:00', 42.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-11 00:00:00', 13.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-12 00:00:00', 16.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-13 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-14 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-16 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-17 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-18 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-19 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-20 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-21 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-22 00:00:00', 6.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-24 00:00:00', 32.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-25 00:00:00', 26.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-26 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-27 00:00:00', 12.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-28 00:00:00', 31.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-29 00:00:00', 10.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-04-30 00:00:00', 38.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-01 00:00:00', 15.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-03 00:00:00', 16.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-04 00:00:00', 15.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-05 00:00:00', 8.68299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-06 00:00:00', 16.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-07 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-08 00:00:00', 22.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-09 00:00:00', 6.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-10 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-11 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-12 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-13 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-14 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-15 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-16 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-17 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-18 00:00:00', 15.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-19 00:00:00', 17.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-20 00:00:00', 6.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-21 00:00:00', 8.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-22 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-23 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-24 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-25 00:00:00', 7.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-26 00:00:00', 6.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-27 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-28 00:00:00', 6.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-29 00:00:00', 14.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-30 00:00:00', 28.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-05-31 00:00:00', 8.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-01 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-02 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-04 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-05 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-06 00:00:00', 31.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-07 00:00:00', 13.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-08 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-09 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-10 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-11 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-12 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-14 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-15 00:00:00', 7.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-16 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-08 00:00:00', 12.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-10 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-12 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-13 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-14 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-17 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-18 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-23 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-24 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-25 00:00:00', 8.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-26 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-27 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-04 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-05 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-06 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-09 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-10 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-12 00:00:00', 9.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-13 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-17 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-18 00:00:00', 11.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-19 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-21 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-22 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-23 00:00:00', 0.224000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-24 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-27 00:00:00', 5.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-02-28 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-01 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-02 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-03 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-04 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-05 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-06 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-10 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-11 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-13 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-14 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-16 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-25 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-26 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-28 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-29 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-30 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-03-31 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-01 00:00:00', 7.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-02 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-06 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-07 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-12 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-14 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-15 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-17 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-18 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-19 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-20 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-21 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-27 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-04-30 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-01 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-05 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-07 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-09 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-11 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-13 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-14 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-15 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-16 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-17 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-18 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-19 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-20 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-24 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-07 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-20 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-21 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-28 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-30 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-10-31 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-05 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-06 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-07 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-12 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-13 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-01 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-02 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-03 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-04 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-09 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-10 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-17 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-18 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-19 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-21 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-22 00:00:00', 6.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-23 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-28 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-29 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-30 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1979-12-31 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-08 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-10 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-14 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-15 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-18 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-19 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-21 00:00:00', 0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-22 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-23 00:00:00', 6.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-24 00:00:00', 8.63099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-25 00:00:00', 9.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-27 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-28 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-01-31 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-01 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-02 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-03 00:00:00', 0.652999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-04 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-07 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-08 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-09 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-12 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-13 00:00:00', 10.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-14 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-16 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-19 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-21 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-22 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-24 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-25 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-26 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-27 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-02-29 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-01 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-02 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-03 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-04 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-05 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-08 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-12 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-14 00:00:00', 11.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-15 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-16 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-17 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-20 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-21 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-24 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-27 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-28 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-01 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-02 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-05 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-17 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-18 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-25 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-26 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-27 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-07 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-08 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-11 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-13 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-15 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-16 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-17 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-21 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-19 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-24 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-25 00:00:00', 5.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-26 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-01 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-02 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-11 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-12 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-13 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-14 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-20 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-27 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-28 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-29 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-30 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1980-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-01 00:00:00', 9.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-02 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-03 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-12 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-13 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-14 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-15 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-16 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-18 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-20 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-23 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-26 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-27 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-28 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-01 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-02 00:00:00', 8.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-03 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-04 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-08 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-10 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-11 00:00:00', 5.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-12 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-13 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-17 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-18 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-19 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-20 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-21 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-22 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-23 00:00:00', 6.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-24 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-26 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-27 00:00:00', 0.602999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-02-28 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-03 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-04 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-05 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-09 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-11 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-13 00:00:00', 0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-15 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-16 00:00:00', 15.4420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-17 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-18 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-19 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-20 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-24 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-25 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-26 00:00:00', 7.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-29 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-30 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-02 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-03 00:00:00', 9.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-06 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-07 00:00:00', 0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-10 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-11 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-12 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-13 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-14 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-16 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-18 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-19 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-20 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-27 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-28 00:00:00', 28.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-04-30 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-01 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-03 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-04 00:00:00', 9.51500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-07 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-08 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-09 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-12 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-13 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-14 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-18 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-05-31 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-23 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-18 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-21 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-22 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-23 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-01 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-02 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-04 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-08 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-16 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-21 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-25 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-26 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-27 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-28 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-29 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-30 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1981-12-31 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-01 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-13 00:00:00', 9.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-16 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-18 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-19 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-20 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-21 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-22 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-29 00:00:00', 9.69499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-30 00:00:00', 10.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-01 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-02 00:00:00', 9.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-06 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-09 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-10 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-14 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-15 00:00:00', 6.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-19 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-22 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-23 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-25 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-26 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-27 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-02-28 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-01 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-03 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-04 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-08 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-09 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-12 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-13 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-14 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-15 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-16 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-19 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-20 00:00:00', 21.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-21 00:00:00', 8.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-26 00:00:00', 6.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-27 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-28 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-29 00:00:00', 7.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-30 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-03-31 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-03 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-14 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-24 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-26 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-27 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-28 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-18 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-23 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-24 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-25 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-27 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-14 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-06-30 00:00:00', 0.207000002264976501, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-01 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-05 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-06 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-14 00:00:00', 0.566999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-03 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-04 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-06 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-10 00:00:00', 0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-11 00:00:00', 7.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-16 00:00:00', 0.178000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-17 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-24 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-25 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-01 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-02 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-03 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-04 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-10 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-11 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-13 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-14 00:00:00', 23.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-15 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-16 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-20 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-23 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-27 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-28 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-29 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-11-30 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-01 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-04 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-06 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-07 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-08 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-09 00:00:00', 0.957000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-10 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-13 00:00:00', 0.140000000596046448, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-16 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-17 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-26 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-27 00:00:00', 0.531000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-28 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-29 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-30 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1982-12-31 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-03 00:00:00', 10.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-04 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-05 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-07 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-10 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-11 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-13 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-14 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-22 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-25 00:00:00', 7.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-26 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-27 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-28 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-05 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-06 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-07 00:00:00', 0.407999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-08 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-09 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-10 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-11 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-12 00:00:00', 0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-19 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-20 00:00:00', 5.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-21 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-22 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-23 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-27 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-02-28 00:00:00', 12.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-01 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-06 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-07 00:00:00', 13.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-08 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-10 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-14 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-16 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-17 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-18 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-19 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-23 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-24 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-25 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-26 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-29 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-30 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-03-31 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-05 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-06 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-07 00:00:00', 20.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-09 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-11 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-12 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-13 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-14 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-26 00:00:00', 7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-04-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-03 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-04 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-07 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-08 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-10 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-11 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-05-31 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-05 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-16 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-17 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-26 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-04 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-10 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-13 00:00:00', 15.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-15 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-16 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-17 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-28 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-29 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1983-12-31 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-03 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-04 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-11 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-12 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-18 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-21 00:00:00', 0.382999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-22 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-25 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-27 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-30 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-01-31 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-01 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-03 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-05 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-06 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-08 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-09 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-10 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-11 00:00:00', 5.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-12 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-14 00:00:00', 7.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-15 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-16 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-17 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-18 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-19 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-20 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-26 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-28 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-02-29 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-02 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-03 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-04 00:00:00', 7.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-05 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-06 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-07 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-08 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-09 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-10 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-11 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-12 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-13 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-14 00:00:00', 15.7650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-15 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-16 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-17 00:00:00', 6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-21 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-22 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-24 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-25 00:00:00', 9.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-26 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-27 00:00:00', 9.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-28 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-03-31 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-04 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-05 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-08 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-09 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-10 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-11 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-13 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-18 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-19 00:00:00', 13.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-26 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-27 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-03 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-07 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-08 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-15 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-08 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-21 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-22 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-11 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-12 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-13 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-14 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-16 00:00:00', 8.32400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-17 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-18 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-19 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-20 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-22 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-27 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-11-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-01 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-02 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-04 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-05 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-06 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-07 00:00:00', 6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-08 00:00:00', 8.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-12 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-13 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-14 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-15 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-16 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-19 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-29 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1984-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-03 00:00:00', 8.00300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-04 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-05 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-12 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-13 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-14 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-15 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-16 00:00:00', 7.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-17 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-18 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-19 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-20 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-23 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-24 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-25 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-26 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-02 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-03 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-04 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-07 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-18 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-19 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-23 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-24 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-27 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-02-28 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-03 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-04 00:00:00', 10.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-08 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-09 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-11 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-14 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-15 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-21 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-22 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-23 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-25 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-26 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-27 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-29 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-02 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-04 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-05 00:00:00', 9.39000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-06 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-07 00:00:00', 7.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-27 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-28 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-04-30 00:00:00', 10.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-01 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-02 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-03 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-06 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-07 00:00:00', 11.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-20 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-23 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-25 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-12 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-16 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-24 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-05 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-06 00:00:00', 7.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-07 00:00:00', 6.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-13 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-14 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-15 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-21 00:00:00', 11.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-22 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-24 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-25 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-26 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1985-12-31 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-05 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-06 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-16 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-17 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-20 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-22 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-24 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-28 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-02 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-03 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-08 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-09 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-12 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-13 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-14 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-17 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-03 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-10 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-11 00:00:00', 9.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-12 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-15 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-16 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-25 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-26 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-27 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-30 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-12 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-13 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-15 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-21 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-22 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-15 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-16 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-17 00:00:00', 5.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-30 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-03 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-12 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-15 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-11 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-13 00:00:00', 0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-14 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-20 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-21 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-25 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-11-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-03 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-04 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-05 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-06 00:00:00', 6.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-09 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-10 00:00:00', 4.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-11 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-21 00:00:00', 7.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-22 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-23 00:00:00', 4.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-08 00:00:00', 8.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-19 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-20 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-21 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-01-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-01 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-02 00:00:00', 1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-06 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-07 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-11 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-16 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-17 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-22 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-23 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-02 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-04 00:00:00', 0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-05 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-06 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-07 00:00:00', 4.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-12 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-13 00:00:00', 5.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-15 00:00:00', 11.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-18 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-19 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-20 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-21 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-22 00:00:00', 9.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-28 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-29 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-30 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-03-31 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-01 00:00:00', 9.68299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-02 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-05 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-07 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-08 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-14 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-16 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-20 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-21 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-28 00:00:00', 4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-04 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-27 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-28 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-30 00:00:00', 8.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-02 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-05 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-11 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-20 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-01 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-09 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-10 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-25 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-26 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-27 00:00:00', 8.75599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-28 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-04 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-28 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-29 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-11-30 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-01 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-14 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-15 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-29 00:00:00', 12.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-30 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1987-12-31 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-01 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-02 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-03 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-08 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-14 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-15 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-17 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-18 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-20 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-21 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-26 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-30 00:00:00', 6.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-01 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-04 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-06 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-07 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-13 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-15 00:00:00', 0.214000001549720764, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-16 00:00:00', 0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-18 00:00:00', 18.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-19 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-26 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-27 00:00:00', 0.351999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-02 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-06 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-09 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-10 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-13 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-15 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-24 00:00:00', 10.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-25 00:00:00', 13.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-26 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-27 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-28 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-29 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-30 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-03-31 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-01 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-02 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-06 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-07 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-08 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-09 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-17 00:00:00', 16.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-29 00:00:00', 17.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-04-30 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-01 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-02 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-13 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-16 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-22 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-29 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-30 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-15 00:00:00', 0.0710000023245811462, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-21 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-22 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-23 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-16 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-18 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-20 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-21 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-23 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-27 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-28 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-29 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1988-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-03 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-04 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-05 00:00:00', 7.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-15 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-16 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-18 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-19 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-25 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-27 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-29 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-30 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-02 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-03 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-06 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-07 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-12 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-13 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-15 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-16 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-20 00:00:00', 6.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-21 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-23 00:00:00', 8.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-24 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-25 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-26 00:00:00', 9.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-27 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-08 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-13 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-17 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-20 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-22 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-29 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-30 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-03-31 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-02 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-05 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-15 00:00:00', 20.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-16 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-17 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-04-30 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-03 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-04 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-05 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-08 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-09 00:00:00', 8.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-10-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-01 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-07 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-08 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-17 00:00:00', 9.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-18 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-22 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-03 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-04 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-05 00:00:00', 0.319999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-06 00:00:00', 22.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-07 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-14 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-15 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-16 00:00:00', 8.49400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-17 00:00:00', 0.949000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-18 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1989-12-31 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-01 00:00:00', 11.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-02 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-03 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-05 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-06 00:00:00', 9.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-07 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-08 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-09 00:00:00', 9.85299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-10 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-11 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-12 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-16 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-17 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-20 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-25 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-26 00:00:00', 6.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-27 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-30 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-01-31 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-03 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-04 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-05 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-06 00:00:00', 9.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-07 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-08 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-11 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-12 00:00:00', 6.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-14 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-16 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-17 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-22 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-23 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-24 00:00:00', 0.0850000008940696716, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-25 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-26 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-09 00:00:00', 14.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-10 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-15 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-17 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-18 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-19 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-20 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-21 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-05 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-06 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-08 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-14 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-15 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-16 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-17 00:00:00', 19.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-27 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-06 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-15 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-30 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-02 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-14 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-08 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-09 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-10 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-11 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-12 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-13 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-20 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-22 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-23 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-24 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-25 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-26 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-27 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1990-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-04 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-05 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-06 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-08 00:00:00', 0.972999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-10 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-11 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-15 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-16 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-17 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-18 00:00:00', 6.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-19 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-20 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-24 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-25 00:00:00', 8.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-26 00:00:00', 7.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-27 00:00:00', 9.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-28 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-29 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-02 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-03 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-05 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-06 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-07 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-08 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-09 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-10 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-11 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-12 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-13 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-14 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-23 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-24 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-25 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-26 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-02 00:00:00', 5.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-04 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-07 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-08 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-09 00:00:00', 0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-10 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-11 00:00:00', 9.22500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-12 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-15 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-16 00:00:00', 10.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-17 00:00:00', 10.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-18 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-20 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-21 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-25 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-29 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-02 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-06 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-11 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-12 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-26 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-27 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-28 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-04-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-01 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-02 00:00:00', 12.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-12 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-13 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-14 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-15 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-16 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-17 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-20 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-21 00:00:00', 8.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-25 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-26 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-27 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-28 00:00:00', 5.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-29 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-13 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-19 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-20 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-21 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-23 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-27 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-28 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-03 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-04 00:00:00', 0.554000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-05 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-06 00:00:00', 9.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-09 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-10 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-11 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-12 00:00:00', 5.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-13 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-14 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-15 00:00:00', 7.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-16 00:00:00', 14.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-17 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-20 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-21 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-27 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-29 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-30 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1991-12-31 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-01 00:00:00', 0.870999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-02 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-03 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-04 00:00:00', 21.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-05 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-06 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-09 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-10 00:00:00', 0.202000007033348083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-14 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-18 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-22 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-23 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-24 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-25 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-26 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-27 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-28 00:00:00', 0.927999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-29 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-01-31 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-01 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-06 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-12 00:00:00', 7.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-16 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-22 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-25 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-27 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-28 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-03 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-04 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-07 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-08 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-09 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-10 00:00:00', 9.52700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-11 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-12 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-16 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-17 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-19 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-23 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-24 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-25 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-26 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-29 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-30 00:00:00', 0.767000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-01 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-02 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-03 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-04 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-06 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-12 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-16 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-20 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-23 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-28 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-04-30 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-02 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-05 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-06 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-07 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-10 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-11 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-12 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-13 00:00:00', 0.813000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-15 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-20 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-16 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-17 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-18 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-19 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-20 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-21 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-03 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-05 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-07 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-10 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-11 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-23 00:00:00', 10.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-24 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-29 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-30 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1992-12-31 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-03 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-05 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-06 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-09 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-10 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-15 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-16 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-18 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-19 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-04 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-05 00:00:00', 1.08700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-06 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-07 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-08 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-14 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-15 00:00:00', 7.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-16 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-17 00:00:00', 0.072999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-22 00:00:00', 11.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-23 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-24 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-25 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-27 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-01 00:00:00', 0.639999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-02 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-03 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-04 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-05 00:00:00', 0.395999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-06 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-09 00:00:00', 8.35000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-10 00:00:00', 22.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-11 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-12 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-13 00:00:00', 5.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-16 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-20 00:00:00', 14.9189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-22 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-23 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-24 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-06 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-07 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-14 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-15 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-16 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-24 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-27 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-28 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-01 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-05 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-07 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-08 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-15 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-16 00:00:00', 5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-22 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-24 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-25 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-18 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-08 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-02 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-03 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-04 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-08 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-17 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-21 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-22 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-26 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-27 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-29 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-11-30 00:00:00', 9.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-02 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-03 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-04 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-06 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-07 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-09 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-13 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-18 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-27 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1993-12-31 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-01 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-02 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-03 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-04 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-06 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-07 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-09 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-17 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-18 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-19 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-24 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-26 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-27 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-01-31 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-02 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-04 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-07 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-09 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-10 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-11 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-12 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-13 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-14 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-15 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-16 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-23 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-24 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-25 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-02 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-03 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-09 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-10 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-11 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-13 00:00:00', 9.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-25 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-30 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-03 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-05 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-13 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-28 00:00:00', 10.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-02 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-07 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-25 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-26 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-01 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-10 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-11 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-18 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-27 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-01 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-02 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-05 00:00:00', 20.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-07 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-08 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-21 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-22 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-27 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-28 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1994-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-02 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-07 00:00:00', 0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-08 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-11 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-12 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-15 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-17 00:00:00', 0.0540000014007091522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-18 00:00:00', 9.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-19 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-23 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-24 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-25 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-06 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-07 00:00:00', 16.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-08 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-09 00:00:00', 16.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-10 00:00:00', 12.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-11 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-17 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-25 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-26 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-27 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-03 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-05 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-06 00:00:00', 0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-07 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-19 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-20 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-21 00:00:00', 9.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-22 00:00:00', 4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-23 00:00:00', 6.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-27 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-28 00:00:00', 4.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-07 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-08 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-17 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-18 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-19 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-20 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-23 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-24 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-27 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-28 00:00:00', 5.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-23 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-13 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-14 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-20 00:00:00', 0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-24 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-27 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-05 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-06 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-07 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-08 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-10 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-13 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-14 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-15 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-18 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-20 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-24 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-27 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1995-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-03 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-07 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-08 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-09 00:00:00', 12.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-10 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-11 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-13 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-14 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-15 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-16 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-18 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-19 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-20 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-21 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-25 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-26 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-27 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-28 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-30 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-01-31 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-01 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-02 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-03 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-04 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-05 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-06 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-07 00:00:00', 0.312999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-12 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-13 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-15 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-17 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-20 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-21 00:00:00', 5.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-22 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-23 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-26 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-27 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-28 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-02-29 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-01 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-03 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-04 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-05 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-06 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-08 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-09 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-10 00:00:00', 0.469000011682510376, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-11 00:00:00', 0.987999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-12 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-15 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-17 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-18 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-19 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-20 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-22 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-24 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-27 00:00:00', 8.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-02 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-03 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-04 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-09 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-10 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-16 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-17 00:00:00', 9.31299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-18 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-19 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-20 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-24 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-25 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-26 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-29 00:00:00', 0.0850000008940696716, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-04-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-01 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-02 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-20 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-29 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-16 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-12 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-13 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-14 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-15 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-17 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-18 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-01 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-02 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-27 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1996-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-04 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-14 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-17 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-18 00:00:00', 8.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-19 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-24 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-26 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-27 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-29 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-01 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-07 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-21 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-22 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-23 00:00:00', 5.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-24 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-02-28 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-01 00:00:00', 11.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-07 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-09 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-10 00:00:00', 9.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-14 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-15 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-17 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-21 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-22 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-27 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-28 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-03-31 00:00:00', 0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-01 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-06 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-07 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-12 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-20 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-21 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-04-30 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-06 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-12 00:00:00', 5.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-16 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-14 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-26 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-01 00:00:00', 0.0280000008642673492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-02 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-06 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-07 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-15 00:00:00', 4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-02 00:00:00', 0.165999993681907654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-10 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-12 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-18 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-19 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-20 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-21 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-22 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-25 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-27 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1997-12-31 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-03 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-04 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-06 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-07 00:00:00', 18.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-11 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-12 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-14 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-15 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-17 00:00:00', 0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-20 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-22 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-25 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-27 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-28 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-29 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-30 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-01-31 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-01 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-05 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-08 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-09 00:00:00', 8.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-10 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-11 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-12 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-13 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-14 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-15 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-16 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-17 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-23 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-27 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-02-28 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-02 00:00:00', 6.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-03 00:00:00', 0.584999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-04 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-06 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-15 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-16 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-17 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-19 00:00:00', 6.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-20 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-21 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-22 00:00:00', 0.75700002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-26 00:00:00', 6.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-07 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-08 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-21 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-22 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-25 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-04-30 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-02 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-06 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-11 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-13 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-05 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-25 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-17 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-28 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-29 00:00:00', 9.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-11-30 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-02 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-03 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-29 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1998-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-10 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-12 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-14 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-18 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-22 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-24 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-11 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-13 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-27 00:00:00', 14.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-01 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-03 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-04 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-05 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-06 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-07 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-08 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-14 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-15 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-16 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-19 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-21 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-22 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-24 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-27 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-29 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-03-31 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-04 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-07 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-09 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-10 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-22 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-12 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-28 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-29 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-03 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-04 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-05 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-09 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-11 00:00:00', 0.893999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-12 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-13 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-20 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-21 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-24 00:00:00', 8.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-29 00:00:00', 0.860000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-11-30 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-18 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '1999-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-08 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-11 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-12 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-13 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-18 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-19 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-20 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-24 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-30 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-01-31 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-03 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-08 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-09 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-15 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-22 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-27 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-04 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-10 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-16 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-27 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-28 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-29 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-17 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-05 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-16 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-19 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-06 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-07 00:00:00', 7.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-08 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-11 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-17 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-29 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-02 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-03 00:00:00', 5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-10 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-16 00:00:00', 11.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-17 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-27 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-28 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2000-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-16 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-17 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-20 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-21 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-22 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-24 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-25 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-28 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-29 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-30 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-06 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-16 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-22 00:00:00', 8.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-23 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-11 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-12 00:00:00', 8.35299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-13 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-19 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-27 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-28 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-23 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-20 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-29 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-11-30 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-01 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-02 00:00:00', 6.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-03 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-06 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-16 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-17 00:00:00', 7.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-21 00:00:00', 0.679000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-22 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2001-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-09 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-10 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-11 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-12 00:00:00', 11.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-13 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-24 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-01-31 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-01 00:00:00', 12.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-02 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-04 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-05 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-06 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-15 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-16 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-17 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-22 00:00:00', 0.938000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-26 00:00:00', 0.324999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-02-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-07 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-20 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-23 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-24 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-30 00:00:00', 0.884000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-03-31 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-04 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-05 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-14 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-15 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-22 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-23 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-26 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-29 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-04-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-02 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-05 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-06 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-14 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-16 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-18 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-11-30 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-02 00:00:00', 0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-03 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-10 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-11 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-12 00:00:00', 8.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-13 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-14 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-15 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-18 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-19 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-20 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-23 00:00:00', 8.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-27 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-28 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2002-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-08 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-11 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-19 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-20 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-21 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-23 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-29 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-06 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-13 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-16 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-17 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-18 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-20 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-21 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-22 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-23 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-24 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-26 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-27 00:00:00', 15.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-02-28 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-01 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-08 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-09 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-14 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-15 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-16 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-22 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-24 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-27 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-28 00:00:00', 17.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-30 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-03-31 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-01 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-02 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-05 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-14 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-15 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-18 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-19 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-23 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-24 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-04 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-15 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-16 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-22 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-23 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-11-30 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-01 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-05 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-07 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-08 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-11 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-12 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-21 00:00:00', 0.133000001311302185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-22 00:00:00', 7.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-25 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-28 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-29 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-30 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2003-12-31 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-01 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-04 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-06 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-07 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-08 00:00:00', 11.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-09 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-11 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-12 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-15 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-16 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-21 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-28 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-29 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-07 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-08 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-09 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-21 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-25 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-13 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-14 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-15 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-17 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-20 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-21 00:00:00', 0.635999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-02 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-21 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-22 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-06 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-07 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-15 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-19 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-20 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-21 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-28 00:00:00', 0.612999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-29 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-03 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-14 00:00:00', 0.526000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-16 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-17 00:00:00', 0.86799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-18 00:00:00', 16.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-22 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-28 00:00:00', 9.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-29 00:00:00', 6.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-30 00:00:00', 0.537999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2004-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-05 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-07 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-08 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-12 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-13 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-20 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-23 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-24 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-26 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-01-31 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-01 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-02 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-03 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-04 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-06 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-10 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-11 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-12 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-13 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-22 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-23 00:00:00', 7.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-04 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-09 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-13 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-14 00:00:00', 13.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-15 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-16 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-17 00:00:00', 5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-18 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-19 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-25 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-26 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-27 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-07 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-08 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-10 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-07 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-09 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-10 00:00:00', 7.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-04 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-05 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-07 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-08 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-26 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-27 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-28 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2005-12-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-10 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-11 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-12 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-13 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-14 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-15 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-23 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-25 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-26 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-27 00:00:00', 15.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-28 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-29 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-30 00:00:00', 6.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-01-31 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-10 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-11 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-15 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-16 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-17 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-18 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-19 00:00:00', 0.349000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-23 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-24 00:00:00', 7.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-25 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-13 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-17 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-18 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-21 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-25 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-26 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-03-31 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-08 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-09 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-20 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-23 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-25 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-09 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-13 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-16 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-17 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-20 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-21 00:00:00', 13.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-11-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-01 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-02 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-03 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-04 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-19 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-24 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-25 00:00:00', 5.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-30 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2006-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-08 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-11 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-12 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-14 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-15 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-16 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-17 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-18 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-24 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-02 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-04 00:00:00', 0.584999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-05 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-06 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-09 00:00:00', 7.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-10 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-11 00:00:00', 6.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-12 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-18 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-19 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-20 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-21 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-25 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-26 00:00:00', 6.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-04 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-08 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-09 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-11 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-12 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-16 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-17 00:00:00', 12.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-18 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-19 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-26 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-29 00:00:00', 12.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-30 00:00:00', 27.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-03-31 00:00:00', 9.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-01 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-04 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-05 00:00:00', 0.0320000015199184418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-06 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-08 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-14 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-17 00:00:00', 0.23399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-18 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-29 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-04-30 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-01 00:00:00', 0.259999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-02 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-03 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-07 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-16 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-17 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-18 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-20 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-24 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-11-30 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-01 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-06 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-07 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-08 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-09 00:00:00', 13.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-10 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-11 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-12 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-17 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-18 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-19 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-20 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-21 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-22 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-23 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2007-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-02 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-03 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-04 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-05 00:00:00', 0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-06 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-07 00:00:00', 8.98499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-08 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-10 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-13 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-15 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-16 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-17 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-19 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-22 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-28 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-02 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-03 00:00:00', 0.779999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-05 00:00:00', 0.29800000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-13 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-14 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-15 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-16 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-20 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-21 00:00:00', 25.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-02-29 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-01 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-02 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-05 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-04 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-09 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-10 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-14 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-04 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-26 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-09-30 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-13 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-19 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-27 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-28 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-29 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-06 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-12 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-13 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-17 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-21 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-24 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-08 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-16 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-17 00:00:00', 13.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-18 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-19 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-20 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-22 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-23 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-27 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-28 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-29 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2008-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-02 00:00:00', 8.97299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-03 00:00:00', 10.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-11 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-12 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-13 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-16 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-17 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-26 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-29 00:00:00', 6.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-02 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-03 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-04 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-09 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-11 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-12 00:00:00', 10.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-13 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-14 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-17 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-18 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-19 00:00:00', 14.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-20 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-22 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-23 00:00:00', 9.99899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-24 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-02 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-03 00:00:00', 8.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-18 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-22 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-23 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-26 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-01 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-02 00:00:00', 7.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-05 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-10 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-11 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-15 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-19 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-20 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-21 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-25 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-26 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-27 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-28 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-01 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-03 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-04 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-08 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-09 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-14 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-18 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-19 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-07 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-19 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-30 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-01 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-22 00:00:00', 6.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-23 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-24 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-28 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-01 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-03 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-04 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-08 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-09 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-10 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-12 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-16 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-19 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-20 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-21 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-22 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-28 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2009-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-17 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-22 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-23 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-27 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-28 00:00:00', 8.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-01-31 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-02 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-03 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-04 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-05 00:00:00', 8.16899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-06 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-07 00:00:00', 7.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-08 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-11 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-12 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-13 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-17 00:00:00', 0.303000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-18 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-19 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-20 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-23 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-24 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-26 00:00:00', 5.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-27 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-02-28 00:00:00', 15.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-01 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-03 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-08 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-21 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-22 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-29 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-30 00:00:00', 7.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-02 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-03 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-07 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-10 00:00:00', 9.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-11 00:00:00', 42.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-15 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-17 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-20 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-21 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-29 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-02 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-03 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-04 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-05 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-10 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-11 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-12 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-16 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-21 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-22 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-02 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-14 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-24 00:00:00', 0.0590000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-25 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-03 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-05 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-05 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-06 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-15 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2010-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-04 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-06 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-07 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-10 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-11 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-13 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-14 00:00:00', 0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-16 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-17 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-18 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-20 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-21 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-30 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-01-31 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-02 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-03 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-04 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-06 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-08 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-09 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-11 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-12 00:00:00', 7.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-13 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-18 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-19 00:00:00', 8.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-21 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-22 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-23 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-25 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-27 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-02-28 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-02 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-04 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-06 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-07 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-11 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-14 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-16 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-17 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-24 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-25 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-26 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-27 00:00:00', 15.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-28 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-03-31 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-03 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-08 00:00:00', 0.671000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-09 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-10 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-14 00:00:00', 6.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-15 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-23 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-28 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-04 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-09 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-10 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-17 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-04 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-12 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-26 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-03 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-11 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-12 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-22 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-28 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-29 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-30 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-10-31 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-01 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-02 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-03 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-04 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-07 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-08 00:00:00', 14.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-09 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-10 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-14 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-17 00:00:00', 7.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-18 00:00:00', 8.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-19 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-22 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-23 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-24 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-25 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-26 00:00:00', 23.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-27 00:00:00', 7.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-28 00:00:00', 9.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-01 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-02 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-03 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-05 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-27 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-28 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2011-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-02 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-03 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-04 00:00:00', 13.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-05 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-06 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-13 00:00:00', 7.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-14 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-15 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-19 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-22 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-25 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-26 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-30 00:00:00', 5.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-02 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-03 00:00:00', 7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-04 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-09 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-11 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-12 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-13 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-17 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-19 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-20 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-26 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-27 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-02-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-01 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-02 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-03 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-04 00:00:00', 14.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-06 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-07 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-10 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-11 00:00:00', 8.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-12 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-13 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-15 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-16 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-17 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-18 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-19 00:00:00', 7.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-24 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-25 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-29 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-30 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-03-31 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-01 00:00:00', 7.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-09 00:00:00', 0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-10 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-21 00:00:00', 7.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-22 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-23 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-25 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-27 00:00:00', 6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-04-30 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-05 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-06 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-07 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-10 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-15 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-16 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-17 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-19 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-22 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-25 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-26 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-27 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-22 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-23 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-14 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-24 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-25 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-27 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-28 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-30 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-10-31 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-01 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-02 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-04 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-15 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-16 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-22 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-23 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-26 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-27 00:00:00', 0.801999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-28 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-29 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-07 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-10 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-12 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-13 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-16 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-17 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-18 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-23 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-24 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-26 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-27 00:00:00', 17.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-28 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2012-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-01 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-03 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-08 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-09 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-10 00:00:00', 0.156000003218650818, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-11 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-12 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-16 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-21 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-22 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-25 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-26 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-27 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-30 00:00:00', 19.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-01-31 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-01 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-02 00:00:00', 8.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-03 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-04 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-09 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-13 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-17 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-18 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-19 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-21 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-26 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-27 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-03 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-07 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-08 00:00:00', 14.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-09 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-12 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-13 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-15 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-16 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-18 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-19 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-20 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-21 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-22 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-23 00:00:00', 6.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-24 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-26 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-03-31 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-05 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-12 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-13 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-15 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-21 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-22 00:00:00', 10.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-23 00:00:00', 17.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-24 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-25 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-26 00:00:00', 18.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-28 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-29 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-04-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-19 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-24 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-02 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-03 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-24 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-27 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-09 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-23 00:00:00', 8.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-28 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-29 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-30 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-04 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-11 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-16 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-19 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-20 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-23 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-24 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-25 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-26 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-01 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-05 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-06 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-07 00:00:00', 6.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-10 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-11 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-15 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-16 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-18 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-21 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-27 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-28 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2013-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-03 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-08 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-13 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-20 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-21 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-22 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-23 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-24 00:00:00', 6.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-25 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-26 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-27 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-29 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-30 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-01-31 00:00:00', 9.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-01 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-02 00:00:00', 13.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-03 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-06 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-10 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-13 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-18 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-19 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-21 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-23 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-24 00:00:00', 0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-26 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-03 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-06 00:00:00', 12.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-07 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-08 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-13 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-14 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-15 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-16 00:00:00', 7.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-17 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-18 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-21 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-22 00:00:00', 0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-23 00:00:00', 15.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-24 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-26 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-01 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-03 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-04 00:00:00', 8.63599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-05 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-10 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-11 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-16 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-24 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-25 00:00:00', 13.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-28 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-29 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-04-30 00:00:00', 9.41399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-01 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-02 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-03 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-04 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-05 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-06 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-07 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-08 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-09 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-17 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-18 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-19 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-29 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-30 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-01 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-06 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (16, '2014-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-08 00:00:00', 11.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-12 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-13 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-14 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-15 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-17 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-18 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-23 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-24 00:00:00', 0.0419999994337558746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-25 00:00:00', 6.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-26 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-27 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-29 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-04 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-06 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-09 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-10 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-12 00:00:00', 9.71100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-13 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-18 00:00:00', 11.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-19 00:00:00', 7.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-20 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-22 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-23 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-24 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-27 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-02-28 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-01 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-02 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-03 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-04 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-05 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-06 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-10 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-13 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-16 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-25 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-30 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-03-31 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-01 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-05 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-06 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-07 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-12 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-14 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-15 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-17 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-18 00:00:00', 8.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-19 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-20 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-21 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-27 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-04-30 00:00:00', 7.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-01 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-05 00:00:00', 0.65700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-07 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-09 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-11 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-13 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-14 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-15 00:00:00', 6.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-16 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-17 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-18 00:00:00', 6.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-19 00:00:00', 5.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-20 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-24 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-25 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-07 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-20 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-21 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-28 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-30 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-10-31 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-05 00:00:00', 5.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-06 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-07 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-08 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-12 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-13 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-02 00:00:00', 7.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-09 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-10 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-17 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-18 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-21 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-22 00:00:00', 7.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-23 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-28 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-29 00:00:00', 0.819000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-30 00:00:00', 0.324000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1979-12-31 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-08 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-10 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-14 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-15 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-18 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-19 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-21 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-22 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-23 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-24 00:00:00', 7.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-25 00:00:00', 10.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-27 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-28 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-01-31 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-01 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-02 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-03 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-04 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-06 00:00:00', 0.0590000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-07 00:00:00', 0.428000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-08 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-12 00:00:00', 0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-13 00:00:00', 8.89700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-14 00:00:00', 0.952000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-19 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-20 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-21 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-22 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-24 00:00:00', 1.03199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-25 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-26 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-27 00:00:00', 6.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-02-29 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-02 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-03 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-04 00:00:00', 5.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-05 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-08 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-09 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-12 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-14 00:00:00', 6.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-15 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-16 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-17 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-20 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-21 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-24 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-27 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-28 00:00:00', 0.421000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-01 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-02 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-05 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-17 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-18 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-25 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-26 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-27 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-07 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-08 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-11 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-13 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-15 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-16 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-17 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-19 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-25 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-26 00:00:00', 1.01800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-02 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-12 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-13 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-14 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-20 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-27 00:00:00', 11.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-28 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-29 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-30 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1980-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-01 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-02 00:00:00', 9.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-03 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-13 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-14 00:00:00', 6.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-15 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-16 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-18 00:00:00', 0.716000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-23 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-26 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-27 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-28 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-01 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-02 00:00:00', 9.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-03 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-04 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-08 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-10 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-11 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-12 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-13 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-17 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-18 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-19 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-20 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-21 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-22 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-23 00:00:00', 8.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-24 00:00:00', 6.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-26 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-27 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-02-28 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-03 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-04 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-05 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-09 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-11 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-13 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-15 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-16 00:00:00', 12.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-17 00:00:00', 0.444000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-18 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-19 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-20 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-24 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-25 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-26 00:00:00', 5.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-29 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-30 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-02 00:00:00', 7.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-03 00:00:00', 7.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-07 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-10 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-11 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-12 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-13 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-14 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-15 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-16 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-18 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-19 00:00:00', 6.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-20 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-27 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-28 00:00:00', 30.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-04-30 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-01 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-03 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-04 00:00:00', 11.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-06 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-07 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-08 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-09 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-13 00:00:00', 0.15700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-05-31 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-01 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-23 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-18 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-21 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-22 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-23 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-24 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-01 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-02 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-04 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-08 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-16 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-21 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-25 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-26 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-27 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-28 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-29 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-30 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1981-12-31 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-01 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-03 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-09 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-13 00:00:00', 6.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-16 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-18 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-19 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-20 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-21 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-22 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-29 00:00:00', 7.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-30 00:00:00', 10.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-01 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-02 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-06 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-09 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-10 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-15 00:00:00', 5.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-19 00:00:00', 5.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-20 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-22 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-23 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-25 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-26 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-27 00:00:00', 0.439999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-02-28 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-01 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-03 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-04 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-08 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-09 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-12 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-13 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-14 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-15 00:00:00', 0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-16 00:00:00', 0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-19 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-20 00:00:00', 21.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-21 00:00:00', 8.95199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-26 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-27 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-28 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-29 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-30 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-03-31 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-03 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-14 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-22 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-24 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-26 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-27 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-28 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-18 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-23 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-24 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-25 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-27 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-14 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-06-30 00:00:00', 0.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-01 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-05 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-06 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-14 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-03 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-04 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-05 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-06 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-10 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-11 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-16 00:00:00', 0.888000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-17 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-24 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-25 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-01 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-02 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-03 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-04 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-10 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-11 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-13 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-14 00:00:00', 21.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-15 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-16 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-20 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-23 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-28 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-29 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-11-30 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-01 00:00:00', 5.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-04 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-06 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-07 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-08 00:00:00', 8.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-09 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-10 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-13 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-14 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-16 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-17 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-27 00:00:00', 0.527999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-28 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-29 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-30 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1982-12-31 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-03 00:00:00', 8.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-04 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-05 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-07 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-10 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-11 00:00:00', 5.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-13 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-14 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-22 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-25 00:00:00', 7.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-26 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-27 00:00:00', 7.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-28 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-05 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-06 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-07 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-08 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-09 00:00:00', 0.430999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-10 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-11 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-12 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-13 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-19 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-20 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-22 00:00:00', 0.0829999968409538269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-23 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-27 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-02-28 00:00:00', 11.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-01 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-06 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-07 00:00:00', 16.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-08 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-10 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-14 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-16 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-17 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-18 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-19 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-23 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-24 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-25 00:00:00', 7.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-26 00:00:00', 1.01800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-29 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-30 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-03-31 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-05 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-06 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-07 00:00:00', 22.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-09 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-11 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-12 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-13 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-26 00:00:00', 10.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-29 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-03 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-04 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-07 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-08 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-10 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-11 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-30 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-05-31 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-05 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-16 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-26 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-04 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-10 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-13 00:00:00', 14.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-14 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-15 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-16 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-17 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-28 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1983-12-31 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-03 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-04 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-11 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-12 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-18 00:00:00', 0.455000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-19 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-21 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-22 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-27 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-30 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-01-31 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-01 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-03 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-06 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-08 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-09 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-10 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-11 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-12 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-13 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-14 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-15 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-16 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-17 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-18 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-19 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-20 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-26 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-28 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-02-29 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-02 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-03 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-04 00:00:00', 6.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-05 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-08 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-09 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-10 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-11 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-12 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-13 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-14 00:00:00', 16.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-15 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-16 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-17 00:00:00', 7.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-21 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-22 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-25 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-26 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-27 00:00:00', 7.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-28 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-03-31 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-05 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-09 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-10 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-18 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-19 00:00:00', 14.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-27 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-03 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-07 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-15 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-07 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-08 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-21 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-22 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-11 00:00:00', 5.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-12 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-13 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-14 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-16 00:00:00', 8.17599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-17 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-19 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-20 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-22 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-27 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-11-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-01 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-02 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-04 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-05 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-06 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-07 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-08 00:00:00', 7.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-12 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-13 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-14 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-15 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-16 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-17 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-19 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-22 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-29 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1984-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-03 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-04 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-05 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-12 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-13 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-14 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-15 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-16 00:00:00', 5.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-17 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-18 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-20 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-21 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-23 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-24 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-25 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-02 00:00:00', 0.653999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-03 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-04 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-18 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-19 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-23 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-24 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-02-28 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-02 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-03 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-04 00:00:00', 11.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-08 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-09 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-10 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-11 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-14 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-15 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-21 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-22 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-25 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-26 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-27 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-02 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-04 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-05 00:00:00', 8.25300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-07 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-27 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-28 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-04-30 00:00:00', 19.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-01 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-02 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-03 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-07 00:00:00', 7.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-08 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-20 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-23 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-25 00:00:00', 0.312999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-16 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-24 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-05 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-06 00:00:00', 5.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-07 00:00:00', 9.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-13 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-14 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-15 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-21 00:00:00', 9.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-22 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-24 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-25 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-26 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-29 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1985-12-31 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-05 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-06 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-16 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-17 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-20 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-22 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-24 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-28 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-02 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-03 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-09 00:00:00', 0.763999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-12 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-13 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-14 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-17 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-03 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-10 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-11 00:00:00', 9.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-12 00:00:00', 9.22299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-13 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-15 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-16 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-22 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-23 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-25 00:00:00', 1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-26 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-27 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-30 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-12 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-14 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-15 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-16 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-22 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-16 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-17 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-08 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-15 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-13 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-14 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-20 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-21 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-25 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-03 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-04 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-05 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-06 00:00:00', 7.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-09 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-10 00:00:00', 6.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-11 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-21 00:00:00', 6.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-22 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-23 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-08 00:00:00', 11.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-13 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-19 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-20 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-21 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-01 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-02 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-06 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-07 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-11 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-12 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-17 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-18 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-22 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-23 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-24 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-25 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-02 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-04 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-05 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-06 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-07 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-12 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-13 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-15 00:00:00', 14.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-18 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-19 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-20 00:00:00', 0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-21 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-22 00:00:00', 10.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-27 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-28 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-29 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-30 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-03-31 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-01 00:00:00', 9.65699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-02 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-05 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-06 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-07 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-08 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-15 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-20 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-21 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-28 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-28 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-30 00:00:00', 15.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-01 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-05 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-20 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-01 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-09 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-10 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-25 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-26 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-27 00:00:00', 5.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-28 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-04 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-28 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-29 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-11-30 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-01 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-14 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-15 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-29 00:00:00', 11.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-30 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1987-12-31 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-01 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-03 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-08 00:00:00', 6.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-14 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-15 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-17 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-18 00:00:00', 0.976999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-20 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-21 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-26 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-30 00:00:00', 8.15400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-01 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-04 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-06 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-07 00:00:00', 7.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-08 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-15 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-16 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-18 00:00:00', 14.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-19 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-21 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-26 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-27 00:00:00', 0.412999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-02 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-06 00:00:00', 15.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-09 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-10 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-11 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-13 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-15 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-22 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-24 00:00:00', 11.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-25 00:00:00', 16.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-26 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-27 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-28 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-29 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-30 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-03-31 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-01 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-06 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-07 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-09 00:00:00', 0.393000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-17 00:00:00', 19.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-29 00:00:00', 21.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-04-30 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-01 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-02 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-13 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-16 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-22 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-23 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-29 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-15 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-21 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-22 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-23 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-16 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-18 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-20 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-21 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-27 00:00:00', 0.421000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-28 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-29 00:00:00', 15.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1988-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-03 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-04 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-05 00:00:00', 7.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-13 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-15 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-16 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-18 00:00:00', 5.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-19 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-25 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-27 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-29 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-30 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-01-31 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-02 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-03 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-06 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-12 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-13 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-15 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-16 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-20 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-21 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-23 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-24 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-25 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-26 00:00:00', 12.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-27 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-02-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-08 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-13 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-17 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-19 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-20 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-22 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-29 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-30 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-03-31 00:00:00', 17.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-05 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-15 00:00:00', 10.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-16 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-17 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-04-30 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-03 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-04 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-05 00:00:00', 0.386000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-08 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-09 00:00:00', 6.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-10-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-01 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-07 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-08 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-17 00:00:00', 8.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-18 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-22 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-04 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-05 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-06 00:00:00', 21.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-07 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-15 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-16 00:00:00', 7.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-17 00:00:00', 0.764999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-18 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1989-12-31 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-01 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-02 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-03 00:00:00', 5.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-05 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-06 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-07 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-08 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-09 00:00:00', 7.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-10 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-11 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-12 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-16 00:00:00', 0.0850000008940696716, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-17 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-20 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-25 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-26 00:00:00', 7.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-27 00:00:00', 5.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-29 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-30 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-01-31 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-03 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-04 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-05 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-06 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-07 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-08 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-11 00:00:00', 0.904999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-12 00:00:00', 7.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-14 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-16 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-17 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-22 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-23 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-25 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-26 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-09 00:00:00', 15.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-10 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-17 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-18 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-19 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-20 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-21 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-06 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-08 00:00:00', 6.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-12 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-14 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-15 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-16 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-17 00:00:00', 14.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-06 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-08 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-14 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-15 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-29 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-30 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-14 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-08 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-10 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-11 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-12 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-13 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-20 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-22 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-23 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-24 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-25 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-26 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-27 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1990-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-04 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-05 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-06 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-08 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-10 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-11 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-15 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-16 00:00:00', 0.592000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-17 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-18 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-19 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-20 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-21 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-24 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-25 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-26 00:00:00', 6.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-27 00:00:00', 9.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-28 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-29 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-02 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-03 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-05 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-06 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-07 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-08 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-09 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-10 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-11 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-12 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-13 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-14 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-23 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-24 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-25 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-26 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-02 00:00:00', 5.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-04 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-07 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-08 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-09 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-10 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-11 00:00:00', 6.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-12 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-15 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-16 00:00:00', 8.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-17 00:00:00', 9.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-18 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-20 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-21 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-23 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-25 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-29 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-02 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-06 00:00:00', 7.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-08 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-11 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-12 00:00:00', 7.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-13 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-26 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-27 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-28 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-02 00:00:00', 10.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-12 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-13 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-14 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-15 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-16 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-20 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-21 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-24 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-26 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-25 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-26 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-27 00:00:00', 9.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-28 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-29 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-10 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-13 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-20 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-21 00:00:00', 5.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-23 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-27 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-28 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-04 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-05 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-06 00:00:00', 7.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-09 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-10 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-11 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-12 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-13 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-14 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-15 00:00:00', 6.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-16 00:00:00', 9.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-17 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-20 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-21 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-22 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-24 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-27 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-29 00:00:00', 0.317000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1991-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-01 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-02 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-03 00:00:00', 0.654999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-04 00:00:00', 18.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-05 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-06 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-07 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-09 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-10 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-14 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-18 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-22 00:00:00', 0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-23 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-24 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-25 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-26 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-27 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-28 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-29 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-01-31 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-01 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-06 00:00:00', 4.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-12 00:00:00', 10.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-16 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-25 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-27 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-28 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-03 00:00:00', 0.291000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-04 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-07 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-08 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-09 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-10 00:00:00', 7.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-11 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-12 00:00:00', 0.349000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-16 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-17 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-19 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-23 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-24 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-26 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-29 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-30 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-01 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-02 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-03 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-04 00:00:00', 6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-06 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-16 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-20 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-28 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-02 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-05 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-06 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-07 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-10 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-12 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-13 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-15 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-25 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-16 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-17 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-18 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-19 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-20 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-21 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-05 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-07 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-08 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-10 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-11 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-23 00:00:00', 6.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-24 00:00:00', 0.855000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-29 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-30 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1992-12-31 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-03 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-05 00:00:00', 0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-06 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-09 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-10 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-15 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-16 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-18 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-19 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-04 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-05 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-06 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-08 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-14 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-15 00:00:00', 6.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-16 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-17 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-22 00:00:00', 7.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-23 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-24 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-25 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-27 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-01 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-02 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-03 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-05 00:00:00', 0.0900000035762786865, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-06 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-09 00:00:00', 6.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-10 00:00:00', 25.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-11 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-12 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-13 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-20 00:00:00', 12.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-22 00:00:00', 8.33100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-23 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-24 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-06 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-07 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-14 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-15 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-24 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-28 00:00:00', 8.50599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-01 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-05 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-06 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-07 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-08 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-15 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-16 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-21 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-24 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-30 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-18 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-08 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-03 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-04 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-08 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-17 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-22 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-26 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-27 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-29 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-11-30 00:00:00', 11.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-02 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-03 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-04 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-06 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-07 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-09 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-13 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-18 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-27 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1993-12-31 00:00:00', 1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-01 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-02 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-03 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-04 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-06 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-07 00:00:00', 8.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-09 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-18 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-19 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-24 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-26 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-27 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-01-31 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-02 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-04 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-07 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-09 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-10 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-11 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-12 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-13 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-14 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-15 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-20 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-23 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-25 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-02 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-09 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-10 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-11 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-13 00:00:00', 6.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-25 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-29 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-30 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-03 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-05 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-28 00:00:00', 16.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-02 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-07 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-25 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-26 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-01 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-10 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-11 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-18 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-27 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-02 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-05 00:00:00', 17.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-07 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-08 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-22 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-26 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-27 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-28 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1994-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-02 00:00:00', 0.0799999982118606567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-07 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-08 00:00:00', 0.193000003695487976, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-12 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-15 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-17 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-18 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-19 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-25 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-06 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-07 00:00:00', 13.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-08 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-09 00:00:00', 9.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-10 00:00:00', 10.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-11 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-17 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-25 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-26 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-27 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-03 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-05 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-06 00:00:00', 0.805000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-07 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-19 00:00:00', 0.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-20 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-21 00:00:00', 7.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-22 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-23 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-27 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-28 00:00:00', 4.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-07 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-08 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-17 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-18 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-19 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-20 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-24 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-27 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-28 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-13 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-20 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-24 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-27 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-29 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-05 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-06 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-07 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-08 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-10 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-13 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-14 00:00:00', 0.268999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-15 00:00:00', 0.42300000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-18 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-20 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-21 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-23 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-24 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-27 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1995-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-03 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-04 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-07 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-08 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-09 00:00:00', 8.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-10 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-11 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-13 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-14 00:00:00', 0.554000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-15 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-16 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-18 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-19 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-20 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-21 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-23 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-25 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-26 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-27 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-28 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-30 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-01-31 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-01 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-02 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-03 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-04 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-05 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-06 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-07 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-08 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-12 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-13 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-14 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-15 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-17 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-20 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-21 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-22 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-23 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-24 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-26 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-27 00:00:00', 0.970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-28 00:00:00', 0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-02-29 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-01 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-03 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-04 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-05 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-06 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-08 00:00:00', 0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-09 00:00:00', 0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-10 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-11 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-12 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-14 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-15 00:00:00', 0.451000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-17 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-18 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-19 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-20 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-22 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-24 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-27 00:00:00', 7.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-02 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-03 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-04 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-09 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-10 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-16 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-17 00:00:00', 15.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-18 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-20 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-24 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-25 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-26 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-29 00:00:00', 0.052000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-04-30 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-01 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-02 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-20 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-27 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-29 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-24 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-16 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-18 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-12 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-13 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-14 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-15 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-17 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-18 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-20 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-01 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-02 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-16 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1996-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-04 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-14 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-17 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-18 00:00:00', 6.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-23 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-26 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-27 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-01 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-02 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-07 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-21 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-22 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-23 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-24 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-02-28 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-01 00:00:00', 15.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-06 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-07 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-09 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-10 00:00:00', 8.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-14 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-15 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-17 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-18 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-21 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-22 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-27 00:00:00', 7.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-03-31 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-01 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-06 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-07 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-12 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-21 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-26 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-04-30 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-06 00:00:00', 8.93299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-07 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-12 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-16 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-08 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-25 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-26 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-02 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-06 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-07 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-15 00:00:00', 5.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-12 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-18 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-19 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-20 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-21 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-22 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-25 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-27 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1997-12-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-03 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-04 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-06 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-07 00:00:00', 17.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-10 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-11 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-12 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-14 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-15 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-20 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-22 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-23 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-25 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-27 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-28 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-29 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-30 00:00:00', 0.716000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-01-31 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-01 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-05 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-08 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-09 00:00:00', 7.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-10 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-11 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-12 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-13 00:00:00', 0.691999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-14 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-16 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-17 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-20 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-23 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-27 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-02-28 00:00:00', 0.880999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-02 00:00:00', 5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-03 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-04 00:00:00', 0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-06 00:00:00', 0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-15 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-16 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-17 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-19 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-20 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-21 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-22 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-26 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-07 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-08 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-21 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-22 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-24 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-25 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-04-30 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-06 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-11 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-13 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-14 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-05 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-08 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-25 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-17 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-28 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-29 00:00:00', 6.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-11-30 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-02 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-03 00:00:00', 0.382999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-29 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1998-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-10 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-12 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-14 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-18 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-22 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-24 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-11 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-13 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-27 00:00:00', 10.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-03 00:00:00', 0.907999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-04 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-05 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-06 00:00:00', 0.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-07 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-08 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-14 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-15 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-16 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-19 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-21 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-22 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-27 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-29 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-03-31 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-04 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-07 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-10 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-22 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-11 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-12 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-28 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-29 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-03 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-04 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-05 00:00:00', 7.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-09 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-11 00:00:00', 0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-12 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-13 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-20 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-21 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-24 00:00:00', 8.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-29 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-11-30 00:00:00', 0.517000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-18 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-19 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '1999-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-08 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-11 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-12 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-13 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-18 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-19 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-20 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-24 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-30 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-01-31 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-03 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-08 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-09 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-15 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-03 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-04 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-16 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-26 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-27 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-28 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-29 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-30 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-17 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-05 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-16 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-19 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-07 00:00:00', 11.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-08 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-11 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-12 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-16 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-17 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-29 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-02 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-03 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-10 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-16 00:00:00', 7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-17 00:00:00', 7.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-27 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-28 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2000-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-16 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-17 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-20 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-21 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-22 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-24 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-25 00:00:00', 0.805000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-28 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-29 00:00:00', 5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-30 00:00:00', 1.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-06 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-16 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-22 00:00:00', 8.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-23 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-11 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-12 00:00:00', 10.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-13 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-19 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-27 00:00:00', 9.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-28 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-23 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-23 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-20 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-29 00:00:00', 0.368999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-11-30 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-01 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-02 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-03 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-06 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-07 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-13 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-17 00:00:00', 5.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-21 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-22 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2001-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-09 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-10 00:00:00', 1.17200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-12 00:00:00', 7.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-13 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-23 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-24 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-01-31 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-01 00:00:00', 11.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-02 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-04 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-05 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-06 00:00:00', 0.517000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-15 00:00:00', 0.978999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-16 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-17 00:00:00', 9.07900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-22 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-26 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-02-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-07 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-11 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-20 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-23 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-24 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-30 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-03-31 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-04 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-05 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-14 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-15 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-22 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-23 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-26 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-29 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-02 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-06 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-14 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-16 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-11-30 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-02 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-03 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-10 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-11 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-12 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-13 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-14 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-15 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-18 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-19 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-20 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-23 00:00:00', 13.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-28 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2002-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-08 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-11 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-19 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-20 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-21 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-23 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-29 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-06 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-16 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-17 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-18 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-20 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-21 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-24 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-26 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-27 00:00:00', 15.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-02-28 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-01 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-02 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-08 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-09 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-14 00:00:00', 1.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-15 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-24 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-27 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-28 00:00:00', 12.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-30 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-03-31 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-01 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-02 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-05 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-14 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-15 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-18 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-19 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-23 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-24 00:00:00', 8.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-04 00:00:00', 4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-15 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-16 00:00:00', 5.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-22 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-23 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-11-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-05 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-07 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-08 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-11 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-12 00:00:00', 6.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-18 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-21 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-22 00:00:00', 7.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-25 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-28 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-29 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-30 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2003-12-31 00:00:00', 0.819000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-01 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-04 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-06 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-07 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-08 00:00:00', 10.3559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-09 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-11 00:00:00', 0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-12 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-15 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-16 00:00:00', 5.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-21 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-28 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-29 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-07 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-08 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-09 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-21 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-25 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-13 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-14 00:00:00', 0.345999985933303833, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-15 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-17 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-21 00:00:00', 0.474999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-02 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-21 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-22 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-06 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-07 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-15 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-19 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-20 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-21 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-28 00:00:00', 0.589999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-29 00:00:00', 0.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-03 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-14 00:00:00', 0.492000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-16 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-17 00:00:00', 0.504000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-18 00:00:00', 9.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-19 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-22 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-27 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-28 00:00:00', 9.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-29 00:00:00', 7.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-30 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2004-12-31 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-05 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-07 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-08 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-12 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-13 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-20 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-24 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-26 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-01-31 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-01 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-02 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-03 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-04 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-06 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-10 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-11 00:00:00', 6.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-12 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-13 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-22 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-23 00:00:00', 8.48499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-07 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-09 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-14 00:00:00', 8.28400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-15 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-16 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-17 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-18 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-19 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-20 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-25 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-26 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-27 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-07 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-08 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-09 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-10 00:00:00', 8.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-07 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-10 00:00:00', 8.62399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-04 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-05 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-07 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-27 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-28 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2005-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-10 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-11 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-12 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-13 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-14 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-15 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-23 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-26 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-27 00:00:00', 13.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-28 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-29 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-30 00:00:00', 8.19900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-01-31 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-10 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-11 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-15 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-17 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-18 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-19 00:00:00', 0.222000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-23 00:00:00', 1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-24 00:00:00', 7.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-25 00:00:00', 0.140000000596046448, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-04 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-13 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-17 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-18 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-21 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-22 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-25 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-26 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-03-31 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-08 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-09 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-20 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-23 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-25 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-09 00:00:00', 5.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-13 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-16 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-17 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-20 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-21 00:00:00', 11.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-11-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-01 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-02 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-03 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-04 00:00:00', 11.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-19 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-24 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-25 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-30 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2006-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-08 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-11 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-12 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-14 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-16 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-17 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-18 00:00:00', 6.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-24 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-02 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-04 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-05 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-06 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-09 00:00:00', 7.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-10 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-11 00:00:00', 7.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-12 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-18 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-19 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-20 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-21 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-25 00:00:00', 0.663999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-26 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-27 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-02-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-04 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-08 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-09 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-11 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-12 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-16 00:00:00', 0.773999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-17 00:00:00', 8.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-18 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-19 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-26 00:00:00', 0.671000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-28 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-29 00:00:00', 11.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-30 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-03-31 00:00:00', 17.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-01 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-04 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-05 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-08 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-14 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-18 00:00:00', 0.194999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-29 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-04-30 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-01 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-02 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-03 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-16 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-17 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-18 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-24 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-11-30 00:00:00', 0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-01 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-06 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-08 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-09 00:00:00', 11.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-10 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-11 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-12 00:00:00', 0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-17 00:00:00', 0.529999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-18 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-19 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-20 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-21 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-22 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-23 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2007-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-02 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-03 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-04 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-05 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-06 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-07 00:00:00', 9.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-08 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-10 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-13 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-15 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-16 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-17 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-19 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-28 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-02 00:00:00', 0.878000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-03 00:00:00', 1.0700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-04 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-05 00:00:00', 0.442000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-10 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-13 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-14 00:00:00', 4.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-15 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-16 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-20 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-21 00:00:00', 21.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-02-29 00:00:00', 0.126000002026557922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-01 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-05 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-06 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-04 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-09 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-10 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-14 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-19 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-22 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-04 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-09-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-13 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-19 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-27 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-28 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-29 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-12 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-13 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-14 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-15 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-17 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-21 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-08 00:00:00', 8.02700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-09 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-16 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-17 00:00:00', 16.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-18 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-19 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-20 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-22 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-23 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-27 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-28 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-29 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2008-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-02 00:00:00', 6.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-03 00:00:00', 7.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-11 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-12 00:00:00', 0.197999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-13 00:00:00', 1.02499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-16 00:00:00', 0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-17 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-18 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-26 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-29 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-02 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-03 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-04 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-09 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-11 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-12 00:00:00', 12.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-13 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-14 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-17 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-18 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-19 00:00:00', 10.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-20 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-22 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-23 00:00:00', 9.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-24 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-01 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-03 00:00:00', 13.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-18 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-23 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-26 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-01 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-02 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-05 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-06 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-10 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-11 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-15 00:00:00', 6.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-20 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-21 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-25 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-26 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-27 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-28 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-01 00:00:00', 0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-03 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-04 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-08 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-14 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-07 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-19 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-30 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-01 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-22 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-23 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-24 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-28 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-01 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-03 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-04 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-08 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-09 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-10 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-12 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-16 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-19 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-20 00:00:00', 7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-21 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-22 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-28 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2009-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-17 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-22 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-23 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-27 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-28 00:00:00', 8.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-02 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-03 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-04 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-05 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-06 00:00:00', 0.638000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-07 00:00:00', 6.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-08 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-11 00:00:00', 0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-12 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-13 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-17 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-18 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-19 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-20 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-22 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-23 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-24 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-25 00:00:00', 0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-26 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-27 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-02-28 00:00:00', 7.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-01 00:00:00', 0.509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-03 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-21 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-22 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-29 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-30 00:00:00', 8.06999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-02 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-03 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-10 00:00:00', 6.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-11 00:00:00', 45.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-12 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-14 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-15 00:00:00', 0.469000011682510376, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-17 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-20 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-21 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-02 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-03 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-04 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-05 00:00:00', 7.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-10 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-11 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-12 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-21 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-22 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-02 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-14 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-25 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-16 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-13 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-03 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-05 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-05 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-06 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-07 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-15 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2010-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-04 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-06 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-07 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-10 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-11 00:00:00', 7.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-13 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-14 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-17 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-18 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-20 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-21 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-01-31 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-02 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-04 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-06 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-08 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-09 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-11 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-12 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-13 00:00:00', 9.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-18 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-19 00:00:00', 8.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-20 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-21 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-22 00:00:00', 8.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-23 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-25 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-27 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-02-28 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-02 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-04 00:00:00', 5.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-06 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-07 00:00:00', 1.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-11 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-14 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-15 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-16 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-17 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-24 00:00:00', 0.647000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-25 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-26 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-27 00:00:00', 21.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-28 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-03-31 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-01 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-03 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-08 00:00:00', 0.945999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-09 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-10 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-11 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-14 00:00:00', 7.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-15 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-23 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-28 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-29 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-04 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-05 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-06 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-08 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-09 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-10 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-17 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-04 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-11 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-12 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-26 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-03 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-11 00:00:00', 0.80699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-12 00:00:00', 5.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-13 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-21 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-22 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-28 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-29 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-30 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-10-31 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-01 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-02 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-03 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-04 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-07 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-08 00:00:00', 15.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-09 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-10 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-14 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-15 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-17 00:00:00', 10.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-18 00:00:00', 9.54800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-19 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-22 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-23 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-24 00:00:00', 6.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-25 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-26 00:00:00', 27.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-27 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-28 00:00:00', 9.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-01 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-02 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-03 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-05 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-26 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-27 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-28 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2011-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-02 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-03 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-04 00:00:00', 15.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-05 00:00:00', 8.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-06 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-13 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-14 00:00:00', 6.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-15 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-19 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-22 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-23 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-25 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-26 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-30 00:00:00', 8.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-02 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-03 00:00:00', 10.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-04 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-09 00:00:00', 4.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-11 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-12 00:00:00', 7.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-13 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-17 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-18 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-19 00:00:00', 5.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-20 00:00:00', 12.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-26 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-27 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-02-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-01 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-02 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-03 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-04 00:00:00', 22.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-06 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-07 00:00:00', 0.866999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-10 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-11 00:00:00', 10.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-12 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-13 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-15 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-16 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-17 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-18 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-19 00:00:00', 13.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-24 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-25 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-29 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-30 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-03-31 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-01 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-06 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-07 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-08 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-09 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-10 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-20 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-21 00:00:00', 8.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-22 00:00:00', 5.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-23 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-24 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-25 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-26 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-27 00:00:00', 10.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-28 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-04-30 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-01 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-02 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-05 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-06 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-07 00:00:00', 11.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-08 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-10 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-11 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-12 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-15 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-16 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-17 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-18 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-19 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-21 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-22 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-25 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-26 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-27 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-30 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-22 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-23 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-14 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-15 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-24 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-25 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-27 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-28 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-30 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-10-31 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-01 00:00:00', 5.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-02 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-04 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-13 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-15 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-16 00:00:00', 5.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-22 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-26 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-27 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-28 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-29 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-07 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-10 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-12 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-13 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-16 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-17 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-18 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-23 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-24 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-26 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-27 00:00:00', 20.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-28 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2012-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-01 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-03 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-08 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-09 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-10 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-11 00:00:00', 0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-12 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-16 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-21 00:00:00', 0.856999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-22 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-26 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-27 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-29 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-30 00:00:00', 18.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-01-31 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-01 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-02 00:00:00', 7.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-03 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-04 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-05 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-09 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-11 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-12 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-13 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-15 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-17 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-18 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-19 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-21 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-25 00:00:00', 0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-26 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-27 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-03 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-04 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-07 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-08 00:00:00', 12.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-09 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-12 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-13 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-15 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-16 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-18 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-19 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-20 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-21 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-22 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-23 00:00:00', 7.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-24 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-26 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-03-31 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-05 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-12 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-13 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-15 00:00:00', 5.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-19 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-21 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-22 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-23 00:00:00', 16.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-24 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-25 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-26 00:00:00', 10.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-28 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-29 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-04-30 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-08 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-19 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-24 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-25 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-02 00:00:00', 0.0419999994337558746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-03 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-04 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-24 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-28 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-27 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-09 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-23 00:00:00', 8.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-28 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-29 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-30 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-04 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-05 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-11 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-19 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-20 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-23 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-24 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-26 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-01 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-05 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-06 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-07 00:00:00', 8.50800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-10 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-11 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-15 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-16 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-18 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-21 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-27 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-28 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2013-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-03 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-04 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-05 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-08 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-13 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-20 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-21 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-22 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-23 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-24 00:00:00', 6.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-25 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-26 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-27 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-29 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-30 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-01-31 00:00:00', 11.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-01 00:00:00', 12.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-02 00:00:00', 15.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-03 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-05 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-06 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-10 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-11 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-13 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-15 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-18 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-19 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-21 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-23 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-24 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-25 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-26 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-03 00:00:00', 1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-06 00:00:00', 13.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-07 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-08 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-09 00:00:00', 0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-13 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-14 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-15 00:00:00', 10.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-16 00:00:00', 6.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-17 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-18 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-21 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-22 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-23 00:00:00', 19.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-24 00:00:00', 6.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-26 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-27 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-01 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-03 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-04 00:00:00', 7.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-05 00:00:00', 0.653999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-06 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-07 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-10 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-11 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-12 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-16 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-22 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-24 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-25 00:00:00', 15.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-28 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-29 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-04-30 00:00:00', 11.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-01 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-02 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-03 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-04 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-06 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-07 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-08 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-09 00:00:00', 10.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-10 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-17 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-18 00:00:00', 6.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-19 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-29 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-30 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-05-31 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-01 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-02 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-04 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-06 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (17, '2014-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-17 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-19 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-20 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-21 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-25 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-26 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-27 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-02 00:00:00', 13.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-03 00:00:00', 5.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-04 00:00:00', 17.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-05 00:00:00', 11.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-06 00:00:00', 8.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-07 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-11 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-12 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-13 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-16 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-17 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-28 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-29 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-30 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (26, '2014-07-31 00:00:00', 9.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-17 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-18 00:00:00', 11.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-19 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-21 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-22 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-23 00:00:00', 0.224000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-24 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-27 00:00:00', 5.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-02-28 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-01 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-02 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-03 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-04 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-05 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-06 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-10 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-11 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-13 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-14 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-16 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-25 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-26 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-28 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-29 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-30 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-03-31 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-01 00:00:00', 7.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-02 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-06 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-07 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-12 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-14 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-15 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-17 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-18 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-19 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-20 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-21 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-27 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-04-30 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-01 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-05 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-07 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-09 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-11 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-13 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-14 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-15 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-16 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-17 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-18 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-19 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-20 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-24 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-07 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-20 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-21 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-28 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-30 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-10-31 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-05 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-06 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-07 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-12 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-13 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-01 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-02 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-03 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-04 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-09 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-10 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-17 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-18 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-19 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-21 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-22 00:00:00', 6.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-23 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-28 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-29 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-30 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1979-12-31 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-08 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-10 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-14 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-15 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-18 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-19 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-21 00:00:00', 0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-22 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-23 00:00:00', 6.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-24 00:00:00', 8.63099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-25 00:00:00', 9.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-27 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-28 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-01-31 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-01 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-02 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-03 00:00:00', 0.652999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-04 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-07 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-08 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-09 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-12 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-13 00:00:00', 10.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-14 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-16 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-19 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-21 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-22 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-24 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-25 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-26 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-27 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-02-29 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-01 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-02 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-03 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-04 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-05 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-08 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-12 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-14 00:00:00', 11.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-15 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-16 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-17 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-20 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-21 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-24 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-27 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-28 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-01 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-02 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-05 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-17 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-18 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-25 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-26 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-27 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-07 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-08 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-11 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-13 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-15 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-16 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-17 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-21 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-19 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-24 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-25 00:00:00', 5.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-26 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-01 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-02 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-11 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-12 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-13 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-14 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-20 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-27 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-28 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-29 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-30 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1980-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-01 00:00:00', 9.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-02 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-03 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-12 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-13 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-14 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-15 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-16 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-18 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-20 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-23 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-26 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-27 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-28 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-01 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-02 00:00:00', 8.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-03 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-04 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-08 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-10 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-11 00:00:00', 5.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-12 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-13 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-17 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-18 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-19 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-20 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-21 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-22 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-23 00:00:00', 6.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-24 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-26 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-27 00:00:00', 0.602999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-02-28 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-03 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-04 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-05 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-09 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-11 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-13 00:00:00', 0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-15 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-16 00:00:00', 15.4420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-17 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-18 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-19 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-20 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-24 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-25 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-26 00:00:00', 7.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-29 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-30 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-02 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-03 00:00:00', 9.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-06 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-07 00:00:00', 0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-10 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-11 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-12 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-13 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-14 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-16 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-18 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-19 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-20 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-27 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-28 00:00:00', 28.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-04-30 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-01 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-03 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-04 00:00:00', 9.51500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-07 00:00:00', 0.444999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-08 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-09 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-12 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-13 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-14 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-18 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-05-31 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-23 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-18 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-21 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-22 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-23 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-01 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-02 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-04 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-08 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-16 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-21 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-25 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-26 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-27 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-28 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-29 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-30 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1981-12-31 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-01 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-13 00:00:00', 9.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-16 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-18 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-19 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-20 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-21 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-22 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-29 00:00:00', 9.69499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-30 00:00:00', 10.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-01 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-02 00:00:00', 9.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-06 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-09 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-10 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-14 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-15 00:00:00', 6.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-19 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-22 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-23 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-25 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-26 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-27 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-02-28 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-01 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-03 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-04 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-08 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-09 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-12 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-13 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-14 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-15 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-16 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-19 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-20 00:00:00', 21.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-21 00:00:00', 8.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-26 00:00:00', 6.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-27 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-28 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-29 00:00:00', 7.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-30 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-03-31 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-03 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-14 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-24 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-26 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-27 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-28 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-18 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-23 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-24 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-25 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-27 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-14 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-06-30 00:00:00', 0.207000002264976501, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-01 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-05 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-06 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-14 00:00:00', 0.566999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-03 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-04 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-06 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-10 00:00:00', 0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-11 00:00:00', 7.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-16 00:00:00', 0.178000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-17 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-24 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-25 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-01 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-02 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-03 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-04 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-10 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-11 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-13 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-14 00:00:00', 23.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-15 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-16 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-20 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-23 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-27 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-28 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-29 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-11-30 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-01 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-04 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-06 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-07 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-08 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-09 00:00:00', 0.957000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-10 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-13 00:00:00', 0.140000000596046448, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-16 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-17 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-26 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-27 00:00:00', 0.531000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-28 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-29 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-30 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1982-12-31 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-03 00:00:00', 10.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-04 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-05 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-07 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-10 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-11 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-13 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-14 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-22 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-25 00:00:00', 7.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-26 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-27 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-28 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-05 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-06 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-07 00:00:00', 0.407999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-08 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-09 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-10 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-11 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-12 00:00:00', 0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-19 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-20 00:00:00', 5.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-21 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-22 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-23 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-27 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-02-28 00:00:00', 12.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-01 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-06 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-07 00:00:00', 13.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-08 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-10 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-14 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-16 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-17 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-18 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-19 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-23 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-24 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-25 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-26 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-29 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-30 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-03-31 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-05 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-06 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-07 00:00:00', 20.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-09 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-11 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-12 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-13 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-14 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-26 00:00:00', 7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-04-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-03 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-04 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-07 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-08 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-10 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-11 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-05-31 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-05 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-16 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-17 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-26 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-04 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-10 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-13 00:00:00', 15.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-15 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-16 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-17 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-28 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-29 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1983-12-31 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-03 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-04 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-11 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-12 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-18 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-20 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-21 00:00:00', 0.382999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-22 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-25 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-27 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-30 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-01-31 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-01 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-03 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-05 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-06 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-08 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-09 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-10 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-11 00:00:00', 5.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-12 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-14 00:00:00', 7.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-15 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-16 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-17 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-18 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-19 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-20 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-26 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-28 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-02-29 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-02 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-03 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-04 00:00:00', 7.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-05 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-06 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-07 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-08 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-09 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-10 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-11 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-12 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-13 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-14 00:00:00', 15.7650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-15 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-16 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-17 00:00:00', 6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-21 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-22 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-24 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-25 00:00:00', 9.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-26 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-27 00:00:00', 9.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-28 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-03-31 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-04 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-05 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-08 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-09 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-10 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-11 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-13 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-18 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-19 00:00:00', 13.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-26 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-27 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-03 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-07 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-08 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-15 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-08 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-21 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-22 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-11 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-12 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-13 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-14 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-16 00:00:00', 8.32400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-17 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-18 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-19 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-20 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-22 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-27 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-11-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-01 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-02 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-04 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-05 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-06 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-07 00:00:00', 6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-08 00:00:00', 8.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-12 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-13 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-14 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-15 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-16 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-19 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-29 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1984-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-03 00:00:00', 8.00300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-04 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-05 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-12 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-13 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-14 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-15 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-16 00:00:00', 7.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-17 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-18 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-19 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-20 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-23 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-24 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-25 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-26 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-02 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-03 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-04 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-07 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-18 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-19 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-23 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-24 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-27 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-02-28 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-03 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-04 00:00:00', 10.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-08 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-09 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-11 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-14 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-15 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-21 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-22 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-23 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-25 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-26 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-27 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-29 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-02 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-04 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-05 00:00:00', 9.39000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-06 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-07 00:00:00', 7.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-27 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-28 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-04-30 00:00:00', 10.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-01 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-02 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-03 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-06 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-07 00:00:00', 11.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-20 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-23 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-25 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-12 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-16 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-24 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-05 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-06 00:00:00', 7.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-07 00:00:00', 6.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-13 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-14 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-15 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-21 00:00:00', 11.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-22 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-24 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-25 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-26 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1985-12-31 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-05 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-06 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-16 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-17 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-20 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-22 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-24 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-28 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-02 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-03 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-08 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-09 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-12 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-13 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-14 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-17 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-03 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-10 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-11 00:00:00', 9.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-12 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-15 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-16 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-25 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-26 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-27 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-30 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-12 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-13 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-15 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-21 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-22 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-15 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-16 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-17 00:00:00', 5.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-30 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-03 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-12 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-15 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-11 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-13 00:00:00', 0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-14 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-20 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-21 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-25 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-11-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-03 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-04 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-05 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-06 00:00:00', 6.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-09 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-10 00:00:00', 4.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-11 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-21 00:00:00', 7.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-22 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-23 00:00:00', 4.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-08 00:00:00', 8.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-19 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-20 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-21 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-01-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-01 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-02 00:00:00', 1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-06 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-07 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-11 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-16 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-17 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-22 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-23 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-02 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-04 00:00:00', 0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-05 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-06 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-07 00:00:00', 4.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-12 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-13 00:00:00', 5.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-15 00:00:00', 11.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-18 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-19 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-20 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-21 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-22 00:00:00', 9.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-28 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-29 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-30 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-03-31 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-01 00:00:00', 9.68299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-02 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-05 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-07 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-08 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-14 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-16 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-20 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-21 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-28 00:00:00', 4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-04 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-27 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-28 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-30 00:00:00', 8.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-02 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-05 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-11 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-20 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-01 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-09 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-10 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-25 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-26 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-27 00:00:00', 8.75599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-28 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-04 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-28 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-29 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-11-30 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-01 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-14 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-15 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-29 00:00:00', 12.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-30 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1987-12-31 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-01 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-02 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-03 00:00:00', 0.409999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-08 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-14 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-15 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-17 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-18 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-20 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-21 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-26 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-30 00:00:00', 6.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-01 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-04 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-06 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-07 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-13 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-15 00:00:00', 0.214000001549720764, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-16 00:00:00', 0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-18 00:00:00', 18.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-19 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-26 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-27 00:00:00', 0.351999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-02 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-06 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-09 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-10 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-13 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-15 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-24 00:00:00', 10.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-25 00:00:00', 13.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-26 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-27 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-28 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-29 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-30 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-03-31 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-01 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-02 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-06 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-07 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-08 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-09 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-17 00:00:00', 16.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-29 00:00:00', 17.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-04-30 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-01 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-02 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-13 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-16 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-22 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-29 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-30 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-15 00:00:00', 0.0710000023245811462, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-21 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-22 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-23 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-16 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-18 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-20 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-21 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-23 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-27 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-28 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-29 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1988-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-03 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-04 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-05 00:00:00', 7.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-15 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-16 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-18 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-19 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-25 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-27 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-29 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-30 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-02 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-03 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-06 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-07 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-12 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-13 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-15 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-16 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-20 00:00:00', 6.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-21 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-23 00:00:00', 8.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-24 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-25 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-26 00:00:00', 9.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-27 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-08 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-13 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-17 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-20 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-22 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-29 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-30 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-03-31 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-02 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-05 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-15 00:00:00', 20.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-16 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-17 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-04-30 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-03 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-04 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-05 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-08 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-09 00:00:00', 8.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-10-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-01 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-07 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-08 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-17 00:00:00', 9.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-18 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-22 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-03 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-04 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-05 00:00:00', 0.319999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-06 00:00:00', 22.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-07 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-14 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-15 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-16 00:00:00', 8.49400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-17 00:00:00', 0.949000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-18 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1989-12-31 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-01 00:00:00', 11.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-02 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-03 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-05 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-06 00:00:00', 9.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-07 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-08 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-09 00:00:00', 9.85299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-10 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-11 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-12 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-16 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-17 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-20 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-25 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-26 00:00:00', 6.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-27 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-30 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-01-31 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-03 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-04 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-05 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-06 00:00:00', 9.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-07 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-08 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-11 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-12 00:00:00', 6.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-14 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-16 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-17 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-22 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-23 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-24 00:00:00', 0.0850000008940696716, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-25 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-26 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-09 00:00:00', 14.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-10 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-15 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-17 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-18 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-19 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-20 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-21 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-05 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-06 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-08 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-14 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-15 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-16 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-17 00:00:00', 19.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-27 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-06 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-15 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-30 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-02 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-14 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-08 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-09 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-10 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-11 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-12 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-13 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-20 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-22 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-23 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-24 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-25 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-26 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-27 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1990-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-04 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-05 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-06 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-08 00:00:00', 0.972999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-10 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-11 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-15 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-16 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-17 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-18 00:00:00', 6.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-19 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-20 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-24 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-25 00:00:00', 8.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-26 00:00:00', 7.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-27 00:00:00', 9.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-28 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-29 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-02 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-03 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-05 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-06 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-07 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-08 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-09 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-10 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-11 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-12 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-13 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-14 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-23 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-24 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-25 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-26 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-02 00:00:00', 5.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-04 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-07 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-08 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-09 00:00:00', 0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-10 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-11 00:00:00', 9.22500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-12 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-15 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-16 00:00:00', 10.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-17 00:00:00', 10.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-18 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-20 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-21 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-25 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-29 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-02 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-06 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-11 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-12 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-26 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-27 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-28 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-04-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-01 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-02 00:00:00', 12.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-12 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-13 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-14 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-15 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-16 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-17 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-20 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-21 00:00:00', 8.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-25 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-26 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-27 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-28 00:00:00', 5.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-29 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-13 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-19 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-20 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-21 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-23 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-27 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-28 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-03 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-04 00:00:00', 0.554000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-05 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-06 00:00:00', 9.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-09 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-10 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-11 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-12 00:00:00', 5.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-13 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-14 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-15 00:00:00', 7.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-16 00:00:00', 14.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-17 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-20 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-21 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-27 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-29 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-30 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1991-12-31 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-01 00:00:00', 0.870999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-02 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-03 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-04 00:00:00', 21.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-05 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-06 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-09 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-10 00:00:00', 0.202000007033348083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-14 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-18 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-22 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-23 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-24 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-25 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-26 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-27 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-28 00:00:00', 0.927999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-29 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-01-31 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-01 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-06 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-12 00:00:00', 7.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-16 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-22 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-25 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-27 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-28 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-03 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-04 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-07 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-08 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-09 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-10 00:00:00', 9.52700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-11 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-12 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-16 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-17 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-19 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-23 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-24 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-25 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-26 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-29 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-30 00:00:00', 0.767000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-01 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-02 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-03 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-04 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-06 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-12 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-16 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-20 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-23 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-28 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-04-30 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-02 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-05 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-06 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-07 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-10 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-11 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-12 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-13 00:00:00', 0.813000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-15 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-20 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-16 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-17 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-18 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-19 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-20 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-21 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-03 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-05 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-07 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-10 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-11 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-23 00:00:00', 10.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-24 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-29 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-30 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1992-12-31 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-03 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-05 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-06 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-09 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-10 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-15 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-16 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-18 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-19 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-04 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-05 00:00:00', 1.08700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-06 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-07 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-08 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-14 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-15 00:00:00', 7.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-16 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-17 00:00:00', 0.072999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-22 00:00:00', 11.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-23 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-24 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-25 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-27 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-01 00:00:00', 0.639999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-02 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-03 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-04 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-05 00:00:00', 0.395999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-06 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-09 00:00:00', 8.35000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-10 00:00:00', 22.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-11 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-12 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-13 00:00:00', 5.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-16 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-20 00:00:00', 14.9189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-22 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-23 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-24 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-06 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-07 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-14 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-15 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-16 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-24 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-27 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-28 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-01 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-05 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-07 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-08 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-15 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-16 00:00:00', 5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-22 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-24 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-25 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-18 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-08 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-02 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-03 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-04 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-08 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-17 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-21 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-22 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-26 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-27 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-29 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-11-30 00:00:00', 9.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-02 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-03 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-04 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-06 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-07 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-09 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-13 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-18 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-27 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1993-12-31 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-01 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-02 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-03 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-04 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-06 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-07 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-09 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-17 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-18 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-19 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-24 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-26 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-27 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-01-31 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-02 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-04 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-07 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-09 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-10 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-11 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-12 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-13 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-14 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-15 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-16 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-23 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-24 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-25 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-02 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-03 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-09 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-10 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-11 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-13 00:00:00', 9.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-25 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-30 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-03 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-05 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-13 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-28 00:00:00', 10.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-02 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-07 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-25 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-26 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-01 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-10 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-11 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-18 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-27 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-01 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-02 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-05 00:00:00', 20.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-07 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-08 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-21 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-22 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-27 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-28 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1994-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-02 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-07 00:00:00', 0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-08 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-11 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-12 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-15 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-17 00:00:00', 0.0540000014007091522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-18 00:00:00', 9.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-19 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-23 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-24 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-25 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-06 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-07 00:00:00', 16.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-08 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-09 00:00:00', 16.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-10 00:00:00', 12.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-11 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-17 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-25 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-26 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-27 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-03 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-05 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-06 00:00:00', 0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-07 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-19 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-20 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-21 00:00:00', 9.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-22 00:00:00', 4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-23 00:00:00', 6.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-27 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-28 00:00:00', 4.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-07 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-08 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-17 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-18 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-19 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-20 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-23 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-24 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-27 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-28 00:00:00', 5.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-23 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-13 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-14 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-20 00:00:00', 0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-24 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-27 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-05 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-06 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-07 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-08 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-10 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-13 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-14 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-15 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-18 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-20 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-24 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-27 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1995-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-03 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-07 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-08 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-09 00:00:00', 12.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-10 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-11 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-13 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-14 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-15 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-16 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-18 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-19 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-20 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-21 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-25 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-26 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-27 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-28 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-30 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-01-31 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-01 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-02 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-03 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-04 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-05 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-06 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-07 00:00:00', 0.312999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-12 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-13 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-15 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-17 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-20 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-21 00:00:00', 5.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-22 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-23 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-26 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-27 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-28 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-02-29 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-01 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-03 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-04 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-05 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-06 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-08 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-09 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-10 00:00:00', 0.469000011682510376, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-11 00:00:00', 0.987999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-12 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-15 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-17 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-18 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-19 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-20 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-22 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-24 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-27 00:00:00', 8.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-02 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-03 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-04 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-09 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-10 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-16 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-17 00:00:00', 9.31299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-18 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-19 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-20 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-24 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-25 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-26 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-29 00:00:00', 0.0850000008940696716, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-04-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-01 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-02 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-20 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-29 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-16 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-12 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-13 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-14 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-15 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-17 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-18 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-01 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-02 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-27 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1996-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-04 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-14 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-17 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-18 00:00:00', 8.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-19 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-24 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-26 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-27 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-29 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-01 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-07 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-21 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-22 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-23 00:00:00', 5.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-24 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-02-28 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-01 00:00:00', 11.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-07 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-09 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-10 00:00:00', 9.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-14 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-15 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-17 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-21 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-22 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-27 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-28 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-03-31 00:00:00', 0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-01 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-06 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-07 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-12 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-20 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-21 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-04-30 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-06 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-12 00:00:00', 5.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-16 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-14 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-26 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-01 00:00:00', 0.0280000008642673492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-02 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-06 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-07 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-15 00:00:00', 4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-02 00:00:00', 0.165999993681907654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-05 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-10 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-12 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-18 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-19 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-20 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-21 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-22 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-25 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-27 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1997-12-31 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-03 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-04 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-06 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-07 00:00:00', 18.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-11 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-12 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-14 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-15 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-17 00:00:00', 0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-20 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-22 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-25 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-27 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-28 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-29 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-30 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-01-31 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-01 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-05 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-08 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-09 00:00:00', 8.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-10 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-11 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-12 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-13 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-14 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-15 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-16 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-17 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-23 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-27 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-02-28 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-02 00:00:00', 6.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-03 00:00:00', 0.584999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-04 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-06 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-15 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-16 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-17 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-19 00:00:00', 6.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-20 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-21 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-22 00:00:00', 0.75700002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-26 00:00:00', 6.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-07 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-08 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-21 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-22 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-25 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-04-30 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-02 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-06 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-11 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-13 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-05 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-25 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-17 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-28 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-29 00:00:00', 9.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-11-30 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-02 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-03 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-29 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1998-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-10 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-12 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-14 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-18 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-22 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-24 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-11 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-13 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-27 00:00:00', 14.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-01 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-03 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-04 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-05 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-06 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-07 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-08 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-14 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-15 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-16 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-19 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-21 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-22 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-24 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-27 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-29 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-03-31 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-04 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-07 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-09 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-10 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-22 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-12 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-28 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-29 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-03 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-04 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-05 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-09 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-11 00:00:00', 0.893999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-12 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-13 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-20 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-21 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-24 00:00:00', 8.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-29 00:00:00', 0.860000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-11-30 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-18 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '1999-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-08 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-11 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-12 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-13 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-18 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-19 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-20 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-24 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-30 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-01-31 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-03 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-08 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-09 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-15 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-22 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-26 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-27 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-03 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-04 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-10 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-16 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-27 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-28 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-29 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-17 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-05 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-16 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-19 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-06 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-07 00:00:00', 7.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-08 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-11 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-17 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-29 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-02 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-03 00:00:00', 5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-10 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-16 00:00:00', 11.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-17 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-27 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-28 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2000-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-16 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-17 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-20 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-21 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-22 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-24 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-25 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-26 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-28 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-29 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-30 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-06 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-16 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-22 00:00:00', 8.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-23 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-11 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-12 00:00:00', 8.35299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-13 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-19 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-27 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-28 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-23 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-20 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-29 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-11-30 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-01 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-02 00:00:00', 6.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-03 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-06 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-16 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-17 00:00:00', 7.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-21 00:00:00', 0.679000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-22 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2001-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-09 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-10 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-11 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-12 00:00:00', 11.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-13 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-24 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-01-31 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-01 00:00:00', 12.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-02 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-04 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-05 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-06 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-15 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-16 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-17 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-22 00:00:00', 0.938000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-26 00:00:00', 0.324999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-02-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-07 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-20 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-23 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-24 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-30 00:00:00', 0.884000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-03-31 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-04 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-05 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-14 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-15 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-22 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-23 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-26 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-29 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-04-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-02 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-05 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-06 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-14 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-16 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-18 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-11-30 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-02 00:00:00', 0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-03 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-10 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-11 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-12 00:00:00', 8.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-13 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-14 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-15 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-18 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-19 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-20 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-23 00:00:00', 8.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-27 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-28 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-30 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2002-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-08 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-11 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-19 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-20 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-21 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-23 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-29 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-06 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-13 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-16 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-17 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-18 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-20 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-21 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-22 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-23 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-24 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-26 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-27 00:00:00', 15.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-02-28 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-01 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-08 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-09 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-14 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-15 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-16 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-22 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-24 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-27 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-28 00:00:00', 17.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-30 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-03-31 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-01 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-02 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-05 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-14 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-15 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-18 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-19 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-23 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-24 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-04 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-07 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-15 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-16 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-22 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-23 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-11-30 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-01 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-05 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-07 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-08 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-11 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-12 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-18 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-21 00:00:00', 0.133000001311302185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-22 00:00:00', 7.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-25 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-28 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-29 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-30 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2003-12-31 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-01 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-04 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-06 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-07 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-08 00:00:00', 11.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-09 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-11 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-12 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-15 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-16 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-21 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-28 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-29 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-07 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-08 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-09 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-21 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-25 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-13 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-14 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-15 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-17 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-20 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-21 00:00:00', 0.635999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-02 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-16 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-21 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-22 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-06 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-07 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-15 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-19 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-20 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-21 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-28 00:00:00', 0.612999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-29 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-03 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-14 00:00:00', 0.526000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-16 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-17 00:00:00', 0.86799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-18 00:00:00', 16.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-22 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-28 00:00:00', 9.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-29 00:00:00', 6.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-30 00:00:00', 0.537999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2004-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-05 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-07 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-08 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-12 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-13 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-20 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-23 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-24 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-26 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-01-31 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-01 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-02 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-03 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-04 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-06 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-10 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-11 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-12 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-13 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-22 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-23 00:00:00', 7.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-04 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-09 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-13 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-14 00:00:00', 13.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-15 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-16 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-17 00:00:00', 5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-18 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-19 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-25 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-26 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-27 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-07 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-08 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-10 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-07 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-09 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-10 00:00:00', 7.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-04 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-05 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-07 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-08 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-26 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-27 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-28 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2005-12-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-10 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-11 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-12 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-13 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-14 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-15 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-23 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-25 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-26 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-27 00:00:00', 15.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-28 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-29 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-30 00:00:00', 6.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-01-31 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-10 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-11 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-15 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-16 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-17 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-18 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-19 00:00:00', 0.349000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-23 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-24 00:00:00', 7.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-25 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-13 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-17 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-18 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-21 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-25 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-26 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-03-31 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-08 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-09 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-20 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-23 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-25 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-09 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-13 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-16 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-17 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-20 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-21 00:00:00', 13.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-11-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-01 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-02 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-03 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-04 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-19 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-24 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-25 00:00:00', 5.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-30 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2006-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-08 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-11 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-12 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-14 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-15 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-16 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-17 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-18 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-24 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-02 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-04 00:00:00', 0.584999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-05 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-06 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-09 00:00:00', 7.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-10 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-11 00:00:00', 6.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-12 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-18 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-19 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-20 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-21 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-25 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-26 00:00:00', 6.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-04 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-08 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-09 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-11 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-12 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-16 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-17 00:00:00', 12.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-18 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-19 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-26 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-28 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-29 00:00:00', 12.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-30 00:00:00', 27.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-03-31 00:00:00', 9.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-01 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-04 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-05 00:00:00', 0.0320000015199184418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-06 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-08 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-14 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-17 00:00:00', 0.23399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-18 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-29 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-04-30 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-01 00:00:00', 0.259999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-02 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-03 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-07 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-16 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-17 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-18 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-20 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-24 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-11-30 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-01 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-06 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-07 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-08 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-09 00:00:00', 13.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-10 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-11 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-12 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-17 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-18 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-19 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-20 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-21 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-22 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-23 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2007-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-02 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-03 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-04 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-05 00:00:00', 0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-06 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-07 00:00:00', 8.98499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-08 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-10 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-13 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-15 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-16 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-17 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-19 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-22 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-28 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-02 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-03 00:00:00', 0.779999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-05 00:00:00', 0.29800000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-13 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-14 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-15 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-16 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-20 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-21 00:00:00', 25.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-02-29 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-01 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-02 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-05 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-06 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-04 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-09 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-10 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-14 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-04 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-26 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-09-30 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-13 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-19 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-27 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-28 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-29 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-06 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-12 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-13 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-17 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-21 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-24 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-08 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-16 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-17 00:00:00', 13.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-18 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-19 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-20 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-22 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-23 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-27 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-28 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-29 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2008-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-02 00:00:00', 8.97299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-03 00:00:00', 10.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-11 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-12 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-13 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-16 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-17 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-26 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-29 00:00:00', 6.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-02 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-03 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-04 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-09 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-11 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-12 00:00:00', 10.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-13 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-14 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-17 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-18 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-19 00:00:00', 14.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-20 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-22 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-23 00:00:00', 9.99899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-24 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-02 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-03 00:00:00', 8.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-18 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-22 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-23 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-26 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-01 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-02 00:00:00', 7.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-05 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-10 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-11 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-15 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-19 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-20 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-21 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-25 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-26 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-27 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-28 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-01 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-03 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-04 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-08 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-09 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-14 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-18 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-19 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-07 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-19 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-30 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-01 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-22 00:00:00', 6.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-23 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-24 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-28 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-01 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-03 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-04 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-08 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-09 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-10 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-12 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-16 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-19 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-20 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-21 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-22 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-28 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2009-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-17 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-22 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-23 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-27 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-28 00:00:00', 8.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-01-31 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-02 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-03 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-04 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-05 00:00:00', 8.16899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-06 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-07 00:00:00', 7.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-08 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-11 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-12 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-13 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-17 00:00:00', 0.303000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-18 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-19 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-20 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-23 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-24 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-26 00:00:00', 5.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-27 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-02-28 00:00:00', 15.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-01 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-03 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-08 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-21 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-22 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-29 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-30 00:00:00', 7.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-02 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-03 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-07 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-10 00:00:00', 9.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-11 00:00:00', 42.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-14 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-15 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-17 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-20 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-21 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-29 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-02 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-03 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-04 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-05 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-10 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-11 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-12 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-16 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-21 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-22 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-02 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-14 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-24 00:00:00', 0.0590000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-25 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-03 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-05 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-05 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-06 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-15 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2010-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-04 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-06 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-07 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-10 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-11 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-13 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-14 00:00:00', 0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-16 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-17 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-18 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-20 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-21 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-30 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-01-31 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-02 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-03 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-04 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-06 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-08 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-09 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-11 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-12 00:00:00', 7.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-13 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-18 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-19 00:00:00', 8.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-21 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-22 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-23 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-25 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-27 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-02-28 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-02 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-03 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-04 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-06 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-07 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-11 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-14 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-16 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-17 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-24 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-25 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-26 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-27 00:00:00', 15.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-28 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-03-31 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-03 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-08 00:00:00', 0.671000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-09 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-10 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-14 00:00:00', 6.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-15 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-23 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-28 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-04 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-08 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-09 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-10 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-17 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-04 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-12 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-26 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-03 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-11 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-12 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-13 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-22 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-28 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-29 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-30 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-10-31 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-01 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-02 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-03 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-04 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-07 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-08 00:00:00', 14.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-09 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-10 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-14 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-17 00:00:00', 7.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-18 00:00:00', 8.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-19 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-22 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-23 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-24 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-25 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-26 00:00:00', 23.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-27 00:00:00', 7.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-28 00:00:00', 9.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-01 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-02 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-03 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-05 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-27 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-28 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2011-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-02 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-03 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-04 00:00:00', 13.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-05 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-06 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-13 00:00:00', 7.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-14 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-15 00:00:00', 0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-19 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-22 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-23 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-25 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-26 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-30 00:00:00', 5.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-02 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-03 00:00:00', 7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-04 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-09 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-11 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-12 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-13 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-17 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-19 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-20 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-26 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-27 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-02-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-01 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-02 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-03 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-04 00:00:00', 14.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-06 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-07 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-10 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-11 00:00:00', 8.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-12 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-13 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-15 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-16 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-17 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-18 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-19 00:00:00', 7.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-24 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-25 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-29 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-30 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-03-31 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-01 00:00:00', 7.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-09 00:00:00', 0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-10 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-21 00:00:00', 7.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-22 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-23 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-25 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-27 00:00:00', 6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-04-30 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-05 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-06 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-07 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-10 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-15 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-16 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-17 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-19 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-22 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-25 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-26 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-27 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-30 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-22 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-23 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-14 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-24 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-25 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-27 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-28 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-30 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-10-31 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-01 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-02 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-04 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-15 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-16 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-22 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-23 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-26 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-27 00:00:00', 0.801999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-28 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-29 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-07 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-10 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-12 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-13 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-16 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-17 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-18 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-23 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-24 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-26 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-27 00:00:00', 17.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-28 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2012-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-01 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-03 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-08 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-09 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-10 00:00:00', 0.156000003218650818, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-11 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-12 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-16 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-21 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-22 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-25 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-26 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-27 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-30 00:00:00', 19.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-01-31 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-01 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-02 00:00:00', 8.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-03 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-04 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-09 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-13 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-17 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-18 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-19 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-21 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-26 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-27 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-03 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-07 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-08 00:00:00', 14.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-09 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-12 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-13 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-15 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-16 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-18 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-19 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-20 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-21 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-22 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-23 00:00:00', 6.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-24 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-26 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-03-31 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-05 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-12 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-13 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-15 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-21 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-22 00:00:00', 10.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-23 00:00:00', 17.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-24 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-25 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-26 00:00:00', 18.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-28 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-29 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-04-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-19 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-24 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-02 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-03 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-24 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-27 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-09 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-23 00:00:00', 8.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-28 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-29 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-30 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-04 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-11 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-16 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-19 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-20 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-23 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-24 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-25 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-26 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-01 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-05 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-06 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-07 00:00:00', 6.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-10 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-11 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-15 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-16 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-18 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-21 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-27 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-28 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2013-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-03 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-04 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-08 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-13 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-20 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-21 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-22 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-23 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-24 00:00:00', 6.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-25 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-26 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-27 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-29 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-30 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-01-31 00:00:00', 9.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-01 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-02 00:00:00', 13.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-03 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-06 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-10 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-11 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-13 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-18 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-19 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-20 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-21 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-23 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-24 00:00:00', 0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-26 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-03 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-06 00:00:00', 12.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-07 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-08 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-13 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-14 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-15 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-16 00:00:00', 7.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-17 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-18 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-21 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-22 00:00:00', 0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-23 00:00:00', 15.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-24 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-26 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-01 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-03 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-04 00:00:00', 8.63599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-05 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-10 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-11 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-16 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-24 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-25 00:00:00', 13.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-28 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-29 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-04-30 00:00:00', 9.41399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-01 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-02 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-03 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-04 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-05 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-06 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-07 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-08 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-09 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-17 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-18 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-19 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-29 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-30 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-01 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-06 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (27, '2014-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-07 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-08 00:00:00', 26.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-09 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-10 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-11 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-12 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-13 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-14 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-15 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-16 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-17 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-18 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-19 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-22 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-23 00:00:00', 6.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-24 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-25 00:00:00', 26.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-26 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-27 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-28 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-29 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-03 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-04 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-05 00:00:00', 1.09099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-06 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-07 00:00:00', 1.2489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-08 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-09 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-10 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-11 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-12 00:00:00', 9.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-13 00:00:00', 8.73200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-14 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-18 00:00:00', 7.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-19 00:00:00', 12.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-20 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-21 00:00:00', 0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-22 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-23 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-24 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-25 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-26 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-27 00:00:00', 12.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-02-28 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-01 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-02 00:00:00', 7.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-03 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-04 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-05 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-06 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-07 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-08 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-10 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-11 00:00:00', 10.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-12 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-13 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-14 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-16 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-18 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-21 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-22 00:00:00', 10.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-23 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-24 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-25 00:00:00', 17.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-26 00:00:00', 5.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-28 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-29 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-30 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-03-31 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-01 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-02 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-03 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-04 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-05 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-06 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-07 00:00:00', 11.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-10 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-11 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-12 00:00:00', 9.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-13 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-14 00:00:00', 8.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-15 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-16 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-17 00:00:00', 9.53400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-18 00:00:00', 33.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-19 00:00:00', 6.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-20 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-21 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-22 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-23 00:00:00', 9.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-24 00:00:00', 12.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-25 00:00:00', 7.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-26 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-27 00:00:00', 11.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-28 00:00:00', 9.21800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-29 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-04-30 00:00:00', 11.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-01 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-03 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-04 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-05 00:00:00', 9.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-06 00:00:00', 6.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-07 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-08 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-09 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-10 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-11 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-12 00:00:00', 8.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-13 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-14 00:00:00', 11.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-15 00:00:00', 7.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-16 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-17 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-18 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-19 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-20 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-21 00:00:00', 13.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-22 00:00:00', 5.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-23 00:00:00', 27.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-24 00:00:00', 14.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-27 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-28 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-05-31 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-01 00:00:00', 9.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-02 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-04 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-05 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-06 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-07 00:00:00', 9.99199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-08 00:00:00', 0.382999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-11 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-12 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-16 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-17 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-18 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-24 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-04 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-05 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-06 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-07 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-16 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-17 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-29 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-13 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-15 00:00:00', 0.437999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-03 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-07 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-08 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-09 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-10 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-16 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-20 00:00:00', 9.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-21 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-26 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-27 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-28 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-29 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-30 00:00:00', 24.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-10-31 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-01 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-04 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-05 00:00:00', 9.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-06 00:00:00', 16.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-07 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-08 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-11 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-12 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-13 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-14 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-20 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-11-30 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-01 00:00:00', 7.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-02 00:00:00', 8.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-03 00:00:00', 8.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-04 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-05 00:00:00', 0.531000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-07 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-08 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-09 00:00:00', 6.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-10 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-13 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-14 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-17 00:00:00', 0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-18 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-19 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-20 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-21 00:00:00', 0.759999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-22 00:00:00', 14.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-23 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-27 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-28 00:00:00', 7.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-29 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-30 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1979-12-31 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-01 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-02 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-04 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-05 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-07 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-08 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-09 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-10 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-13 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-14 00:00:00', 6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-15 00:00:00', 13.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-16 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-18 00:00:00', 9.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-19 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-20 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-21 00:00:00', 11.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-22 00:00:00', 19.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-23 00:00:00', 14.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-24 00:00:00', 8.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-25 00:00:00', 13.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-26 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-27 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-28 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-01-31 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-01 00:00:00', 6.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-02 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-03 00:00:00', 0.611999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-04 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-05 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-06 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-08 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-11 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-12 00:00:00', 13.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-13 00:00:00', 18.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-14 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-16 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-17 00:00:00', 7.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-18 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-19 00:00:00', 8.04399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-20 00:00:00', 8.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-21 00:00:00', 11.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-22 00:00:00', 12.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-24 00:00:00', 16.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-25 00:00:00', 6.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-26 00:00:00', 27.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-27 00:00:00', 10.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-28 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-02-29 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-01 00:00:00', 0.74299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-02 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-03 00:00:00', 23.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-04 00:00:00', 8.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-05 00:00:00', 6.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-06 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-08 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-09 00:00:00', 1.17200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-10 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-11 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-12 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-13 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-14 00:00:00', 12.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-15 00:00:00', 17.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-16 00:00:00', 7.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-17 00:00:00', 18.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-19 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-20 00:00:00', 16.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-21 00:00:00', 3.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-22 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-23 00:00:00', 0.517000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-24 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-25 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-27 00:00:00', 9.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-28 00:00:00', 10.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-29 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-03-31 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-01 00:00:00', 21.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-02 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-04 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-05 00:00:00', 6.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-06 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-07 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-08 00:00:00', 0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-09 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-13 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-14 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-16 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-17 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-18 00:00:00', 10.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-20 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-21 00:00:00', 5.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-25 00:00:00', 10.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-26 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-27 00:00:00', 8.06499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-28 00:00:00', 7.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-29 00:00:00', 8.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-04-30 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-01 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-02 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-03 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-04 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-05 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-08 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-09 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-10 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-11 00:00:00', 22.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-12 00:00:00', 5.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-14 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-15 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-18 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-19 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-20 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-21 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-22 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-23 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-05-31 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-01 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-19 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-20 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-26 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-13 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-15 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-16 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-08 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-11 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-16 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-17 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-10 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-24 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-29 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-09-30 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-01 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-05 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-06 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-09 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-10 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-11 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-12 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-13 00:00:00', 6.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-14 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-15 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-16 00:00:00', 5.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-17 00:00:00', 5.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-18 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-19 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-20 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-21 00:00:00', 7.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-22 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-29 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-30 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-10-31 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-01 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-02 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-03 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-04 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-05 00:00:00', 0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-06 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-11 00:00:00', 0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-12 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-16 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-17 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-18 00:00:00', 8.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-19 00:00:00', 24.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-20 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-21 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-22 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-23 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-24 00:00:00', 9.57400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-25 00:00:00', 16.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-26 00:00:00', 8.51099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-11-30 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-01 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-02 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-03 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-09 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-11 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-12 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-13 00:00:00', 16.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-14 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-20 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-26 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-27 00:00:00', 8.14500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-28 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-29 00:00:00', 0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-30 00:00:00', 5.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1980-12-31 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-01 00:00:00', 9.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-02 00:00:00', 10.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-03 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-04 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-05 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-06 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-09 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-12 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-13 00:00:00', 8.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-14 00:00:00', 17.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-15 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-16 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-17 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-18 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-19 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-20 00:00:00', 17.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-21 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-22 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-23 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-24 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-26 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-27 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-28 00:00:00', 7.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-29 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-30 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-01-31 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-01 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-02 00:00:00', 17.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-03 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-04 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-08 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-10 00:00:00', 5.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-11 00:00:00', 12.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-12 00:00:00', 7.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-13 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-14 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-16 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-17 00:00:00', 9.97000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-18 00:00:00', 15.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-19 00:00:00', 4.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-20 00:00:00', 10.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-21 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-22 00:00:00', 16.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-23 00:00:00', 18.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-24 00:00:00', 12.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-25 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-26 00:00:00', 8.47299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-27 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-02-28 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-01 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-02 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-03 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-04 00:00:00', 18.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-05 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-06 00:00:00', 0.451000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-07 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-08 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-09 00:00:00', 5.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-10 00:00:00', 7.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-11 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-13 00:00:00', 0.529999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-14 00:00:00', 7.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-15 00:00:00', 18.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-16 00:00:00', 13.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-17 00:00:00', 15.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-18 00:00:00', 9.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-19 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-20 00:00:00', 15.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-21 00:00:00', 0.451000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-23 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-24 00:00:00', 6.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-25 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-26 00:00:00', 27.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-27 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-28 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-29 00:00:00', 10.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-30 00:00:00', 8.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-02 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-03 00:00:00', 15.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-06 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-07 00:00:00', 29.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-08 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-09 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-10 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-11 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-12 00:00:00', 7.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-13 00:00:00', 16.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-14 00:00:00', 5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-15 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-18 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-19 00:00:00', 11.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-20 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-21 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-22 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-24 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-25 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-26 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-27 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-28 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-29 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-04-30 00:00:00', 6.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-01 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-02 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-03 00:00:00', 0.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-04 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-05 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-08 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-09 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-10 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-11 00:00:00', 9.62199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-12 00:00:00', 7.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-13 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-14 00:00:00', 4.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-18 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-19 00:00:00', 9.57400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-20 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-22 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-24 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-25 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-29 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-30 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-05-31 00:00:00', 7.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-05 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-06 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-07 00:00:00', 6.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-09 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-10 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-14 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-17 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-18 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-21 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-23 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-24 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-25 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-26 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-27 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-28 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-29 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-05 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-07 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-08 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-09 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-10 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-11 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-23 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-24 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-26 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-27 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-01 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-15 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-19 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-22 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-23 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-24 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-10 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-11 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-18 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-23 00:00:00', 6.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-24 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-09 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-10 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-14 00:00:00', 9.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-15 00:00:00', 7.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-16 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-18 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-19 00:00:00', 19.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-20 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-24 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-25 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-26 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-28 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-06 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-07 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-08 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-14 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-15 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-20 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-21 00:00:00', 7.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-22 00:00:00', 12.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-23 00:00:00', 33.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-24 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-25 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-26 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-01 00:00:00', 5.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-02 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-04 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-05 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-06 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-07 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-08 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-09 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-10 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-12 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-13 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-15 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-16 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-17 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-19 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-20 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-21 00:00:00', 9.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-22 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-24 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-25 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-26 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-27 00:00:00', 13.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-28 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-29 00:00:00', 9.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-30 00:00:00', 17.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1981-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-01 00:00:00', 7.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-02 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-03 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-08 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-09 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-10 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-11 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-12 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-13 00:00:00', 13.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-14 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-15 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-16 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-17 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-18 00:00:00', 17.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-19 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-20 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-21 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-22 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-26 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-27 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-28 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-29 00:00:00', 6.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-30 00:00:00', 9.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-01-31 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-01 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-02 00:00:00', 12.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-03 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-06 00:00:00', 10.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-07 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-09 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-10 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-11 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-12 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-15 00:00:00', 11.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-16 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-19 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-20 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-22 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-23 00:00:00', 6.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-24 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-25 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-26 00:00:00', 7.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-27 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-02-28 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-01 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-03 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-04 00:00:00', 10.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-05 00:00:00', 1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-06 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-08 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-09 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-11 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-12 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-13 00:00:00', 14.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-14 00:00:00', 8.93299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-15 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-16 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-19 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-20 00:00:00', 17.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-21 00:00:00', 6.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-26 00:00:00', 11.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-27 00:00:00', 7.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-28 00:00:00', 8.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-29 00:00:00', 8.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-30 00:00:00', 9.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-03-31 00:00:00', 8.92599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-03 00:00:00', 11.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-04 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-10 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-11 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-14 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-16 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-17 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-21 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-22 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-23 00:00:00', 7.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-24 00:00:00', 5.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-25 00:00:00', 0.691999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-26 00:00:00', 8.02200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-27 00:00:00', 6.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-28 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-04-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-01 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-06 00:00:00', 7.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-07 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-08 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-09 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-10 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-11 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-12 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-14 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-17 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-18 00:00:00', 6.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-19 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-20 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-21 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-22 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-23 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-24 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-25 00:00:00', 5.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-27 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-28 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-29 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-04 00:00:00', 0.740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-13 00:00:00', 0.0710000023245811462, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-14 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-25 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-26 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-27 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-28 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-29 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-06-30 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-01 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-02 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-03 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-04 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-05 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-06 00:00:00', 5.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-14 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-15 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-12 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-25 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-13 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-14 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-16 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-17 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-19 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-29 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-09-30 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-02 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-03 00:00:00', 7.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-04 00:00:00', 26.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-05 00:00:00', 4.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-06 00:00:00', 18.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-07 00:00:00', 8.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-08 00:00:00', 23.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-09 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-10 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-11 00:00:00', 15.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-12 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-14 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-15 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-16 00:00:00', 4.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-17 00:00:00', 1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-19 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-21 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-22 00:00:00', 5.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-23 00:00:00', 6.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-24 00:00:00', 13.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-25 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-26 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-10-31 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-01 00:00:00', 7.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-02 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-03 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-04 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-05 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-08 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-09 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-10 00:00:00', 20.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-11 00:00:00', 9.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-13 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-14 00:00:00', 36.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-15 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-16 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-20 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-27 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-28 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-29 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-11-30 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-01 00:00:00', 6.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-02 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-06 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-07 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-08 00:00:00', 7.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-09 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-12 00:00:00', 0.257999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-13 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-16 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-17 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-18 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-27 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-28 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-29 00:00:00', 5.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-30 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1982-12-31 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-02 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-03 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-04 00:00:00', 11.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-05 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-06 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-07 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-08 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-11 00:00:00', 5.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-12 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-13 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-14 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-15 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-16 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-20 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-21 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-22 00:00:00', 11.1579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-23 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-24 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-25 00:00:00', 15.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-26 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-27 00:00:00', 10.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-28 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-07 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-09 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-10 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-16 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-17 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-18 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-19 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-20 00:00:00', 9.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-21 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-22 00:00:00', 13.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-23 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-26 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-27 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-02-28 00:00:00', 12.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-01 00:00:00', 6.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-02 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-03 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-05 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-06 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-07 00:00:00', 22.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-08 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-10 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-14 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-16 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-17 00:00:00', 16.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-18 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-19 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-20 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-23 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-24 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-25 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-26 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-27 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-28 00:00:00', 0.841000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-29 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-30 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-03-31 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-03 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-05 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-06 00:00:00', 0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-07 00:00:00', 8.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-08 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-11 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-12 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-13 00:00:00', 7.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-14 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-15 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-16 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-17 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-18 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-19 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-20 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-21 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-24 00:00:00', 5.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-25 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-26 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-27 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-28 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-29 00:00:00', 26.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-04-30 00:00:00', 14.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-03 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-04 00:00:00', 8.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-05 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-06 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-07 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-08 00:00:00', 10.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-09 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-10 00:00:00', 8.60700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-11 00:00:00', 11.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-12 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-13 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-14 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-15 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-16 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-17 00:00:00', 7.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-18 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-26 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-27 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-30 00:00:00', 7.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-05-31 00:00:00', 18.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-01 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-07 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-08 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-09 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-14 00:00:00', 6.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-15 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-19 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-21 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-22 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-25 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-26 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-01 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-03 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-04 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-05 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-07 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-09 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-10 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-18 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-07 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-15 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-17 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-03 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-09 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-11 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-23 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-29 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-02 00:00:00', 0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-03 00:00:00', 5.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-04 00:00:00', 0.537000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-05 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-09 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-12 00:00:00', 0.612999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-13 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-14 00:00:00', 5.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-15 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-16 00:00:00', 6.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-17 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-19 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-20 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-21 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-22 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-24 00:00:00', 0.939999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-25 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-26 00:00:00', 6.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-27 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-28 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-29 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-11-30 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-01 00:00:00', 6.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-02 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-03 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-04 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-05 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-06 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-10 00:00:00', 13.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-11 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-12 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-13 00:00:00', 10.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-14 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-15 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-16 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-17 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-28 00:00:00', 6.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-29 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-30 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1983-12-31 00:00:00', 12.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-03 00:00:00', 7.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-04 00:00:00', 11.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-09 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-10 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-11 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-12 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-15 00:00:00', 0.193000003695487976, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-16 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-18 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-21 00:00:00', 0.602999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-22 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-27 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-30 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-01-31 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-01 00:00:00', 7.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-03 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-04 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-05 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-06 00:00:00', 6.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-07 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-08 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-09 00:00:00', 7.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-10 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-11 00:00:00', 10.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-12 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-13 00:00:00', 10.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-14 00:00:00', 24.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-15 00:00:00', 11.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-16 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-17 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-18 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-19 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-20 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-21 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-22 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-23 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-25 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-26 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-28 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-02-29 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-01 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-02 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-03 00:00:00', 8.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-04 00:00:00', 12.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-05 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-07 00:00:00', 6.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-08 00:00:00', 28.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-09 00:00:00', 36.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-10 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-11 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-13 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-14 00:00:00', 6.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-15 00:00:00', 6.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-16 00:00:00', 12.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-17 00:00:00', 7.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-18 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-19 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-20 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-21 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-22 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-23 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-24 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-25 00:00:00', 8.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-26 00:00:00', 8.12600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-27 00:00:00', 49.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-28 00:00:00', 34.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-29 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-03-31 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-01 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-02 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-03 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-04 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-05 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-06 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-07 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-08 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-09 00:00:00', 6.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-10 00:00:00', 9.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-11 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-12 00:00:00', 6.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-13 00:00:00', 13.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-14 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-18 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-19 00:00:00', 8.31200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-20 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-21 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-23 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-24 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-26 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-27 00:00:00', 11.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-28 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-29 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-04-30 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-01 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-02 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-03 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-06 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-07 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-08 00:00:00', 6.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-09 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-11 00:00:00', 0.848999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-12 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-13 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-15 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-16 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-18 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-19 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-20 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-21 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-22 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-23 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-24 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-25 00:00:00', 0.884000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-27 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-28 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-29 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-05-31 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-01 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-03 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-04 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-08 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-09 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-01 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-02 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-20 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-09 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-10 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-12 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-06 00:00:00', 0.072999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-07 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-08 00:00:00', 10.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-09 00:00:00', 1.18299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-18 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-19 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-21 00:00:00', 5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-22 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-29 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-02 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-03 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-06 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-07 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-08 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-09 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-10 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-11 00:00:00', 7.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-12 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-13 00:00:00', 15.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-14 00:00:00', 10.7650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-15 00:00:00', 14.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-16 00:00:00', 20.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-17 00:00:00', 5.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-18 00:00:00', 8.27999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-19 00:00:00', 25.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-20 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-21 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-22 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-23 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-24 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-26 00:00:00', 0.811999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-27 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-11-30 00:00:00', 11.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-01 00:00:00', 9.13099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-02 00:00:00', 9.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-04 00:00:00', 0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-05 00:00:00', 10.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-06 00:00:00', 5.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-07 00:00:00', 9.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-08 00:00:00', 22.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-09 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-10 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-11 00:00:00', 0.860000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-12 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-13 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-15 00:00:00', 18.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-16 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-21 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-28 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-29 00:00:00', 6.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-30 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1984-12-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-01 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-02 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-03 00:00:00', 6.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-04 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-05 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-06 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-10 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-11 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-12 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-13 00:00:00', 9.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-14 00:00:00', 13.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-15 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-16 00:00:00', 18.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-17 00:00:00', 18.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-18 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-19 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-20 00:00:00', 10.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-22 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-23 00:00:00', 8.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-24 00:00:00', 6.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-25 00:00:00', 13.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-26 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-29 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-01 00:00:00', 8.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-02 00:00:00', 11.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-03 00:00:00', 7.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-04 00:00:00', 21.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-07 00:00:00', 9.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-08 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-10 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-11 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-17 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-18 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-19 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-20 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-23 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-24 00:00:00', 10.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-27 00:00:00', 0.811999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-02-28 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-02 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-03 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-04 00:00:00', 24.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-05 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-06 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-08 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-09 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-10 00:00:00', 6.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-11 00:00:00', 7.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-12 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-14 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-15 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-20 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-21 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-22 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-23 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-25 00:00:00', 17.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-26 00:00:00', 9.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-27 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-28 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-29 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-30 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-02 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-03 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-04 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-05 00:00:00', 7.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-06 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-07 00:00:00', 32.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-08 00:00:00', 5.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-09 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-11 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-12 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-14 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-16 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-17 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-18 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-21 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-23 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-24 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-27 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-28 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-29 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-04-30 00:00:00', 14.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-01 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-02 00:00:00', 11.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-03 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-04 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-05 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-06 00:00:00', 8.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-07 00:00:00', 13.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-09 00:00:00', 0.156000003218650818, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-10 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-11 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-12 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-19 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-20 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-21 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-22 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-23 00:00:00', 7.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-24 00:00:00', 6.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-25 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-26 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-27 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-28 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-29 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-30 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-05-31 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-01 00:00:00', 0.976999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-09 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-10 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-11 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-13 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-14 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-17 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-18 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-19 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-20 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-22 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-01 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-13 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-14 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-19 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-29 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-30 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-04 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-05 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-11 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-12 00:00:00', 17.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-13 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-14 00:00:00', 0.74299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-22 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-23 00:00:00', 13.508000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-24 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-25 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-26 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-27 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-28 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-29 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-30 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-10-31 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-04 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-09 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-11 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-12 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-15 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-16 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-17 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-18 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-19 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-20 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-23 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-24 00:00:00', 6.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-04 00:00:00', 8.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-05 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-06 00:00:00', 18.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-07 00:00:00', 10.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-08 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-13 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-14 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-15 00:00:00', 0.412000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-17 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-18 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-19 00:00:00', 5.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-20 00:00:00', 6.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-21 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-22 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-23 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-24 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-25 00:00:00', 8.53199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-26 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-28 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-29 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-30 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1985-12-31 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-01 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-05 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-06 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-11 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-13 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-14 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-15 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-16 00:00:00', 28.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-17 00:00:00', 8.66199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-18 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-20 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-21 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-22 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-24 00:00:00', 7.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-25 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-27 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-28 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-29 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-01 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-02 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-03 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-04 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-06 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-08 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-09 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-11 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-12 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-13 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-14 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-15 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-16 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-17 00:00:00', 6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-18 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-23 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-27 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-02-28 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-01 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-03 00:00:00', 16.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-05 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-10 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-11 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-12 00:00:00', 18.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-13 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-14 00:00:00', 0.671000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-15 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-16 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-17 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-20 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-21 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-22 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-23 00:00:00', 5.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-24 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-25 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-26 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-27 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-28 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-29 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-30 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-03-31 00:00:00', 0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-04 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-07 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-08 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-09 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-10 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-11 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-12 00:00:00', 25.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-13 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-14 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-15 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-16 00:00:00', 7.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-17 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-18 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-19 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-21 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-22 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-23 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-24 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-25 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-26 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-27 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-28 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-29 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-06 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-07 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-08 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-12 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-13 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-14 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-15 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-16 00:00:00', 8.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-17 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-22 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-24 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-25 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-26 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-27 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-28 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-29 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-30 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-01 00:00:00', 0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-02 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-03 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-04 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-05 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-06 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-09 00:00:00', 0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-10 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-11 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-20 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-21 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-22 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-24 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-08 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-20 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-09-30 00:00:00', 6.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-01 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-03 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-04 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-06 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-07 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-08 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-09 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-12 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-13 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-14 00:00:00', 15.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-15 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-06 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-08 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-09 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-10 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-11 00:00:00', 12.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-12 00:00:00', 7.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-13 00:00:00', 11.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-14 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-15 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-16 00:00:00', 0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-18 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-19 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-20 00:00:00', 6.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-21 00:00:00', 5.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-22 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-25 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-26 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-27 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-28 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-11-30 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-01 00:00:00', 8.09599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-02 00:00:00', 10.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-03 00:00:00', 11.1549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-04 00:00:00', 17.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-05 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-06 00:00:00', 6.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-07 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-09 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-10 00:00:00', 19.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-11 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-12 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-20 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-21 00:00:00', 7.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-22 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-23 00:00:00', 7.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-24 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-01 00:00:00', 6.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-04 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-08 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-12 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-13 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-15 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-16 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-18 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-19 00:00:00', 16.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-20 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-21 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-26 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-27 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-28 00:00:00', 6.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-29 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-30 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-01-31 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-01 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-02 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-03 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-06 00:00:00', 13.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-07 00:00:00', 10.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-08 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-10 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-11 00:00:00', 13.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-12 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-14 00:00:00', 0.0970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-15 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-16 00:00:00', 6.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-17 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-19 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-20 00:00:00', 0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-21 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-22 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-23 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-24 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-02-28 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-01 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-02 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-03 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-04 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-05 00:00:00', 26.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-06 00:00:00', 13.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-07 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-08 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-09 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-10 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-11 00:00:00', 12.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-12 00:00:00', 5.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-13 00:00:00', 18.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-14 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-15 00:00:00', 36.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-16 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-17 00:00:00', 19.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-18 00:00:00', 13.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-19 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-20 00:00:00', 10.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-21 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-22 00:00:00', 16.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-23 00:00:00', 5.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-24 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-25 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-27 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-28 00:00:00', 16.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-29 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-30 00:00:00', 0.769999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-03-31 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-01 00:00:00', 16.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-02 00:00:00', 5.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-03 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-05 00:00:00', 7.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-06 00:00:00', 23.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-07 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-08 00:00:00', 18.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-09 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-11 00:00:00', 0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-12 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-13 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-14 00:00:00', 6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-15 00:00:00', 5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-16 00:00:00', 14.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-17 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-18 00:00:00', 0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-19 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-20 00:00:00', 11.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-21 00:00:00', 14.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-22 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-27 00:00:00', 0.368999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-28 00:00:00', 14.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-29 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-04-30 00:00:00', 0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-03 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-04 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-19 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-20 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-21 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-22 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-26 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-27 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-28 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-30 00:00:00', 17.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-05-31 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-01 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-02 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-06 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-15 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-16 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-01 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-02 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-04 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-05 00:00:00', 4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-11 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-12 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-13 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-14 00:00:00', 8.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-15 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-16 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-17 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-18 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-19 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-20 00:00:00', 0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-24 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-26 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-29 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-30 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-07-31 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-03 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-17 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-20 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-24 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-09-30 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-01 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-02 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-07 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-08 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-09 00:00:00', 7.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-10 00:00:00', 16.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-11 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-12 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-13 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-18 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-20 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-21 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-22 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-23 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-24 00:00:00', 6.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-25 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-26 00:00:00', 28.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-27 00:00:00', 14.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-28 00:00:00', 10.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-29 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-04 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-05 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-08 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-09 00:00:00', 0.647000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-15 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-16 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-22 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-23 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-24 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-25 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-26 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-27 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-28 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-29 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-11-30 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-01 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-07 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-08 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-09 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-10 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-11 00:00:00', 6.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-14 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-15 00:00:00', 10.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-16 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-24 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-25 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-27 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-28 00:00:00', 6.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-29 00:00:00', 28.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-30 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1987-12-31 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-01 00:00:00', 12.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-02 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-03 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-07 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-08 00:00:00', 12.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-12 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-14 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-15 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-16 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-17 00:00:00', 7.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-18 00:00:00', 0.638000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-19 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-20 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-21 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-23 00:00:00', 0.0970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-24 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-25 00:00:00', 0.337000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-26 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-27 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-28 00:00:00', 1.01800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-29 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-30 00:00:00', 12.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-01-31 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-01 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-02 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-03 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-04 00:00:00', 10.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-05 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-06 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-07 00:00:00', 6.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-08 00:00:00', 0.469000011682510376, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-14 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-15 00:00:00', 0.728999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-16 00:00:00', 6.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-18 00:00:00', 6.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-19 00:00:00', 10.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-20 00:00:00', 0.519999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-21 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-25 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-26 00:00:00', 6.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-27 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-28 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-02-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-01 00:00:00', 0.554000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-02 00:00:00', 15.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-03 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-06 00:00:00', 21.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-07 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-09 00:00:00', 9.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-10 00:00:00', 14.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-11 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-12 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-13 00:00:00', 17.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-14 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-15 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-16 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-17 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-18 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-19 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-20 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-21 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-22 00:00:00', 10.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-23 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-24 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-25 00:00:00', 18.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-26 00:00:00', 0.846000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-28 00:00:00', 17.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-29 00:00:00', 10.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-30 00:00:00', 14.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-03-31 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-01 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-02 00:00:00', 15.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-03 00:00:00', 15.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-04 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-05 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-06 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-07 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-08 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-09 00:00:00', 10.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-10 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-12 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-16 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-17 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-18 00:00:00', 6.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-19 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-22 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-23 00:00:00', 5.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-24 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-25 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-28 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-29 00:00:00', 17.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-04-30 00:00:00', 12.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-01 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-02 00:00:00', 6.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-03 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-04 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-05 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-07 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-08 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-10 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-11 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-12 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-13 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-14 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-15 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-16 00:00:00', 8.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-17 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-22 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-23 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-24 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-30 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-05-31 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-06 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-08 00:00:00', 0.435000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-09 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-10 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-14 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-15 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-20 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-21 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-28 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-29 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-07 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-09 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-10 00:00:00', 0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-13 00:00:00', 0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-15 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-18 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-20 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-26 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-30 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-08-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-01 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-02 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-05 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-09 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-21 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-03 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-04 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-06 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-07 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-08 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-11 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-12 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-15 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-16 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-21 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-22 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-23 00:00:00', 18.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-29 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-01 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-06 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-15 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-16 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-21 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-22 00:00:00', 5.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-23 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-24 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-29 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-11-30 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-01 00:00:00', 0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-02 00:00:00', 8.27900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-03 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-05 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-06 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-07 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-13 00:00:00', 0.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-14 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-15 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-16 00:00:00', 15.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-17 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-18 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-19 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-20 00:00:00', 17.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-21 00:00:00', 20.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-22 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-23 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-24 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-26 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-27 00:00:00', 9.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-28 00:00:00', 47.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-29 00:00:00', 19.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-30 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1988-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-03 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-04 00:00:00', 14.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-05 00:00:00', 12.4110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-06 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-07 00:00:00', 4.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-08 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-13 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-14 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-15 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-16 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-18 00:00:00', 6.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-19 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-22 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-25 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-26 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-27 00:00:00', 12.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-28 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-29 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-30 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-01-31 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-02 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-03 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-05 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-06 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-07 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-12 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-13 00:00:00', 7.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-14 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-15 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-16 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-17 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-18 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-19 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-20 00:00:00', 6.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-21 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-22 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-23 00:00:00', 8.46300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-24 00:00:00', 11.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-25 00:00:00', 8.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-26 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-27 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-02 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-05 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-07 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-08 00:00:00', 6.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-09 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-11 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-12 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-13 00:00:00', 4.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-14 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-15 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-16 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-17 00:00:00', 7.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-18 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-19 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-20 00:00:00', 8.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-21 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-22 00:00:00', 12.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-23 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-24 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-28 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-29 00:00:00', 18.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-30 00:00:00', 6.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-03-31 00:00:00', 16.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-01 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-02 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-03 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-04 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-05 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-07 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-08 00:00:00', 4.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-09 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-11 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-15 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-16 00:00:00', 12.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-17 00:00:00', 7.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-22 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-04-30 00:00:00', 11.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-01 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-03 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-04 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-05 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-06 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-08 00:00:00', 8.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-09 00:00:00', 8.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-11 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-12 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-14 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-15 00:00:00', 15.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-16 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-17 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-18 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-20 00:00:00', 0.78200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-21 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-22 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-23 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-30 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-02 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-07 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-08 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-09 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-12 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-15 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-16 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-16 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-17 00:00:00', 1.14600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-18 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-19 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-20 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-22 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-23 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-24 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-07-31 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-27 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-28 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-08-31 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-21 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-22 00:00:00', 8.95600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-23 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-29 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-09-30 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-10 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-12 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-13 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-18 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-23 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-24 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-29 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-10-31 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-01 00:00:00', 17.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-02 00:00:00', 0.893999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-07 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-08 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-16 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-17 00:00:00', 8.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-18 00:00:00', 8.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-21 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-22 00:00:00', 9.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-25 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-26 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-03 00:00:00', 6.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-04 00:00:00', 16.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-05 00:00:00', 19.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-06 00:00:00', 48.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-07 00:00:00', 6.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-08 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-09 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-10 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-14 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-15 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-16 00:00:00', 14.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-17 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-18 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-23 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-24 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-25 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-27 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-28 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-29 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-30 00:00:00', 0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1989-12-31 00:00:00', 12.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-01 00:00:00', 12.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-02 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-03 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-04 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-05 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-06 00:00:00', 8.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-07 00:00:00', 22.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-08 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-09 00:00:00', 6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-10 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-11 00:00:00', 11.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-12 00:00:00', 10.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-13 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-16 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-17 00:00:00', 9.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-18 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-22 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-23 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-25 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-26 00:00:00', 8.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-27 00:00:00', 5.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-28 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-30 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-01-31 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-01 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-03 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-04 00:00:00', 6.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-05 00:00:00', 0.760999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-06 00:00:00', 7.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-07 00:00:00', 11.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-08 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-11 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-12 00:00:00', 20.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-13 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-14 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-15 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-16 00:00:00', 5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-17 00:00:00', 10.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-21 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-22 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-23 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-24 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-25 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-26 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-06 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-07 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-08 00:00:00', 11.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-09 00:00:00', 5.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-10 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-12 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-13 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-14 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-15 00:00:00', 21.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-16 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-17 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-18 00:00:00', 13.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-19 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-20 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-21 00:00:00', 8.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-22 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-27 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-28 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-29 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-30 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-03-31 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-01 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-03 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-04 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-05 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-06 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-07 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-08 00:00:00', 21.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-09 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-10 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-11 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-12 00:00:00', 0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-13 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-14 00:00:00', 6.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-15 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-16 00:00:00', 9.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-17 00:00:00', 10.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-18 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-19 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-20 00:00:00', 12.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-21 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-23 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-24 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-25 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-26 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-27 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-04-30 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-01 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-02 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-05 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-06 00:00:00', 8.32900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-07 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-08 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-09 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-10 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-13 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-14 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-15 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-23 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-24 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-25 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-27 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-28 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-30 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-05-31 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-01 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-04 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-05 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-06 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-08 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-09 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-11 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-12 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-05 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-08 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-09 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-02 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-03 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-21 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-22 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-03 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-06 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-12 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-15 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-16 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-18 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-19 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-23 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-27 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-28 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-29 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-30 00:00:00', 17.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-10-31 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-01 00:00:00', 13.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-02 00:00:00', 16.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-03 00:00:00', 0.676999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-09 00:00:00', 0.0869999974966049194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-10 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-14 00:00:00', 13.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-15 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-16 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-22 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-27 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-28 00:00:00', 0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-11-30 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-06 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-07 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-08 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-09 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-10 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-11 00:00:00', 5.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-12 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-13 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-14 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-18 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-19 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-20 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-21 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-22 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-23 00:00:00', 7.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-24 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-25 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-26 00:00:00', 31.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-27 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-28 00:00:00', 0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-29 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1990-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-04 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-05 00:00:00', 13.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-06 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-07 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-08 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-10 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-11 00:00:00', 0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-12 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-16 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-17 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-18 00:00:00', 10.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-19 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-20 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-21 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-23 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-24 00:00:00', 9.99199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-25 00:00:00', 4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-26 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-27 00:00:00', 19.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-28 00:00:00', 15.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-29 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-01-31 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-01 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-02 00:00:00', 8.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-03 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-04 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-05 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-06 00:00:00', 5.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-07 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-08 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-09 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-10 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-11 00:00:00', 7.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-12 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-13 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-14 00:00:00', 6.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-15 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-24 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-25 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-26 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-01 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-02 00:00:00', 7.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-03 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-04 00:00:00', 1.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-05 00:00:00', 8.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-06 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-07 00:00:00', 17.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-08 00:00:00', 14.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-09 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-10 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-11 00:00:00', 10.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-12 00:00:00', 13.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-15 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-16 00:00:00', 10.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-17 00:00:00', 24.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-18 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-20 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-21 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-22 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-23 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-27 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-28 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-29 00:00:00', 9.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-02 00:00:00', 6.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-05 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-06 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-07 00:00:00', 10.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-08 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-09 00:00:00', 10.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-11 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-12 00:00:00', 5.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-13 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-14 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-15 00:00:00', 6.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-16 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-20 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-21 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-23 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-24 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-25 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-26 00:00:00', 7.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-27 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-28 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-29 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-04-30 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-01 00:00:00', 7.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-02 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-04 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-05 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-08 00:00:00', 5.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-09 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-10 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-12 00:00:00', 7.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-13 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-14 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-15 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-16 00:00:00', 25.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-17 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-18 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-19 00:00:00', 15.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-20 00:00:00', 9.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-21 00:00:00', 9.50300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-22 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-23 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-24 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-25 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-26 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-27 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-28 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-29 00:00:00', 0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-30 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-05 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-06 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-09 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-10 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-15 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-17 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-18 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-19 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-21 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-24 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-25 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-03 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-04 00:00:00', 0.509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-05 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-13 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-15 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-07 00:00:00', 0.712999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-13 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-14 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-25 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-26 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-27 00:00:00', 5.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-28 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-29 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-09-30 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-01 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-02 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-03 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-05 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-06 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-07 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-11 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-18 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-21 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-25 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-26 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-27 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-03 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-07 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-08 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-09 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-10 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-11 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-13 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-14 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-15 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-16 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-17 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-18 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-19 00:00:00', 11.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-20 00:00:00', 12.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-21 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-23 00:00:00', 9.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-24 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-27 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-28 00:00:00', 6.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-29 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-02 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-03 00:00:00', 17.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-04 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-05 00:00:00', 16.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-06 00:00:00', 10.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-07 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-08 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-09 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-10 00:00:00', 6.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-11 00:00:00', 5.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-12 00:00:00', 9.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-13 00:00:00', 30.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-14 00:00:00', 32.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-15 00:00:00', 27.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-16 00:00:00', 29.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-17 00:00:00', 12.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-18 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-21 00:00:00', 1.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-22 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-26 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-27 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-29 00:00:00', 0.150000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-30 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1991-12-31 00:00:00', 6.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-01 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-02 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-03 00:00:00', 7.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-04 00:00:00', 30.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-05 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-06 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-07 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-08 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-09 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-10 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-11 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-12 00:00:00', 0.0179999992251396179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-13 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-14 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-15 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-16 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-17 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-18 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-19 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-21 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-22 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-23 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-24 00:00:00', 8.79399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-25 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-26 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-27 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-28 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-29 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-01-31 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-01 00:00:00', 11.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-02 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-03 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-04 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-05 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-06 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-07 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-09 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-10 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-11 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-12 00:00:00', 14.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-13 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-15 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-16 00:00:00', 5.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-17 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-22 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-23 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-24 00:00:00', 0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-25 00:00:00', 12.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-26 00:00:00', 11.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-27 00:00:00', 10.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-28 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-02-29 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-01 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-02 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-03 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-04 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-05 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-07 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-08 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-09 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-10 00:00:00', 6.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-11 00:00:00', 10.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-12 00:00:00', 6.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-13 00:00:00', 0.907999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-16 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-17 00:00:00', 8.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-18 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-19 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-20 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-22 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-23 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-24 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-25 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-26 00:00:00', 6.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-27 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-29 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-30 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-03-31 00:00:00', 14.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-01 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-02 00:00:00', 7.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-03 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-04 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-06 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-07 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-09 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-10 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-11 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-12 00:00:00', 5.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-15 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-16 00:00:00', 6.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-17 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-19 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-20 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-21 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-22 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-23 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-24 00:00:00', 13.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-25 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-26 00:00:00', 4.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-27 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-28 00:00:00', 16.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-29 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-04-30 00:00:00', 6.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-01 00:00:00', 17.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-02 00:00:00', 7.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-03 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-05 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-06 00:00:00', 7.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-07 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-08 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-09 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-10 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-11 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-12 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-13 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-14 00:00:00', 0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-15 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-16 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-17 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-18 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-19 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-20 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-21 00:00:00', 0.602999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-22 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-23 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-24 00:00:00', 9.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-25 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-26 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-27 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-28 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-29 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-01 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-05 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-06 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-10 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-12 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-13 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-14 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-15 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-20 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-21 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-08 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-30 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-08-31 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-05 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-06 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-07 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-19 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-07 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-08 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-09 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-16 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-17 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-24 00:00:00', 0.0869999974966049194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-03 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-11 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-15 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-16 00:00:00', 12.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-17 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-18 00:00:00', 1.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-19 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-20 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-27 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-29 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-01 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-02 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-03 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-05 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-06 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-07 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-08 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-09 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-10 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-11 00:00:00', 9.71599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-12 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-13 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-14 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-16 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-18 00:00:00', 12.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-19 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-20 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-21 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-22 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-23 00:00:00', 23.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-24 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-27 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-28 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-29 00:00:00', 7.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-30 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1992-12-31 00:00:00', 10.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-01 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-02 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-03 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-05 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-06 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-07 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-09 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-10 00:00:00', 17.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-11 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-12 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-13 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-14 00:00:00', 0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-15 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-16 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-18 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-19 00:00:00', 8.12600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-20 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-23 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-24 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-26 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-29 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-30 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-01-31 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-01 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-02 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-03 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-04 00:00:00', 19.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-05 00:00:00', 18.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-06 00:00:00', 15.9189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-07 00:00:00', 29.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-08 00:00:00', 6.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-11 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-12 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-13 00:00:00', 14.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-14 00:00:00', 10.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-15 00:00:00', 9.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-16 00:00:00', 9.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-17 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-18 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-19 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-22 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-24 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-25 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-26 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-27 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-02-28 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-01 00:00:00', 5.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-02 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-03 00:00:00', 8.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-04 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-05 00:00:00', 17.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-06 00:00:00', 11.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-07 00:00:00', 26.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-08 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-09 00:00:00', 14.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-10 00:00:00', 24.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-11 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-12 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-13 00:00:00', 12.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-14 00:00:00', 0.903999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-15 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-16 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-17 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-18 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-20 00:00:00', 11.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-21 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-22 00:00:00', 11.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-23 00:00:00', 11.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-24 00:00:00', 7.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-25 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-03-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-04 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-05 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-06 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-07 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-09 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-10 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-13 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-14 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-15 00:00:00', 17.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-16 00:00:00', 29.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-17 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-18 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-19 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-22 00:00:00', 0.529999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-23 00:00:00', 7.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-24 00:00:00', 32.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-25 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-26 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-27 00:00:00', 8.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-28 00:00:00', 8.65900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-29 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-04-30 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-01 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-02 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-04 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-05 00:00:00', 11.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-07 00:00:00', 20.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-08 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-09 00:00:00', 8.08899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-10 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-11 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-14 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-15 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-16 00:00:00', 21.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-17 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-18 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-20 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-21 00:00:00', 9.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-22 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-23 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-24 00:00:00', 48.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-25 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-26 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-30 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-05-31 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-02 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-06 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-14 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-20 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-22 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-23 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-26 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-27 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-28 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-22 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-23 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-24 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-26 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-10 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-18 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-27 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-09-30 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-01 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-05 00:00:00', 10.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-06 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-07 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-08 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-09 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-16 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-17 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-28 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-29 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-30 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-10-31 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-01 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-02 00:00:00', 14.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-03 00:00:00', 12.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-04 00:00:00', 12.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-05 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-06 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-07 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-08 00:00:00', 6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-09 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-10 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-11 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-12 00:00:00', 5.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-13 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-14 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-15 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-17 00:00:00', 6.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-18 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-21 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-22 00:00:00', 7.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-23 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-24 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-25 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-26 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-27 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-28 00:00:00', 13.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-29 00:00:00', 29.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-11-30 00:00:00', 12.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-01 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-02 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-03 00:00:00', 5.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-04 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-05 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-06 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-07 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-09 00:00:00', 0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-11 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-12 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-13 00:00:00', 7.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-16 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-18 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-20 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-21 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-25 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-26 00:00:00', 6.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-27 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-29 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-30 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1993-12-31 00:00:00', 20.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-01 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-02 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-03 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-04 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-06 00:00:00', 17.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-07 00:00:00', 10.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-09 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-10 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-17 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-18 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-19 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-20 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-21 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-22 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-24 00:00:00', 6.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-25 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-26 00:00:00', 8.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-27 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-28 00:00:00', 7.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-01-31 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-02 00:00:00', 12.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-03 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-04 00:00:00', 11.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-05 00:00:00', 0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-07 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-08 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-09 00:00:00', 9.50300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-10 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-11 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-12 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-13 00:00:00', 9.89500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-14 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-15 00:00:00', 10.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-16 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-17 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-18 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-20 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-21 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-23 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-24 00:00:00', 8.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-25 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-26 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-27 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-02-28 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-01 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-02 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-03 00:00:00', 8.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-04 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-05 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-06 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-07 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-08 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-09 00:00:00', 19.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-10 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-11 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-12 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-13 00:00:00', 20.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-14 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-16 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-17 00:00:00', 11.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-18 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-24 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-25 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-26 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-28 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-29 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-30 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-01 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-02 00:00:00', 9.23499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-03 00:00:00', 7.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-04 00:00:00', 8.48200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-05 00:00:00', 5.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-06 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-09 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-13 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-14 00:00:00', 0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-15 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-16 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-22 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-27 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-28 00:00:00', 32.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-04-30 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-02 00:00:00', 6.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-04 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-05 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-06 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-07 00:00:00', 5.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-08 00:00:00', 6.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-09 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-17 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-18 00:00:00', 7.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-19 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-21 00:00:00', 0.398999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-22 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-23 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-24 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-26 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-07 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-08 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-10 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-11 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-12 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-13 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-25 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-03 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-18 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-19 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-20 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-21 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-29 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-01 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-04 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-05 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-06 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-10 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-11 00:00:00', 0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-12 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-16 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-17 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-20 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-21 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-23 00:00:00', 0.705999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-24 00:00:00', 8.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-25 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-26 00:00:00', 6.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-01 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-02 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-05 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-06 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-07 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-08 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-09 00:00:00', 9.43500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-10 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-11 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-16 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-17 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-18 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-19 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-21 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-22 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-23 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-24 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-25 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-26 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-27 00:00:00', 6.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-11-30 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-01 00:00:00', 7.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-02 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-04 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-05 00:00:00', 38.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-06 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-07 00:00:00', 5.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-08 00:00:00', 4.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-14 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-15 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-17 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-18 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-19 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-20 00:00:00', 6.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-21 00:00:00', 19.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-22 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-23 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-24 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-26 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-28 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-29 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1994-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-06 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-07 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-08 00:00:00', 0.0489999987185001373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-11 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-12 00:00:00', 9.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-13 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-14 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-15 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-16 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-17 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-18 00:00:00', 13.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-19 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-23 00:00:00', 0.878000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-24 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-25 00:00:00', 9.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-26 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-27 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-28 00:00:00', 4.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-01 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-05 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-06 00:00:00', 10.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-07 00:00:00', 22.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-08 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-09 00:00:00', 9.74699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-10 00:00:00', 19.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-11 00:00:00', 5.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-12 00:00:00', 0.421000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-14 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-16 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-17 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-18 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-19 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-25 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-26 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-27 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-02-28 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-03 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-04 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-05 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-06 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-07 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-08 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-09 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-11 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-12 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-16 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-17 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-18 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-19 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-20 00:00:00', 7.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-21 00:00:00', 12.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-22 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-23 00:00:00', 7.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-24 00:00:00', 0.846000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-26 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-27 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-28 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-29 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-30 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-03-31 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-07 00:00:00', 6.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-08 00:00:00', 5.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-09 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-17 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-18 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-19 00:00:00', 7.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-20 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-21 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-22 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-25 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-26 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-27 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-28 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-04-30 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-04 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-09 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-10 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-11 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-12 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-14 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-16 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-17 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-19 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-22 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-23 00:00:00', 7.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-25 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-26 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-28 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-02 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-03 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-09 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-13 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-17 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-20 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-21 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-22 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-24 00:00:00', 1.03199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-25 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-26 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-29 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-02 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-07 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-08 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-24 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-29 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-30 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-08-31 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-22 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-23 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-28 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-01 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-03 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-04 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-08 00:00:00', 0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-12 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-13 00:00:00', 4.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-14 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-16 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-17 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-18 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-24 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-27 00:00:00', 8.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-03 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-04 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-05 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-06 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-07 00:00:00', 9.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-08 00:00:00', 5.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-09 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-10 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-11 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-13 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-14 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-15 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-17 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-18 00:00:00', 5.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-19 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-20 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-23 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-24 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-27 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-28 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-29 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1995-12-31 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-03 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-06 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-07 00:00:00', 5.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-08 00:00:00', 9.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-09 00:00:00', 9.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-10 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-11 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-13 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-14 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-15 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-16 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-18 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-19 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-20 00:00:00', 7.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-21 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-25 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-26 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-27 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-28 00:00:00', 7.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-29 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-30 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-01-31 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-01 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-02 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-03 00:00:00', 20.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-04 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-05 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-06 00:00:00', 12.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-07 00:00:00', 7.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-08 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-09 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-10 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-11 00:00:00', 7.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-12 00:00:00', 10.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-13 00:00:00', 8.32199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-14 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-15 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-17 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-18 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-19 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-20 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-21 00:00:00', 12.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-22 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-23 00:00:00', 1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-24 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-26 00:00:00', 8.02000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-27 00:00:00', 8.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-28 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-02-29 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-01 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-02 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-03 00:00:00', 23.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-04 00:00:00', 17.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-05 00:00:00', 13.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-06 00:00:00', 12.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-07 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-09 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-10 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-11 00:00:00', 5.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-12 00:00:00', 19.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-13 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-14 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-15 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-16 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-17 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-18 00:00:00', 7.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-19 00:00:00', 8.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-20 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-21 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-22 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-24 00:00:00', 8.48200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-25 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-26 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-27 00:00:00', 10.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-28 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-29 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-30 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-03-31 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-01 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-02 00:00:00', 7.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-03 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-04 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-05 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-06 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-07 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-09 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-10 00:00:00', 1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-11 00:00:00', 31.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-12 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-14 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-15 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-16 00:00:00', 9.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-17 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-18 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-19 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-20 00:00:00', 7.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-21 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-22 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-23 00:00:00', 10.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-24 00:00:00', 9.49199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-25 00:00:00', 0.456000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-26 00:00:00', 7.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-28 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-29 00:00:00', 8.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-04-30 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-01 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-06 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-07 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-08 00:00:00', 7.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-09 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-10 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-11 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-12 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-15 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-16 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-20 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-21 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-22 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-23 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-24 00:00:00', 0.647000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-26 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-27 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-08 00:00:00', 0.236000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-09 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-12 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-13 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-17 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-28 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-29 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-06-30 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-13 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-23 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-07-31 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-02 00:00:00', 5.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-21 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-22 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-23 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-24 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-25 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-02 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-07 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-08 00:00:00', 0.170000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-13 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-14 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-15 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-16 00:00:00', 6.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-17 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-18 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-10-31 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-01 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-04 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-08 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-11 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-12 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-13 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-14 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-18 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-19 00:00:00', 0.767000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-11-30 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-01 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-02 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-03 00:00:00', 0.430999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-05 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-06 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-12 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-13 00:00:00', 0.0419999994337558746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-15 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-16 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-17 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-18 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-23 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-24 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-25 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-26 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-27 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-28 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1996-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-03 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-04 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-05 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-06 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-08 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-09 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-11 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-12 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-13 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-14 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-15 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-16 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-17 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-18 00:00:00', 18.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-19 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-23 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-24 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-26 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-27 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-28 00:00:00', 0.904999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-29 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-30 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-01-31 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-01 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-02 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-06 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-07 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-08 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-09 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-11 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-13 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-14 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-20 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-21 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-22 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-23 00:00:00', 18.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-24 00:00:00', 14.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-25 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-02-28 00:00:00', 6.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-01 00:00:00', 20.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-02 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-03 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-05 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-06 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-07 00:00:00', 13.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-08 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-09 00:00:00', 8.60499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-10 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-14 00:00:00', 7.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-15 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-16 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-17 00:00:00', 0.663999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-18 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-19 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-21 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-22 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-23 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-25 00:00:00', 0.0970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-26 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-27 00:00:00', 13.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-28 00:00:00', 21.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-30 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-03-31 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-01 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-02 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-03 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-05 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-06 00:00:00', 8.27200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-07 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-08 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-09 00:00:00', 5.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-10 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-11 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-12 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-13 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-14 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-15 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-18 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-19 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-20 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-21 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-24 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-25 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-26 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-29 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-04-30 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-01 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-02 00:00:00', 0.324000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-03 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-04 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-06 00:00:00', 7.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-07 00:00:00', 5.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-08 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-10 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-11 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-12 00:00:00', 8.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-13 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-15 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-16 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-17 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-25 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-26 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-27 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-28 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-02 00:00:00', 0.114000000059604645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-03 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-04 00:00:00', 6.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-08 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-09 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-12 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-17 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-19 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-20 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-25 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-08 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-14 00:00:00', 0.767000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-15 00:00:00', 12.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-22 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-25 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-26 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-10-31 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-01 00:00:00', 0.218999996781349182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-02 00:00:00', 10.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-04 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-05 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-06 00:00:00', 27.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-07 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-14 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-15 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-16 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-17 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-18 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-20 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-22 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-23 00:00:00', 0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-24 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-25 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-26 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-28 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-29 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-11-30 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-02 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-03 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-04 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-05 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-06 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-08 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-10 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-11 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-12 00:00:00', 1.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-13 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-14 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-17 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-18 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-19 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-20 00:00:00', 5.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-21 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-22 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-23 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-25 00:00:00', 7.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-26 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-27 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-28 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1997-12-31 00:00:00', 1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-01 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-02 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-03 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-04 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-06 00:00:00', 10.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-07 00:00:00', 26.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-08 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-09 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-10 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-11 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-12 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-14 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-15 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-16 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-17 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-18 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-19 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-20 00:00:00', 5.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-21 00:00:00', 0.0610000006854534149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-22 00:00:00', 7.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-23 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-24 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-25 00:00:00', 7.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-26 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-27 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-28 00:00:00', 5.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-29 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-30 00:00:00', 7.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-01-31 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-01 00:00:00', 6.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-02 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-03 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-05 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-07 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-08 00:00:00', 12.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-09 00:00:00', 27.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-10 00:00:00', 24.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-11 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-12 00:00:00', 7.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-13 00:00:00', 8.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-14 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-15 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-16 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-17 00:00:00', 8.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-18 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-21 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-22 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-23 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-24 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-27 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-02-28 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-01 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-02 00:00:00', 11.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-03 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-04 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-06 00:00:00', 8.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-07 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-12 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-13 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-14 00:00:00', 12.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-15 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-16 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-17 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-18 00:00:00', 10.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-19 00:00:00', 18.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-20 00:00:00', 11.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-21 00:00:00', 5.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-22 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-26 00:00:00', 8.65699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-30 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-03-31 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-01 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-02 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-03 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-05 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-06 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-07 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-08 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-09 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-20 00:00:00', 6.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-21 00:00:00', 32.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-22 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-23 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-24 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-25 00:00:00', 15.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-26 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-04-30 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-01 00:00:00', 14.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-02 00:00:00', 5.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-03 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-05 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-06 00:00:00', 5.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-07 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-10 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-11 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-13 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-15 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-16 00:00:00', 10.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-17 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-18 00:00:00', 10.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-21 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-23 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-25 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-26 00:00:00', 7.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-27 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-28 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-29 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-05-31 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-03 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-05 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-06 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-07 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-10 00:00:00', 0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-11 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-12 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-13 00:00:00', 5.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-14 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-22 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-24 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-25 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-28 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-25 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-26 00:00:00', 9.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-29 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-04 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-05 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-06 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-07 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-08 00:00:00', 0.781000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-30 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-12 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-13 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-03 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-09 00:00:00', 7.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-10 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-25 00:00:00', 6.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-26 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-12 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-17 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-18 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-24 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-28 00:00:00', 12.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-29 00:00:00', 8.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-11-30 00:00:00', 8.30799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-01 00:00:00', 0.841000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-02 00:00:00', 21.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-03 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-05 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-06 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-22 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-25 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-29 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-30 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1998-12-31 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-08 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-10 00:00:00', 16.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-12 00:00:00', 12.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-14 00:00:00', 11.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-18 00:00:00', 13.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-20 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-22 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-24 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-26 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-28 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-07 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-09 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-11 00:00:00', 20.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-13 00:00:00', 30.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-15 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-17 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-19 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-25 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-27 00:00:00', 16.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-01 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-03 00:00:00', 26.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-04 00:00:00', 7.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-05 00:00:00', 7.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-06 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-07 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-08 00:00:00', 0.351999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-09 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-13 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-14 00:00:00', 6.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-15 00:00:00', 8.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-16 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-17 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-18 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-19 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-20 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-21 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-22 00:00:00', 15.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-23 00:00:00', 7.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-24 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-25 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-27 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-28 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-29 00:00:00', 17.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-30 00:00:00', 8.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-03-31 00:00:00', 8.94699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-03 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-04 00:00:00', 8.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-05 00:00:00', 8.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-06 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-07 00:00:00', 15.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-08 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-09 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-10 00:00:00', 11.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-11 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-16 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-17 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-19 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-22 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-06 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-11 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-12 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-23 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-24 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-06 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-11 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-12 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-13 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-30 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-17 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-18 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-28 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-29 00:00:00', 7.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-14 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-16 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-17 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-24 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-26 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-27 00:00:00', 0.231999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-28 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-30 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-02 00:00:00', 9.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-03 00:00:00', 7.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-05 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-06 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-08 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-09 00:00:00', 13.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-11 00:00:00', 8.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-12 00:00:00', 6.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-13 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-14 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-17 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-18 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-19 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-20 00:00:00', 10.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-21 00:00:00', 6.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-23 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-24 00:00:00', 6.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-25 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-26 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-27 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-28 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-29 00:00:00', 17.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-11-30 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-01 00:00:00', 0.301999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-04 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-05 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-06 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-09 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-10 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-11 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-18 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-19 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-25 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-26 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '1999-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-06 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-07 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-08 00:00:00', 12.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-09 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-11 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-12 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-13 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-14 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-17 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-18 00:00:00', 7.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-19 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-20 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-22 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-23 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-24 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-25 00:00:00', 0.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-28 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-29 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-30 00:00:00', 9.09099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-01-31 00:00:00', 7.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-03 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-04 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-08 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-09 00:00:00', 9.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-10 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-14 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-15 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-16 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-22 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-26 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-27 00:00:00', 8.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-28 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-02-29 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-02 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-03 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-04 00:00:00', 5.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-09 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-10 00:00:00', 7.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-11 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-15 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-16 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-24 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-26 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-27 00:00:00', 21.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-28 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-29 00:00:00', 10.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-30 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-02 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-03 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-08 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-13 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-16 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-17 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-18 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-24 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-26 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-28 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-29 00:00:00', 0.787000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-03 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-10 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-28 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-02 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-09 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-22 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-23 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-20 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-25 00:00:00', 0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-02 00:00:00', 0.740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-03 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-04 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-05 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-06 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-07 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-13 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-14 00:00:00', 0.293000012636184692, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-15 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-16 00:00:00', 10.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-18 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-19 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-23 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-24 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-04 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-05 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-06 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-07 00:00:00', 18.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-08 00:00:00', 7.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-09 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-10 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-11 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-12 00:00:00', 7.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-14 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-16 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-17 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-22 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-23 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-24 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-25 00:00:00', 0.388999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-29 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-02 00:00:00', 7.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-03 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-04 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-09 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-10 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-12 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-13 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-14 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-15 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-16 00:00:00', 15.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-17 00:00:00', 6.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-25 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-26 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-27 00:00:00', 6.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-28 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2000-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-03 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-16 00:00:00', 5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-19 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-20 00:00:00', 1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-21 00:00:00', 8.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-22 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-23 00:00:00', 0.155000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-24 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-25 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-26 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-27 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-28 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-29 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-30 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-01-31 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-04 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-05 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-06 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-07 00:00:00', 0.0750000029802322388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-09 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-10 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-15 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-16 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-17 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-19 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-20 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-21 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-22 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-23 00:00:00', 0.703000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-27 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-05 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-10 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-11 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-12 00:00:00', 12.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-13 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-14 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-17 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-18 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-19 00:00:00', 6.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-25 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-27 00:00:00', 5.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-28 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-29 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-01 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-02 00:00:00', 4.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-05 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-15 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-17 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-19 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-23 00:00:00', 1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-26 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-01 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-07 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-19 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-28 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-14 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-16 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-22 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-19 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-14 00:00:00', 0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-26 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-28 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-09 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-17 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-18 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-19 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-20 00:00:00', 0.0489999987185001373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-21 00:00:00', 0.287000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-22 00:00:00', 0.252000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-23 00:00:00', 5.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-28 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-30 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-10-31 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-01 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-02 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-05 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-08 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-09 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-10 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-15 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-20 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-28 00:00:00', 0.990000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-29 00:00:00', 7.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-11-30 00:00:00', 5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-01 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-02 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-03 00:00:00', 6.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-04 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-05 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-06 00:00:00', 7.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-09 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-10 00:00:00', 0.787999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-11 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-12 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-13 00:00:00', 6.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-16 00:00:00', 5.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-17 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-18 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-20 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-21 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-22 00:00:00', 13.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-23 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-24 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-28 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2001-12-31 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-02 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-05 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-06 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-09 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-10 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-11 00:00:00', 12.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-12 00:00:00', 14.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-13 00:00:00', 10.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-14 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-15 00:00:00', 0.460999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-23 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-24 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-25 00:00:00', 0.515999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-30 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-01-31 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-01 00:00:00', 8.75300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-02 00:00:00', 10.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-03 00:00:00', 6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-04 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-05 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-06 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-11 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-12 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-13 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-14 00:00:00', 13.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-15 00:00:00', 11.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-16 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-17 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-18 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-19 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-21 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-22 00:00:00', 0.86799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-23 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-25 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-26 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-27 00:00:00', 9.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-02-28 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-01 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-02 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-07 00:00:00', 12.8970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-08 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-10 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-11 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-13 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-14 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-17 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-18 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-19 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-20 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-21 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-22 00:00:00', 18.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-23 00:00:00', 7.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-24 00:00:00', 21.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-25 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-26 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-29 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-30 00:00:00', 5.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-03-31 00:00:00', 1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-03 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-04 00:00:00', 5.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-05 00:00:00', 9.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-06 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-12 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-13 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-14 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-15 00:00:00', 7.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-16 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-17 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-19 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-22 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-23 00:00:00', 12.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-24 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-25 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-26 00:00:00', 13.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-27 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-29 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-04-30 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-01 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-02 00:00:00', 0.833999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-03 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-04 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-05 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-06 00:00:00', 8.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-08 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-12 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-13 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-14 00:00:00', 11.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-15 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-17 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-22 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-26 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-27 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-01 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-05 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-22 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-01 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-09 00:00:00', 0.0540000014007091522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-10 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-30 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-14 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-27 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-12 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-18 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-24 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-04 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-05 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-10 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-12 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-13 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-14 00:00:00', 9.91899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-15 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-16 00:00:00', 9.88099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-17 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-18 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-22 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-27 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-28 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-29 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-11-30 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-02 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-03 00:00:00', 12.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-04 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-08 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-09 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-10 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-11 00:00:00', 9.54399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-12 00:00:00', 13.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-13 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-14 00:00:00', 22.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-15 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-16 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-17 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-18 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-19 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-20 00:00:00', 11.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-21 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-22 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-23 00:00:00', 15.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-24 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-26 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-27 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-28 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-30 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2002-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-05 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-06 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-07 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-08 00:00:00', 12.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-09 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-11 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-15 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-16 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-17 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-18 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-19 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-20 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-21 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-22 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-23 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-26 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-27 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-29 00:00:00', 7.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-30 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-01-31 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-01 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-05 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-06 00:00:00', 7.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-07 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-11 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-12 00:00:00', 6.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-13 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-14 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-15 00:00:00', 9.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-16 00:00:00', 6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-17 00:00:00', 5.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-18 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-19 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-20 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-21 00:00:00', 10.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-22 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-23 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-24 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-26 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-27 00:00:00', 12.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-02-28 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-01 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-02 00:00:00', 7.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-03 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-08 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-09 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-10 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-12 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-13 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-14 00:00:00', 29.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-15 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-16 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-18 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-19 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-20 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-21 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-22 00:00:00', 27.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-23 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-24 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-27 00:00:00', 15.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-28 00:00:00', 7.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-29 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-30 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-03-31 00:00:00', 9.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-01 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-02 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-03 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-05 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-06 00:00:00', 7.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-07 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-09 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-14 00:00:00', 5.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-15 00:00:00', 13.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-16 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-17 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-18 00:00:00', 9.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-19 00:00:00', 5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-21 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-22 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-23 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-24 00:00:00', 8.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-25 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-01 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-02 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-05 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-09 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-10 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-12 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-14 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-15 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-16 00:00:00', 0.257999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-22 00:00:00', 0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-25 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-26 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-27 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-05-31 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-02 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-03 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-07 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-21 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-01 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-05 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-06 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-03 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-04 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-05 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-06 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-07 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-08 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-20 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-21 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-29 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-01 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-02 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-03 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-04 00:00:00', 13.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-05 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-06 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-07 00:00:00', 0.953000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-08 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-12 00:00:00', 7.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-13 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-14 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-15 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-16 00:00:00', 16.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-17 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-22 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-23 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-29 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-11-30 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-01 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-02 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-04 00:00:00', 0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-05 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-06 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-07 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-08 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-11 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-12 00:00:00', 16.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-13 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-18 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-20 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-21 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-22 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-23 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-25 00:00:00', 0.101999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-26 00:00:00', 0.45199999213218689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-28 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-29 00:00:00', 7.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-30 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2003-12-31 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-01 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-02 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-04 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-05 00:00:00', 7.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-06 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-07 00:00:00', 17.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-08 00:00:00', 9.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-09 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-10 00:00:00', 13.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-11 00:00:00', 7.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-12 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-13 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-14 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-15 00:00:00', 5.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-16 00:00:00', 11.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-20 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-21 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-22 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-24 00:00:00', 0.202000007033348083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-25 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-26 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-27 00:00:00', 6.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-28 00:00:00', 4.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-29 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-30 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-01-31 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-01 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-03 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-04 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-07 00:00:00', 6.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-08 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-09 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-12 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-15 00:00:00', 0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-16 00:00:00', 5.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-17 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-18 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-20 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-21 00:00:00', 9.45199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-24 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-25 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-02-29 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-01 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-03 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-04 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-11 00:00:00', 0.505999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-12 00:00:00', 0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-13 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-14 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-15 00:00:00', 9.00599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-16 00:00:00', 10.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-17 00:00:00', 16.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-19 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-20 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-21 00:00:00', 13.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-22 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-01 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-02 00:00:00', 9.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-03 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-05 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-06 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-07 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-08 00:00:00', 0.442000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-16 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-18 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-21 00:00:00', 0.750999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-22 00:00:00', 7.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-25 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-26 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-27 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-28 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-29 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-06 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-07 00:00:00', 20.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-16 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-19 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-22 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-27 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-05-31 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-14 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-21 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-12 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-13 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-15 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-17 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-18 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-19 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-21 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-22 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-22 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-30 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-12 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-13 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-14 00:00:00', 0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-15 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-18 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-19 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-23 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-24 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-27 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-05 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-08 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-09 00:00:00', 0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-15 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-16 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-17 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-18 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-19 00:00:00', 16.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-20 00:00:00', 17.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-21 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-22 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-24 00:00:00', 0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-25 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-28 00:00:00', 16.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-29 00:00:00', 16.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-11-30 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-02 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-03 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-04 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-08 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-09 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-10 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-12 00:00:00', 5.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-13 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-14 00:00:00', 15.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-15 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-16 00:00:00', 7.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-17 00:00:00', 13.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-18 00:00:00', 18.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-19 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-21 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-22 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-23 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-27 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-28 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-29 00:00:00', 5.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-30 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2004-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-01 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-02 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-03 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-04 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-05 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-07 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-08 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-09 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-11 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-12 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-13 00:00:00', 5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-14 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-15 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-20 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-21 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-22 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-24 00:00:00', 7.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-25 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-26 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-27 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-28 00:00:00', 0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-30 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-01-31 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-01 00:00:00', 10.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-02 00:00:00', 9.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-03 00:00:00', 15.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-04 00:00:00', 6.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-06 00:00:00', 0.759999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-07 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-09 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-10 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-11 00:00:00', 13.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-12 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-13 00:00:00', 7.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-15 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-16 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-17 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-18 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-19 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-22 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-23 00:00:00', 8.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-24 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-26 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-27 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-02-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-03 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-04 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-05 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-07 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-08 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-09 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-10 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-11 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-12 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-13 00:00:00', 8.48700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-14 00:00:00', 15.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-15 00:00:00', 7.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-16 00:00:00', 8.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-17 00:00:00', 13.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-18 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-19 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-20 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-21 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-25 00:00:00', 9.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-26 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-27 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-03-31 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-01 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-04 00:00:00', 8.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-05 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-06 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-08 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-09 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-11 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-12 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-13 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-19 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-23 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-25 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-27 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-29 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-01 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-02 00:00:00', 0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-04 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-05 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-07 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-08 00:00:00', 13.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-12 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-13 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-18 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-19 00:00:00', 0.395999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-20 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-23 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-24 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-25 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-26 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-27 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-28 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-02 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-10 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-11 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-13 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-12 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-23 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-24 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-02 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-14 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-23 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-24 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-06 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-07 00:00:00', 14.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-08 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-09 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-10 00:00:00', 19.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-11 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-12 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-13 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-14 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-16 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-19 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-20 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-21 00:00:00', 0.187999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-22 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-23 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-24 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-03 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-04 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-05 00:00:00', 7.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-06 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-07 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-08 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-14 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-18 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-24 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-25 00:00:00', 10.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-26 00:00:00', 15.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-27 00:00:00', 10.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-28 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-29 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2005-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-01 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-02 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-03 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-10 00:00:00', 7.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-11 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-12 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-13 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-14 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-15 00:00:00', 13.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-16 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-17 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-18 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-19 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-20 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-22 00:00:00', 0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-23 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-24 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-25 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-26 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-27 00:00:00', 24.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-28 00:00:00', 12.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-29 00:00:00', 4.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-30 00:00:00', 9.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-01-31 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-01 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-02 00:00:00', 1.17200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-05 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-06 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-09 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-10 00:00:00', 15.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-11 00:00:00', 10.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-12 00:00:00', 0.351999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-13 00:00:00', 8.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-14 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-15 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-16 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-17 00:00:00', 11.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-18 00:00:00', 6.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-19 00:00:00', 11.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-20 00:00:00', 0.619000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-21 00:00:00', 0.839999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-22 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-23 00:00:00', 10.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-24 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-25 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-27 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-02-28 00:00:00', 0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-01 00:00:00', 7.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-02 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-03 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-04 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-05 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-06 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-07 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-13 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-14 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-15 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-16 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-17 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-18 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-19 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-20 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-21 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-22 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-25 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-26 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-27 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-29 00:00:00', 0.425999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-30 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-03-31 00:00:00', 8.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-01 00:00:00', 0.474000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-05 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-08 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-09 00:00:00', 11.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-10 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-13 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-15 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-19 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-20 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-28 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-29 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-04-30 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-01 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-04 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-06 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-16 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-26 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-03 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-06-30 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-01 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-18 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-19 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-28 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-29 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-05 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-13 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-14 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-15 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-16 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-17 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-18 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-20 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-22 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-23 00:00:00', 8.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-24 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-25 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-28 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-29 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-01 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-02 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-03 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-05 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-09 00:00:00', 8.86200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-10 00:00:00', 0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-12 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-13 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-14 00:00:00', 0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-15 00:00:00', 12.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-16 00:00:00', 14.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-17 00:00:00', 11.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-18 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-19 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-20 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-21 00:00:00', 11.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-22 00:00:00', 0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-29 00:00:00', 1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-11-30 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-01 00:00:00', 6.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-02 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-03 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-04 00:00:00', 6.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-05 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-10 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-14 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-15 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-16 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-19 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-20 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-23 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-24 00:00:00', 14.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-25 00:00:00', 7.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-26 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-28 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-29 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-30 00:00:00', 10.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2006-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-01 00:00:00', 0.904999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-02 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-08 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-09 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-10 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-11 00:00:00', 7.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-12 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-13 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-14 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-15 00:00:00', 10.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-16 00:00:00', 5.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-17 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-18 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-23 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-24 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-01 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-02 00:00:00', 12.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-03 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-04 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-05 00:00:00', 8.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-06 00:00:00', 6.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-07 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-08 00:00:00', 0.592000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-09 00:00:00', 11.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-10 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-11 00:00:00', 7.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-12 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-13 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-16 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-17 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-18 00:00:00', 5.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-19 00:00:00', 8.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-20 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-21 00:00:00', 7.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-22 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-23 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-24 00:00:00', 6.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-25 00:00:00', 16.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-26 00:00:00', 14.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-27 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-02-28 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-01 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-03 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-04 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-05 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-06 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-08 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-09 00:00:00', 9.26500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-10 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-11 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-12 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-13 00:00:00', 1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-15 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-16 00:00:00', 9.72099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-17 00:00:00', 27.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-18 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-19 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-22 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-23 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-24 00:00:00', 11.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-25 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-26 00:00:00', 8.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-27 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-28 00:00:00', 13.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-29 00:00:00', 13.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-30 00:00:00', 22.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-03-31 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-01 00:00:00', 9.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-02 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-03 00:00:00', 0.128000006079673767, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-04 00:00:00', 16.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-05 00:00:00', 0.783999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-06 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-08 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-09 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-10 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-12 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-13 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-14 00:00:00', 0.610000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-16 00:00:00', 0.916000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-17 00:00:00', 10.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-19 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-22 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-29 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-04-30 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-01 00:00:00', 1.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-02 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-03 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-06 00:00:00', 0.0689999982714653015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-07 00:00:00', 7.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-16 00:00:00', 7.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-17 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-18 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-24 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-26 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-29 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-02 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-03 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-04 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-05 00:00:00', 11.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-28 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-06 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-07 00:00:00', 0.307000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-21 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-23 00:00:00', 0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-01 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-19 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-23 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-13 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-19 00:00:00', 0.898000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-20 00:00:00', 7.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-22 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-23 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-24 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-25 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-26 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-27 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-28 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-11-30 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-01 00:00:00', 5.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-03 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-04 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-05 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-06 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-07 00:00:00', 10.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-08 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-09 00:00:00', 9.58600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-10 00:00:00', 14.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-11 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-12 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-13 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-15 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-16 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-17 00:00:00', 0.773999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-18 00:00:00', 18.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-19 00:00:00', 10.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-20 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-21 00:00:00', 14.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-22 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-23 00:00:00', 6.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2007-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-01 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-02 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-03 00:00:00', 10.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-04 00:00:00', 5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-05 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-06 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-07 00:00:00', 10.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-08 00:00:00', 7.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-10 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-11 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-12 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-13 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-14 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-15 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-16 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-17 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-18 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-19 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-20 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-21 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-28 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-29 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-01-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-01 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-02 00:00:00', 0.654999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-03 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-04 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-05 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-06 00:00:00', 0.345999985933303833, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-07 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-08 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-09 00:00:00', 0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-10 00:00:00', 0.640999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-13 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-14 00:00:00', 7.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-15 00:00:00', 5.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-16 00:00:00', 18.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-17 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-20 00:00:00', 7.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-21 00:00:00', 7.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-26 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-27 00:00:00', 0.052000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-28 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-02-29 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-01 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-02 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-03 00:00:00', 13.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-04 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-05 00:00:00', 7.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-06 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-07 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-12 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-13 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-14 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-15 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-24 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-25 00:00:00', 0.532999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-26 00:00:00', 0.859000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-27 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-29 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-30 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-03-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-03 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-04 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-05 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-06 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-07 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-09 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-10 00:00:00', 4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-12 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-13 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-14 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-15 00:00:00', 13.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-17 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-18 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-19 00:00:00', 23.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-20 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-21 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-22 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-23 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-24 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-04-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-03 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-04 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-05 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-09 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-12 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-13 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-15 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-16 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-21 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-22 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-23 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-24 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-25 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-26 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-27 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-25 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-26 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-02 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-18 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-21 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-26 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-27 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-17 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-05 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-26 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-27 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-28 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-29 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-09-30 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-10 00:00:00', 0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-11 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-13 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-18 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-19 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-23 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-24 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-27 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-28 00:00:00', 23.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-29 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-01 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-02 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-05 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-06 00:00:00', 6.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-07 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-08 00:00:00', 14.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-09 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-10 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-12 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-13 00:00:00', 0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-15 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-17 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-19 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-21 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-22 00:00:00', 7.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-23 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-24 00:00:00', 8.99699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-25 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-29 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-11-30 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-05 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-06 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-08 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-09 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-10 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-11 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-13 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-14 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-15 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-16 00:00:00', 10.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-17 00:00:00', 21.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-18 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-19 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-20 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-22 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-23 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-24 00:00:00', 0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-25 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-27 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-28 00:00:00', 7.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-29 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2008-12-31 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-01 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-02 00:00:00', 16.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-03 00:00:00', 16.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-04 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-09 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-10 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-11 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-13 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-14 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-15 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-16 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-17 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-21 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-25 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-26 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-27 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-28 00:00:00', 6.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-29 00:00:00', 8.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-30 00:00:00', 6.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-01-31 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-01 00:00:00', 9.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-02 00:00:00', 10.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-03 00:00:00', 15.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-04 00:00:00', 5.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-05 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-08 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-09 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-10 00:00:00', 9.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-11 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-12 00:00:00', 18.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-13 00:00:00', 0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-14 00:00:00', 0.582000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-17 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-18 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-19 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-20 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-22 00:00:00', 10.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-23 00:00:00', 19.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-24 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-25 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-02-28 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-01 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-02 00:00:00', 8.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-03 00:00:00', 17.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-04 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-05 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-06 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-07 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-08 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-09 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-16 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-17 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-18 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-19 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-21 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-22 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-23 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-24 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-26 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-27 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-29 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-03-31 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-01 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-02 00:00:00', 6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-03 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-05 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-06 00:00:00', 6.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-07 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-09 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-10 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-11 00:00:00', 16.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-12 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-14 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-15 00:00:00', 15.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-16 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-17 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-18 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-19 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-20 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-21 00:00:00', 27.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-22 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-25 00:00:00', 9.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-26 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-27 00:00:00', 8.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-28 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-04-30 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-01 00:00:00', 6.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-02 00:00:00', 7.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-03 00:00:00', 12.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-04 00:00:00', 22.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-05 00:00:00', 7.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-06 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-07 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-08 00:00:00', 6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-09 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-10 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-11 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-13 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-14 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-18 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-19 00:00:00', 13.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-20 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-24 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-05-31 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-01 00:00:00', 11.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-02 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-04 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-06 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-07 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-08 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-09 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-12 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-13 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-14 00:00:00', 0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-29 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-03 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-06 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-01 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-02 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-25 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-02 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-15 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-16 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-17 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-18 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-19 00:00:00', 0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-20 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-21 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-23 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-25 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-26 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-27 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-01 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-27 00:00:00', 0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-30 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-10-31 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-01 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-02 00:00:00', 21.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-04 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-05 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-07 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-08 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-09 00:00:00', 0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-14 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-16 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-20 00:00:00', 0.866999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-22 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-23 00:00:00', 14.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-24 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-25 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-27 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-28 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-29 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-11-30 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-01 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-02 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-03 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-04 00:00:00', 12.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-05 00:00:00', 0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-08 00:00:00', 5.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-09 00:00:00', 10.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-10 00:00:00', 10.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-11 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-12 00:00:00', 7.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-14 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-15 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-16 00:00:00', 12.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-19 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-20 00:00:00', 8.99199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-21 00:00:00', 13.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-22 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-25 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-26 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-27 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-28 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-29 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2009-12-31 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-03 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-05 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-06 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-07 00:00:00', 12.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-08 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-14 00:00:00', 0.549000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-15 00:00:00', 0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-16 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-17 00:00:00', 9.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-18 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-19 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-20 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-21 00:00:00', 0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-22 00:00:00', 21.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-23 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-24 00:00:00', 0.639999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-26 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-27 00:00:00', 17.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-28 00:00:00', 13.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-29 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-30 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-01-31 00:00:00', 13.3660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-01 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-02 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-03 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-04 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-05 00:00:00', 30.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-06 00:00:00', 21.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-07 00:00:00', 16.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-08 00:00:00', 10.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-09 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-10 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-11 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-12 00:00:00', 7.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-13 00:00:00', 7.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-17 00:00:00', 0.545000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-18 00:00:00', 6.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-19 00:00:00', 20.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-20 00:00:00', 19.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-21 00:00:00', 14.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-22 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-23 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-24 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-25 00:00:00', 9.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-26 00:00:00', 11.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-27 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-02-28 00:00:00', 14.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-01 00:00:00', 6.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-02 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-03 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-04 00:00:00', 16.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-05 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-06 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-07 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-08 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-11 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-12 00:00:00', 5.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-13 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-14 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-15 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-20 00:00:00', 0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-21 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-22 00:00:00', 14.7589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-23 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-25 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-26 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-27 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-29 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-30 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-03-31 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-01 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-02 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-03 00:00:00', 6.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-04 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-06 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-07 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-09 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-10 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-11 00:00:00', 17.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-12 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-14 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-15 00:00:00', 11.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-16 00:00:00', 1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-20 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-21 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-22 00:00:00', 0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-24 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-26 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-27 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-28 00:00:00', 0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-29 00:00:00', 5.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-04-30 00:00:00', 0.592000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-01 00:00:00', 10.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-02 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-03 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-04 00:00:00', 15.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-05 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-06 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-07 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-08 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-09 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-10 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-11 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-13 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-15 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-16 00:00:00', 10.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-17 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-18 00:00:00', 0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-21 00:00:00', 7.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-22 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-26 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-05-31 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-02 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-03 00:00:00', 0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-04 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-06 00:00:00', 0.184000000357627869, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-07 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-08 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-11 00:00:00', 0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-12 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-13 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-14 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-15 00:00:00', 0.691999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-16 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-17 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-21 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-21 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-22 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-28 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-29 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-30 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-03 00:00:00', 0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-06 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-24 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-06 00:00:00', 0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-12 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-15 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-16 00:00:00', 11.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-17 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-09-30 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-08 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-13 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-14 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-15 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-26 00:00:00', 0.160999998450279236, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-28 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-29 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-30 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-10-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-01 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-02 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-03 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-04 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-05 00:00:00', 5.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-03 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-04 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-05 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-06 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-07 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-15 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-16 00:00:00', 0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2010-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-03 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-04 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-06 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-07 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-08 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-10 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-11 00:00:00', 10.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-12 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-13 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-14 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-16 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-17 00:00:00', 13.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-18 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-20 00:00:00', 5.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-21 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-22 00:00:00', 0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-23 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-27 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-28 00:00:00', 14.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-29 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-30 00:00:00', 14.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-01-31 00:00:00', 17.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-01 00:00:00', 19.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-02 00:00:00', 8.48700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-03 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-04 00:00:00', 14.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-05 00:00:00', 0.727999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-06 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-08 00:00:00', 10.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-09 00:00:00', 8.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-10 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-11 00:00:00', 6.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-12 00:00:00', 10.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-13 00:00:00', 7.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-14 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-16 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-17 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-18 00:00:00', 7.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-19 00:00:00', 7.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-20 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-21 00:00:00', 11.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-22 00:00:00', 14.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-23 00:00:00', 10.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-24 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-25 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-26 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-02-28 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-02 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-03 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-04 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-05 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-06 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-07 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-10 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-11 00:00:00', 0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-12 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-13 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-14 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-15 00:00:00', 8.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-16 00:00:00', 0.75700002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-17 00:00:00', 12.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-23 00:00:00', 0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-24 00:00:00', 7.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-25 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-26 00:00:00', 7.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-27 00:00:00', 14.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-28 00:00:00', 0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-30 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-03-31 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-01 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-02 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-03 00:00:00', 7.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-04 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-08 00:00:00', 24.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-09 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-10 00:00:00', 5.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-11 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-12 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-13 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-14 00:00:00', 11.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-15 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-16 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-19 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-23 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-26 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-27 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-28 00:00:00', 10.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-29 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-04-30 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-04 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-05 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-06 00:00:00', 10.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-07 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-08 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-09 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-10 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-11 00:00:00', 0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-12 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-15 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-16 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-18 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-19 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-22 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-23 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-24 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-25 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-26 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-27 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-28 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-29 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-04 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-05 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-07 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-08 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-10 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-11 00:00:00', 6.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-12 00:00:00', 6.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-13 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-14 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-17 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-22 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-24 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-25 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-26 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-27 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-02 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-03 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-30 00:00:00', 0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-07-31 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-27 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-29 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-30 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-04 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-10 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-15 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-16 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-23 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-27 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-28 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-29 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-03 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-07 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-10 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-11 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-12 00:00:00', 6.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-13 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-14 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-19 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-20 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-21 00:00:00', 8.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-22 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-23 00:00:00', 6.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-27 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-28 00:00:00', 11.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-29 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-30 00:00:00', 8.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-10-31 00:00:00', 6.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-01 00:00:00', 12.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-02 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-03 00:00:00', 7.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-04 00:00:00', 8.96599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-05 00:00:00', 0.116999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-06 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-07 00:00:00', 15.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-08 00:00:00', 24.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-09 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-10 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-13 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-14 00:00:00', 23.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-15 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-16 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-17 00:00:00', 10.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-18 00:00:00', 15.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-19 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-20 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-21 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-22 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-23 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-24 00:00:00', 15.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-25 00:00:00', 9.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-26 00:00:00', 16.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-27 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-28 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-11-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-01 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-02 00:00:00', 6.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-03 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-04 00:00:00', 0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-05 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-06 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-12 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-18 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-19 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-20 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-24 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-25 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-26 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-27 00:00:00', 7.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-28 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-30 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2011-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-02 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-03 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-04 00:00:00', 5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-05 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-06 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-10 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-11 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-12 00:00:00', 0.368999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-13 00:00:00', 26.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-14 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-15 00:00:00', 9.85700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-16 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-19 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-21 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-22 00:00:00', 5.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-23 00:00:00', 0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-24 00:00:00', 0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-25 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-26 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-27 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-28 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-29 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-30 00:00:00', 12.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-01-31 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-01 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-02 00:00:00', 7.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-03 00:00:00', 20.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-04 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-05 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-06 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-07 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-09 00:00:00', 6.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-10 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-11 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-12 00:00:00', 9.90499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-13 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-14 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-15 00:00:00', 0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-16 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-17 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-18 00:00:00', 9.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-19 00:00:00', 29.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-20 00:00:00', 16.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-21 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-22 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-23 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-26 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-27 00:00:00', 20.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-02-29 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-01 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-02 00:00:00', 15.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-03 00:00:00', 7.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-04 00:00:00', 7.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-05 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-06 00:00:00', 7.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-07 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-08 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-09 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-10 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-11 00:00:00', 15.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-12 00:00:00', 8.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-13 00:00:00', 7.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-14 00:00:00', 9.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-15 00:00:00', 6.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-16 00:00:00', 41.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-17 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-18 00:00:00', 12.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-19 00:00:00', 28.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-20 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-23 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-24 00:00:00', 5.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-25 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-26 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-28 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-29 00:00:00', 20.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-30 00:00:00', 13.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-03-31 00:00:00', 5.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-01 00:00:00', 13.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-05 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-06 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-07 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-08 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-09 00:00:00', 7.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-10 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-19 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-20 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-21 00:00:00', 11.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-22 00:00:00', 8.01099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-23 00:00:00', 6.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-24 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-25 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-26 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-27 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-28 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-29 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-04-30 00:00:00', 0.347000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-01 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-02 00:00:00', 5.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-03 00:00:00', 0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-04 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-05 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-06 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-07 00:00:00', 16.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-08 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-09 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-10 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-11 00:00:00', 11.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-12 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-13 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-14 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-15 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-16 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-17 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-18 00:00:00', 5.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-19 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-21 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-24 00:00:00', 0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-25 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-26 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-27 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-28 00:00:00', 0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-29 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-05-31 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-04 00:00:00', 0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-05 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-07 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-08 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-09 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-11 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-12 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-15 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-16 00:00:00', 0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-19 00:00:00', 0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-20 00:00:00', 0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-21 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-22 00:00:00', 6.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-23 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-24 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-25 00:00:00', 0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-26 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-28 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-06 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-09 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-18 00:00:00', 0.836000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-23 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-24 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-25 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-26 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-04 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-06 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-07 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-09 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-10 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-11 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-12 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-13 00:00:00', 0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-16 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-25 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-08-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-05 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-17 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-18 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-21 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-29 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-14 00:00:00', 8.41100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-15 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-17 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-20 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-21 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-24 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-25 00:00:00', 20.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-26 00:00:00', 4.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-27 00:00:00', 25.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-28 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-29 00:00:00', 6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-30 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-10-31 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-01 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-02 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-03 00:00:00', 9.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-04 00:00:00', 15.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-09 00:00:00', 0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-10 00:00:00', 0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-12 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-13 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-15 00:00:00', 8.52999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-16 00:00:00', 8.25300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-17 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-18 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-19 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-22 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-23 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-25 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-26 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-27 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-28 00:00:00', 21.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-29 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-11-30 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-03 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-05 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-06 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-07 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-08 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-10 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-11 00:00:00', 11.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-12 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-13 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-15 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-16 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-17 00:00:00', 9.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-18 00:00:00', 8.66199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-19 00:00:00', 0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-22 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-23 00:00:00', 23.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-24 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-25 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-26 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-27 00:00:00', 11.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-28 00:00:00', 0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2012-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-01 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-03 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-04 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-06 00:00:00', 0.546999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-07 00:00:00', 1.06700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-08 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-09 00:00:00', 9.06700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-10 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-11 00:00:00', 28.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-12 00:00:00', 8.06499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-15 00:00:00', 0.643999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-16 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-19 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-21 00:00:00', 7.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-22 00:00:00', 16.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-24 00:00:00', 0.763999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-25 00:00:00', 6.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-26 00:00:00', 8.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-27 00:00:00', 9.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-29 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-30 00:00:00', 8.93299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-01-31 00:00:00', 6.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-01 00:00:00', 9.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-02 00:00:00', 18.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-03 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-04 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-05 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-09 00:00:00', 10.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-10 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-11 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-12 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-13 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-14 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-15 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-17 00:00:00', 0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-18 00:00:00', 10.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-19 00:00:00', 5.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-20 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-21 00:00:00', 12.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-22 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-23 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-24 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-25 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-26 00:00:00', 6.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-27 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-02-28 00:00:00', 0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-01 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-02 00:00:00', 7.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-03 00:00:00', 13.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-04 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-05 00:00:00', 0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-06 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-07 00:00:00', 7.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-08 00:00:00', 22.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-09 00:00:00', 5.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-10 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-11 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-12 00:00:00', 14.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-13 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-15 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-16 00:00:00', 5.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-17 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-19 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-20 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-21 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-22 00:00:00', 5.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-23 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-24 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-25 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-26 00:00:00', 11.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-28 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-29 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-30 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-03-31 00:00:00', 11.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-01 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-05 00:00:00', 0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-06 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-10 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-11 00:00:00', 8.62100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-12 00:00:00', 5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-13 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-15 00:00:00', 20.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-16 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-17 00:00:00', 0.123999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-18 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-19 00:00:00', 9.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-20 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-21 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-22 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-23 00:00:00', 26.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-24 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-25 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-26 00:00:00', 16.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-28 00:00:00', 7.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-29 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-04-30 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-01 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-02 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-03 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-04 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-05 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-06 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-08 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-12 00:00:00', 9.44499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-13 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-16 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-18 00:00:00', 0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-19 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-20 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-21 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-22 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-23 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-24 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-25 00:00:00', 5.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-26 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-27 00:00:00', 0.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-05-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-01 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-02 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-03 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-04 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-05 00:00:00', 0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-13 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-14 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-16 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-24 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-27 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-28 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-29 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-06-30 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-02 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-08 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-09 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-11 00:00:00', 0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-12 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-14 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-27 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-07-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-07 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-08 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-10 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-11 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-12 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-13 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-14 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-16 00:00:00', 0.796999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-17 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-18 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-19 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-20 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-21 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-24 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-29 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-08-31 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-09 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-10 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-14 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-15 00:00:00', 0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-19 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-27 00:00:00', 0.28200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-29 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-09-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-04 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-05 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-06 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-10 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-13 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-16 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-17 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-22 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-23 00:00:00', 13.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-25 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-26 00:00:00', 7.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-28 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-29 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-30 00:00:00', 7.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-10-31 00:00:00', 0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-01 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-04 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-05 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-06 00:00:00', 0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-07 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-10 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-11 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-15 00:00:00', 0.716000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-16 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-17 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-18 00:00:00', 5.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-19 00:00:00', 10.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-20 00:00:00', 7.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-22 00:00:00', 0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-23 00:00:00', 1.17200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-24 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-25 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-26 00:00:00', 7.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-28 00:00:00', 0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-29 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-11-30 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-01 00:00:00', 9.10700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-02 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-03 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-04 00:00:00', 4.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-05 00:00:00', 14.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-06 00:00:00', 20.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-07 00:00:00', 25.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-08 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-09 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-10 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-11 00:00:00', 9.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-13 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-14 00:00:00', 0.0960000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-15 00:00:00', 7.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-16 00:00:00', 13.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-17 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-18 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-20 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-21 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-24 00:00:00', 0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-26 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-27 00:00:00', 5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-28 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-29 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2013-12-31 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-02 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-03 00:00:00', 0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-04 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-05 00:00:00', 0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-06 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-08 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-09 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-12 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-13 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-15 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-16 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-20 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-21 00:00:00', 16.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-22 00:00:00', 15.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-23 00:00:00', 9.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-24 00:00:00', 38.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-25 00:00:00', 10.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-26 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-27 00:00:00', 13.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-28 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-29 00:00:00', 6.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-30 00:00:00', 9.84099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-01-31 00:00:00', 11.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-01 00:00:00', 9.60999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-02 00:00:00', 7.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-03 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-04 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-06 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-07 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-08 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-11 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-12 00:00:00', 0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-13 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-14 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-18 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-19 00:00:00', 8.64500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-20 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-21 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-22 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-23 00:00:00', 10.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-24 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-02-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-01 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-02 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-03 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-04 00:00:00', 0.398000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-05 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-06 00:00:00', 8.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-07 00:00:00', 24.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-08 00:00:00', 20.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-09 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-10 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-13 00:00:00', 18.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-14 00:00:00', 10.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-15 00:00:00', 7.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-16 00:00:00', 8.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-17 00:00:00', 6.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-18 00:00:00', 8.35999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-19 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-20 00:00:00', 21.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-21 00:00:00', 9.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-22 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-23 00:00:00', 15.0679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-24 00:00:00', 7.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-25 00:00:00', 0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-26 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-27 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-29 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-30 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-03-31 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-01 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-02 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-03 00:00:00', 7.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-04 00:00:00', 26.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-05 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-06 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-07 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-09 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-10 00:00:00', 23.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-11 00:00:00', 14.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-12 00:00:00', 8.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-13 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-16 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-17 00:00:00', 0.0790000036358833313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-20 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-22 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-24 00:00:00', 27.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-25 00:00:00', 19.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-26 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-27 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-28 00:00:00', 13.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-29 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-04-30 00:00:00', 15.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-01 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-02 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-03 00:00:00', 7.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-04 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-05 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-06 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-07 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-08 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-09 00:00:00', 6.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-11 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-13 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-15 00:00:00', 0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-16 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-17 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-18 00:00:00', 8.64500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-19 00:00:00', 10.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-20 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-21 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-23 00:00:00', 0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-25 00:00:00', 0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-28 00:00:00', 0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-29 00:00:00', 8.61200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-30 00:00:00', 20.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-05-31 00:00:00', 0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-01 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-02 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-03 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-04 00:00:00', 0.0209999997168779373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-05 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-06 00:00:00', 15.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-07 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-11 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-12 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-14 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-15 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-16 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-17 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-19 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-21 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-25 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-29 00:00:00', 0.00200000009499490261, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-06-30 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-01 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-02 00:00:00', 0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-03 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-04 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-05 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-06 00:00:00', 0.642000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-07 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-08 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-09 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-10 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-11 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-12 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-13 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-14 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-15 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-16 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-17 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-18 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-19 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-20 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-21 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-22 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-23 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-24 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-25 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-26 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-27 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-28 00:00:00', 0, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-29 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-30 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (28, '2014-07-31 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-01 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-02 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-03 00:00:00', 5.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-04 00:00:00', 7.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-05 00:00:00', 5.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-06 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-07 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-08 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-09 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-10 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-11 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-12 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-13 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-14 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-15 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-16 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-17 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-18 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-19 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-20 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-21 00:00:00', 7.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-22 00:00:00', 8.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-23 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-24 00:00:00', 5.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-25 00:00:00', 5.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-26 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-27 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-28 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-29 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-30 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-01-31 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-01 00:00:00', 5.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-02 00:00:00', 6.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-03 00:00:00', 6.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-04 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-05 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-06 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-07 00:00:00', 6.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-08 00:00:00', 5.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-09 00:00:00', 5.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-10 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-11 00:00:00', 8.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-12 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-13 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-14 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-15 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-16 00:00:00', 5.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-17 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-18 00:00:00', 5.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-19 00:00:00', 6.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-20 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-21 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-22 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-23 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-24 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-25 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-26 00:00:00', 6.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-27 00:00:00', 4.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-02-28 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-01 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-02 00:00:00', 5.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-03 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-04 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-05 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-06 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-07 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-08 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-09 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-10 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-11 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-12 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-13 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-14 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-15 00:00:00', 6.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-16 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-17 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-18 00:00:00', 5.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-19 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-20 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-21 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-22 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-23 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-24 00:00:00', 4.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-25 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-26 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-27 00:00:00', 7.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-28 00:00:00', 5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-29 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-30 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-03-31 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-01 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-02 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-03 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-04 00:00:00', 5.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-05 00:00:00', 6.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-06 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-07 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-08 00:00:00', 4.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-09 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-10 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-11 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-12 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-13 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-14 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-15 00:00:00', 7.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-16 00:00:00', 5.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-17 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-18 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-19 00:00:00', 5.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-20 00:00:00', 7.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-21 00:00:00', 7.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-22 00:00:00', 5.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-23 00:00:00', 7.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-24 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-25 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-26 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-27 00:00:00', 6.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-28 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-29 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-04-30 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-01 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-02 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-03 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-04 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-05 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-06 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-07 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-08 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-09 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-10 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-11 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-12 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-13 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-14 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-15 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-16 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-17 00:00:00', 7.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-18 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-19 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-20 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-21 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-22 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-23 00:00:00', 5.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-24 00:00:00', 5.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-25 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-26 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-27 00:00:00', 4.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-28 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-29 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-30 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-05-31 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-01 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-02 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-03 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-04 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-05 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-06 00:00:00', 4.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-07 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-08 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-09 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-10 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-11 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-12 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-13 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-14 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-15 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-16 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-17 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-18 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-19 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-20 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-21 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-22 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-23 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-24 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-25 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-26 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-27 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-28 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-29 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-06-30 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-01 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-02 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-03 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-04 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-05 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-06 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-07 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-08 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-09 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-10 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-11 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-12 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-13 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-14 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-15 00:00:00', 1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-16 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-17 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-18 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-19 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-20 00:00:00', 5.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-21 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-22 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-23 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-24 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-25 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-26 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-27 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-28 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-29 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-30 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-07-31 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-01 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-02 00:00:00', 5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-03 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-04 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-05 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-06 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-07 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-08 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-09 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-10 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-11 00:00:00', 0.998000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-12 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-13 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-14 00:00:00', 1.10099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-15 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-16 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-17 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-18 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-19 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-20 00:00:00', 6.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-21 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-22 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-23 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-24 00:00:00', 1.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-25 00:00:00', 1.21599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-26 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-27 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-28 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-29 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-30 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-08-31 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-01 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-02 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-03 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-04 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-05 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-06 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-07 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-08 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-09 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-10 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-11 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-12 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-13 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-14 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-15 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-16 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-17 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-18 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-19 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-20 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-21 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-22 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-23 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-24 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-25 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-26 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-27 00:00:00', 1.07400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-28 00:00:00', 1.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-29 00:00:00', 0.922999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-09-30 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-01 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-02 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-03 00:00:00', 1.32799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-04 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-05 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-06 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-07 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-08 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-09 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-10 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-11 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-12 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-13 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-14 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-15 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-16 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-17 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-18 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-19 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-20 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-21 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-22 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-23 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-24 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-25 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-26 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-27 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-28 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-29 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-30 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-10-31 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-01 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-02 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-03 00:00:00', 4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-04 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-05 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-06 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-07 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-08 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-09 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-10 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-11 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-12 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-13 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-14 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-15 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-16 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-17 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-18 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-19 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-20 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-21 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-22 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-23 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-24 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-25 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-26 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-27 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-28 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-29 00:00:00', 7.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-11-30 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-01 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-02 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-03 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-04 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-05 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-06 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-07 00:00:00', 5.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-08 00:00:00', 6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-09 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-10 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-11 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-12 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-13 00:00:00', 6.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-14 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-15 00:00:00', 7.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-16 00:00:00', 6.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-17 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-18 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-19 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-20 00:00:00', 7.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-21 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-22 00:00:00', 5.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-23 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-24 00:00:00', 6.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-25 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-26 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-27 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-28 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-29 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-30 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1979-12-31 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-01 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-02 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-03 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-04 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-05 00:00:00', 6.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-06 00:00:00', 8.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-07 00:00:00', 6.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-08 00:00:00', 5.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-09 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-10 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-11 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-12 00:00:00', 5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-13 00:00:00', 6.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-14 00:00:00', 5.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-15 00:00:00', 6.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-16 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-17 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-18 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-19 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-20 00:00:00', 5.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-21 00:00:00', 6.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-22 00:00:00', 6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-23 00:00:00', 5.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-24 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-25 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-26 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-27 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-28 00:00:00', 6.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-29 00:00:00', 7.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-30 00:00:00', 5.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-01-31 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-01 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-02 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-03 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-04 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-05 00:00:00', 5.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-06 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-07 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-08 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-09 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-10 00:00:00', 5.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-11 00:00:00', 6.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-12 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-13 00:00:00', 6.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-14 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-15 00:00:00', 5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-16 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-17 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-18 00:00:00', 7.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-19 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-20 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-21 00:00:00', 5.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-22 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-23 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-24 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-25 00:00:00', 5.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-26 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-27 00:00:00', 5.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-28 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-02-29 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-01 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-02 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-03 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-04 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-05 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-06 00:00:00', 6.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-07 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-08 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-09 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-10 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-11 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-12 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-13 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-14 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-15 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-16 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-17 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-18 00:00:00', 5.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-19 00:00:00', 8.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-20 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-21 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-22 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-23 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-24 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-25 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-26 00:00:00', 5.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-27 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-28 00:00:00', 4.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-29 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-30 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-03-31 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-01 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-02 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-03 00:00:00', 7.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-04 00:00:00', 8.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-05 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-06 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-07 00:00:00', 4.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-08 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-09 00:00:00', 5.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-10 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-11 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-12 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-13 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-14 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-15 00:00:00', 6.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-16 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-17 00:00:00', 4.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-18 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-19 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-20 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-21 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-22 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-23 00:00:00', 4.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-24 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-25 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-26 00:00:00', 5.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-27 00:00:00', 6.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-28 00:00:00', 4.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-29 00:00:00', 4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-04-30 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-01 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-02 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-03 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-04 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-05 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-06 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-07 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-08 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-09 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-10 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-11 00:00:00', 4.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-12 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-13 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-14 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-15 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-16 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-17 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-18 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-19 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-20 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-21 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-22 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-23 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-24 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-25 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-26 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-27 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-28 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-29 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-30 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-05-31 00:00:00', 4.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-01 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-02 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-03 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-04 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-05 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-06 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-07 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-08 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-09 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-10 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-11 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-12 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-13 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-14 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-15 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-16 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-17 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-18 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-19 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-20 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-21 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-22 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-23 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-24 00:00:00', 5.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-25 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-26 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-27 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-28 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-29 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-06-30 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-01 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-02 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-03 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-04 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-05 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-06 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-07 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-08 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-09 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-10 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-11 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-12 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-13 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-14 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-15 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-16 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-17 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-18 00:00:00', 6.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-19 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-20 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-21 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-22 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-23 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-24 00:00:00', 1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-25 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-26 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-27 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-28 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-29 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-30 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-07-31 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-01 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-02 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-03 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-04 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-05 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-06 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-07 00:00:00', 4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-08 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-09 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-10 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-11 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-12 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-13 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-14 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-15 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-16 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-17 00:00:00', 0.968999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-18 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-19 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-20 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-21 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-22 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-23 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-24 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-25 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-26 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-27 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-28 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-29 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-30 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-08-31 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-01 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-02 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-03 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-04 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-05 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-06 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-07 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-08 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-09 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-10 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-11 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-12 00:00:00', 1.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-13 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-14 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-15 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-16 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-17 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-18 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-19 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-20 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-21 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-22 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-23 00:00:00', 5.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-24 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-25 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-26 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-27 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-28 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-29 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-09-30 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-01 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-02 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-03 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-04 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-05 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-06 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-07 00:00:00', 4.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-08 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-09 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-10 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-11 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-12 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-13 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-14 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-15 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-16 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-17 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-18 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-19 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-20 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-21 00:00:00', 4.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-22 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-23 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-24 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-25 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-26 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-27 00:00:00', 1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-28 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-29 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-30 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-10-31 00:00:00', 1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-01 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-02 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-03 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-04 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-05 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-06 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-07 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-08 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-09 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-10 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-11 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-12 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-13 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-14 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-15 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-16 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-17 00:00:00', 5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-18 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-19 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-20 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-21 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-22 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-23 00:00:00', 6.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-24 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-25 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-26 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-27 00:00:00', 5.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-28 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-29 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-11-30 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-01 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-02 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-03 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-04 00:00:00', 4.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-05 00:00:00', 6.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-06 00:00:00', 6.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-07 00:00:00', 6.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-08 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-09 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-10 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-11 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-12 00:00:00', 8.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-13 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-14 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-15 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-16 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-17 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-18 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-19 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-20 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-21 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-22 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-23 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-24 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-25 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-26 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-27 00:00:00', 4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-28 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-29 00:00:00', 6.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-30 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1980-12-31 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-01 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-02 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-03 00:00:00', 6.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-04 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-05 00:00:00', 6.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-06 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-07 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-08 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-09 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-10 00:00:00', 6.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-11 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-12 00:00:00', 7.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-13 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-14 00:00:00', 6.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-15 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-16 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-17 00:00:00', 6.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-18 00:00:00', 8.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-19 00:00:00', 6.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-20 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-21 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-22 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-23 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-24 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-25 00:00:00', 8.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-26 00:00:00', 6.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-27 00:00:00', 5.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-28 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-29 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-30 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-01-31 00:00:00', 5.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-01 00:00:00', 8.25300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-02 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-03 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-04 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-05 00:00:00', 6.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-06 00:00:00', 6.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-07 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-08 00:00:00', 4.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-09 00:00:00', 8.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-10 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-11 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-12 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-13 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-14 00:00:00', 5.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-15 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-16 00:00:00', 6.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-17 00:00:00', 7.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-18 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-19 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-20 00:00:00', 6.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-21 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-22 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-23 00:00:00', 4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-24 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-25 00:00:00', 6.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-26 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-27 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-02-28 00:00:00', 5.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-01 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-02 00:00:00', 8.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-03 00:00:00', 6.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-04 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-05 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-06 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-07 00:00:00', 7.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-08 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-09 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-10 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-11 00:00:00', 5.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-12 00:00:00', 8.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-13 00:00:00', 7.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-14 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-15 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-16 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-17 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-18 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-19 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-20 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-21 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-22 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-23 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-24 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-25 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-26 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-27 00:00:00', 6.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-28 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-29 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-30 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-03-31 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-01 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-02 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-03 00:00:00', 4.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-04 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-05 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-06 00:00:00', 8.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-07 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-08 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-09 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-10 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-11 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-12 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-13 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-14 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-15 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-16 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-17 00:00:00', 7.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-18 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-19 00:00:00', 5.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-20 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-21 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-22 00:00:00', 4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-23 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-24 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-25 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-26 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-27 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-28 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-29 00:00:00', 5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-04-30 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-01 00:00:00', 6.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-02 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-03 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-04 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-05 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-06 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-07 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-08 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-09 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-10 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-11 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-12 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-13 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-14 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-15 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-16 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-17 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-18 00:00:00', 5.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-19 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-20 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-21 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-22 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-23 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-24 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-25 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-26 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-27 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-28 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-29 00:00:00', 5.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-30 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-05-31 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-01 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-02 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-03 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-04 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-05 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-06 00:00:00', 5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-07 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-08 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-09 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-10 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-11 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-12 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-13 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-14 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-15 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-16 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-17 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-18 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-19 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-20 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-21 00:00:00', 1.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-22 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-23 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-24 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-25 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-26 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-27 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-28 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-29 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-06-30 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-01 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-02 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-03 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-04 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-05 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-06 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-07 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-08 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-09 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-10 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-11 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-12 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-13 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-14 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-15 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-16 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-17 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-18 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-19 00:00:00', 1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-20 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-21 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-22 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-23 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-24 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-25 00:00:00', 1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-26 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-27 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-28 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-29 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-30 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-07-31 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-01 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-02 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-03 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-04 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-05 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-06 00:00:00', 1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-07 00:00:00', 1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-08 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-09 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-10 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-11 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-12 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-13 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-14 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-15 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-16 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-17 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-18 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-19 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-20 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-21 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-22 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-23 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-24 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-25 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-26 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-27 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-28 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-29 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-30 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-08-31 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-01 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-02 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-03 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-04 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-05 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-06 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-07 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-08 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-09 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-10 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-11 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-12 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-13 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-14 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-15 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-16 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-17 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-18 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-19 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-20 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-21 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-22 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-23 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-24 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-25 00:00:00', 0.949000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-26 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-27 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-28 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-29 00:00:00', 1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-09-30 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-01 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-02 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-03 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-04 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-05 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-06 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-07 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-08 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-09 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-10 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-11 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-12 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-13 00:00:00', 4.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-14 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-15 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-16 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-17 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-18 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-19 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-20 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-21 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-22 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-23 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-24 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-25 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-26 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-27 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-28 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-29 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-30 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-10-31 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-01 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-02 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-03 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-04 00:00:00', 6.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-05 00:00:00', 6.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-06 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-07 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-08 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-09 00:00:00', 1.16299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-10 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-11 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-12 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-13 00:00:00', 6.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-14 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-15 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-16 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-17 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-18 00:00:00', 5.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-19 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-20 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-21 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-22 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-23 00:00:00', 6.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-24 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-25 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-26 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-27 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-28 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-29 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-11-30 00:00:00', 5.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-01 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-02 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-03 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-04 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-05 00:00:00', 5.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-06 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-07 00:00:00', 7.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-08 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-09 00:00:00', 6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-10 00:00:00', 6.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-11 00:00:00', 6.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-12 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-13 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-14 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-15 00:00:00', 7.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-16 00:00:00', 8.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-17 00:00:00', 7.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-18 00:00:00', 7.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-19 00:00:00', 7.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-20 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-21 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-22 00:00:00', 7.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-23 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-24 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-25 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-26 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-27 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-28 00:00:00', 1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-29 00:00:00', 6.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-30 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1981-12-31 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-01 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-02 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-03 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-04 00:00:00', 5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-05 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-06 00:00:00', 6.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-07 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-08 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-09 00:00:00', 5.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-10 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-11 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-12 00:00:00', 5.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-13 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-14 00:00:00', 7.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-15 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-16 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-17 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-18 00:00:00', 5.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-19 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-20 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-21 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-22 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-23 00:00:00', 5.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-24 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-25 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-26 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-27 00:00:00', 4.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-28 00:00:00', 6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-29 00:00:00', 9.97099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-30 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-01-31 00:00:00', 7.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-01 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-02 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-03 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-04 00:00:00', 8.23900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-05 00:00:00', 7.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-06 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-07 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-08 00:00:00', 7.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-09 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-10 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-11 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-12 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-13 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-14 00:00:00', 8.44900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-15 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-16 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-17 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-18 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-19 00:00:00', 5.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-20 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-21 00:00:00', 9.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-22 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-23 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-24 00:00:00', 6.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-25 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-26 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-27 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-02-28 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-01 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-02 00:00:00', 6.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-03 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-04 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-05 00:00:00', 4.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-06 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-07 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-08 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-09 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-10 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-11 00:00:00', 6.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-12 00:00:00', 6.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-13 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-14 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-15 00:00:00', 7.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-16 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-17 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-18 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-19 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-20 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-21 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-22 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-23 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-24 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-25 00:00:00', 7.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-26 00:00:00', 5.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-27 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-28 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-29 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-30 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-03-31 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-01 00:00:00', 5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-02 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-03 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-04 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-05 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-06 00:00:00', 6.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-07 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-08 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-09 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-10 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-11 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-12 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-13 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-14 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-15 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-16 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-17 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-18 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-19 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-20 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-21 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-22 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-23 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-24 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-25 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-26 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-27 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-28 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-29 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-04-30 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-01 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-02 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-03 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-04 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-05 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-06 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-07 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-08 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-09 00:00:00', 5.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-10 00:00:00', 6.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-11 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-12 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-13 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-14 00:00:00', 1.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-15 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-16 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-17 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-18 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-19 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-20 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-21 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-22 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-23 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-24 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-25 00:00:00', 5.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-26 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-27 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-28 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-29 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-30 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-05-31 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-01 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-02 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-03 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-04 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-05 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-06 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-07 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-08 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-09 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-10 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-11 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-12 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-13 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-14 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-15 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-16 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-17 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-18 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-19 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-20 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-21 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-22 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-23 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-24 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-25 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-26 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-27 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-28 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-29 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-06-30 00:00:00', 4.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-01 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-02 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-03 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-04 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-05 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-06 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-07 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-08 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-09 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-10 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-11 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-12 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-13 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-14 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-15 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-16 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-17 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-18 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-19 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-20 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-21 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-22 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-23 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-24 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-25 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-26 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-27 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-28 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-29 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-30 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-07-31 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-01 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-02 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-03 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-04 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-05 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-06 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-07 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-08 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-09 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-10 00:00:00', 6.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-11 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-12 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-13 00:00:00', 0.913999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-14 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-15 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-16 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-17 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-18 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-19 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-20 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-21 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-22 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-23 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-24 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-25 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-26 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-27 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-28 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-29 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-30 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-08-31 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-01 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-02 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-03 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-04 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-05 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-06 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-07 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-08 00:00:00', 1.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-09 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-10 00:00:00', 0.981000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-11 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-12 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-13 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-14 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-15 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-16 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-17 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-18 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-19 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-20 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-21 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-22 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-23 00:00:00', 0.865999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-24 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-25 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-26 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-27 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-28 00:00:00', 0.947000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-29 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-09-30 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-01 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-02 00:00:00', 4.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-03 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-04 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-05 00:00:00', 5.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-06 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-07 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-08 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-09 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-10 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-11 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-12 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-13 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-14 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-15 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-16 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-17 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-18 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-19 00:00:00', 4.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-20 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-21 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-22 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-23 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-24 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-25 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-26 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-27 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-28 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-29 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-30 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-10-31 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-01 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-02 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-03 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-04 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-05 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-06 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-07 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-08 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-09 00:00:00', 5.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-10 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-11 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-12 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-13 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-14 00:00:00', 5.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-15 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-16 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-17 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-18 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-19 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-20 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-21 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-22 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-23 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-24 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-25 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-26 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-27 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-28 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-29 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-11-30 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-01 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-02 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-03 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-04 00:00:00', 6.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-05 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-06 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-07 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-08 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-09 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-10 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-11 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-12 00:00:00', 0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-13 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-14 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-15 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-16 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-17 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-18 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-19 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-20 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-21 00:00:00', 1.09099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-22 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-23 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-24 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-25 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-26 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-27 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-28 00:00:00', 5.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-29 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-30 00:00:00', 6.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1982-12-31 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-01 00:00:00', 8.17099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-02 00:00:00', 7.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-03 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-04 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-05 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-06 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-07 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-08 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-09 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-10 00:00:00', 6.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-11 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-12 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-13 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-14 00:00:00', 6.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-15 00:00:00', 7.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-16 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-17 00:00:00', 7.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-18 00:00:00', 6.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-19 00:00:00', 5.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-20 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-21 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-22 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-23 00:00:00', 7.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-24 00:00:00', 6.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-25 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-26 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-27 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-28 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-29 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-30 00:00:00', 5.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-01-31 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-01 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-02 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-03 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-04 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-05 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-06 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-07 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-08 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-09 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-10 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-11 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-12 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-13 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-14 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-15 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-16 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-17 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-18 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-19 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-20 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-21 00:00:00', 7.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-22 00:00:00', 7.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-23 00:00:00', 6.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-24 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-25 00:00:00', 6.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-26 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-27 00:00:00', 6.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-02-28 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-01 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-02 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-03 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-04 00:00:00', 6.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-05 00:00:00', 8.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-06 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-07 00:00:00', 5.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-08 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-09 00:00:00', 6.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-10 00:00:00', 5.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-11 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-12 00:00:00', 7.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-13 00:00:00', 6.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-14 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-15 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-16 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-17 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-18 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-19 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-20 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-21 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-22 00:00:00', 6.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-23 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-24 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-25 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-26 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-27 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-28 00:00:00', 5.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-29 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-30 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-03-31 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-01 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-02 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-03 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-04 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-05 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-06 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-07 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-08 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-09 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-10 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-11 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-12 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-13 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-14 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-15 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-16 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-17 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-18 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-19 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-20 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-21 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-22 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-23 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-24 00:00:00', 6.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-25 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-26 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-27 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-28 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-29 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-04-30 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-01 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-02 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-03 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-04 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-05 00:00:00', 7.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-06 00:00:00', 5.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-07 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-08 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-09 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-10 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-11 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-12 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-13 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-14 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-15 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-16 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-17 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-18 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-19 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-20 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-21 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-22 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-23 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-24 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-25 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-26 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-27 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-28 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-29 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-30 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-05-31 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-01 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-02 00:00:00', 1.1390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-03 00:00:00', 1.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-04 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-05 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-06 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-07 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-08 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-09 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-10 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-11 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-12 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-13 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-14 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-15 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-16 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-17 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-18 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-19 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-20 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-21 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-22 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-23 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-24 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-25 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-26 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-27 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-28 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-29 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-06-30 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-01 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-02 00:00:00', 5.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-03 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-04 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-05 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-06 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-07 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-08 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-09 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-10 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-11 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-12 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-13 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-14 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-15 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-16 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-17 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-18 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-19 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-20 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-21 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-22 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-23 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-24 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-25 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-26 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-27 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-28 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-29 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-30 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-07-31 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-01 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-02 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-03 00:00:00', 1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-04 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-05 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-06 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-07 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-08 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-09 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-10 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-11 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-12 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-13 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-14 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-15 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-16 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-17 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-18 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-19 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-20 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-21 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-22 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-23 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-24 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-25 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-26 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-27 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-28 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-29 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-30 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-08-31 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-01 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-03 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-05 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-07 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-09 00:00:00', 4.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-11 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-13 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-15 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-17 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-19 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-21 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-23 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-25 00:00:00', 4.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-27 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-29 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-01 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-03 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-05 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-07 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-09 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-11 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-13 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-15 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-17 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-19 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-21 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-23 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-25 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-27 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-29 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-30 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-10-31 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-01 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-02 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-03 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-04 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-05 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-06 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-07 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-08 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-09 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-10 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-11 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-12 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-13 00:00:00', 5.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-14 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-15 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-16 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-17 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-18 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-19 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-20 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-21 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-22 00:00:00', 5.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-23 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-24 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-25 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-26 00:00:00', 6.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-27 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-28 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-29 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-11-30 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-01 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-02 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-03 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-04 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-05 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-06 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-07 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-08 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-09 00:00:00', 6.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-10 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-11 00:00:00', 7.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-12 00:00:00', 6.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-13 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-14 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-15 00:00:00', 6.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-16 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-17 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-18 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-19 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-20 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-21 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-22 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-23 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-24 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-25 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-26 00:00:00', 6.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-27 00:00:00', 5.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-28 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-29 00:00:00', 5.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-30 00:00:00', 7.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1983-12-31 00:00:00', 5.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-01 00:00:00', 7.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-02 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-03 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-04 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-05 00:00:00', 4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-06 00:00:00', 6.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-07 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-08 00:00:00', 6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-09 00:00:00', 6.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-10 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-11 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-12 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-13 00:00:00', 6.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-14 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-15 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-16 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-17 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-18 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-19 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-20 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-21 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-22 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-23 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-24 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-25 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-26 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-27 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-28 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-29 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-30 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-01-31 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-01 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-02 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-03 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-04 00:00:00', 5.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-05 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-06 00:00:00', 4.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-07 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-08 00:00:00', 9.43999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-09 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-10 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-11 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-12 00:00:00', 6.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-13 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-14 00:00:00', 5.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-15 00:00:00', 6.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-16 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-17 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-18 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-19 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-20 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-21 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-22 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-23 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-24 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-25 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-26 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-27 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-28 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-02-29 00:00:00', 4.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-01 00:00:00', 5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-02 00:00:00', 5.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-03 00:00:00', 5.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-04 00:00:00', 4.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-05 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-06 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-07 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-08 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-09 00:00:00', 6.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-10 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-11 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-12 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-13 00:00:00', 6.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-14 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-15 00:00:00', 5.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-16 00:00:00', 4.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-17 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-18 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-19 00:00:00', 7.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-20 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-21 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-22 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-23 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-24 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-25 00:00:00', 5.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-26 00:00:00', 8.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-27 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-28 00:00:00', 4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-29 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-30 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-03-31 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-01 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-02 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-03 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-04 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-05 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-06 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-07 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-08 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-09 00:00:00', 7.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-10 00:00:00', 8.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-11 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-12 00:00:00', 5.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-13 00:00:00', 5.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-14 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-15 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-16 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-17 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-18 00:00:00', 4.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-19 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-20 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-21 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-22 00:00:00', 6.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-23 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-24 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-25 00:00:00', 6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-26 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-27 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-28 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-29 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-04-30 00:00:00', 6.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-01 00:00:00', 7.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-02 00:00:00', 7.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-03 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-04 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-05 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-06 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-07 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-08 00:00:00', 4.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-09 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-10 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-11 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-12 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-13 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-14 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-15 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-16 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-17 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-18 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-19 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-20 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-21 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-22 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-23 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-24 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-25 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-26 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-27 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-28 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-29 00:00:00', 5.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-30 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-05-31 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-01 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-02 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-03 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-04 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-05 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-06 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-07 00:00:00', 1.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-08 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-09 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-10 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-11 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-12 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-13 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-14 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-15 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-16 00:00:00', 6.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-17 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-18 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-19 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-20 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-21 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-22 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-23 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-24 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-25 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-26 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-27 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-28 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-29 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-06-30 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-01 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-02 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-03 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-04 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-05 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-06 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-07 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-08 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-09 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-10 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-11 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-12 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-13 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-14 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-15 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-16 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-17 00:00:00', 0.971000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-18 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-19 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-20 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-21 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-22 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-23 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-24 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-25 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-26 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-27 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-28 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-29 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-30 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-07-31 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-01 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-02 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-03 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-04 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-05 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-06 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-07 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-08 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-09 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-10 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-11 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-12 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-13 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-14 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-15 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-16 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-17 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-18 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-19 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-20 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-21 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-22 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-23 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-24 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-25 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-26 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-27 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-28 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-29 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-30 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-08-31 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-01 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-02 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-03 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-04 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-05 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-06 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-07 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-08 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-09 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-10 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-11 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-12 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-13 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-14 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-15 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-16 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-17 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-18 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-19 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-20 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-21 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-22 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-23 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-24 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-25 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-26 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-27 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-28 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-29 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-09-30 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-01 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-02 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-03 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-04 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-05 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-06 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-07 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-08 00:00:00', 6.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-09 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-10 00:00:00', 4.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-11 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-12 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-13 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-14 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-15 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-16 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-17 00:00:00', 5.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-18 00:00:00', 6.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-19 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-20 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-21 00:00:00', 6.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-22 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-23 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-24 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-25 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-26 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-27 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-28 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-29 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-30 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-10-31 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-01 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-02 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-03 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-04 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-05 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-06 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-07 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-08 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-09 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-10 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-11 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-12 00:00:00', 7.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-13 00:00:00', 7.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-14 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-15 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-16 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-17 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-18 00:00:00', 5.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-19 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-20 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-21 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-22 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-23 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-24 00:00:00', 6.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-25 00:00:00', 7.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-26 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-27 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-28 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-29 00:00:00', 8.27000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-11-30 00:00:00', 6.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-01 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-02 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-03 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-04 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-05 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-06 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-07 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-08 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-09 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-10 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-11 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-12 00:00:00', 4.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-13 00:00:00', 7.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-14 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-15 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-16 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-17 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-18 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-19 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-20 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-21 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-22 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-23 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-24 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-25 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-26 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-27 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-28 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-29 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-30 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1984-12-31 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-01 00:00:00', 5.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-02 00:00:00', 9.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-03 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-04 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-05 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-06 00:00:00', 5.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-07 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-08 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-09 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-10 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-11 00:00:00', 6.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-12 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-13 00:00:00', 5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-14 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-15 00:00:00', 5.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-16 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-17 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-18 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-19 00:00:00', 6.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-20 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-21 00:00:00', 9.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-22 00:00:00', 6.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-23 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-24 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-25 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-26 00:00:00', 6.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-27 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-28 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-29 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-30 00:00:00', 7.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-01-31 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-01 00:00:00', 7.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-02 00:00:00', 7.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-03 00:00:00', 6.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-04 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-05 00:00:00', 9.61200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-06 00:00:00', 8.96599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-07 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-08 00:00:00', 5.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-09 00:00:00', 9.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-10 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-11 00:00:00', 6.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-12 00:00:00', 5.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-13 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-14 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-15 00:00:00', 6.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-16 00:00:00', 8.49400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-17 00:00:00', 4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-18 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-19 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-20 00:00:00', 6.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-21 00:00:00', 8.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-22 00:00:00', 6.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-23 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-24 00:00:00', 5.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-25 00:00:00', 7.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-26 00:00:00', 8.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-27 00:00:00', 6.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-02-28 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-01 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-02 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-03 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-04 00:00:00', 6.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-05 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-06 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-07 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-08 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-09 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-10 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-11 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-12 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-13 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-14 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-15 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-16 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-17 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-18 00:00:00', 6.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-19 00:00:00', 5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-20 00:00:00', 7.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-21 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-22 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-23 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-24 00:00:00', 7.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-25 00:00:00', 5.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-26 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-27 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-28 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-29 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-30 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-03-31 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-01 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-02 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-03 00:00:00', 5.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-04 00:00:00', 4.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-05 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-06 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-07 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-08 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-09 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-10 00:00:00', 5.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-11 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-12 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-13 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-14 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-15 00:00:00', 6.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-16 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-17 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-18 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-19 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-20 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-21 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-22 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-23 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-24 00:00:00', 4.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-25 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-26 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-27 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-28 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-29 00:00:00', 4.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-04-30 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-01 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-02 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-03 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-04 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-05 00:00:00', 4.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-06 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-07 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-08 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-09 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-10 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-11 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-12 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-13 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-14 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-15 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-16 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-17 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-18 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-19 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-20 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-21 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-22 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-23 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-24 00:00:00', 5.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-25 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-26 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-27 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-28 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-29 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-30 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-05-31 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-01 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-02 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-03 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-04 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-05 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-06 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-07 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-08 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-09 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-10 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-11 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-12 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-13 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-14 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-15 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-16 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-17 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-18 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-19 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-20 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-21 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-22 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-23 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-24 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-25 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-26 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-27 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-28 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-29 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-06-30 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-01 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-02 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-03 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-04 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-05 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-06 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-07 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-08 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-09 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-10 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-11 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-12 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-13 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-14 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-15 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-16 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-17 00:00:00', 5.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-18 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-19 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-20 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-21 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-22 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-23 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-24 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-25 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-26 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-27 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-28 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-29 00:00:00', 5.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-30 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-07-31 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-01 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-02 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-03 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-04 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-05 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-06 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-07 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-08 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-09 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-10 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-11 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-12 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-13 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-14 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-15 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-16 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-17 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-18 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-19 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-20 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-21 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-22 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-23 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-24 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-25 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-26 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-27 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-28 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-29 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-30 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-08-31 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-01 00:00:00', 1.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-02 00:00:00', 0.808000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-03 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-04 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-05 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-06 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-07 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-08 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-09 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-10 00:00:00', 0.994000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-11 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-12 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-13 00:00:00', 0.739000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-14 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-15 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-16 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-17 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-18 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-19 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-20 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-21 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-22 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-23 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-24 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-25 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-26 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-27 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-28 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-29 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-09-30 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-01 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-02 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-03 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-04 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-05 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-06 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-07 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-08 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-09 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-10 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-11 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-12 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-13 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-14 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-15 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-16 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-17 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-18 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-19 00:00:00', 5.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-20 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-21 00:00:00', 5.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-22 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-23 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-24 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-25 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-26 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-27 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-28 00:00:00', 6.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-29 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-30 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-10-31 00:00:00', 5.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-01 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-02 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-03 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-04 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-05 00:00:00', 1.03199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-06 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-07 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-08 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-09 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-10 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-11 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-12 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-13 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-14 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-15 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-16 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-17 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-18 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-19 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-20 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-21 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-22 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-23 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-24 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-25 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-26 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-27 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-28 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-29 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-11-30 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-01 00:00:00', 6.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-02 00:00:00', 6.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-03 00:00:00', 6.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-04 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-05 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-06 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-07 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-08 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-09 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-10 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-11 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-12 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-13 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-14 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-15 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-16 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-17 00:00:00', 6.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-18 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-19 00:00:00', 10.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-20 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-21 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-22 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-23 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-24 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-25 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-26 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-27 00:00:00', 5.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-28 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-29 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-30 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1985-12-31 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-01 00:00:00', 5.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-02 00:00:00', 6.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-03 00:00:00', 6.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-04 00:00:00', 7.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-05 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-06 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-07 00:00:00', 6.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-08 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-09 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-10 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-11 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-12 00:00:00', 7.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-13 00:00:00', 7.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-14 00:00:00', 5.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-15 00:00:00', 7.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-16 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-17 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-18 00:00:00', 7.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-19 00:00:00', 6.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-20 00:00:00', 7.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-21 00:00:00', 7.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-22 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-23 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-24 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-25 00:00:00', 5.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-26 00:00:00', 6.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-27 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-28 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-29 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-30 00:00:00', 7.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-01-31 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-01 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-02 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-03 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-04 00:00:00', 6.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-05 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-06 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-07 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-08 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-09 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-10 00:00:00', 5.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-11 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-12 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-13 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-14 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-15 00:00:00', 7.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-16 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-17 00:00:00', 5.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-18 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-19 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-20 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-21 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-22 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-23 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-24 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-25 00:00:00', 5.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-26 00:00:00', 7.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-27 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-02-28 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-01 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-02 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-03 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-04 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-05 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-06 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-07 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-08 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-09 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-10 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-11 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-12 00:00:00', 6.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-13 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-14 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-15 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-16 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-17 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-18 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-19 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-20 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-21 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-22 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-23 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-24 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-25 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-26 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-27 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-28 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-29 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-30 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-03-31 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-01 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-02 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-03 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-04 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-05 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-06 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-07 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-08 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-09 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-10 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-11 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-12 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-13 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-14 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-15 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-16 00:00:00', 5.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-17 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-18 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-19 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-20 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-21 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-22 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-23 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-24 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-25 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-26 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-27 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-28 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-29 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-04-30 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-01 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-02 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-03 00:00:00', 7.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-04 00:00:00', 7.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-05 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-06 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-07 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-08 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-09 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-10 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-11 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-12 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-13 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-14 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-15 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-16 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-17 00:00:00', 4.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-18 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-19 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-20 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-21 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-22 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-23 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-24 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-25 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-26 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-27 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-28 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-29 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-30 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-01 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-02 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-03 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-04 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-05 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-06 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-07 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-08 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-09 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-10 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-11 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-12 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-13 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-14 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-15 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-16 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-17 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-18 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-19 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-20 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-21 00:00:00', 4.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-22 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-23 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-24 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-25 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-26 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-27 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-28 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-29 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-06-30 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-01 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-02 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-03 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-04 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-05 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-06 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-07 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-08 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-09 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-10 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-11 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-12 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-13 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-14 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-15 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-16 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-17 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-18 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-19 00:00:00', 5.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-20 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-21 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-22 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-23 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-24 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-25 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-26 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-27 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-28 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-29 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-30 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-07-31 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-01 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-02 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-03 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-04 00:00:00', 5.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-05 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-06 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-07 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-08 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-09 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-10 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-11 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-12 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-13 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-14 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-15 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-16 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-17 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-18 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-19 00:00:00', 4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-20 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-21 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-22 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-23 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-24 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-25 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-26 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-27 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-28 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-29 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-30 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-08-31 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-01 00:00:00', 1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-02 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-03 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-04 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-05 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-06 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-07 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-08 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-09 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-10 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-11 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-12 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-13 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-14 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-15 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-16 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-17 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-18 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-19 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-20 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-21 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-22 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-23 00:00:00', 1.01800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-24 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-25 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-26 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-27 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-28 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-29 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-09-30 00:00:00', 6.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-01 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-02 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-03 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-04 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-05 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-06 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-07 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-08 00:00:00', 4.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-09 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-10 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-11 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-12 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-13 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-14 00:00:00', 4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-15 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-16 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-17 00:00:00', 1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-18 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-19 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-20 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-21 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-22 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-23 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-24 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-25 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-26 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-27 00:00:00', 1.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-28 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-29 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-30 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-10-31 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-01 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-02 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-03 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-04 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-05 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-06 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-07 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-08 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-09 00:00:00', 5.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-10 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-11 00:00:00', 6.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-12 00:00:00', 5.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-13 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-14 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-15 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-16 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-17 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-18 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-19 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-20 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-21 00:00:00', 5.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-22 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-23 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-24 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-25 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-26 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-27 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-28 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-29 00:00:00', 4.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-11-30 00:00:00', 6.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-01 00:00:00', 7.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-02 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-03 00:00:00', 4.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-04 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-05 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-06 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-07 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-08 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-09 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-10 00:00:00', 7.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-11 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-12 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-13 00:00:00', 5.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-14 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-15 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-16 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-17 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-18 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-19 00:00:00', 7.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-20 00:00:00', 8.94900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-21 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-22 00:00:00', 7.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-23 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-01 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-02 00:00:00', 7.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-03 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-04 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-05 00:00:00', 6.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-06 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-07 00:00:00', 6.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-08 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-09 00:00:00', 5.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-10 00:00:00', 6.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-11 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-12 00:00:00', 5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-13 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-14 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-15 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-16 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-17 00:00:00', 6.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-18 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-19 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-20 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-21 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-22 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-23 00:00:00', 8.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-24 00:00:00', 7.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-25 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-26 00:00:00', 5.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-27 00:00:00', 6.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-28 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-29 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-30 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-01-31 00:00:00', 6.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-01 00:00:00', 5.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-02 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-03 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-04 00:00:00', 7.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-05 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-06 00:00:00', 5.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-07 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-08 00:00:00', 6.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-09 00:00:00', 8.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-10 00:00:00', 5.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-11 00:00:00', 6.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-12 00:00:00', 5.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-13 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-14 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-15 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-16 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-17 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-18 00:00:00', 7.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-19 00:00:00', 7.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-20 00:00:00', 5.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-21 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-22 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-23 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-24 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-25 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-26 00:00:00', 6.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-27 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-02-28 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-01 00:00:00', 5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-02 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-03 00:00:00', 5.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-04 00:00:00', 5.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-05 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-06 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-07 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-08 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-09 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-10 00:00:00', 4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-11 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-12 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-13 00:00:00', 4.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-14 00:00:00', 9.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-15 00:00:00', 5.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-16 00:00:00', 5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-17 00:00:00', 5.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-18 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-19 00:00:00', 4.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-20 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-21 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-22 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-23 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-24 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-25 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-26 00:00:00', 5.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-27 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-28 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-29 00:00:00', 4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-30 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-03-31 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-01 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-02 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-03 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-04 00:00:00', 5.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-05 00:00:00', 5.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-06 00:00:00', 5.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-07 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-08 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-09 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-10 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-11 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-12 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-13 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-14 00:00:00', 6.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-15 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-16 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-17 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-18 00:00:00', 7.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-19 00:00:00', 5.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-20 00:00:00', 6.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-21 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-22 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-23 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-24 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-25 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-26 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-27 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-28 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-29 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-04-30 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-01 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-02 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-03 00:00:00', 5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-04 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-05 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-06 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-07 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-08 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-09 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-10 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-11 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-12 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-13 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-14 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-15 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-16 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-17 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-18 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-19 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-20 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-21 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-22 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-23 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-24 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-25 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-26 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-27 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-28 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-29 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-30 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-05-31 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-01 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-02 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-03 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-04 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-05 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-06 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-07 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-08 00:00:00', 5.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-09 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-10 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-11 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-12 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-13 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-14 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-15 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-16 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-17 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-18 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-19 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-20 00:00:00', 7.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-21 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-22 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-23 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-24 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-25 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-26 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-27 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-28 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-29 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-06-30 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-01 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-02 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-03 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-04 00:00:00', 5.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-05 00:00:00', 4.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-06 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-07 00:00:00', 1.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-08 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-09 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-10 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-11 00:00:00', 5.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-12 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-13 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-14 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-15 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-16 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-17 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-18 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-19 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-20 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-21 00:00:00', 1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-22 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-23 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-24 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-25 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-26 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-27 00:00:00', 1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-28 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-29 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-30 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-07-31 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-01 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-02 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-03 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-04 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-05 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-06 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-07 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-08 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-09 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-10 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-11 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-12 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-13 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-14 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-15 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-16 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-17 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-18 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-19 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-20 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-21 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-22 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-23 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-24 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-25 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-26 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-27 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-28 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-29 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-30 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-08-31 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-01 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-02 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-03 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-04 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-05 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-06 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-07 00:00:00', 4.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-08 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-09 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-10 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-11 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-12 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-13 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-14 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-15 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-16 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-17 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-18 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-19 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-20 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-21 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-22 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-23 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-24 00:00:00', 4.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-25 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-26 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-27 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-28 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-29 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-09-30 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-01 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-02 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-03 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-04 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-05 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-06 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-07 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-08 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-09 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-10 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-11 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-12 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-13 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-14 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-15 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-16 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-17 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-18 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-19 00:00:00', 0.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-20 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-21 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-22 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-23 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-24 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-25 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-26 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-27 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-28 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-29 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-30 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-10-31 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-01 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-02 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-03 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-04 00:00:00', 6.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-05 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-06 00:00:00', 6.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-07 00:00:00', 7.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-08 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-09 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-10 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-11 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-12 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-13 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-14 00:00:00', 5.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-15 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-16 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-17 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-18 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-19 00:00:00', 5.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-20 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-21 00:00:00', 6.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-22 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-23 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-24 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-25 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-26 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-27 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-28 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-29 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-11-30 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-01 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-02 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-03 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-04 00:00:00', 7.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-05 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-06 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-07 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-08 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-09 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-10 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-11 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-12 00:00:00', 6.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-13 00:00:00', 7.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-14 00:00:00', 5.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-15 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-16 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-17 00:00:00', 6.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-18 00:00:00', 6.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-19 00:00:00', 5.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-20 00:00:00', 7.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-21 00:00:00', 6.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-22 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-23 00:00:00', 8.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-24 00:00:00', 8.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-25 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-26 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-27 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-28 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-29 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-30 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1987-12-31 00:00:00', 6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-01 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-02 00:00:00', 5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-03 00:00:00', 5.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-04 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-05 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-06 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-07 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-08 00:00:00', 4.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-09 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-10 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-11 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-12 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-13 00:00:00', 7.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-14 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-15 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-16 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-17 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-18 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-19 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-20 00:00:00', 7.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-21 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-22 00:00:00', 6.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-23 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-24 00:00:00', 4.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-25 00:00:00', 6.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-26 00:00:00', 7.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-27 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-28 00:00:00', 4.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-29 00:00:00', 8.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-30 00:00:00', 5.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-01-31 00:00:00', 9.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-01 00:00:00', 8.06000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-02 00:00:00', 8.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-03 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-04 00:00:00', 5.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-05 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-06 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-07 00:00:00', 5.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-08 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-09 00:00:00', 7.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-10 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-11 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-12 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-13 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-14 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-15 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-16 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-17 00:00:00', 7.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-18 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-19 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-20 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-21 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-22 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-23 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-24 00:00:00', 7.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-25 00:00:00', 7.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-26 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-27 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-28 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-02-29 00:00:00', 7.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-01 00:00:00', 7.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-02 00:00:00', 6.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-03 00:00:00', 6.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-04 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-05 00:00:00', 7.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-06 00:00:00', 5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-07 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-08 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-09 00:00:00', 8.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-10 00:00:00', 5.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-11 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-12 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-13 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-14 00:00:00', 6.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-15 00:00:00', 5.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-16 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-17 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-18 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-19 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-20 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-21 00:00:00', 6.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-22 00:00:00', 6.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-23 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-24 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-25 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-26 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-27 00:00:00', 7.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-28 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-29 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-30 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-03-31 00:00:00', 7.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-01 00:00:00', 7.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-02 00:00:00', 5.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-03 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-04 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-05 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-06 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-07 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-08 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-09 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-10 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-11 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-12 00:00:00', 4.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-13 00:00:00', 4.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-14 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-15 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-16 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-17 00:00:00', 4.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-18 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-19 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-20 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-21 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-22 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-23 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-24 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-25 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-26 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-27 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-28 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-29 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-04-30 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-01 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-02 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-03 00:00:00', 4.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-04 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-05 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-06 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-07 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-08 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-09 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-10 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-11 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-12 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-13 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-14 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-15 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-16 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-17 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-18 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-19 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-20 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-21 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-22 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-23 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-24 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-25 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-26 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-27 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-28 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-29 00:00:00', 5.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-30 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-05-31 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-01 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-02 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-03 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-04 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-05 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-06 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-07 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-08 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-09 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-10 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-11 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-12 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-13 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-14 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-15 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-16 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-17 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-18 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-19 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-20 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-21 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-22 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-23 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-24 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-25 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-26 00:00:00', 5.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-27 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-28 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-29 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-06-30 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-01 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-02 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-03 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-04 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-05 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-06 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-07 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-08 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-09 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-10 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-11 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-12 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-13 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-14 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-15 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-16 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-17 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-18 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-19 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-20 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-21 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-22 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-23 00:00:00', 5.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-24 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-25 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-26 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-27 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-28 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-29 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-30 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-07-31 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-01 00:00:00', 4.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-02 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-03 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-04 00:00:00', 0.619000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-05 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-06 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-07 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-08 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-09 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-10 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-11 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-12 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-13 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-14 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-15 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-16 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-17 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-18 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-19 00:00:00', 0.986000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-20 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-21 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-22 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-23 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-24 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-25 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-26 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-27 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-28 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-29 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-30 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-08-31 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-01 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-02 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-03 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-04 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-05 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-06 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-07 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-08 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-09 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-10 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-11 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-12 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-13 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-14 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-15 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-16 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-17 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-18 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-19 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-20 00:00:00', 0.65700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-21 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-22 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-23 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-24 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-25 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-26 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-27 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-28 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-29 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-09-30 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-01 00:00:00', 0.898000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-02 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-03 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-04 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-05 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-06 00:00:00', 1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-07 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-08 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-09 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-10 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-11 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-12 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-13 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-14 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-15 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-16 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-17 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-18 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-19 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-20 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-21 00:00:00', 4.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-22 00:00:00', 5.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-23 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-24 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-25 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-26 00:00:00', 5.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-27 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-28 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-29 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-30 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-10-31 00:00:00', 5.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-01 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-02 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-03 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-04 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-05 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-06 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-07 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-08 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-09 00:00:00', 5.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-10 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-11 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-12 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-13 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-14 00:00:00', 4.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-15 00:00:00', 5.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-16 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-17 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-18 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-19 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-20 00:00:00', 4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-21 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-22 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-23 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-24 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-25 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-26 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-27 00:00:00', 4.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-28 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-29 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-11-30 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-01 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-02 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-03 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-04 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-05 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-06 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-07 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-08 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-09 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-10 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-11 00:00:00', 5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-12 00:00:00', 6.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-13 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-14 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-15 00:00:00', 6.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-16 00:00:00', 5.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-17 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-18 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-19 00:00:00', 7.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-20 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-21 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-22 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-23 00:00:00', 6.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-24 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-25 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-26 00:00:00', 9.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-27 00:00:00', 8.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-28 00:00:00', 5.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-29 00:00:00', 6.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-30 00:00:00', 6.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1988-12-31 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-01 00:00:00', 4.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-02 00:00:00', 6.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-03 00:00:00', 5.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-04 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-05 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-06 00:00:00', 6.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-07 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-08 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-09 00:00:00', 6.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-10 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-11 00:00:00', 6.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-12 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-13 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-14 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-15 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-16 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-17 00:00:00', 6.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-18 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-19 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-20 00:00:00', 7.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-21 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-22 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-23 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-24 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-25 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-26 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-27 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-28 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-29 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-30 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-01-31 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-01 00:00:00', 7.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-02 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-03 00:00:00', 5.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-04 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-05 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-06 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-07 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-08 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-09 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-10 00:00:00', 5.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-11 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-12 00:00:00', 5.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-13 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-14 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-15 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-16 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-17 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-18 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-19 00:00:00', 6.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-20 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-21 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-22 00:00:00', 7.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-23 00:00:00', 6.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-24 00:00:00', 5.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-25 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-26 00:00:00', 4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-27 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-02-28 00:00:00', 5.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-01 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-02 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-03 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-04 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-05 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-06 00:00:00', 4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-07 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-08 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-09 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-10 00:00:00', 6.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-11 00:00:00', 6.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-12 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-13 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-14 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-15 00:00:00', 6.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-16 00:00:00', 6.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-17 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-18 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-19 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-20 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-21 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-22 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-23 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-24 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-25 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-26 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-27 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-28 00:00:00', 5.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-29 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-30 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-03-31 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-01 00:00:00', 6.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-02 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-03 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-04 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-05 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-06 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-07 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-08 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-09 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-10 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-11 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-12 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-13 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-14 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-15 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-16 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-17 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-18 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-19 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-20 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-21 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-22 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-23 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-24 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-25 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-26 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-27 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-28 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-29 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-04-30 00:00:00', 6.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-01 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-02 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-03 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-04 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-05 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-06 00:00:00', 5.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-07 00:00:00', 7.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-08 00:00:00', 5.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-09 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-10 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-11 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-12 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-13 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-14 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-15 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-16 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-17 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-18 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-19 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-20 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-21 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-22 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-23 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-24 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-25 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-26 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-27 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-28 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-29 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-30 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-05-31 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-01 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-02 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-03 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-04 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-05 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-06 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-07 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-08 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-09 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-10 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-11 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-12 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-13 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-14 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-15 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-16 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-17 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-18 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-19 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-20 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-21 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-22 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-23 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-24 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-25 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-26 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-27 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-28 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-29 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-06-30 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-01 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-02 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-03 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-04 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-05 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-06 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-07 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-08 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-09 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-10 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-11 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-12 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-13 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-14 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-15 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-16 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-17 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-18 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-19 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-20 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-21 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-22 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-23 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-24 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-25 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-26 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-27 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-28 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-29 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-30 00:00:00', 5.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-07-31 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-01 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-02 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-03 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-04 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-05 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-06 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-07 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-08 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-09 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-10 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-11 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-12 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-13 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-14 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-15 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-16 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-17 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-18 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-19 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-20 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-21 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-22 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-23 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-24 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-25 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-26 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-27 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-28 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-29 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-30 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-08-31 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-01 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-02 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-03 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-04 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-05 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-06 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-07 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-08 00:00:00', 0.982999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-09 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-10 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-11 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-12 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-13 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-14 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-15 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-16 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-17 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-18 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-19 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-20 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-21 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-22 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-23 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-24 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-25 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-26 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-27 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-28 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-29 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-09-30 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-01 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-02 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-03 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-04 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-05 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-06 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-07 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-08 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-09 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-10 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-11 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-12 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-13 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-14 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-15 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-16 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-17 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-18 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-19 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-20 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-21 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-22 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-23 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-24 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-25 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-26 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-27 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-28 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-29 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-30 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-10-31 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-01 00:00:00', 6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-02 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-03 00:00:00', 0.958999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-04 00:00:00', 0.978999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-05 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-06 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-07 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-08 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-09 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-10 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-11 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-12 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-13 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-14 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-15 00:00:00', 6.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-16 00:00:00', 7.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-17 00:00:00', 5.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-18 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-19 00:00:00', 6.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-20 00:00:00', 7.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-21 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-22 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-23 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-24 00:00:00', 5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-25 00:00:00', 7.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-26 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-27 00:00:00', 7.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-28 00:00:00', 6.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-29 00:00:00', 5.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-11-30 00:00:00', 5.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-01 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-02 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-03 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-04 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-05 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-06 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-07 00:00:00', 5.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-08 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-09 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-10 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-11 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-12 00:00:00', 6.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-13 00:00:00', 6.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-14 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-15 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-16 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-17 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-18 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-19 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-20 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-21 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-22 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-23 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-24 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-25 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-26 00:00:00', 5.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-27 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-28 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-29 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-30 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1989-12-31 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-01 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-02 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-03 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-04 00:00:00', 6.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-05 00:00:00', 7.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-06 00:00:00', 5.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-07 00:00:00', 5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-08 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-09 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-10 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-11 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-12 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-13 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-14 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-15 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-16 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-17 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-18 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-19 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-20 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-21 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-22 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-23 00:00:00', 6.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-24 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-25 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-26 00:00:00', 6.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-27 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-28 00:00:00', 5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-29 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-30 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-01-31 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-01 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-02 00:00:00', 6.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-03 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-04 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-05 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-06 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-07 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-08 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-09 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-10 00:00:00', 7.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-11 00:00:00', 6.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-12 00:00:00', 5.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-13 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-14 00:00:00', 6.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-15 00:00:00', 8.59099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-16 00:00:00', 7.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-17 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-18 00:00:00', 5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-19 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-20 00:00:00', 5.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-21 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-22 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-23 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-24 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-25 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-26 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-27 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-02-28 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-01 00:00:00', 6.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-02 00:00:00', 6.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-03 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-04 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-05 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-06 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-07 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-08 00:00:00', 6.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-09 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-10 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-11 00:00:00', 7.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-12 00:00:00', 6.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-13 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-14 00:00:00', 7.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-15 00:00:00', 6.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-16 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-17 00:00:00', 6.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-18 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-19 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-20 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-21 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-22 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-23 00:00:00', 5.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-24 00:00:00', 6.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-25 00:00:00', 5.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-26 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-27 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-28 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-29 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-30 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-03-31 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-01 00:00:00', 6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-02 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-03 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-04 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-05 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-06 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-07 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-08 00:00:00', 4.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-09 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-10 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-11 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-12 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-13 00:00:00', 6.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-14 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-15 00:00:00', 5.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-16 00:00:00', 6.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-17 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-18 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-19 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-20 00:00:00', 4.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-21 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-22 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-23 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-24 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-25 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-26 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-27 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-28 00:00:00', 5.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-29 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-04-30 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-01 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-02 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-03 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-04 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-05 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-06 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-07 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-08 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-09 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-10 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-11 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-12 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-13 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-14 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-15 00:00:00', 6.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-16 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-17 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-18 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-19 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-20 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-21 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-22 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-23 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-24 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-25 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-26 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-27 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-28 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-29 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-30 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-05-31 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-01 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-02 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-03 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-04 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-05 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-06 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-07 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-08 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-09 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-10 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-11 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-12 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-13 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-14 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-15 00:00:00', 1.00199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-16 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-17 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-18 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-19 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-20 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-21 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-22 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-23 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-24 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-25 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-26 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-27 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-28 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-29 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-06-30 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-01 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-02 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-03 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-04 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-05 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-06 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-07 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-08 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-09 00:00:00', 5.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-10 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-11 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-12 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-13 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-14 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-15 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-16 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-17 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-18 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-19 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-20 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-21 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-22 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-23 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-24 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-25 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-26 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-27 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-28 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-29 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-30 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-07-31 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-01 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-02 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-03 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-04 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-05 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-06 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-07 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-08 00:00:00', 1.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-09 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-10 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-11 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-12 00:00:00', 5.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-13 00:00:00', 5.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-14 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-15 00:00:00', 0.995000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-16 00:00:00', 0.908999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-17 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-18 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-19 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-20 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-21 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-22 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-23 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-24 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-25 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-26 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-27 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-28 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-29 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-30 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-08-31 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-01 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-02 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-03 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-04 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-05 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-06 00:00:00', 1.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-07 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-08 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-09 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-10 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-11 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-12 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-13 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-14 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-15 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-16 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-17 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-18 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-19 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-20 00:00:00', 1.23500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-21 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-22 00:00:00', 1.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-23 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-24 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-25 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-26 00:00:00', 1.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-27 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-28 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-29 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-09-30 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-01 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-02 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-03 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-04 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-05 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-06 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-07 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-08 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-09 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-10 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-11 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-12 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-13 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-14 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-15 00:00:00', 6.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-16 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-17 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-18 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-19 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-20 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-21 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-22 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-23 00:00:00', 4.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-24 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-25 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-26 00:00:00', 4.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-27 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-28 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-29 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-30 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-10-31 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-01 00:00:00', 5.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-02 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-03 00:00:00', 5.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-04 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-05 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-06 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-07 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-08 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-09 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-10 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-11 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-12 00:00:00', 5.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-13 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-14 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-15 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-16 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-17 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-18 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-19 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-20 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-21 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-22 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-23 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-24 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-25 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-26 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-27 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-28 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-29 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-11-30 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-01 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-02 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-03 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-04 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-05 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-06 00:00:00', 5.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-07 00:00:00', 4.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-08 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-09 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-10 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-11 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-12 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-13 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-14 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-15 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-16 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-17 00:00:00', 8.61400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-18 00:00:00', 6.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-19 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-20 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-21 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-22 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-23 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-24 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-25 00:00:00', 5.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-26 00:00:00', 6.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-27 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-28 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-29 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-30 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1990-12-31 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-01 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-02 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-03 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-04 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-05 00:00:00', 6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-06 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-07 00:00:00', 6.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-08 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-09 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-10 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-11 00:00:00', 0.783999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-12 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-13 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-14 00:00:00', 6.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-15 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-16 00:00:00', 4.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-17 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-18 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-19 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-20 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-21 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-22 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-23 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-24 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-25 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-26 00:00:00', 5.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-27 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-28 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-29 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-30 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-01-31 00:00:00', 6.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-01 00:00:00', 8.19900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-02 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-03 00:00:00', 5.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-04 00:00:00', 6.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-05 00:00:00', 6.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-06 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-07 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-08 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-09 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-10 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-11 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-12 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-13 00:00:00', 4.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-14 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-15 00:00:00', 5.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-16 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-17 00:00:00', 6.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-18 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-19 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-20 00:00:00', 6.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-21 00:00:00', 6.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-22 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-23 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-24 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-25 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-26 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-27 00:00:00', 6.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-02-28 00:00:00', 7.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-01 00:00:00', 5.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-02 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-03 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-04 00:00:00', 5.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-05 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-06 00:00:00', 8.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-07 00:00:00', 7.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-08 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-09 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-10 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-11 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-12 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-13 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-14 00:00:00', 7.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-15 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-16 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-17 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-18 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-19 00:00:00', 5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-20 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-21 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-22 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-23 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-24 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-25 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-26 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-27 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-28 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-29 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-30 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-03-31 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-01 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-02 00:00:00', 5.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-03 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-04 00:00:00', 5.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-05 00:00:00', 5.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-06 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-07 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-08 00:00:00', 6.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-09 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-10 00:00:00', 6.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-11 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-12 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-13 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-14 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-15 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-16 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-17 00:00:00', 6.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-18 00:00:00', 5.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-19 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-20 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-21 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-22 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-23 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-24 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-25 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-26 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-27 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-28 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-29 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-04-30 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-01 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-02 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-03 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-04 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-05 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-06 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-07 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-08 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-09 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-10 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-11 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-12 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-13 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-14 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-15 00:00:00', 4.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-16 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-17 00:00:00', 7.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-18 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-19 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-20 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-21 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-22 00:00:00', 7.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-23 00:00:00', 7.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-24 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-25 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-26 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-27 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-28 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-29 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-30 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-05-31 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-01 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-02 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-03 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-04 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-05 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-06 00:00:00', 4.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-07 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-08 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-09 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-10 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-11 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-12 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-13 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-14 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-15 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-16 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-17 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-18 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-19 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-20 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-21 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-22 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-23 00:00:00', 5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-24 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-25 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-26 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-27 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-28 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-29 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-06-30 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-01 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-02 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-03 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-04 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-05 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-06 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-07 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-08 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-09 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-10 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-11 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-12 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-13 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-14 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-15 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-16 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-17 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-18 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-19 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-20 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-21 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-22 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-23 00:00:00', 1.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-24 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-25 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-26 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-27 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-28 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-29 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-30 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-07-31 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-01 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-02 00:00:00', 1.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-03 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-04 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-05 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-06 00:00:00', 1.18200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-07 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-08 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-09 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-10 00:00:00', 0.953000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-11 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-12 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-13 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-14 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-15 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-16 00:00:00', 0.811999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-17 00:00:00', 0.934000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-18 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-19 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-20 00:00:00', 5.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-21 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-22 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-23 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-24 00:00:00', 1.1390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-25 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-26 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-27 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-28 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-29 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-30 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-08-31 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-01 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-02 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-03 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-04 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-05 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-06 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-07 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-08 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-09 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-10 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-11 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-12 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-13 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-14 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-15 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-16 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-17 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-18 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-19 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-20 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-21 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-22 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-23 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-24 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-25 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-26 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-27 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-28 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-29 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-09-30 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-01 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-02 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-03 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-04 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-05 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-06 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-07 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-08 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-09 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-10 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-11 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-12 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-13 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-14 00:00:00', 0.919000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-15 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-16 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-17 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-18 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-19 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-20 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-21 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-22 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-23 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-24 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-25 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-26 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-27 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-28 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-29 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-30 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-10-31 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-01 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-02 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-03 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-04 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-05 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-06 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-07 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-08 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-09 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-10 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-11 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-12 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-13 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-14 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-15 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-16 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-17 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-18 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-19 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-20 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-21 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-22 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-23 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-24 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-25 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-26 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-27 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-28 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-29 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-11-30 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-01 00:00:00', 8.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-02 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-03 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-04 00:00:00', 6.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-05 00:00:00', 7.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-06 00:00:00', 5.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-07 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-08 00:00:00', 6.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-09 00:00:00', 7.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-10 00:00:00', 9.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-11 00:00:00', 6.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-12 00:00:00', 6.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-13 00:00:00', 5.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-14 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-15 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-16 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-17 00:00:00', 6.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-18 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-19 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-20 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-21 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-22 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-23 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-24 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-25 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-26 00:00:00', 7.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-27 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-28 00:00:00', 8.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-29 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-30 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1991-12-31 00:00:00', 5.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-01 00:00:00', 7.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-02 00:00:00', 6.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-03 00:00:00', 8.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-04 00:00:00', 5.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-05 00:00:00', 4.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-06 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-07 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-08 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-09 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-10 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-11 00:00:00', 8.26799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-12 00:00:00', 4.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-13 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-14 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-15 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-16 00:00:00', 8.74899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-17 00:00:00', 8.00300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-18 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-19 00:00:00', 7.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-20 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-21 00:00:00', 6.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-22 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-23 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-24 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-25 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-26 00:00:00', 4.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-27 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-28 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-29 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-30 00:00:00', 6.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-01-31 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-01 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-02 00:00:00', 6.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-03 00:00:00', 5.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-04 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-05 00:00:00', 6.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-06 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-07 00:00:00', 5.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-08 00:00:00', 6.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-09 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-10 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-11 00:00:00', 7.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-12 00:00:00', 6.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-13 00:00:00', 5.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-14 00:00:00', 7.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-15 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-16 00:00:00', 4.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-17 00:00:00', 4.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-18 00:00:00', 7.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-19 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-20 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-21 00:00:00', 6.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-22 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-23 00:00:00', 9.06200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-24 00:00:00', 8.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-25 00:00:00', 8.20600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-26 00:00:00', 6.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-27 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-28 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-02-29 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-01 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-02 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-03 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-04 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-05 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-06 00:00:00', 6.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-07 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-08 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-09 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-10 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-11 00:00:00', 5.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-12 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-13 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-14 00:00:00', 8.16100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-15 00:00:00', 6.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-16 00:00:00', 5.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-17 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-18 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-19 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-20 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-21 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-22 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-23 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-24 00:00:00', 5.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-25 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-26 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-27 00:00:00', 4.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-28 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-29 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-30 00:00:00', 7.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-03-31 00:00:00', 8.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-01 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-02 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-03 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-04 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-05 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-06 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-07 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-08 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-09 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-10 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-11 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-12 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-13 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-14 00:00:00', 5.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-15 00:00:00', 5.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-16 00:00:00', 4.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-17 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-18 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-19 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-20 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-21 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-22 00:00:00', 5.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-23 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-24 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-25 00:00:00', 6.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-26 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-27 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-28 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-29 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-04-30 00:00:00', 4.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-01 00:00:00', 5.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-02 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-03 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-04 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-05 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-06 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-07 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-08 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-09 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-10 00:00:00', 6.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-11 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-12 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-13 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-14 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-15 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-16 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-17 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-18 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-19 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-20 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-21 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-22 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-23 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-24 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-25 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-26 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-27 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-28 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-29 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-30 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-05-31 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-01 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-02 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-03 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-04 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-05 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-06 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-07 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-08 00:00:00', 1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-09 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-10 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-11 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-12 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-13 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-14 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-15 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-16 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-17 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-18 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-19 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-20 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-21 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-22 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-23 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-24 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-25 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-26 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-27 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-28 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-29 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-06-30 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-01 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-02 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-03 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-04 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-05 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-06 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-07 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-08 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-09 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-10 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-11 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-12 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-13 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-14 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-15 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-16 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-17 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-18 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-19 00:00:00', 0.994000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-20 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-21 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-22 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-23 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-24 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-25 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-26 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-27 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-28 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-29 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-30 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-07-31 00:00:00', 0.878000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-01 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-02 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-03 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-04 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-05 00:00:00', 4.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-06 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-07 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-08 00:00:00', 4.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-09 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-10 00:00:00', 0.981000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-11 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-12 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-13 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-14 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-15 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-16 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-17 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-18 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-19 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-20 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-21 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-22 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-23 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-24 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-25 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-26 00:00:00', 1.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-27 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-28 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-29 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-30 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-08-31 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-01 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-02 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-03 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-04 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-05 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-06 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-07 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-08 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-09 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-10 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-11 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-12 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-13 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-14 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-15 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-16 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-17 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-18 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-19 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-20 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-21 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-22 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-23 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-24 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-25 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-26 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-27 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-28 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-29 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-09-30 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-01 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-02 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-03 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-04 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-05 00:00:00', 1.07400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-06 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-07 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-08 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-09 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-10 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-11 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-12 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-13 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-14 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-15 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-16 00:00:00', 5.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-17 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-18 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-19 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-20 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-21 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-22 00:00:00', 0.922999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-23 00:00:00', 0.873000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-24 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-25 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-26 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-27 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-28 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-29 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-30 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-10-31 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-01 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-02 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-03 00:00:00', 4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-04 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-05 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-06 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-07 00:00:00', 6.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-08 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-09 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-10 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-11 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-12 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-13 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-14 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-15 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-16 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-17 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-18 00:00:00', 5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-19 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-20 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-21 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-22 00:00:00', 7.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-23 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-24 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-25 00:00:00', 5.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-26 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-27 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-28 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-29 00:00:00', 5.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-11-30 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-01 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-02 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-03 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-04 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-05 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-06 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-07 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-08 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-09 00:00:00', 6.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-10 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-11 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-12 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-13 00:00:00', 8.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-14 00:00:00', 6.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-15 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-16 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-17 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-18 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-19 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-20 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-21 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-22 00:00:00', 5.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-23 00:00:00', 4.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-24 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-25 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-26 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-27 00:00:00', 5.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-28 00:00:00', 6.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-29 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-30 00:00:00', 6.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1992-12-31 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-01 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-02 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-03 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-04 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-05 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-06 00:00:00', 6.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-07 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-08 00:00:00', 6.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-09 00:00:00', 7.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-10 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-11 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-12 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-13 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-14 00:00:00', 4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-15 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-16 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-17 00:00:00', 4.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-18 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-19 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-20 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-21 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-22 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-23 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-24 00:00:00', 6.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-25 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-26 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-27 00:00:00', 6.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-28 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-29 00:00:00', 5.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-30 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-01-31 00:00:00', 6.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-01 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-02 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-03 00:00:00', 8.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-04 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-05 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-06 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-07 00:00:00', 6.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-08 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-09 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-10 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-11 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-12 00:00:00', 5.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-13 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-14 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-15 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-16 00:00:00', 7.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-17 00:00:00', 5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-18 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-19 00:00:00', 7.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-20 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-21 00:00:00', 7.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-22 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-23 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-24 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-25 00:00:00', 4.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-26 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-27 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-02-28 00:00:00', 5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-01 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-02 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-03 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-04 00:00:00', 7.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-05 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-06 00:00:00', 8.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-07 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-08 00:00:00', 6.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-09 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-10 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-11 00:00:00', 5.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-12 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-13 00:00:00', 6.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-14 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-15 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-16 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-17 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-18 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-19 00:00:00', 7.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-20 00:00:00', 5.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-21 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-22 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-23 00:00:00', 6.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-24 00:00:00', 4.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-25 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-26 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-27 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-28 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-29 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-30 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-03-31 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-01 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-02 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-03 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-04 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-05 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-06 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-07 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-08 00:00:00', 5.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-09 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-10 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-11 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-12 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-13 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-14 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-15 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-16 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-17 00:00:00', 6.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-18 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-19 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-20 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-21 00:00:00', 4.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-22 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-23 00:00:00', 6.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-24 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-25 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-26 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-27 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-28 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-29 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-04-30 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-01 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-02 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-03 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-04 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-05 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-06 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-07 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-08 00:00:00', 6.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-09 00:00:00', 4.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-10 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-11 00:00:00', 1.10300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-12 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-13 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-14 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-15 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-16 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-17 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-18 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-19 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-20 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-21 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-22 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-23 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-24 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-25 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-26 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-27 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-28 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-29 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-30 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-05-31 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-01 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-02 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-03 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-04 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-05 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-06 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-07 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-08 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-09 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-10 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-11 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-12 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-13 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-14 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-15 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-16 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-17 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-18 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-19 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-20 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-21 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-22 00:00:00', 5.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-23 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-24 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-25 00:00:00', 0.894999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-26 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-27 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-28 00:00:00', 1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-29 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-06-30 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-01 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-02 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-03 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-04 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-05 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-06 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-07 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-08 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-09 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-10 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-11 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-12 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-13 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-14 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-15 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-16 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-17 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-18 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-19 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-20 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-21 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-22 00:00:00', 5.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-23 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-24 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-25 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-26 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-27 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-28 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-29 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-30 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-07-31 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-01 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-02 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-03 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-04 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-05 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-06 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-07 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-08 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-09 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-10 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-11 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-12 00:00:00', 1.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-13 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-14 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-15 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-16 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-17 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-18 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-19 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-20 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-21 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-22 00:00:00', 1.21599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-23 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-24 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-25 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-26 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-27 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-28 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-29 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-30 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-08-31 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-01 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-02 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-03 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-04 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-05 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-06 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-07 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-08 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-09 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-10 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-11 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-12 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-13 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-14 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-15 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-16 00:00:00', 5.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-17 00:00:00', 0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-18 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-19 00:00:00', 0.925999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-20 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-21 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-22 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-23 00:00:00', 5.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-24 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-25 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-26 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-27 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-28 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-29 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-09-30 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-01 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-02 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-03 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-04 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-05 00:00:00', 5.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-06 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-07 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-08 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-09 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-10 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-11 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-12 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-13 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-14 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-15 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-16 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-17 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-18 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-19 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-20 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-21 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-22 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-23 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-24 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-25 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-26 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-27 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-28 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-29 00:00:00', 5.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-30 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-10-31 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-01 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-02 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-03 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-04 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-05 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-06 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-07 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-08 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-09 00:00:00', 6.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-10 00:00:00', 7.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-11 00:00:00', 7.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-12 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-13 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-14 00:00:00', 5.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-15 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-16 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-17 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-18 00:00:00', 5.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-19 00:00:00', 5.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-20 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-21 00:00:00', 4.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-22 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-23 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-24 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-25 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-26 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-27 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-28 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-29 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-11-30 00:00:00', 5.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-01 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-02 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-03 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-04 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-05 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-06 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-07 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-08 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-09 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-10 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-11 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-12 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-13 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-14 00:00:00', 6.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-15 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-16 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-17 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-18 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-19 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-20 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-21 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-22 00:00:00', 6.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-23 00:00:00', 6.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-24 00:00:00', 6.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-25 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-26 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-27 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-28 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-29 00:00:00', 5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-30 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1993-12-31 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-01 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-02 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-03 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-04 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-05 00:00:00', 8.40699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-06 00:00:00', 6.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-07 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-08 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-09 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-10 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-11 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-12 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-13 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-14 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-15 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-16 00:00:00', 6.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-17 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-18 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-19 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-20 00:00:00', 7.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-21 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-22 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-23 00:00:00', 7.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-24 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-25 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-26 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-27 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-28 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-29 00:00:00', 6.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-30 00:00:00', 5.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-01-31 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-01 00:00:00', 10.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-02 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-03 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-04 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-05 00:00:00', 8.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-06 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-07 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-08 00:00:00', 7.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-09 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-10 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-11 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-12 00:00:00', 8.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-13 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-14 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-15 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-16 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-17 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-18 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-19 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-20 00:00:00', 4.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-21 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-22 00:00:00', 7.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-23 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-24 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-25 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-26 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-27 00:00:00', 6.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-02-28 00:00:00', 7.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-01 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-02 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-03 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-04 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-05 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-06 00:00:00', 5.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-07 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-08 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-09 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-10 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-11 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-12 00:00:00', 5.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-13 00:00:00', 7.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-14 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-15 00:00:00', 6.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-16 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-17 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-18 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-19 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-20 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-21 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-22 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-23 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-24 00:00:00', 6.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-25 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-26 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-27 00:00:00', 6.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-28 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-29 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-30 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-03-31 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-01 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-02 00:00:00', 8.08100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-03 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-04 00:00:00', 5.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-05 00:00:00', 6.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-06 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-07 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-08 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-09 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-10 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-11 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-12 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-13 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-14 00:00:00', 1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-15 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-16 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-17 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-18 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-19 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-20 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-21 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-22 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-23 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-24 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-25 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-26 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-27 00:00:00', 5.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-28 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-29 00:00:00', 5.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-04-30 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-01 00:00:00', 6.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-02 00:00:00', 5.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-03 00:00:00', 6.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-04 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-05 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-06 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-07 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-08 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-09 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-10 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-11 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-12 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-13 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-14 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-15 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-16 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-17 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-18 00:00:00', 5.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-19 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-20 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-21 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-22 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-23 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-24 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-25 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-26 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-27 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-28 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-29 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-30 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-05-31 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-01 00:00:00', 0.823000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-02 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-03 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-04 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-05 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-06 00:00:00', 4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-07 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-08 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-09 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-10 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-11 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-12 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-13 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-14 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-15 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-16 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-17 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-18 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-19 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-20 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-21 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-22 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-23 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-24 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-25 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-26 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-27 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-28 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-29 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-06-30 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-01 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-02 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-03 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-04 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-05 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-06 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-07 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-08 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-09 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-10 00:00:00', 5.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-11 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-12 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-13 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-14 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-15 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-16 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-17 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-18 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-19 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-20 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-21 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-22 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-23 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-24 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-25 00:00:00', 0.927999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-26 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-27 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-28 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-29 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-30 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-07-31 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-01 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-02 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-03 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-04 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-05 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-06 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-07 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-08 00:00:00', 5.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-09 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-10 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-11 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-12 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-13 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-14 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-15 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-16 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-17 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-18 00:00:00', 1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-19 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-20 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-21 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-22 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-23 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-24 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-25 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-26 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-27 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-28 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-29 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-30 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-08-31 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-01 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-02 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-03 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-04 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-05 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-06 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-07 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-08 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-09 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-10 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-11 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-12 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-13 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-14 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-15 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-16 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-17 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-18 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-19 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-20 00:00:00', 1.14600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-21 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-22 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-23 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-24 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-25 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-26 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-27 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-28 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-29 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-09-30 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-01 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-02 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-03 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-04 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-05 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-06 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-07 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-08 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-09 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-10 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-11 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-12 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-13 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-14 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-15 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-16 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-17 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-18 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-19 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-20 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-21 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-22 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-23 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-24 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-25 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-26 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-27 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-28 00:00:00', 1.02799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-29 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-30 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-10-31 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-01 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-02 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-03 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-04 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-05 00:00:00', 6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-06 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-07 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-08 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-09 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-10 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-11 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-12 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-13 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-14 00:00:00', 5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-15 00:00:00', 5.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-16 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-17 00:00:00', 5.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-18 00:00:00', 6.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-19 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-20 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-21 00:00:00', 5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-22 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-23 00:00:00', 7.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-24 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-25 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-26 00:00:00', 7.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-27 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-28 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-29 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-11-30 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-01 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-02 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-03 00:00:00', 6.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-04 00:00:00', 8.32199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-05 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-06 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-07 00:00:00', 6.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-08 00:00:00', 4.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-09 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-10 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-11 00:00:00', 6.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-12 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-13 00:00:00', 6.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-14 00:00:00', 5.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-15 00:00:00', 5.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-16 00:00:00', 7.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-17 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-18 00:00:00', 6.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-19 00:00:00', 5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-20 00:00:00', 8.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-21 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-22 00:00:00', 5.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-23 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-24 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-25 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-26 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-27 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-28 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-29 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-30 00:00:00', 7.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1994-12-31 00:00:00', 6.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-01 00:00:00', 6.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-02 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-03 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-04 00:00:00', 5.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-05 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-06 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-07 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-08 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-09 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-10 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-11 00:00:00', 7.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-12 00:00:00', 7.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-13 00:00:00', 6.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-14 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-15 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-16 00:00:00', 5.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-17 00:00:00', 9.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-18 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-19 00:00:00', 4.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-20 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-21 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-22 00:00:00', 5.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-23 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-24 00:00:00', 5.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-25 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-26 00:00:00', 7.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-27 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-28 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-29 00:00:00', 6.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-30 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-01-31 00:00:00', 5.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-01 00:00:00', 5.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-02 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-03 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-04 00:00:00', 5.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-05 00:00:00', 9.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-06 00:00:00', 6.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-07 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-08 00:00:00', 7.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-09 00:00:00', 7.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-10 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-11 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-12 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-13 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-14 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-15 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-16 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-17 00:00:00', 6.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-18 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-19 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-20 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-21 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-22 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-23 00:00:00', 6.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-24 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-25 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-26 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-27 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-02-28 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-01 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-02 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-03 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-04 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-05 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-06 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-07 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-08 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-09 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-10 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-11 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-12 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-13 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-14 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-15 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-16 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-17 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-18 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-19 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-20 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-21 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-22 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-23 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-24 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-25 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-26 00:00:00', 7.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-27 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-28 00:00:00', 5.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-29 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-30 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-03-31 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-01 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-02 00:00:00', 5.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-03 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-04 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-05 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-06 00:00:00', 4.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-07 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-08 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-09 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-10 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-11 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-12 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-13 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-14 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-15 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-16 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-17 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-18 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-19 00:00:00', 4.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-20 00:00:00', 6.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-21 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-22 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-23 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-24 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-25 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-26 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-27 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-28 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-29 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-04-30 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-01 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-02 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-03 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-04 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-05 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-06 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-07 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-08 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-09 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-10 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-11 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-12 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-13 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-14 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-15 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-16 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-17 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-18 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-19 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-20 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-21 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-22 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-23 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-24 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-25 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-26 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-27 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-28 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-29 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-30 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-05-31 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-01 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-02 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-03 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-04 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-05 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-06 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-07 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-08 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-09 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-10 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-11 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-12 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-13 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-14 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-15 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-16 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-17 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-18 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-19 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-20 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-21 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-22 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-23 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-24 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-25 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-26 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-27 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-28 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-29 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-06-30 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-01 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-02 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-03 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-04 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-05 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-06 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-07 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-08 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-09 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-10 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-11 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-12 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-13 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-14 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-15 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-16 00:00:00', 0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-17 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-18 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-19 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-20 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-21 00:00:00', 1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-22 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-23 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-24 00:00:00', 5.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-25 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-26 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-27 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-28 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-29 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-30 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-07-31 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-01 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-02 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-03 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-04 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-05 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-06 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-07 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-08 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-09 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-10 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-11 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-12 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-13 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-14 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-15 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-16 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-17 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-18 00:00:00', 1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-19 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-20 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-21 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-22 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-23 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-24 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-25 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-26 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-27 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-28 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-29 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-30 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-08-31 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-01 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-02 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-03 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-04 00:00:00', 1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-05 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-06 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-07 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-08 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-09 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-10 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-11 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-12 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-13 00:00:00', 1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-14 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-15 00:00:00', 0.962000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-16 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-17 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-18 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-19 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-20 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-21 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-22 00:00:00', 7.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-23 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-24 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-25 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-26 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-27 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-28 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-29 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-09-30 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-01 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-02 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-03 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-04 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-05 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-06 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-07 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-08 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-09 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-10 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-11 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-12 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-13 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-14 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-15 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-16 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-17 00:00:00', 5.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-18 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-19 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-20 00:00:00', 0.680999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-21 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-22 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-23 00:00:00', 5.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-24 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-25 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-26 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-27 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-28 00:00:00', 0.949999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-29 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-30 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-10-31 00:00:00', 5.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-01 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-02 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-03 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-04 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-05 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-06 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-07 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-08 00:00:00', 5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-09 00:00:00', 5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-10 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-11 00:00:00', 5.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-12 00:00:00', 5.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-13 00:00:00', 4.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-14 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-15 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-16 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-17 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-18 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-19 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-20 00:00:00', 4.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-21 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-22 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-23 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-24 00:00:00', 7.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-25 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-26 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-27 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-28 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-29 00:00:00', 5.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-11-30 00:00:00', 5.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-01 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-02 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-03 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-04 00:00:00', 6.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-05 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-06 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-07 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-08 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-09 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-10 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-11 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-12 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-13 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-14 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-15 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-16 00:00:00', 7.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-17 00:00:00', 6.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-18 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-19 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-20 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-21 00:00:00', 5.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-22 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-23 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-24 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-25 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-26 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-27 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-28 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-29 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-30 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1995-12-31 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-01 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-02 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-03 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-04 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-05 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-06 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-07 00:00:00', 5.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-08 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-09 00:00:00', 6.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-10 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-11 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-12 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-13 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-14 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-15 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-16 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-17 00:00:00', 6.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-18 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-19 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-20 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-21 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-22 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-23 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-24 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-25 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-26 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-27 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-28 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-29 00:00:00', 6.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-30 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-01-31 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-01 00:00:00', 5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-02 00:00:00', 6.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-03 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-04 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-05 00:00:00', 7.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-06 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-07 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-08 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-09 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-10 00:00:00', 8.33800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-11 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-12 00:00:00', 6.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-13 00:00:00', 5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-14 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-15 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-16 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-17 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-18 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-19 00:00:00', 5.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-20 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-21 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-22 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-23 00:00:00', 6.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-24 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-25 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-26 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-27 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-28 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-02-29 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-01 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-02 00:00:00', 8.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-03 00:00:00', 7.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-04 00:00:00', 6.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-05 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-06 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-07 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-08 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-09 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-10 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-11 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-12 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-13 00:00:00', 5.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-14 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-15 00:00:00', 5.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-16 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-17 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-18 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-19 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-20 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-21 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-22 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-23 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-24 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-25 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-26 00:00:00', 6.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-27 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-28 00:00:00', 4.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-29 00:00:00', 4.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-30 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-03-31 00:00:00', 6.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-01 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-02 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-03 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-04 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-05 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-06 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-07 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-08 00:00:00', 5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-09 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-10 00:00:00', 5.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-11 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-12 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-13 00:00:00', 8.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-14 00:00:00', 7.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-15 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-16 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-17 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-18 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-19 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-20 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-21 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-22 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-23 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-24 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-25 00:00:00', 6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-26 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-27 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-28 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-29 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-04-30 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-01 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-02 00:00:00', 4.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-03 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-04 00:00:00', 1.2489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-05 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-06 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-07 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-08 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-09 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-10 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-11 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-12 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-13 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-14 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-15 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-16 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-17 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-18 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-19 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-20 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-21 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-22 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-23 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-24 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-25 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-26 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-27 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-28 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-29 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-30 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-05-31 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-01 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-02 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-03 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-04 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-05 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-06 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-07 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-08 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-09 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-10 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-11 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-12 00:00:00', 4.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-13 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-14 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-15 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-16 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-17 00:00:00', 1.27799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-18 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-19 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-20 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-21 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-22 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-23 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-24 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-25 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-26 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-27 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-28 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-29 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-06-30 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-01 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-02 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-03 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-04 00:00:00', 1.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-05 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-06 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-07 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-08 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-09 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-10 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-11 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-12 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-13 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-14 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-15 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-16 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-17 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-18 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-19 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-20 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-21 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-22 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-23 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-24 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-25 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-26 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-27 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-28 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-29 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-30 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-07-31 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-01 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-02 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-03 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-04 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-05 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-06 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-07 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-08 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-09 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-10 00:00:00', 1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-11 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-12 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-13 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-14 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-15 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-16 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-17 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-18 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-19 00:00:00', 0.986000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-20 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-21 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-22 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-23 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-24 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-25 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-26 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-27 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-28 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-29 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-30 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-08-31 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-01 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-02 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-03 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-04 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-05 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-06 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-07 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-08 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-09 00:00:00', 4.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-10 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-11 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-12 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-13 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-14 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-15 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-16 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-17 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-18 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-19 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-20 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-21 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-22 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-23 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-24 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-25 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-26 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-27 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-28 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-29 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-09-30 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-01 00:00:00', 5.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-02 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-03 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-04 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-05 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-06 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-07 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-08 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-09 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-10 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-11 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-12 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-13 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-14 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-15 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-16 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-17 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-18 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-19 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-20 00:00:00', 1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-21 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-22 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-23 00:00:00', 5.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-24 00:00:00', 5.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-25 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-26 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-27 00:00:00', 6.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-28 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-29 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-30 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-10-31 00:00:00', 7.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-01 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-02 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-03 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-04 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-05 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-06 00:00:00', 4.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-07 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-08 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-09 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-10 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-11 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-12 00:00:00', 4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-13 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-14 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-15 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-16 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-17 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-18 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-19 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-20 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-21 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-22 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-23 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-24 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-25 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-26 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-27 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-28 00:00:00', 5.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-29 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-11-30 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-01 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-02 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-03 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-04 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-05 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-06 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-07 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-08 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-09 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-10 00:00:00', 4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-11 00:00:00', 5.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-12 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-13 00:00:00', 5.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-14 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-15 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-16 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-17 00:00:00', 8.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-18 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-19 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-20 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-21 00:00:00', 6.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-22 00:00:00', 6.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-23 00:00:00', 6.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-24 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-25 00:00:00', 7.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-26 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-27 00:00:00', 7.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-28 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-29 00:00:00', 7.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-30 00:00:00', 5.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1996-12-31 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-01 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-02 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-03 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-04 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-05 00:00:00', 5.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-06 00:00:00', 5.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-07 00:00:00', 6.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-08 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-09 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-10 00:00:00', 6.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-11 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-12 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-13 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-14 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-15 00:00:00', 5.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-16 00:00:00', 8.23700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-17 00:00:00', 5.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-18 00:00:00', 6.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-19 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-20 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-21 00:00:00', 4.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-22 00:00:00', 5.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-23 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-24 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-25 00:00:00', 5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-26 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-27 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-28 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-29 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-30 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-01-31 00:00:00', 6.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-01 00:00:00', 7.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-02 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-03 00:00:00', 5.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-04 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-05 00:00:00', 6.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-06 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-07 00:00:00', 5.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-08 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-09 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-10 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-11 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-12 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-13 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-14 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-15 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-16 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-17 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-18 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-19 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-20 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-21 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-22 00:00:00', 7.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-23 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-24 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-25 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-26 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-27 00:00:00', 7.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-02-28 00:00:00', 6.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-01 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-02 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-03 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-04 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-05 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-06 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-07 00:00:00', 7.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-08 00:00:00', 7.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-09 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-10 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-11 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-12 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-13 00:00:00', 5.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-14 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-15 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-16 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-17 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-18 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-19 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-20 00:00:00', 6.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-21 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-22 00:00:00', 6.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-23 00:00:00', 5.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-24 00:00:00', 7.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-25 00:00:00', 8.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-26 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-27 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-28 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-29 00:00:00', 7.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-30 00:00:00', 5.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-03-31 00:00:00', 5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-01 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-02 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-03 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-04 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-05 00:00:00', 6.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-06 00:00:00', 7.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-07 00:00:00', 5.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-08 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-09 00:00:00', 5.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-10 00:00:00', 8.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-11 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-12 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-13 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-14 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-15 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-16 00:00:00', 5.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-17 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-18 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-19 00:00:00', 6.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-20 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-21 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-22 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-23 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-24 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-25 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-26 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-27 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-28 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-29 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-04-30 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-01 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-02 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-03 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-04 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-05 00:00:00', 7.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-06 00:00:00', 6.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-07 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-08 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-09 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-10 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-11 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-12 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-13 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-14 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-15 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-16 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-17 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-18 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-19 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-20 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-21 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-22 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-23 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-24 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-25 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-26 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-27 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-28 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-29 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-30 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-05-31 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-01 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-02 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-03 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-04 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-05 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-06 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-07 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-08 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-09 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-10 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-11 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-12 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-13 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-14 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-15 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-16 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-17 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-18 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-19 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-20 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-21 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-22 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-23 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-24 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-25 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-26 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-27 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-28 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-29 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-06-30 00:00:00', 1.03199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-01 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-02 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-03 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-04 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-05 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-06 00:00:00', 1.08399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-07 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-08 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-09 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-10 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-11 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-12 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-13 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-14 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-15 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-16 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-17 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-18 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-19 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-20 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-21 00:00:00', 5.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-22 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-23 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-24 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-25 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-26 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-27 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-28 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-29 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-30 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-07-31 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-01 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-02 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-03 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-04 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-05 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-06 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-07 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-08 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-09 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-10 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-11 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-12 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-13 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-14 00:00:00', 1.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-15 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-16 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-17 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-18 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-19 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-20 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-21 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-22 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-23 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-24 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-25 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-26 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-27 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-28 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-29 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-30 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-08-31 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-01 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-02 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-03 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-04 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-05 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-06 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-07 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-08 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-09 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-10 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-11 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-12 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-13 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-14 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-15 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-16 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-17 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-18 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-19 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-20 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-21 00:00:00', 0.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-22 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-23 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-24 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-25 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-26 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-27 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-28 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-29 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-09-30 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-01 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-02 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-03 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-04 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-05 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-06 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-07 00:00:00', 4.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-08 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-09 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-10 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-11 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-12 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-13 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-14 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-15 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-16 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-17 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-18 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-19 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-20 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-21 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-22 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-23 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-24 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-25 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-26 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-27 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-28 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-29 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-30 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-10-31 00:00:00', 4.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-01 00:00:00', 6.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-02 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-03 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-04 00:00:00', 5.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-05 00:00:00', 4.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-06 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-07 00:00:00', 5.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-08 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-09 00:00:00', 0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-10 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-11 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-12 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-13 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-14 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-15 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-16 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-17 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-18 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-19 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-20 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-21 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-22 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-23 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-24 00:00:00', 5.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-25 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-26 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-27 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-28 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-29 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-11-30 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-01 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-02 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-03 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-04 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-05 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-06 00:00:00', 5.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-07 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-08 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-09 00:00:00', 6.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-10 00:00:00', 7.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-11 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-12 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-13 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-14 00:00:00', 7.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-15 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-16 00:00:00', 6.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-17 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-18 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-19 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-20 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-21 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-22 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-23 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-24 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-25 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-26 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-27 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-28 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-29 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-30 00:00:00', 6.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1997-12-31 00:00:00', 6.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-01 00:00:00', 7.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-02 00:00:00', 6.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-03 00:00:00', 5.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-04 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-05 00:00:00', 6.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-06 00:00:00', 7.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-07 00:00:00', 5.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-08 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-09 00:00:00', 6.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-10 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-11 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-12 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-13 00:00:00', 9.03899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-14 00:00:00', 6.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-15 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-16 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-17 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-18 00:00:00', 7.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-19 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-20 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-21 00:00:00', 6.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-22 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-23 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-24 00:00:00', 7.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-25 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-26 00:00:00', 6.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-27 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-28 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-29 00:00:00', 7.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-30 00:00:00', 7.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-01-31 00:00:00', 6.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-01 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-02 00:00:00', 6.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-03 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-04 00:00:00', 6.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-05 00:00:00', 5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-06 00:00:00', 6.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-07 00:00:00', 8.02200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-08 00:00:00', 9.30799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-09 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-10 00:00:00', 5.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-11 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-12 00:00:00', 6.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-13 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-14 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-15 00:00:00', 6.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-16 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-17 00:00:00', 5.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-18 00:00:00', 6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-19 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-20 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-21 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-22 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-23 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-24 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-25 00:00:00', 4.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-26 00:00:00', 5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-27 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-02-28 00:00:00', 6.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-01 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-02 00:00:00', 6.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-03 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-04 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-05 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-06 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-07 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-08 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-09 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-10 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-11 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-12 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-13 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-14 00:00:00', 5.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-15 00:00:00', 6.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-16 00:00:00', 5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-17 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-18 00:00:00', 7.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-19 00:00:00', 7.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-20 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-21 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-22 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-23 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-24 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-25 00:00:00', 7.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-26 00:00:00', 4.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-27 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-28 00:00:00', 1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-29 00:00:00', 6.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-30 00:00:00', 9.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-03-31 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-01 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-02 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-03 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-04 00:00:00', 7.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-05 00:00:00', 5.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-06 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-07 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-08 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-09 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-10 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-11 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-12 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-13 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-14 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-15 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-16 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-17 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-18 00:00:00', 4.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-19 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-20 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-21 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-22 00:00:00', 5.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-23 00:00:00', 5.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-24 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-25 00:00:00', 5.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-26 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-27 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-28 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-29 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-04-30 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-01 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-02 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-03 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-04 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-05 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-06 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-07 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-08 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-09 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-10 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-11 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-12 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-13 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-14 00:00:00', 6.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-15 00:00:00', 5.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-16 00:00:00', 4.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-17 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-18 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-19 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-20 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-21 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-22 00:00:00', 7.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-23 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-24 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-25 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-26 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-27 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-28 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-29 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-30 00:00:00', 5.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-05-31 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-01 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-02 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-03 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-04 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-05 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-06 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-07 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-08 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-09 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-10 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-11 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-12 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-13 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-14 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-15 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-16 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-17 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-18 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-19 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-20 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-21 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-22 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-23 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-24 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-25 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-26 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-27 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-28 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-29 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-06-30 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-01 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-02 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-03 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-04 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-05 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-06 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-07 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-08 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-09 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-10 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-11 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-12 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-13 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-14 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-15 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-16 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-17 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-18 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-19 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-20 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-21 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-22 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-23 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-24 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-25 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-26 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-27 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-28 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-29 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-30 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-07-31 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-01 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-02 00:00:00', 0.972999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-03 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-04 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-05 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-06 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-07 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-08 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-09 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-10 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-11 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-12 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-13 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-14 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-15 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-16 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-17 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-18 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-19 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-20 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-21 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-22 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-23 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-24 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-25 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-26 00:00:00', 0.903999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-27 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-28 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-29 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-30 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-08-31 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-01 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-02 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-03 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-04 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-05 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-06 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-07 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-08 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-09 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-10 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-11 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-12 00:00:00', 4.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-13 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-14 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-15 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-16 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-17 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-18 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-19 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-20 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-21 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-22 00:00:00', 1.20899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-23 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-24 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-25 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-26 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-27 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-28 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-29 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-09-30 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-01 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-02 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-03 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-04 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-05 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-06 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-07 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-08 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-09 00:00:00', 7.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-10 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-11 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-12 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-13 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-14 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-15 00:00:00', 1.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-16 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-17 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-18 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-19 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-20 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-21 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-22 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-23 00:00:00', 0.982999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-24 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-25 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-26 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-27 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-28 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-29 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-30 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-10-31 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-01 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-02 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-03 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-04 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-05 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-06 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-07 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-08 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-09 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-10 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-11 00:00:00', 5.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-12 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-13 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-14 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-15 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-16 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-17 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-18 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-19 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-20 00:00:00', 4.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-21 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-22 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-23 00:00:00', 1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-24 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-25 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-26 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-27 00:00:00', 4.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-28 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-29 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-11-30 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-01 00:00:00', 7.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-02 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-03 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-04 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-05 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-06 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-07 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-08 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-09 00:00:00', 5.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-10 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-11 00:00:00', 6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-12 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-13 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-14 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-15 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-16 00:00:00', 6.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-17 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-18 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-19 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-20 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-21 00:00:00', 7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-22 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-23 00:00:00', 6.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-24 00:00:00', 7.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-25 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-26 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-27 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-28 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-29 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-30 00:00:00', 7.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1998-12-31 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-02 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-04 00:00:00', 6.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-06 00:00:00', 7.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-08 00:00:00', 7.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-10 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-12 00:00:00', 6.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-14 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-16 00:00:00', 8.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-18 00:00:00', 6.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-20 00:00:00', 6.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-22 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-24 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-26 00:00:00', 7.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-28 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-30 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-01 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-03 00:00:00', 5.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-05 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-07 00:00:00', 7.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-09 00:00:00', 7.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-11 00:00:00', 9.67300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-13 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-15 00:00:00', 6.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-17 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-19 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-21 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-23 00:00:00', 5.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-25 00:00:00', 7.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-27 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-01 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-03 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-04 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-05 00:00:00', 4.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-06 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-07 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-08 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-09 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-10 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-11 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-12 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-13 00:00:00', 6.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-14 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-15 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-16 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-17 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-18 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-19 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-20 00:00:00', 6.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-21 00:00:00', 7.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-22 00:00:00', 6.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-23 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-24 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-25 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-26 00:00:00', 5.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-27 00:00:00', 7.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-28 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-29 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-30 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-03-31 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-01 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-02 00:00:00', 5.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-03 00:00:00', 7.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-04 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-05 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-06 00:00:00', 5.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-07 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-08 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-09 00:00:00', 6.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-10 00:00:00', 5.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-11 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-12 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-13 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-14 00:00:00', 6.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-15 00:00:00', 7.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-16 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-17 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-18 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-19 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-20 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-21 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-22 00:00:00', 4.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-23 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-24 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-25 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-26 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-27 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-28 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-29 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-04-30 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-01 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-02 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-03 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-04 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-05 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-06 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-07 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-08 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-09 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-10 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-11 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-12 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-13 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-14 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-15 00:00:00', 4.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-16 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-17 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-18 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-19 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-20 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-21 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-22 00:00:00', 6.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-23 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-24 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-25 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-26 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-27 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-28 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-29 00:00:00', 1.18200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-30 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-05-31 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-01 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-02 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-03 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-04 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-05 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-06 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-07 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-08 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-09 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-10 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-11 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-12 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-13 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-14 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-15 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-16 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-17 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-18 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-19 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-20 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-21 00:00:00', 1.12699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-22 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-23 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-24 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-25 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-26 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-27 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-28 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-29 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-06-30 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-01 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-02 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-03 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-04 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-05 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-06 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-07 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-08 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-09 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-10 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-11 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-12 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-13 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-14 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-15 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-16 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-17 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-18 00:00:00', 5.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-19 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-20 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-21 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-22 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-23 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-24 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-25 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-26 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-27 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-28 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-29 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-30 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-07-31 00:00:00', 1.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-01 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-02 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-03 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-04 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-05 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-06 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-07 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-08 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-09 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-10 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-11 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-12 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-13 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-14 00:00:00', 1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-15 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-16 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-17 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-18 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-19 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-20 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-21 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-22 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-23 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-24 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-25 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-26 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-27 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-28 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-29 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-30 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-08-31 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-01 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-02 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-03 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-04 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-05 00:00:00', 4.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-06 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-07 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-08 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-09 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-10 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-11 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-12 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-13 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-14 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-15 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-16 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-17 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-18 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-19 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-20 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-21 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-22 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-23 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-24 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-25 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-26 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-27 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-28 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-29 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-09-30 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-01 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-02 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-03 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-04 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-05 00:00:00', 0.708000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-06 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-07 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-08 00:00:00', 1.20599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-09 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-10 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-11 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-12 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-13 00:00:00', 5.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-14 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-15 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-16 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-17 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-18 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-19 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-20 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-21 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-22 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-23 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-24 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-25 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-26 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-27 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-28 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-29 00:00:00', 6.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-30 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-10-31 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-01 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-02 00:00:00', 5.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-03 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-04 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-05 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-06 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-07 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-08 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-09 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-10 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-11 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-12 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-13 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-14 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-15 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-16 00:00:00', 5.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-17 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-18 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-19 00:00:00', 6.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-20 00:00:00', 5.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-21 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-22 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-23 00:00:00', 4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-24 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-25 00:00:00', 7.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-26 00:00:00', 8.13099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-27 00:00:00', 6.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-28 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-29 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-11-30 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-01 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-02 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-03 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-04 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-05 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-06 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-07 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-08 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-09 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-10 00:00:00', 5.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-11 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-12 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-13 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-14 00:00:00', 6.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-15 00:00:00', 5.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-16 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-17 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-18 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-19 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-20 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-21 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-22 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-23 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-24 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-25 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-26 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-27 00:00:00', 6.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-28 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-29 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-30 00:00:00', 5.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '1999-12-31 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-01 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-02 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-03 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-04 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-05 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-06 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-07 00:00:00', 6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-08 00:00:00', 6.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-09 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-10 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-11 00:00:00', 5.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-12 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-13 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-14 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-15 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-16 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-17 00:00:00', 6.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-18 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-19 00:00:00', 8.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-20 00:00:00', 6.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-21 00:00:00', 6.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-22 00:00:00', 6.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-23 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-24 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-25 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-26 00:00:00', 6.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-27 00:00:00', 8.27700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-28 00:00:00', 8.71300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-29 00:00:00', 6.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-30 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-01-31 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-01 00:00:00', 6.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-02 00:00:00', 6.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-03 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-04 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-05 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-06 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-07 00:00:00', 6.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-08 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-09 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-10 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-11 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-12 00:00:00', 4.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-13 00:00:00', 5.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-14 00:00:00', 6.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-15 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-16 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-17 00:00:00', 5.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-18 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-19 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-20 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-21 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-22 00:00:00', 4.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-23 00:00:00', 5.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-24 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-25 00:00:00', 5.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-26 00:00:00', 6.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-27 00:00:00', 4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-28 00:00:00', 7.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-02-29 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-01 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-02 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-03 00:00:00', 6.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-04 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-05 00:00:00', 6.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-06 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-07 00:00:00', 5.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-08 00:00:00', 6.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-09 00:00:00', 6.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-10 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-11 00:00:00', 5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-12 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-13 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-14 00:00:00', 6.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-15 00:00:00', 5.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-16 00:00:00', 5.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-17 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-18 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-19 00:00:00', 5.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-20 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-21 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-22 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-23 00:00:00', 6.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-24 00:00:00', 8.22999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-25 00:00:00', 7.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-26 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-27 00:00:00', 4.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-28 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-29 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-30 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-03-31 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-01 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-02 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-03 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-04 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-05 00:00:00', 5.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-06 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-07 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-08 00:00:00', 6.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-09 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-10 00:00:00', 6.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-11 00:00:00', 5.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-12 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-13 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-14 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-15 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-16 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-17 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-18 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-19 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-20 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-21 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-22 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-23 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-24 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-25 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-26 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-27 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-28 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-29 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-04-30 00:00:00', 7.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-01 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-02 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-03 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-04 00:00:00', 5.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-05 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-06 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-07 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-08 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-09 00:00:00', 4.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-10 00:00:00', 5.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-11 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-12 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-13 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-14 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-15 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-16 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-17 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-18 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-19 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-20 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-21 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-22 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-23 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-24 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-25 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-26 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-27 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-28 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-29 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-30 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-05-31 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-01 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-02 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-03 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-04 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-05 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-06 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-07 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-08 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-09 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-10 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-11 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-12 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-13 00:00:00', 4.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-14 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-15 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-16 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-17 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-18 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-19 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-20 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-21 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-22 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-23 00:00:00', 1.11000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-24 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-25 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-26 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-27 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-28 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-29 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-06-30 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-01 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-02 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-03 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-04 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-05 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-06 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-07 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-08 00:00:00', 0.919000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-09 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-10 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-11 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-12 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-13 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-14 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-15 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-16 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-17 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-18 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-19 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-20 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-21 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-22 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-23 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-24 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-25 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-26 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-27 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-28 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-29 00:00:00', 1.18299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-30 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-07-31 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-01 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-02 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-03 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-04 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-05 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-06 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-07 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-08 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-09 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-10 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-11 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-12 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-13 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-14 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-15 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-16 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-17 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-18 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-19 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-20 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-21 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-22 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-23 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-24 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-25 00:00:00', 1.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-26 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-27 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-28 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-29 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-30 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-08-31 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-01 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-02 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-03 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-04 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-05 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-06 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-07 00:00:00', 0.825999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-08 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-09 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-10 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-11 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-12 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-13 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-14 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-15 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-16 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-17 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-18 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-19 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-20 00:00:00', 4.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-21 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-22 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-23 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-24 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-25 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-26 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-27 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-28 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-29 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-09-30 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-01 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-02 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-03 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-04 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-05 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-06 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-07 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-08 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-09 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-10 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-11 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-12 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-13 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-14 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-15 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-16 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-17 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-18 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-19 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-20 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-21 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-22 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-23 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-24 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-25 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-26 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-27 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-28 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-29 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-30 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-10-31 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-01 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-02 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-03 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-04 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-05 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-06 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-07 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-08 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-09 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-10 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-11 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-12 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-13 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-14 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-15 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-16 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-17 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-18 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-19 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-20 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-21 00:00:00', 1.0700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-22 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-23 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-24 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-25 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-26 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-27 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-28 00:00:00', 5.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-29 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-11-30 00:00:00', 4.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-01 00:00:00', 8.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-02 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-03 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-04 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-05 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-06 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-07 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-08 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-09 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-10 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-11 00:00:00', 5.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-12 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-13 00:00:00', 4.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-14 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-15 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-16 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-17 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-18 00:00:00', 7.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-19 00:00:00', 5.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-20 00:00:00', 7.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-21 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-22 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-23 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-24 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-25 00:00:00', 6.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-26 00:00:00', 5.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-27 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-28 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-29 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-30 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2000-12-31 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-01 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-02 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-03 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-04 00:00:00', 7.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-05 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-06 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-07 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-08 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-09 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-10 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-11 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-12 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-13 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-14 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-15 00:00:00', 5.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-16 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-17 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-18 00:00:00', 5.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-19 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-20 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-21 00:00:00', 5.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-22 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-23 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-24 00:00:00', 5.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-25 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-26 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-27 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-28 00:00:00', 5.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-29 00:00:00', 5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-30 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-01-31 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-01 00:00:00', 5.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-02 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-03 00:00:00', 5.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-04 00:00:00', 7.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-05 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-06 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-07 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-08 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-09 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-10 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-11 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-12 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-13 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-14 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-15 00:00:00', 7.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-16 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-17 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-18 00:00:00', 7.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-19 00:00:00', 7.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-20 00:00:00', 5.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-21 00:00:00', 9.43299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-22 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-23 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-24 00:00:00', 6.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-25 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-26 00:00:00', 7.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-27 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-02-28 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-01 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-02 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-03 00:00:00', 5.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-04 00:00:00', 6.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-05 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-06 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-07 00:00:00', 5.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-08 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-09 00:00:00', 6.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-10 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-11 00:00:00', 5.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-12 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-13 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-14 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-15 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-16 00:00:00', 5.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-17 00:00:00', 6.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-18 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-19 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-20 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-21 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-22 00:00:00', 5.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-23 00:00:00', 6.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-24 00:00:00', 5.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-25 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-26 00:00:00', 6.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-27 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-28 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-29 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-30 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-03-31 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-01 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-02 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-03 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-04 00:00:00', 6.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-05 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-06 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-07 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-08 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-09 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-10 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-11 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-12 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-13 00:00:00', 5.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-14 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-15 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-16 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-17 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-18 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-19 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-20 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-21 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-22 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-23 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-24 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-25 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-26 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-27 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-28 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-29 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-04-30 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-01 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-02 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-03 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-04 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-05 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-06 00:00:00', 4.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-07 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-08 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-09 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-10 00:00:00', 3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-11 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-12 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-13 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-14 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-15 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-16 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-17 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-18 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-19 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-20 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-21 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-22 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-23 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-24 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-25 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-26 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-27 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-28 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-29 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-30 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-05-31 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-01 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-02 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-03 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-04 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-05 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-06 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-07 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-08 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-09 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-10 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-11 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-12 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-13 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-14 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-15 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-16 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-17 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-18 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-19 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-20 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-21 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-22 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-23 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-24 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-25 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-26 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-27 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-28 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-29 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-06-30 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-01 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-02 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-03 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-04 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-05 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-06 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-07 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-08 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-09 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-10 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-11 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-12 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-13 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-14 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-15 00:00:00', 5.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-16 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-17 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-18 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-19 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-20 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-21 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-22 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-23 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-24 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-25 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-26 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-27 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-28 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-29 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-30 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-07-31 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-01 00:00:00', 0.887000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-02 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-03 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-04 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-05 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-06 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-07 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-08 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-09 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-10 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-11 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-12 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-13 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-14 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-15 00:00:00', 1.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-16 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-17 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-18 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-19 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-20 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-21 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-22 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-23 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-24 00:00:00', 1.06700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-25 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-26 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-27 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-28 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-29 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-30 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-08-31 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-01 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-02 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-03 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-04 00:00:00', 1.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-05 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-06 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-07 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-08 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-09 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-10 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-11 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-12 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-13 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-14 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-15 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-16 00:00:00', 0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-17 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-18 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-19 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-20 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-21 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-22 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-23 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-24 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-25 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-26 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-27 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-28 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-29 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-09-30 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-01 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-02 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-03 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-04 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-05 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-06 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-07 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-08 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-09 00:00:00', 4.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-10 00:00:00', 4.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-11 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-12 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-13 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-14 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-15 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-16 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-17 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-18 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-19 00:00:00', 5.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-20 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-21 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-22 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-23 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-24 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-25 00:00:00', 6.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-26 00:00:00', 4.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-27 00:00:00', 6.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-28 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-29 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-30 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-10-31 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-01 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-02 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-03 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-04 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-05 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-06 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-07 00:00:00', 6.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-08 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-09 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-10 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-11 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-12 00:00:00', 6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-13 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-14 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-15 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-16 00:00:00', 5.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-17 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-18 00:00:00', 5.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-19 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-20 00:00:00', 5.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-21 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-22 00:00:00', 6.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-23 00:00:00', 4.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-24 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-25 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-26 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-27 00:00:00', 4.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-28 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-29 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-11-30 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-01 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-02 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-03 00:00:00', 4.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-04 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-05 00:00:00', 5.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-06 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-07 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-08 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-09 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-10 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-11 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-12 00:00:00', 6.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-13 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-14 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-15 00:00:00', 6.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-16 00:00:00', 6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-17 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-18 00:00:00', 6.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-19 00:00:00', 9.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-20 00:00:00', 8.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-21 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-22 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-23 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-24 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-25 00:00:00', 5.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-26 00:00:00', 5.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-27 00:00:00', 6.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-28 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-29 00:00:00', 6.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-30 00:00:00', 7.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2001-12-31 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-01 00:00:00', 7.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-02 00:00:00', 7.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-03 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-04 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-05 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-06 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-07 00:00:00', 7.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-08 00:00:00', 7.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-09 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-10 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-11 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-12 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-13 00:00:00', 6.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-14 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-15 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-16 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-17 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-18 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-19 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-20 00:00:00', 4.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-21 00:00:00', 4.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-22 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-23 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-24 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-25 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-26 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-27 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-28 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-29 00:00:00', 6.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-30 00:00:00', 5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-01-31 00:00:00', 5.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-01 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-02 00:00:00', 5.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-03 00:00:00', 7.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-04 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-05 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-06 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-07 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-08 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-09 00:00:00', 4.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-10 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-11 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-12 00:00:00', 7.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-13 00:00:00', 8.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-14 00:00:00', 7.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-15 00:00:00', 5.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-16 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-17 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-18 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-19 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-20 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-21 00:00:00', 5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-22 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-23 00:00:00', 5.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-24 00:00:00', 7.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-25 00:00:00', 7.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-26 00:00:00', 7.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-27 00:00:00', 8.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-02-28 00:00:00', 5.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-01 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-02 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-03 00:00:00', 5.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-04 00:00:00', 6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-05 00:00:00', 6.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-06 00:00:00', 5.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-07 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-08 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-09 00:00:00', 4.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-10 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-11 00:00:00', 4.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-12 00:00:00', 5.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-13 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-14 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-15 00:00:00', 7.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-16 00:00:00', 6.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-17 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-18 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-19 00:00:00', 6.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-20 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-21 00:00:00', 8.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-22 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-23 00:00:00', 5.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-24 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-25 00:00:00', 5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-26 00:00:00', 6.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-27 00:00:00', 7.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-28 00:00:00', 7.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-29 00:00:00', 7.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-30 00:00:00', 5.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-03-31 00:00:00', 4.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-01 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-02 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-03 00:00:00', 6.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-04 00:00:00', 7.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-05 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-06 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-07 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-08 00:00:00', 6.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-09 00:00:00', 4.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-10 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-11 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-12 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-13 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-14 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-15 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-16 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-17 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-18 00:00:00', 5.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-19 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-20 00:00:00', 5.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-21 00:00:00', 5.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-22 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-23 00:00:00', 4.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-24 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-25 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-26 00:00:00', 7.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-27 00:00:00', 3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-28 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-29 00:00:00', 5.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-04-30 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-01 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-02 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-03 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-04 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-05 00:00:00', 5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-06 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-07 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-08 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-09 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-10 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-11 00:00:00', 6.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-12 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-13 00:00:00', 4.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-14 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-15 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-16 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-17 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-18 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-19 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-20 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-21 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-22 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-23 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-24 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-25 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-26 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-27 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-28 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-29 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-30 00:00:00', 4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-05-31 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-01 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-02 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-03 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-04 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-05 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-06 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-07 00:00:00', 6.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-08 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-09 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-10 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-11 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-12 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-13 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-14 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-15 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-16 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-17 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-18 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-19 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-20 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-21 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-22 00:00:00', 5.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-23 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-24 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-25 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-26 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-27 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-28 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-29 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-06-30 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-01 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-02 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-03 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-04 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-05 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-06 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-07 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-08 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-09 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-10 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-11 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-12 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-13 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-14 00:00:00', 0.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-15 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-16 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-17 00:00:00', 1.07700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-18 00:00:00', 0.901000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-19 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-20 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-21 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-22 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-23 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-24 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-25 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-26 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-27 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-28 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-29 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-30 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-07-31 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-01 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-02 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-03 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-04 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-05 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-06 00:00:00', 1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-07 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-08 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-09 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-10 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-11 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-12 00:00:00', 5.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-13 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-14 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-15 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-16 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-17 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-18 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-19 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-20 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-21 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-22 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-23 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-24 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-25 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-26 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-27 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-28 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-29 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-30 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-08-31 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-01 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-02 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-03 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-04 00:00:00', 0.856000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-05 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-06 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-07 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-08 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-09 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-10 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-11 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-12 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-13 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-14 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-15 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-16 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-17 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-18 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-19 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-20 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-21 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-22 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-23 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-24 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-25 00:00:00', 0.981000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-26 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-27 00:00:00', 0.913999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-28 00:00:00', 1.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-29 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-09-30 00:00:00', 0.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-01 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-02 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-03 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-04 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-05 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-06 00:00:00', 1.14600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-07 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-08 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-09 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-10 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-11 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-12 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-13 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-14 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-15 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-16 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-17 00:00:00', 1.28199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-18 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-19 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-20 00:00:00', 0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-21 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-22 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-23 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-24 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-25 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-26 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-27 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-28 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-29 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-30 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-10-31 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-01 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-02 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-03 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-04 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-05 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-06 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-07 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-08 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-09 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-10 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-11 00:00:00', 5.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-12 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-13 00:00:00', 6.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-14 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-15 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-16 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-17 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-18 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-19 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-20 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-21 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-22 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-23 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-24 00:00:00', 4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-25 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-26 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-27 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-28 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-29 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-11-30 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-01 00:00:00', 5.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-02 00:00:00', 4.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-03 00:00:00', 6.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-04 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-05 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-06 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-07 00:00:00', 5.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-08 00:00:00', 7.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-09 00:00:00', 7.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-10 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-11 00:00:00', 4.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-12 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-13 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-14 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-15 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-16 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-17 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-18 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-19 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-20 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-21 00:00:00', 8.52499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-22 00:00:00', 6.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-23 00:00:00', 5.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-24 00:00:00', 5.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-25 00:00:00', 6.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-26 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-27 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-28 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-29 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-30 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2002-12-31 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-01 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-02 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-03 00:00:00', 5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-04 00:00:00', 6.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-05 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-06 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-07 00:00:00', 7.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-08 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-09 00:00:00', 6.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-10 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-11 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-12 00:00:00', 6.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-13 00:00:00', 8.03400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-14 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-15 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-16 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-17 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-18 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-19 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-20 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-21 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-22 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-23 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-24 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-25 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-26 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-27 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-28 00:00:00', 6.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-29 00:00:00', 7.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-30 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-01-31 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-01 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-02 00:00:00', 7.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-03 00:00:00', 6.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-04 00:00:00', 7.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-05 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-06 00:00:00', 5.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-07 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-08 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-09 00:00:00', 6.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-10 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-11 00:00:00', 6.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-12 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-13 00:00:00', 5.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-14 00:00:00', 9.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-15 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-16 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-17 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-18 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-19 00:00:00', 5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-20 00:00:00', 8.27999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-21 00:00:00', 5.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-22 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-23 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-24 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-25 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-26 00:00:00', 7.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-27 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-02-28 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-01 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-02 00:00:00', 5.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-03 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-04 00:00:00', 7.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-05 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-06 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-07 00:00:00', 7.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-08 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-09 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-10 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-11 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-12 00:00:00', 6.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-13 00:00:00', 7.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-14 00:00:00', 7.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-15 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-16 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-17 00:00:00', 7.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-18 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-19 00:00:00', 6.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-20 00:00:00', 8.43500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-21 00:00:00', 7.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-22 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-23 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-24 00:00:00', 4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-25 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-26 00:00:00', 8.07699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-27 00:00:00', 6.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-28 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-29 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-30 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-03-31 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-01 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-02 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-03 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-04 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-05 00:00:00', 6.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-06 00:00:00', 6.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-07 00:00:00', 6.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-08 00:00:00', 5.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-09 00:00:00', 5.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-10 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-11 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-12 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-13 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-14 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-15 00:00:00', 4.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-16 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-17 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-18 00:00:00', 5.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-19 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-20 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-21 00:00:00', 6.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-22 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-23 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-24 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-25 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-26 00:00:00', 4.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-27 00:00:00', 5.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-28 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-29 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-04-30 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-01 00:00:00', 5.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-02 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-03 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-04 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-05 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-06 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-07 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-08 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-09 00:00:00', 4.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-10 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-11 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-12 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-13 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-14 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-15 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-16 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-17 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-18 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-19 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-20 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-21 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-22 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-23 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-24 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-25 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-26 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-27 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-28 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-29 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-30 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-05-31 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-01 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-02 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-03 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-04 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-05 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-06 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-07 00:00:00', 5.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-08 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-09 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-10 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-11 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-12 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-13 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-14 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-15 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-16 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-17 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-18 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-19 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-20 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-21 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-22 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-23 00:00:00', 1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-24 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-25 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-26 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-27 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-28 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-29 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-06-30 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-01 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-02 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-03 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-04 00:00:00', 5.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-05 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-06 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-07 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-08 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-09 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-10 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-11 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-12 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-13 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-14 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-15 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-16 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-17 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-18 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-19 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-20 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-21 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-22 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-23 00:00:00', 5.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-24 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-25 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-26 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-27 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-28 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-29 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-30 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-07-31 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-01 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-02 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-03 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-04 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-05 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-06 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-07 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-08 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-09 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-10 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-11 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-12 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-13 00:00:00', 1.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-14 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-15 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-16 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-17 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-18 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-19 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-20 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-21 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-22 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-23 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-24 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-25 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-26 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-27 00:00:00', 1.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-28 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-29 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-30 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-08-31 00:00:00', 1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-01 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-02 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-03 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-04 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-05 00:00:00', 1.09099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-06 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-07 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-08 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-09 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-10 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-11 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-12 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-13 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-14 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-15 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-16 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-17 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-18 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-19 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-20 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-21 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-22 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-23 00:00:00', 4.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-24 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-25 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-26 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-27 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-28 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-29 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-09-30 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-01 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-02 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-03 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-04 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-05 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-06 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-07 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-08 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-09 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-10 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-11 00:00:00', 0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-12 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-13 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-14 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-15 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-16 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-17 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-18 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-19 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-20 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-21 00:00:00', 1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-22 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-23 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-24 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-25 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-26 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-27 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-28 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-29 00:00:00', 5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-30 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-10-31 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-01 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-02 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-03 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-04 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-05 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-06 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-07 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-08 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-09 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-10 00:00:00', 6.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-11 00:00:00', 6.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-12 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-13 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-14 00:00:00', 6.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-15 00:00:00', 6.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-16 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-17 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-18 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-19 00:00:00', 5.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-20 00:00:00', 7.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-21 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-22 00:00:00', 5.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-23 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-24 00:00:00', 6.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-25 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-26 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-27 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-28 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-29 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-11-30 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-01 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-02 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-03 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-04 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-05 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-06 00:00:00', 7.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-07 00:00:00', 6.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-08 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-09 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-10 00:00:00', 5.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-11 00:00:00', 5.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-12 00:00:00', 6.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-13 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-14 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-15 00:00:00', 6.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-16 00:00:00', 6.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-17 00:00:00', 6.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-18 00:00:00', 7.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-19 00:00:00', 8.25100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-20 00:00:00', 6.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-21 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-22 00:00:00', 5.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-23 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-24 00:00:00', 6.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-25 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-26 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-27 00:00:00', 7.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-28 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-29 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-30 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2003-12-31 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-01 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-02 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-03 00:00:00', 5.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-04 00:00:00', 6.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-05 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-06 00:00:00', 8.73200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-07 00:00:00', 7.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-08 00:00:00', 8.50100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-09 00:00:00', 7.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-10 00:00:00', 5.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-11 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-12 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-13 00:00:00', 4.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-14 00:00:00', 7.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-15 00:00:00', 6.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-16 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-17 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-18 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-19 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-20 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-21 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-22 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-23 00:00:00', 5.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-24 00:00:00', 6.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-25 00:00:00', 5.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-26 00:00:00', 6.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-27 00:00:00', 7.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-28 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-29 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-30 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-01-31 00:00:00', 1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-01 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-02 00:00:00', 6.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-03 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-04 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-05 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-06 00:00:00', 8.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-07 00:00:00', 6.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-08 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-09 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-10 00:00:00', 6.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-11 00:00:00', 7.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-12 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-13 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-14 00:00:00', 6.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-15 00:00:00', 9.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-16 00:00:00', 5.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-17 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-18 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-19 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-20 00:00:00', 5.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-21 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-22 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-23 00:00:00', 6.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-24 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-25 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-26 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-27 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-28 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-02-29 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-01 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-02 00:00:00', 6.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-03 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-04 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-05 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-06 00:00:00', 7.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-07 00:00:00', 5.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-08 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-09 00:00:00', 5.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-10 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-11 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-12 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-13 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-14 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-15 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-16 00:00:00', 5.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-17 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-18 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-19 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-20 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-21 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-22 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-23 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-24 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-25 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-26 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-27 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-28 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-29 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-30 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-03-31 00:00:00', 5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-01 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-02 00:00:00', 5.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-03 00:00:00', 6.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-04 00:00:00', 5.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-05 00:00:00', 5.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-06 00:00:00', 5.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-07 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-08 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-09 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-10 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-11 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-12 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-13 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-14 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-15 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-16 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-17 00:00:00', 6.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-18 00:00:00', 6.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-19 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-20 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-21 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-22 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-23 00:00:00', 6.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-24 00:00:00', 6.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-25 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-26 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-27 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-28 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-29 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-04-30 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-01 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-02 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-03 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-04 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-05 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-06 00:00:00', 5.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-07 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-08 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-09 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-10 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-11 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-12 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-13 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-14 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-15 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-16 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-17 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-18 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-19 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-20 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-21 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-22 00:00:00', 5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-23 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-24 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-25 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-26 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-27 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-28 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-29 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-30 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-05-31 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-01 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-02 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-03 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-04 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-05 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-06 00:00:00', 5.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-07 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-08 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-09 00:00:00', 1.05799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-10 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-11 00:00:00', 1.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-12 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-13 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-14 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-15 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-16 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-17 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-18 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-19 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-20 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-21 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-22 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-23 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-24 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-25 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-26 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-27 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-28 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-29 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-06-30 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-01 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-02 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-03 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-04 00:00:00', 4.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-05 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-06 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-07 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-08 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-09 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-10 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-11 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-12 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-13 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-14 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-15 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-16 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-17 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-18 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-19 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-20 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-21 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-22 00:00:00', 0.908999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-23 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-24 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-25 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-26 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-27 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-28 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-29 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-30 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-07-31 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-01 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-02 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-03 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-04 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-05 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-06 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-07 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-08 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-09 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-10 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-11 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-12 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-13 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-14 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-15 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-16 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-17 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-18 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-19 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-20 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-21 00:00:00', 1.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-22 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-23 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-24 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-25 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-26 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-27 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-28 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-29 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-30 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-08-31 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-01 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-02 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-03 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-04 00:00:00', 0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-05 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-06 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-07 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-08 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-09 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-10 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-11 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-12 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-13 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-14 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-15 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-16 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-17 00:00:00', 1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-18 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-19 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-20 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-21 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-22 00:00:00', 0.949999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-23 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-24 00:00:00', 1.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-25 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-26 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-27 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-28 00:00:00', 1.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-29 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-09-30 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-01 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-02 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-03 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-04 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-05 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-06 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-07 00:00:00', 5.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-08 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-09 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-10 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-11 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-12 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-13 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-14 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-15 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-16 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-17 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-18 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-19 00:00:00', 1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-20 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-21 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-22 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-23 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-24 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-25 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-26 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-27 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-28 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-29 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-30 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-10-31 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-01 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-02 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-03 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-04 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-05 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-06 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-07 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-08 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-09 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-10 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-11 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-12 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-13 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-14 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-15 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-16 00:00:00', 1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-17 00:00:00', 6.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-18 00:00:00', 5.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-19 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-20 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-21 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-22 00:00:00', 6.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-23 00:00:00', 7.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-24 00:00:00', 6.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-25 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-26 00:00:00', 5.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-27 00:00:00', 7.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-28 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-29 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-11-30 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-01 00:00:00', 5.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-02 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-03 00:00:00', 5.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-04 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-05 00:00:00', 5.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-06 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-07 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-08 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-09 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-10 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-11 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-12 00:00:00', 5.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-13 00:00:00', 5.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-14 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-15 00:00:00', 7.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-16 00:00:00', 5.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-17 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-18 00:00:00', 6.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-19 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-20 00:00:00', 6.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-21 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-22 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-23 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-24 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-25 00:00:00', 6.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-26 00:00:00', 6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-27 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-28 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-29 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-30 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2004-12-31 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-01 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-02 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-03 00:00:00', 8.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-04 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-05 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-06 00:00:00', 6.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-07 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-08 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-09 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-10 00:00:00', 4.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-11 00:00:00', 6.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-12 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-13 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-14 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-15 00:00:00', 5.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-16 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-17 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-18 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-19 00:00:00', 6.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-20 00:00:00', 6.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-21 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-22 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-23 00:00:00', 8.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-24 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-25 00:00:00', 7.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-26 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-27 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-28 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-29 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-30 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-01-31 00:00:00', 7.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-01 00:00:00', 8.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-02 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-03 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-04 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-05 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-06 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-07 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-08 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-09 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-10 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-11 00:00:00', 5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-12 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-13 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-14 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-15 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-16 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-17 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-18 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-19 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-20 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-21 00:00:00', 6.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-22 00:00:00', 5.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-23 00:00:00', 4.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-24 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-25 00:00:00', 5.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-26 00:00:00', 6.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-27 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-02-28 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-01 00:00:00', 5.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-02 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-03 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-04 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-05 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-06 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-07 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-08 00:00:00', 4.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-09 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-10 00:00:00', 6.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-11 00:00:00', 7.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-12 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-13 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-14 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-15 00:00:00', 5.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-16 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-17 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-18 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-19 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-20 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-21 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-22 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-23 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-24 00:00:00', 6.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-25 00:00:00', 5.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-26 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-27 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-28 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-29 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-30 00:00:00', 6.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-03-31 00:00:00', 5.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-01 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-02 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-03 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-04 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-05 00:00:00', 7.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-06 00:00:00', 4.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-07 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-08 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-09 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-10 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-11 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-12 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-13 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-14 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-15 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-16 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-17 00:00:00', 6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-18 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-19 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-20 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-21 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-22 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-23 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-24 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-25 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-26 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-27 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-28 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-29 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-04-30 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-01 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-02 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-03 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-04 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-05 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-06 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-07 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-08 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-09 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-10 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-11 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-12 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-13 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-14 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-15 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-16 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-17 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-18 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-19 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-20 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-21 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-22 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-23 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-24 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-25 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-26 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-27 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-28 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-29 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-30 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-05-31 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-01 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-02 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-03 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-04 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-05 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-06 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-07 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-08 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-09 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-10 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-11 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-12 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-13 00:00:00', 1.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-14 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-15 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-16 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-17 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-18 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-19 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-20 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-21 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-22 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-23 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-24 00:00:00', 5.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-25 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-26 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-27 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-28 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-29 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-06-30 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-01 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-02 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-03 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-04 00:00:00', 0.777000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-05 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-06 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-07 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-08 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-09 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-10 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-11 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-12 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-13 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-14 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-15 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-16 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-17 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-18 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-19 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-20 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-21 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-22 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-23 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-24 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-25 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-26 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-27 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-28 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-29 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-30 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-07-31 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-01 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-02 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-03 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-04 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-05 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-06 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-07 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-08 00:00:00', 1.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-09 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-10 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-11 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-12 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-13 00:00:00', 1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-14 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-15 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-16 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-17 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-18 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-19 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-20 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-21 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-22 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-23 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-24 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-25 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-26 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-27 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-28 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-29 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-30 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-08-31 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-01 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-02 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-03 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-04 00:00:00', 1.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-05 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-06 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-07 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-08 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-09 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-10 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-11 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-12 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-13 00:00:00', 1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-14 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-15 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-16 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-17 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-18 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-19 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-20 00:00:00', 1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-21 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-22 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-23 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-24 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-25 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-26 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-27 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-28 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-29 00:00:00', 0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-09-30 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-01 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-02 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-03 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-04 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-05 00:00:00', 1.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-06 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-07 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-08 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-09 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-10 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-11 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-12 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-13 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-14 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-15 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-16 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-17 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-18 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-19 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-20 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-21 00:00:00', 4.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-22 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-23 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-24 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-25 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-26 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-27 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-28 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-29 00:00:00', 4.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-30 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-10-31 00:00:00', 4.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-01 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-02 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-03 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-04 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-05 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-06 00:00:00', 5.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-07 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-08 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-09 00:00:00', 5.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-10 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-11 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-12 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-13 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-14 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-15 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-16 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-17 00:00:00', 6.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-18 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-19 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-20 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-21 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-22 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-23 00:00:00', 4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-24 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-25 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-26 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-27 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-28 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-29 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-11-30 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-01 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-02 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-03 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-04 00:00:00', 6.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-05 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-06 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-07 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-08 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-09 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-10 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-11 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-12 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-13 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-14 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-15 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-16 00:00:00', 5.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-17 00:00:00', 6.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-18 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-19 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-20 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-21 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-22 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-23 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-24 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-25 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-26 00:00:00', 6.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-27 00:00:00', 4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-28 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-29 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-30 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2005-12-31 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-01 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-02 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-03 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-04 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-05 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-06 00:00:00', 6.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-07 00:00:00', 5.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-08 00:00:00', 5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-09 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-10 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-11 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-12 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-13 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-14 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-15 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-16 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-17 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-18 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-19 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-20 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-21 00:00:00', 7.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-22 00:00:00', 5.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-23 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-24 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-25 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-26 00:00:00', 4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-27 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-28 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-29 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-30 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-01-31 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-01 00:00:00', 7.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-02 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-03 00:00:00', 7.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-04 00:00:00', 7.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-05 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-06 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-07 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-08 00:00:00', 6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-09 00:00:00', 8.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-10 00:00:00', 5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-11 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-12 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-13 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-14 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-15 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-16 00:00:00', 7.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-17 00:00:00', 5.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-18 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-19 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-20 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-21 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-22 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-23 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-24 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-25 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-26 00:00:00', 6.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-27 00:00:00', 6.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-02-28 00:00:00', 6.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-01 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-02 00:00:00', 5.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-03 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-04 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-05 00:00:00', 4.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-06 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-07 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-08 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-09 00:00:00', 6.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-10 00:00:00', 6.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-11 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-12 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-13 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-14 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-15 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-16 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-17 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-18 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-19 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-20 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-21 00:00:00', 5.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-22 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-23 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-24 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-25 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-26 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-27 00:00:00', 4.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-28 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-29 00:00:00', 5.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-30 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-03-31 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-01 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-02 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-03 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-04 00:00:00', 6.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-05 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-06 00:00:00', 4.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-07 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-08 00:00:00', 5.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-09 00:00:00', 7.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-10 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-11 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-12 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-13 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-14 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-15 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-16 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-17 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-18 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-19 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-20 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-21 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-22 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-23 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-24 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-25 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-26 00:00:00', 4.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-27 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-28 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-29 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-04-30 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-01 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-02 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-03 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-04 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-05 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-06 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-07 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-08 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-09 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-10 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-11 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-12 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-13 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-14 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-15 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-16 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-17 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-18 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-19 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-20 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-21 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-22 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-23 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-24 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-25 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-26 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-27 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-28 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-29 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-30 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-05-31 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-01 00:00:00', 0.883000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-02 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-03 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-04 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-05 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-06 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-07 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-08 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-09 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-10 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-11 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-12 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-13 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-14 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-15 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-16 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-17 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-18 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-19 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-20 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-21 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-22 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-23 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-24 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-25 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-26 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-27 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-28 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-29 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-06-30 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-01 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-02 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-03 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-04 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-05 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-06 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-07 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-08 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-09 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-10 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-11 00:00:00', 6.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-12 00:00:00', 5.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-13 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-14 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-15 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-16 00:00:00', 1.12699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-17 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-18 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-19 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-20 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-21 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-22 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-23 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-24 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-25 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-26 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-27 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-28 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-29 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-30 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-07-31 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-01 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-02 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-03 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-04 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-05 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-06 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-07 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-08 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-09 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-10 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-11 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-12 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-13 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-14 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-15 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-16 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-17 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-18 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-19 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-20 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-21 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-22 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-23 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-24 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-25 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-26 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-27 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-28 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-29 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-30 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-08-31 00:00:00', 1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-01 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-02 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-03 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-04 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-05 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-06 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-07 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-08 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-09 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-10 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-11 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-12 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-13 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-14 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-15 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-16 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-17 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-18 00:00:00', 5.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-19 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-20 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-21 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-22 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-23 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-24 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-25 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-26 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-27 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-28 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-29 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-09-30 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-01 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-02 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-03 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-04 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-05 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-06 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-07 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-08 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-09 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-10 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-11 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-12 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-13 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-14 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-15 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-16 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-17 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-18 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-19 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-20 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-21 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-22 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-23 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-24 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-25 00:00:00', 0.998000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-26 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-27 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-28 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-29 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-30 00:00:00', 4.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-10-31 00:00:00', 4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-01 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-02 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-03 00:00:00', 5.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-04 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-05 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-06 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-07 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-08 00:00:00', 5.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-09 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-10 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-11 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-12 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-13 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-14 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-15 00:00:00', 6.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-16 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-17 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-18 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-19 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-20 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-21 00:00:00', 5.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-22 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-23 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-24 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-25 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-26 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-27 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-28 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-29 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-11-30 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-01 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-02 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-03 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-04 00:00:00', 4.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-05 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-06 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-07 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-08 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-09 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-10 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-11 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-12 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-13 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-14 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-15 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-16 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-17 00:00:00', 0.986000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-18 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-19 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-20 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-21 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-22 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-23 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-24 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-25 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-26 00:00:00', 6.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-27 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-28 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-29 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-30 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2006-12-31 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-01 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-02 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-03 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-04 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-05 00:00:00', 4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-06 00:00:00', 8.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-07 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-08 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-09 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-10 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-11 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-12 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-13 00:00:00', 6.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-14 00:00:00', 6.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-15 00:00:00', 5.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-16 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-17 00:00:00', 6.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-18 00:00:00', 4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-19 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-20 00:00:00', 6.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-21 00:00:00', 6.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-22 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-23 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-24 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-25 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-26 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-27 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-28 00:00:00', 5.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-29 00:00:00', 6.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-30 00:00:00', 5.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-01-31 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-01 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-02 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-03 00:00:00', 6.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-04 00:00:00', 5.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-05 00:00:00', 6.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-06 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-07 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-08 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-09 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-10 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-11 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-12 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-13 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-14 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-15 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-16 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-17 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-18 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-19 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-20 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-21 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-22 00:00:00', 6.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-23 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-24 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-25 00:00:00', 6.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-26 00:00:00', 6.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-27 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-02-28 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-01 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-02 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-03 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-04 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-05 00:00:00', 6.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-06 00:00:00', 5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-07 00:00:00', 6.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-08 00:00:00', 6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-09 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-10 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-11 00:00:00', 4.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-12 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-13 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-14 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-15 00:00:00', 7.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-16 00:00:00', 7.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-17 00:00:00', 5.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-18 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-19 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-20 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-21 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-22 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-23 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-24 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-25 00:00:00', 6.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-26 00:00:00', 6.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-27 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-28 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-29 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-30 00:00:00', 5.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-03-31 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-01 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-02 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-03 00:00:00', 6.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-04 00:00:00', 4.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-05 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-06 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-07 00:00:00', 5.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-08 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-09 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-10 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-11 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-12 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-13 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-14 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-15 00:00:00', 6.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-16 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-17 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-18 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-19 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-20 00:00:00', 5.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-21 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-22 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-23 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-24 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-25 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-26 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-27 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-28 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-29 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-04-30 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-01 00:00:00', 4.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-02 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-03 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-04 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-05 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-06 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-07 00:00:00', 4.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-08 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-09 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-10 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-11 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-12 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-13 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-14 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-15 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-16 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-17 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-18 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-19 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-20 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-21 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-22 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-23 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-24 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-25 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-26 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-27 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-28 00:00:00', 1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-29 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-30 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-05-31 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-01 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-02 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-03 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-04 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-05 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-06 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-07 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-08 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-09 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-10 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-11 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-12 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-13 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-14 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-15 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-16 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-17 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-18 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-19 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-20 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-21 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-22 00:00:00', 0.815999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-23 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-24 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-25 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-26 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-27 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-28 00:00:00', 5.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-29 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-06-30 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-01 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-02 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-03 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-04 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-05 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-06 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-07 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-08 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-09 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-10 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-11 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-12 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-13 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-14 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-15 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-16 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-17 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-18 00:00:00', 0.901000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-19 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-20 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-21 00:00:00', 4.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-22 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-23 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-24 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-25 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-26 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-27 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-28 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-29 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-30 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-07-31 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-01 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-02 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-03 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-04 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-05 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-06 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-07 00:00:00', 0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-08 00:00:00', 0.978999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-09 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-10 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-11 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-12 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-13 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-14 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-15 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-16 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-17 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-18 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-19 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-20 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-21 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-22 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-23 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-24 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-25 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-26 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-27 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-28 00:00:00', 0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-29 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-30 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-08-31 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-01 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-02 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-03 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-04 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-05 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-06 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-07 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-08 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-09 00:00:00', 1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-10 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-11 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-12 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-13 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-14 00:00:00', 1.16900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-15 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-16 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-17 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-18 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-19 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-20 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-21 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-22 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-23 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-24 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-25 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-26 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-27 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-28 00:00:00', 0.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-29 00:00:00', 1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-09-30 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-01 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-02 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-03 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-04 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-05 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-06 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-07 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-08 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-09 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-10 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-11 00:00:00', 1.07400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-12 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-13 00:00:00', 1.28199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-14 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-15 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-16 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-17 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-18 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-19 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-20 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-21 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-22 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-23 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-24 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-25 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-26 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-27 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-28 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-29 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-30 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-10-31 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-01 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-02 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-03 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-04 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-05 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-06 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-07 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-08 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-09 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-10 00:00:00', 4.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-11 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-12 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-13 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-14 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-15 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-16 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-17 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-18 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-19 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-20 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-21 00:00:00', 6.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-22 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-23 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-24 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-25 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-26 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-27 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-28 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-29 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-11-30 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-01 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-02 00:00:00', 7.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-03 00:00:00', 6.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-04 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-05 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-06 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-07 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-08 00:00:00', 7.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-09 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-10 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-11 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-12 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-13 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-14 00:00:00', 7.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-15 00:00:00', 6.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-16 00:00:00', 5.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-17 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-18 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-19 00:00:00', 5.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-20 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-21 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-22 00:00:00', 6.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-23 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-24 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-25 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-26 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-27 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-28 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-29 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-30 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2007-12-31 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-01 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-02 00:00:00', 6.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-03 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-04 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-05 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-06 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-07 00:00:00', 6.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-08 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-09 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-10 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-11 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-12 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-13 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-14 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-15 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-16 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-17 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-18 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-19 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-20 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-21 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-22 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-23 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-24 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-25 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-26 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-27 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-28 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-29 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-30 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-01-31 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-01 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-02 00:00:00', 6.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-03 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-04 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-05 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-06 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-07 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-08 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-09 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-10 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-11 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-12 00:00:00', 7.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-13 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-14 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-15 00:00:00', 7.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-16 00:00:00', 6.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-17 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-18 00:00:00', 6.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-19 00:00:00', 8.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-20 00:00:00', 5.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-21 00:00:00', 6.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-22 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-23 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-24 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-25 00:00:00', 5.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-26 00:00:00', 6.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-27 00:00:00', 6.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-28 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-02-29 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-01 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-02 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-03 00:00:00', 5.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-04 00:00:00', 7.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-05 00:00:00', 6.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-06 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-07 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-08 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-09 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-10 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-11 00:00:00', 5.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-12 00:00:00', 5.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-13 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-14 00:00:00', 8.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-15 00:00:00', 5.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-16 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-17 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-18 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-19 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-20 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-21 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-22 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-23 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-24 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-25 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-26 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-27 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-28 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-29 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-30 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-03-31 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-01 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-02 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-03 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-04 00:00:00', 4.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-05 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-06 00:00:00', 5.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-07 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-08 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-09 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-10 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-11 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-12 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-13 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-14 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-15 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-16 00:00:00', 4.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-17 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-18 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-19 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-20 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-21 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-22 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-23 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-24 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-25 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-26 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-27 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-28 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-29 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-04-30 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-01 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-02 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-03 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-04 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-05 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-06 00:00:00', 5.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-07 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-08 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-09 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-10 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-11 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-12 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-13 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-14 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-15 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-16 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-17 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-18 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-19 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-20 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-21 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-22 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-23 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-24 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-25 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-26 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-27 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-28 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-29 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-30 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-05-31 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-01 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-02 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-03 00:00:00', 0.808000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-04 00:00:00', 1.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-05 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-06 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-07 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-08 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-09 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-10 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-11 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-12 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-13 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-14 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-15 00:00:00', 4.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-16 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-17 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-18 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-19 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-20 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-21 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-22 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-23 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-24 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-25 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-26 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-27 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-28 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-29 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-06-30 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-01 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-02 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-03 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-04 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-05 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-06 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-07 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-08 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-09 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-10 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-11 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-12 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-13 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-14 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-15 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-16 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-17 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-18 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-19 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-20 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-21 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-22 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-23 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-24 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-25 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-26 00:00:00', 1.25899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-27 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-28 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-29 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-30 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-07-31 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-01 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-02 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-03 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-04 00:00:00', 5.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-05 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-06 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-07 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-08 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-09 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-10 00:00:00', 5.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-11 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-12 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-13 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-14 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-15 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-16 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-17 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-18 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-19 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-20 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-21 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-22 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-23 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-24 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-25 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-26 00:00:00', 1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-27 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-28 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-29 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-30 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-08-31 00:00:00', 1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-01 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-02 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-03 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-04 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-05 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-06 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-07 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-08 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-09 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-10 00:00:00', 1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-11 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-12 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-13 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-14 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-15 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-16 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-17 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-18 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-19 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-20 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-21 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-22 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-23 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-24 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-25 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-26 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-27 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-28 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-29 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-09-30 00:00:00', 4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-01 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-02 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-03 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-04 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-05 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-06 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-07 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-08 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-09 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-10 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-11 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-12 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-13 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-14 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-15 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-16 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-17 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-18 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-19 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-20 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-21 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-22 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-23 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-24 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-25 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-26 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-27 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-28 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-29 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-30 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-10-31 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-01 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-02 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-03 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-04 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-05 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-06 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-07 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-08 00:00:00', 4.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-09 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-10 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-11 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-12 00:00:00', 4.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-13 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-14 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-15 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-16 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-17 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-18 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-19 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-20 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-21 00:00:00', 7.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-22 00:00:00', 6.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-23 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-24 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-25 00:00:00', 4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-26 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-27 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-28 00:00:00', 4.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-29 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-11-30 00:00:00', 1.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-01 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-02 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-03 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-04 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-05 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-06 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-07 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-08 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-09 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-10 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-11 00:00:00', 6.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-12 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-13 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-14 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-15 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-16 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-17 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-18 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-19 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-20 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-21 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-22 00:00:00', 5.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-23 00:00:00', 6.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-24 00:00:00', 6.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-25 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-26 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-27 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-28 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-29 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-30 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2008-12-31 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-01 00:00:00', 7.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-02 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-03 00:00:00', 6.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-04 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-05 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-06 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-07 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-08 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-09 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-10 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-11 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-12 00:00:00', 5.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-13 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-14 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-15 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-16 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-17 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-18 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-19 00:00:00', 5.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-20 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-21 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-22 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-23 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-24 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-25 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-26 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-27 00:00:00', 6.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-28 00:00:00', 5.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-29 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-30 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-01-31 00:00:00', 7.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-01 00:00:00', 6.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-02 00:00:00', 5.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-03 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-04 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-05 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-06 00:00:00', 7.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-07 00:00:00', 6.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-08 00:00:00', 5.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-09 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-10 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-11 00:00:00', 8.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-12 00:00:00', 6.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-13 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-14 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-15 00:00:00', 5.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-16 00:00:00', 5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-17 00:00:00', 5.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-18 00:00:00', 6.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-19 00:00:00', 5.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-20 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-21 00:00:00', 6.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-22 00:00:00', 7.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-23 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-24 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-25 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-26 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-27 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-02-28 00:00:00', 8.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-01 00:00:00', 7.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-02 00:00:00', 7.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-03 00:00:00', 6.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-04 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-05 00:00:00', 4.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-06 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-07 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-08 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-09 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-10 00:00:00', 8.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-11 00:00:00', 5.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-12 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-13 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-14 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-15 00:00:00', 6.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-16 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-17 00:00:00', 4.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-18 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-19 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-20 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-21 00:00:00', 5.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-22 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-23 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-24 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-25 00:00:00', 8.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-26 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-27 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-28 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-29 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-30 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-03-31 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-01 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-02 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-03 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-04 00:00:00', 5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-05 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-06 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-07 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-08 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-09 00:00:00', 6.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-10 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-11 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-12 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-13 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-14 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-15 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-16 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-17 00:00:00', 5.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-18 00:00:00', 6.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-19 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-20 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-21 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-22 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-23 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-24 00:00:00', 5.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-25 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-26 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-27 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-28 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-29 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-04-30 00:00:00', 4.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-01 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-02 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-03 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-04 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-05 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-06 00:00:00', 5.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-07 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-08 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-09 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-10 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-11 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-12 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-13 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-14 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-15 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-16 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-17 00:00:00', 4.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-18 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-19 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-20 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-21 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-22 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-23 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-24 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-25 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-26 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-27 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-28 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-29 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-30 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-05-31 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-01 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-02 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-03 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-04 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-05 00:00:00', 0.987999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-06 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-07 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-08 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-09 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-10 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-11 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-12 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-13 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-14 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-15 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-16 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-17 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-18 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-19 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-20 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-21 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-22 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-23 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-24 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-25 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-26 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-27 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-28 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-29 00:00:00', 5.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-06-30 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-01 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-02 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-03 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-04 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-05 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-06 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-07 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-08 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-09 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-10 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-11 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-12 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-13 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-14 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-15 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-16 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-17 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-18 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-19 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-20 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-21 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-22 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-23 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-24 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-25 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-26 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-27 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-28 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-29 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-30 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-07-31 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-01 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-02 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-03 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-04 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-05 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-06 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-07 00:00:00', 1.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-08 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-09 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-10 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-11 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-12 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-13 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-14 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-15 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-16 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-17 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-18 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-19 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-20 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-21 00:00:00', 0.971000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-22 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-23 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-24 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-25 00:00:00', 4.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-26 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-27 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-28 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-29 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-30 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-08-31 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-01 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-02 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-03 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-04 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-05 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-06 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-07 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-08 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-09 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-10 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-11 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-12 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-13 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-14 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-15 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-16 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-17 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-18 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-19 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-20 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-21 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-22 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-23 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-24 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-25 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-26 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-27 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-28 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-29 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-09-30 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-01 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-02 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-03 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-04 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-05 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-06 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-07 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-08 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-09 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-10 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-11 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-12 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-13 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-14 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-15 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-16 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-17 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-18 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-19 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-20 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-21 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-22 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-23 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-24 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-25 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-26 00:00:00', 4.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-27 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-28 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-29 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-30 00:00:00', 7.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-10-31 00:00:00', 6.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-01 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-02 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-03 00:00:00', 6.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-04 00:00:00', 4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-05 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-06 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-07 00:00:00', 5.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-08 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-09 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-10 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-11 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-12 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-13 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-14 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-15 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-16 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-17 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-18 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-19 00:00:00', 6.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-20 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-21 00:00:00', 6.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-22 00:00:00', 6.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-23 00:00:00', 5.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-24 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-25 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-26 00:00:00', 7.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-27 00:00:00', 5.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-28 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-29 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-11-30 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-01 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-02 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-03 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-04 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-05 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-06 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-07 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-08 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-09 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-10 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-11 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-12 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-13 00:00:00', 6.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-14 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-15 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-16 00:00:00', 4.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-17 00:00:00', 8.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-18 00:00:00', 6.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-19 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-20 00:00:00', 5.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-21 00:00:00', 6.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-22 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-23 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-24 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-25 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-26 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-27 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-28 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-29 00:00:00', 4.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-30 00:00:00', 6.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2009-12-31 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-01 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-02 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-03 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-04 00:00:00', 6.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-05 00:00:00', 5.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-06 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-07 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-08 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-09 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-10 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-11 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-12 00:00:00', 6.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-13 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-14 00:00:00', 7.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-15 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-16 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-17 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-18 00:00:00', 4.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-19 00:00:00', 5.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-20 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-21 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-22 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-23 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-24 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-25 00:00:00', 7.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-26 00:00:00', 5.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-27 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-28 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-29 00:00:00', 6.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-30 00:00:00', 5.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-01-31 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-01 00:00:00', 5.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-02 00:00:00', 6.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-03 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-04 00:00:00', 7.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-05 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-06 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-07 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-08 00:00:00', 7.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-09 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-10 00:00:00', 6.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-11 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-12 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-13 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-14 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-15 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-16 00:00:00', 6.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-17 00:00:00', 7.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-18 00:00:00', 7.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-19 00:00:00', 6.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-20 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-21 00:00:00', 6.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-22 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-23 00:00:00', 6.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-24 00:00:00', 5.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-25 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-26 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-27 00:00:00', 6.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-02-28 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-01 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-02 00:00:00', 6.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-03 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-04 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-05 00:00:00', 5.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-06 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-07 00:00:00', 5.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-08 00:00:00', 5.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-09 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-10 00:00:00', 5.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-11 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-12 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-13 00:00:00', 5.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-14 00:00:00', 7.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-15 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-16 00:00:00', 6.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-17 00:00:00', 5.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-18 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-19 00:00:00', 6.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-20 00:00:00', 6.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-21 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-22 00:00:00', 5.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-23 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-24 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-25 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-26 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-27 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-28 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-29 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-30 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-03-31 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-01 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-02 00:00:00', 5.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-03 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-04 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-05 00:00:00', 5.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-06 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-07 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-08 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-09 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-10 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-11 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-12 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-13 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-14 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-15 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-16 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-17 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-18 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-19 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-20 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-21 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-22 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-23 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-24 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-25 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-26 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-27 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-28 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-29 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-04-30 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-01 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-02 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-03 00:00:00', 4.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-04 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-05 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-06 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-07 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-08 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-09 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-10 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-11 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-12 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-13 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-14 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-15 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-16 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-17 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-18 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-19 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-20 00:00:00', 5.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-21 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-22 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-23 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-24 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-25 00:00:00', 5.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-26 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-27 00:00:00', 4.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-28 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-29 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-30 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-05-31 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-01 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-02 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-03 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-04 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-05 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-06 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-07 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-08 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-09 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-10 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-11 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-12 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-13 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-14 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-15 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-16 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-17 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-18 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-19 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-20 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-21 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-22 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-23 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-24 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-25 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-26 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-27 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-28 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-29 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-06-30 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-01 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-02 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-03 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-04 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-05 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-06 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-07 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-08 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-09 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-10 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-11 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-12 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-13 00:00:00', 0.777000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-14 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-15 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-16 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-17 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-18 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-19 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-20 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-21 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-22 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-23 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-24 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-25 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-26 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-27 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-28 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-29 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-30 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-07-31 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-01 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-02 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-03 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-04 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-05 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-06 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-07 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-08 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-09 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-10 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-11 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-12 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-13 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-14 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-15 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-16 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-17 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-18 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-19 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-20 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-21 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-22 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-23 00:00:00', 6.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-24 00:00:00', 4.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-25 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-26 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-27 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-28 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-29 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-30 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-08-31 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-01 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-02 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-03 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-04 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-05 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-06 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-07 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-08 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-09 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-10 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-11 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-12 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-13 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-14 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-15 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-16 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-17 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-18 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-19 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-20 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-21 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-22 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-23 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-24 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-25 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-26 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-27 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-28 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-29 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-09-30 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-01 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-02 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-03 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-04 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-05 00:00:00', 1.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-06 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-07 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-08 00:00:00', 5.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-09 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-10 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-11 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-12 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-13 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-14 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-15 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-16 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-17 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-18 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-19 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-20 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-21 00:00:00', 6.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-22 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-23 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-24 00:00:00', 0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-25 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-26 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-27 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-28 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-29 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-30 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-10-31 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-01 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-02 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-03 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-04 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-05 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-06 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-07 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-08 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-09 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-10 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-11 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-12 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-13 00:00:00', 0.994000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-14 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-15 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-16 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-17 00:00:00', 1.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-18 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-19 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-20 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-21 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-22 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-23 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-24 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-25 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-26 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-27 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-28 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-29 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-11-30 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-01 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-02 00:00:00', 5.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-03 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-04 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-05 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-06 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-07 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-08 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-09 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-10 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-11 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-12 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-13 00:00:00', 5.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-14 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-15 00:00:00', 4.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-16 00:00:00', 5.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-17 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-18 00:00:00', 6.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-19 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-20 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-21 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-22 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-23 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-24 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-25 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-26 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-27 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-28 00:00:00', 1.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-29 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-30 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2010-12-31 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-01 00:00:00', 6.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-02 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-03 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-04 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-05 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-06 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-07 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-08 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-09 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-10 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-11 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-12 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-13 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-14 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-15 00:00:00', 8.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-16 00:00:00', 6.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-17 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-18 00:00:00', 6.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-19 00:00:00', 6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-20 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-21 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-22 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-23 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-24 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-25 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-26 00:00:00', 8.05300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-27 00:00:00', 6.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-28 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-29 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-30 00:00:00', 6.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-01-31 00:00:00', 8.53600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-01 00:00:00', 9.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-02 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-03 00:00:00', 7.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-04 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-05 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-06 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-07 00:00:00', 6.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-08 00:00:00', 5.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-09 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-10 00:00:00', 8.39700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-11 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-12 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-13 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-14 00:00:00', 5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-15 00:00:00', 4.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-16 00:00:00', 7.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-17 00:00:00', 5.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-18 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-19 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-20 00:00:00', 8.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-21 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-22 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-23 00:00:00', 6.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-24 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-25 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-26 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-27 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-02-28 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-01 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-02 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-03 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-04 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-05 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-06 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-07 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-08 00:00:00', 6.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-09 00:00:00', 5.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-10 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-11 00:00:00', 6.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-12 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-13 00:00:00', 5.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-14 00:00:00', 5.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-15 00:00:00', 6.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-16 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-17 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-18 00:00:00', 5.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-19 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-20 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-21 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-22 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-23 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-24 00:00:00', 5.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-25 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-26 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-27 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-28 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-29 00:00:00', 1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-30 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-03-31 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-01 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-02 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-03 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-04 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-05 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-06 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-07 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-08 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-09 00:00:00', 6.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-10 00:00:00', 7.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-11 00:00:00', 6.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-12 00:00:00', 6.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-13 00:00:00', 5.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-14 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-15 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-16 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-17 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-18 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-19 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-20 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-21 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-22 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-23 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-24 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-25 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-26 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-27 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-28 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-29 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-04-30 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-01 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-02 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-03 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-04 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-05 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-06 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-07 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-08 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-09 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-10 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-11 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-12 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-13 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-14 00:00:00', 4.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-15 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-16 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-17 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-18 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-19 00:00:00', 5.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-20 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-21 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-22 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-23 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-24 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-25 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-26 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-27 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-28 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-29 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-30 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-05-31 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-01 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-02 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-03 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-04 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-05 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-06 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-07 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-08 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-09 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-10 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-11 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-12 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-13 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-14 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-15 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-16 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-17 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-18 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-19 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-20 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-21 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-22 00:00:00', 4.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-23 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-24 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-25 00:00:00', 5.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-26 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-27 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-28 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-29 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-06-30 00:00:00', 4.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-01 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-02 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-03 00:00:00', 1.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-04 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-05 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-06 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-07 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-08 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-09 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-10 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-11 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-12 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-13 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-14 00:00:00', 5.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-15 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-16 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-17 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-18 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-19 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-20 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-21 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-22 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-23 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-24 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-25 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-26 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-27 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-28 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-29 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-30 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-07-31 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-01 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-02 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-03 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-04 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-05 00:00:00', 1.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-06 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-07 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-08 00:00:00', 5.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-09 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-10 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-11 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-12 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-13 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-14 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-15 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-16 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-17 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-18 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-19 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-20 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-21 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-22 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-23 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-24 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-25 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-26 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-27 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-28 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-29 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-30 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-08-31 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-01 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-02 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-03 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-04 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-05 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-06 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-07 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-08 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-09 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-10 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-11 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-12 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-13 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-14 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-15 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-16 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-17 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-18 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-19 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-20 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-21 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-22 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-23 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-24 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-25 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-26 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-27 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-28 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-29 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-09-30 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-01 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-02 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-03 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-04 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-05 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-06 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-07 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-08 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-09 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-10 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-11 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-12 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-13 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-14 00:00:00', 5.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-15 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-16 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-17 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-18 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-19 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-20 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-21 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-22 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-23 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-24 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-25 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-26 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-27 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-28 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-29 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-30 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-10-31 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-01 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-02 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-03 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-04 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-05 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-06 00:00:00', 7.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-07 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-08 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-09 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-10 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-11 00:00:00', 5.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-12 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-13 00:00:00', 5.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-14 00:00:00', 5.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-15 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-16 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-17 00:00:00', 6.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-18 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-19 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-20 00:00:00', 6.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-21 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-22 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-23 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-24 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-25 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-26 00:00:00', 5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-27 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-28 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-29 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-11-30 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-01 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-02 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-03 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-04 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-05 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-06 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-07 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-08 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-09 00:00:00', 5.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-10 00:00:00', 6.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-11 00:00:00', 6.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-12 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-13 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-14 00:00:00', 1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-15 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-16 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-17 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-18 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-19 00:00:00', 5.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-20 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-21 00:00:00', 4.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-22 00:00:00', 8.42800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-23 00:00:00', 6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-24 00:00:00', 7.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-25 00:00:00', 6.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-26 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-27 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-28 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-29 00:00:00', 7.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-30 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2011-12-31 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-01 00:00:00', 7.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-02 00:00:00', 6.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-03 00:00:00', 5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-04 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-05 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-06 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-07 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-08 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-09 00:00:00', 7.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-10 00:00:00', 7.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-11 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-12 00:00:00', 10.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-13 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-14 00:00:00', 5.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-15 00:00:00', 5.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-16 00:00:00', 5.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-17 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-18 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-19 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-20 00:00:00', 5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-21 00:00:00', 5.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-22 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-23 00:00:00', 6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-24 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-25 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-26 00:00:00', 5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-27 00:00:00', 5.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-28 00:00:00', 6.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-29 00:00:00', 6.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-30 00:00:00', 5.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-01-31 00:00:00', 7.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-01 00:00:00', 7.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-02 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-03 00:00:00', 5.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-04 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-05 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-06 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-07 00:00:00', 5.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-08 00:00:00', 8.31200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-09 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-10 00:00:00', 6.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-11 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-12 00:00:00', 5.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-13 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-14 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-15 00:00:00', 5.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-16 00:00:00', 8.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-17 00:00:00', 7.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-18 00:00:00', 7.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-19 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-20 00:00:00', 5.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-21 00:00:00', 5.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-22 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-23 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-24 00:00:00', 6.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-25 00:00:00', 8.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-26 00:00:00', 7.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-27 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-28 00:00:00', 6.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-02-29 00:00:00', 5.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-01 00:00:00', 8.28899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-02 00:00:00', 7.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-03 00:00:00', 8.33800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-04 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-05 00:00:00', 8.64500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-06 00:00:00', 5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-07 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-08 00:00:00', 4.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-09 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-10 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-11 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-12 00:00:00', 4.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-13 00:00:00', 9.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-14 00:00:00', 7.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-15 00:00:00', 10.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-16 00:00:00', 6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-17 00:00:00', 7.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-18 00:00:00', 5.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-19 00:00:00', 6.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-20 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-21 00:00:00', 5.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-22 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-23 00:00:00', 5.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-24 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-25 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-26 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-27 00:00:00', 6.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-28 00:00:00', 7.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-29 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-30 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-03-31 00:00:00', 6.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-01 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-02 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-03 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-04 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-05 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-06 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-07 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-08 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-09 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-10 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-11 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-12 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-13 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-14 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-15 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-16 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-17 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-18 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-19 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-20 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-21 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-22 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-23 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-24 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-25 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-26 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-27 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-28 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-29 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-04-30 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-01 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-02 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-03 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-04 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-05 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-06 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-07 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-08 00:00:00', 4.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-09 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-10 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-11 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-12 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-13 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-14 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-15 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-16 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-17 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-18 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-19 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-20 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-21 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-22 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-23 00:00:00', 5.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-24 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-25 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-26 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-27 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-28 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-29 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-30 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-05-31 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-01 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-02 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-03 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-04 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-05 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-06 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-07 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-08 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-09 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-10 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-11 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-12 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-13 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-14 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-15 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-16 00:00:00', 0.864000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-17 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-18 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-19 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-20 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-21 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-22 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-23 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-24 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-25 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-26 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-27 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-28 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-29 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-06-30 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-01 00:00:00', 0.944999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-02 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-03 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-04 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-05 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-06 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-07 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-08 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-09 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-10 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-11 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-12 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-13 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-14 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-15 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-16 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-17 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-18 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-19 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-20 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-21 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-22 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-23 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-24 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-25 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-26 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-27 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-28 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-29 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-30 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-07-31 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-01 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-02 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-03 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-04 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-05 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-06 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-07 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-08 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-09 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-10 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-11 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-12 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-13 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-14 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-15 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-16 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-17 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-18 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-19 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-20 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-21 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-22 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-23 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-24 00:00:00', 5.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-25 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-26 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-27 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-28 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-29 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-30 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-08-31 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-01 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-02 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-03 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-04 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-05 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-06 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-07 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-08 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-09 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-10 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-11 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-12 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-13 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-14 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-15 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-16 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-17 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-18 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-19 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-20 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-21 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-22 00:00:00', 1.13699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-23 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-24 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-25 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-26 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-27 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-28 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-29 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-09-30 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-01 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-02 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-03 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-04 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-05 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-06 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-07 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-08 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-09 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-10 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-11 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-12 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-13 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-14 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-15 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-16 00:00:00', 0.769999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-17 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-18 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-19 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-20 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-21 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-22 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-23 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-24 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-25 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-26 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-27 00:00:00', 4.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-28 00:00:00', 5.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-29 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-30 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-10-31 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-01 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-02 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-03 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-04 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-05 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-06 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-07 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-08 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-09 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-10 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-11 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-12 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-13 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-14 00:00:00', 7.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-15 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-16 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-17 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-18 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-19 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-20 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-21 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-22 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-23 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-24 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-25 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-26 00:00:00', 6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-27 00:00:00', 5.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-28 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-29 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-11-30 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-01 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-02 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-03 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-04 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-05 00:00:00', 5.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-06 00:00:00', 6.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-07 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-08 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-09 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-10 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-11 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-12 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-13 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-14 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-15 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-16 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-17 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-18 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-19 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-20 00:00:00', 5.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-21 00:00:00', 8.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-22 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-23 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-24 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-25 00:00:00', 6.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-26 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-27 00:00:00', 5.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-28 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-29 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-30 00:00:00', 6.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2012-12-31 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-01 00:00:00', 6.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-02 00:00:00', 5.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-03 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-04 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-05 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-06 00:00:00', 6.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-07 00:00:00', 8.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-08 00:00:00', 7.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-09 00:00:00', 9.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-10 00:00:00', 10.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-11 00:00:00', 8.48200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-12 00:00:00', 6.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-13 00:00:00', 7.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-14 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-15 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-16 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-17 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-18 00:00:00', 6.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-19 00:00:00', 6.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-20 00:00:00', 8.88799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-21 00:00:00', 8.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-22 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-23 00:00:00', 9.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-24 00:00:00', 8.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-25 00:00:00', 7.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-26 00:00:00', 9.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-27 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-28 00:00:00', 7.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-29 00:00:00', 7.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-30 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-01-31 00:00:00', 6.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-01 00:00:00', 9.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-02 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-03 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-04 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-05 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-06 00:00:00', 6.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-07 00:00:00', 6.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-08 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-09 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-10 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-11 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-12 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-13 00:00:00', 5.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-14 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-15 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-16 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-17 00:00:00', 6.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-18 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-19 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-20 00:00:00', 6.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-21 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-22 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-23 00:00:00', 5.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-24 00:00:00', 6.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-25 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-26 00:00:00', 6.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-27 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-02-28 00:00:00', 9.57199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-01 00:00:00', 9.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-02 00:00:00', 8.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-03 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-04 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-05 00:00:00', 8.85700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-06 00:00:00', 7.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-07 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-08 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-09 00:00:00', 5.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-10 00:00:00', 8.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-11 00:00:00', 4.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-12 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-13 00:00:00', 4.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-14 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-15 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-16 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-17 00:00:00', 7.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-18 00:00:00', 5.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-19 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-20 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-21 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-22 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-23 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-24 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-25 00:00:00', 6.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-26 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-27 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-28 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-29 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-30 00:00:00', 4.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-03-31 00:00:00', 6.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-01 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-02 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-03 00:00:00', 1.18200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-04 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-05 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-06 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-07 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-08 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-09 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-10 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-11 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-12 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-13 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-14 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-15 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-16 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-17 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-18 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-19 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-20 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-21 00:00:00', 5.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-22 00:00:00', 6.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-23 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-24 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-25 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-26 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-27 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-28 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-29 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-04-30 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-01 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-02 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-03 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-04 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-05 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-06 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-07 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-08 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-09 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-10 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-11 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-12 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-13 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-14 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-15 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-16 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-17 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-18 00:00:00', 5.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-19 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-20 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-21 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-22 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-23 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-24 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-25 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-26 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-27 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-28 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-29 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-30 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-05-31 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-01 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-02 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-03 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-04 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-05 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-06 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-07 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-08 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-09 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-10 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-11 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-12 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-13 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-14 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-15 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-16 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-17 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-18 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-19 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-20 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-21 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-22 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-23 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-24 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-25 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-26 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-27 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-28 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-29 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-06-30 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-01 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-02 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-03 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-04 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-05 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-06 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-07 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-08 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-09 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-10 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-11 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-12 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-13 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-14 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-15 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-16 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-17 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-18 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-19 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-20 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-21 00:00:00', 5.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-22 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-23 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-24 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-25 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-26 00:00:00', 1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-27 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-28 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-29 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-30 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-07-31 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-01 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-02 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-03 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-04 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-05 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-06 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-07 00:00:00', 5.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-08 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-09 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-10 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-11 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-12 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-13 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-14 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-15 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-16 00:00:00', 1.18299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-17 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-18 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-19 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-20 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-21 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-22 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-23 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-24 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-25 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-26 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-27 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-28 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-29 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-30 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-08-31 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-01 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-02 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-03 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-04 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-05 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-06 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-07 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-08 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-09 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-10 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-11 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-12 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-13 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-14 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-15 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-16 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-17 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-18 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-19 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-20 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-21 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-22 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-23 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-24 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-25 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-26 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-27 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-28 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-29 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-09-30 00:00:00', 0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-01 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-02 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-03 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-04 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-05 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-06 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-07 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-08 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-09 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-10 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-11 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-12 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-13 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-14 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-15 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-16 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-17 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-18 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-19 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-20 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-21 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-22 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-23 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-24 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-25 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-26 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-27 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-28 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-29 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-30 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-10-31 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-01 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-02 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-03 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-04 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-05 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-06 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-07 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-08 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-09 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-10 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-11 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-12 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-13 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-14 00:00:00', 4.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-15 00:00:00', 4.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-16 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-17 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-18 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-19 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-20 00:00:00', 5.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-21 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-22 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-23 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-24 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-25 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-26 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-27 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-28 00:00:00', 5.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-29 00:00:00', 6.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-11-30 00:00:00', 6.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-01 00:00:00', 6.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-02 00:00:00', 4.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-03 00:00:00', 7.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-04 00:00:00', 7.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-05 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-06 00:00:00', 6.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-07 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-08 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-09 00:00:00', 7.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-10 00:00:00', 7.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-11 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-12 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-13 00:00:00', 8.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-14 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-15 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-16 00:00:00', 6.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-17 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-18 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-19 00:00:00', 6.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-20 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-21 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-22 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-23 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-24 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-25 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-26 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-27 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-28 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-29 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-30 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2013-12-31 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-01 00:00:00', 7.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-02 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-03 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-04 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-05 00:00:00', 0.584999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-06 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-07 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-08 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-09 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-10 00:00:00', 5.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-11 00:00:00', 7.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-12 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-13 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-14 00:00:00', 6.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-15 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-16 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-17 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-18 00:00:00', 5.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-19 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-20 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-21 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-22 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-23 00:00:00', 7.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-24 00:00:00', 5.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-25 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-26 00:00:00', 6.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-27 00:00:00', 5.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-28 00:00:00', 7.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-29 00:00:00', 6.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-30 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-01-31 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-01 00:00:00', 7.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-02 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-03 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-04 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-05 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-06 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-07 00:00:00', 5.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-08 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-09 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-10 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-11 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-12 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-13 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-14 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-15 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-16 00:00:00', 8.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-17 00:00:00', 6.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-18 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-19 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-20 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-21 00:00:00', 4.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-22 00:00:00', 5.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-23 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-24 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-25 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-26 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-27 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-02-28 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-01 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-02 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-03 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-04 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-05 00:00:00', 7.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-06 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-07 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-08 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-09 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-10 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-11 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-12 00:00:00', 8.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-13 00:00:00', 8.61200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-14 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-15 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-16 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-17 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-18 00:00:00', 6.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-19 00:00:00', 7.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-20 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-21 00:00:00', 0.884999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-22 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-23 00:00:00', 6.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-24 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-25 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-26 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-27 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-28 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-29 00:00:00', 6.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-30 00:00:00', 7.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-03-31 00:00:00', 6.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-01 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-02 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-03 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-04 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-05 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-06 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-07 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-08 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-09 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-10 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-11 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-12 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-13 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-14 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-15 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-16 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-17 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-18 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-19 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-20 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-21 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-22 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-23 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-24 00:00:00', 4.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-25 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-26 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-27 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-28 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-29 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-04-30 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-01 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-02 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-03 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-04 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-05 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-06 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-07 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-08 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-09 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-10 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-11 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-12 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-13 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-14 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-15 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-16 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-17 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-18 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-19 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-20 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-21 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-22 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-23 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-24 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-25 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-26 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-27 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-28 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-29 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-30 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-05-31 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-01 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-02 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-03 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-04 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-05 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-06 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-07 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-08 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-09 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-10 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-11 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-12 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-13 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-14 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-15 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-16 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-17 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-18 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-19 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-20 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-21 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-22 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-23 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-24 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-25 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-26 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-27 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-28 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-29 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-06-30 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-01 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-02 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-03 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-04 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-05 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-06 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-07 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-08 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-09 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-10 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-11 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-12 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-13 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-14 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-15 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-16 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-17 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-18 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-19 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-20 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-21 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-22 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-23 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-24 00:00:00', 4.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-25 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-26 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-27 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-28 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-29 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-30 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (29, '2014-07-31 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-01 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-02 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-03 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-04 00:00:00', 5.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-05 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-06 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-07 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-08 00:00:00', 5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-09 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-10 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-11 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-12 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-13 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-14 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-15 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-16 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-17 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-18 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-19 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-20 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-21 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-22 00:00:00', 6.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-23 00:00:00', 4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-24 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-25 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-26 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-27 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-28 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-29 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-30 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-01-31 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-01 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-02 00:00:00', 4.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-03 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-04 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-05 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-06 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-07 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-08 00:00:00', 5.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-09 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-10 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-11 00:00:00', 6.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-12 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-13 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-14 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-15 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-16 00:00:00', 5.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-17 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-18 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-19 00:00:00', 7.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-20 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-21 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-22 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-23 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-24 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-25 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-26 00:00:00', 5.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-27 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-02-28 00:00:00', 4.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-01 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-02 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-03 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-04 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-05 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-06 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-07 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-08 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-09 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-10 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-11 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-12 00:00:00', 4.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-13 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-14 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-15 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-16 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-17 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-18 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-19 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-20 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-21 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-22 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-23 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-24 00:00:00', 5.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-25 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-26 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-27 00:00:00', 6.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-28 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-29 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-30 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-03-31 00:00:00', 4.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-01 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-02 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-03 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-04 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-05 00:00:00', 5.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-06 00:00:00', 5.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-07 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-08 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-09 00:00:00', 4.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-10 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-11 00:00:00', 6.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-12 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-13 00:00:00', 5.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-14 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-15 00:00:00', 6.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-16 00:00:00', 6.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-17 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-18 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-19 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-20 00:00:00', 6.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-21 00:00:00', 7.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-22 00:00:00', 6.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-23 00:00:00', 6.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-24 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-25 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-26 00:00:00', 5.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-27 00:00:00', 6.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-28 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-29 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-04-30 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-01 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-02 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-03 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-04 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-05 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-06 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-07 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-08 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-09 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-10 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-11 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-12 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-13 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-14 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-15 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-16 00:00:00', 4.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-17 00:00:00', 6.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-18 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-19 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-20 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-21 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-22 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-23 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-24 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-25 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-26 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-27 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-28 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-29 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-30 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-05-31 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-01 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-02 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-03 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-04 00:00:00', 5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-05 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-06 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-07 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-08 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-09 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-10 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-11 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-12 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-13 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-14 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-15 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-16 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-17 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-18 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-19 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-20 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-21 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-22 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-23 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-24 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-25 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-26 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-27 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-28 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-29 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-06-30 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-01 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-02 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-03 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-04 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-05 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-06 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-07 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-08 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-09 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-10 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-11 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-12 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-13 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-14 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-15 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-16 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-17 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-18 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-19 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-20 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-21 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-22 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-23 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-24 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-25 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-26 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-27 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-28 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-29 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-30 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-07-31 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-01 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-02 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-03 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-04 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-05 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-06 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-07 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-08 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-09 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-10 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-11 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-12 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-13 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-14 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-15 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-16 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-17 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-18 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-19 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-20 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-21 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-22 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-23 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-24 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-25 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-26 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-27 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-28 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-29 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-30 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-08-31 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-01 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-02 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-03 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-04 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-05 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-06 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-07 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-08 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-09 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-10 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-11 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-12 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-13 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-14 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-15 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-16 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-17 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-18 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-19 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-20 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-21 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-22 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-23 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-24 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-25 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-26 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-27 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-28 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-29 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-09-30 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-01 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-02 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-03 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-04 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-05 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-06 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-07 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-08 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-09 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-10 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-11 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-12 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-13 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-14 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-15 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-16 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-17 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-18 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-19 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-20 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-21 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-22 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-23 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-24 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-25 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-26 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-27 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-28 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-29 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-30 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-10-31 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-01 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-02 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-03 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-04 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-05 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-06 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-07 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-08 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-09 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-10 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-11 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-12 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-13 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-14 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-15 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-16 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-17 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-18 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-19 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-20 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-21 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-22 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-23 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-24 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-25 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-26 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-27 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-28 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-29 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-11-30 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-01 00:00:00', 5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-02 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-03 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-04 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-05 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-06 00:00:00', 4.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-07 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-08 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-09 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-10 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-11 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-12 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-13 00:00:00', 5.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-14 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-15 00:00:00', 4.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-16 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-17 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-18 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-19 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-20 00:00:00', 6.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-21 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-22 00:00:00', 5.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-23 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-24 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-25 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-26 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-27 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-28 00:00:00', 5.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-29 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-30 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1979-12-31 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-01 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-02 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-03 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-04 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-05 00:00:00', 5.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-06 00:00:00', 6.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-07 00:00:00', 5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-08 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-09 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-10 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-11 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-12 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-13 00:00:00', 4.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-14 00:00:00', 5.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-15 00:00:00', 5.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-16 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-17 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-18 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-19 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-20 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-21 00:00:00', 5.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-22 00:00:00', 5.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-23 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-24 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-25 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-26 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-27 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-28 00:00:00', 5.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-29 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-30 00:00:00', 4.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-01-31 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-01 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-02 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-03 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-04 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-05 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-06 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-07 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-08 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-09 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-10 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-11 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-12 00:00:00', 6.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-13 00:00:00', 4.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-14 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-15 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-16 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-17 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-18 00:00:00', 6.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-19 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-20 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-21 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-22 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-23 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-24 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-25 00:00:00', 6.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-26 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-27 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-28 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-02-29 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-01 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-02 00:00:00', 6.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-03 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-04 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-05 00:00:00', 5.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-06 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-07 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-08 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-09 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-10 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-11 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-12 00:00:00', 4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-13 00:00:00', 5.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-14 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-15 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-16 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-17 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-18 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-19 00:00:00', 7.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-20 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-21 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-22 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-23 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-24 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-25 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-26 00:00:00', 5.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-27 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-28 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-29 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-30 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-03-31 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-01 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-02 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-03 00:00:00', 6.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-04 00:00:00', 7.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-05 00:00:00', 5.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-06 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-07 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-08 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-09 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-10 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-11 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-12 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-13 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-14 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-15 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-16 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-17 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-18 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-19 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-20 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-21 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-22 00:00:00', 4.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-23 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-24 00:00:00', 5.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-25 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-26 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-27 00:00:00', 6.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-28 00:00:00', 5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-29 00:00:00', 6.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-04-30 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-01 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-02 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-03 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-04 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-05 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-06 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-07 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-08 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-09 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-10 00:00:00', 5.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-11 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-12 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-13 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-14 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-15 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-16 00:00:00', 4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-17 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-18 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-19 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-20 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-21 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-22 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-23 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-24 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-25 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-26 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-27 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-28 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-29 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-30 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-05-31 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-01 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-02 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-03 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-04 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-05 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-06 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-07 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-08 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-09 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-10 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-11 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-12 00:00:00', 4.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-13 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-14 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-15 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-16 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-17 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-18 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-19 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-20 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-21 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-22 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-23 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-24 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-25 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-26 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-27 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-28 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-29 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-06-30 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-01 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-02 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-03 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-04 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-05 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-06 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-07 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-08 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-09 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-10 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-11 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-12 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-13 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-14 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-15 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-16 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-17 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-18 00:00:00', 6.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-19 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-20 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-21 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-22 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-23 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-24 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-25 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-26 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-27 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-28 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-29 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-30 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-07-31 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-01 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-02 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-03 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-04 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-05 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-06 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-07 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-08 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-09 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-10 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-11 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-12 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-13 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-14 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-15 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-16 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-17 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-18 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-19 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-20 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-21 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-22 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-23 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-24 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-25 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-26 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-27 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-28 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-29 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-30 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-08-31 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-01 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-02 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-03 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-04 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-05 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-06 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-07 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-08 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-09 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-10 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-11 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-12 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-13 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-14 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-15 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-16 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-17 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-18 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-19 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-20 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-21 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-22 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-23 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-24 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-25 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-26 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-27 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-28 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-29 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-09-30 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-01 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-02 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-03 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-04 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-05 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-06 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-07 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-08 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-09 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-10 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-11 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-12 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-13 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-14 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-15 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-16 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-17 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-18 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-19 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-20 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-21 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-22 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-23 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-24 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-25 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-26 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-27 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-28 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-29 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-30 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-10-31 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-01 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-02 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-03 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-04 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-05 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-06 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-07 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-08 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-09 00:00:00', 4.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-10 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-11 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-12 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-13 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-14 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-15 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-16 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-17 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-18 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-19 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-20 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-21 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-22 00:00:00', 5.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-23 00:00:00', 6.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-24 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-25 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-26 00:00:00', 5.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-27 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-28 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-29 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-11-30 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-01 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-02 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-03 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-04 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-05 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-06 00:00:00', 5.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-07 00:00:00', 5.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-08 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-09 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-10 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-11 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-12 00:00:00', 6.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-13 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-14 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-15 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-16 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-17 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-18 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-19 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-20 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-21 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-22 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-23 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-24 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-25 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-26 00:00:00', 5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-27 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-28 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-29 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-30 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1980-12-31 00:00:00', 5.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-01 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-02 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-03 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-04 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-05 00:00:00', 5.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-06 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-07 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-08 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-09 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-10 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-11 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-12 00:00:00', 5.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-13 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-14 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-15 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-16 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-17 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-18 00:00:00', 6.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-19 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-20 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-21 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-22 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-23 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-24 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-25 00:00:00', 5.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-26 00:00:00', 5.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-27 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-28 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-29 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-30 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-01-31 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-01 00:00:00', 6.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-02 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-03 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-04 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-05 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-06 00:00:00', 4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-07 00:00:00', 3.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-08 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-09 00:00:00', 6.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-10 00:00:00', 5.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-11 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-12 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-13 00:00:00', 5.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-14 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-15 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-16 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-17 00:00:00', 6.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-18 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-19 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-20 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-21 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-22 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-23 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-24 00:00:00', 4.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-25 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-26 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-27 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-02-28 00:00:00', 5.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-01 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-02 00:00:00', 6.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-03 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-04 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-05 00:00:00', 1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-06 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-07 00:00:00', 5.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-08 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-09 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-10 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-11 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-12 00:00:00', 6.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-13 00:00:00', 6.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-14 00:00:00', 5.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-15 00:00:00', 4.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-16 00:00:00', 5.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-17 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-18 00:00:00', 4.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-19 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-20 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-21 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-22 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-23 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-24 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-25 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-26 00:00:00', 4.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-27 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-28 00:00:00', 7.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-29 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-30 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-03-31 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-01 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-02 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-03 00:00:00', 5.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-04 00:00:00', 5.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-05 00:00:00', 5.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-06 00:00:00', 7.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-07 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-08 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-09 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-10 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-11 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-12 00:00:00', 5.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-13 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-14 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-15 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-16 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-17 00:00:00', 5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-18 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-19 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-20 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-21 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-22 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-23 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-24 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-25 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-26 00:00:00', 5.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-27 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-28 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-29 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-04-30 00:00:00', 5.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-01 00:00:00', 5.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-02 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-03 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-04 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-05 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-06 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-07 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-08 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-09 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-10 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-11 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-12 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-13 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-14 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-15 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-16 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-17 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-18 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-19 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-20 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-21 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-22 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-23 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-24 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-25 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-26 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-27 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-28 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-29 00:00:00', 5.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-30 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-05-31 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-01 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-02 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-03 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-04 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-05 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-06 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-07 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-08 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-09 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-10 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-11 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-12 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-13 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-14 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-15 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-16 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-17 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-18 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-19 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-20 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-21 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-22 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-23 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-24 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-25 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-26 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-27 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-28 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-29 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-06-30 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-01 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-02 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-03 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-04 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-05 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-06 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-07 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-08 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-09 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-10 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-11 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-12 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-13 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-14 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-15 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-16 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-17 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-18 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-19 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-20 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-21 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-22 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-23 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-24 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-25 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-26 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-27 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-28 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-29 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-30 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-07-31 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-01 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-02 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-03 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-04 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-05 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-06 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-07 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-08 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-09 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-10 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-11 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-12 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-13 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-14 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-15 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-16 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-17 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-18 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-19 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-20 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-21 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-22 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-23 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-24 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-25 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-26 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-27 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-28 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-29 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-30 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-08-31 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-01 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-02 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-03 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-04 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-05 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-06 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-07 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-08 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-09 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-10 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-11 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-12 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-13 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-14 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-15 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-16 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-17 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-18 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-19 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-20 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-21 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-22 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-23 00:00:00', 5.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-24 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-25 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-26 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-27 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-28 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-29 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-09-30 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-01 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-02 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-03 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-04 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-05 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-06 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-07 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-08 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-09 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-10 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-11 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-12 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-13 00:00:00', 4.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-14 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-15 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-16 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-17 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-18 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-19 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-20 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-21 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-22 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-23 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-24 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-25 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-26 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-27 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-28 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-29 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-30 00:00:00', 0.819999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-10-31 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-01 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-02 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-03 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-04 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-05 00:00:00', 4.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-06 00:00:00', 4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-07 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-08 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-09 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-10 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-11 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-12 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-13 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-14 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-15 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-16 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-17 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-18 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-19 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-20 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-21 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-22 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-23 00:00:00', 7.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-24 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-25 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-26 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-27 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-28 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-29 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-11-30 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-01 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-02 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-03 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-04 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-05 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-06 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-07 00:00:00', 6.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-08 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-09 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-10 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-11 00:00:00', 5.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-12 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-13 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-14 00:00:00', 4.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-15 00:00:00', 6.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-16 00:00:00', 6.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-17 00:00:00', 6.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-18 00:00:00', 6.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-19 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-20 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-21 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-22 00:00:00', 6.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-23 00:00:00', 6.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-24 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-25 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-26 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-27 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-28 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-29 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-30 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1981-12-31 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-01 00:00:00', 4.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-02 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-03 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-04 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-05 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-06 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-07 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-08 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-09 00:00:00', 5.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-10 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-11 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-12 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-13 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-14 00:00:00', 5.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-15 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-16 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-17 00:00:00', 4.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-18 00:00:00', 5.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-19 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-20 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-21 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-22 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-23 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-24 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-25 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-26 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-27 00:00:00', 5.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-28 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-29 00:00:00', 8.29599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-30 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-01-31 00:00:00', 5.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-01 00:00:00', 7.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-02 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-03 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-04 00:00:00', 6.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-05 00:00:00', 6.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-06 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-07 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-08 00:00:00', 5.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-09 00:00:00', 4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-10 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-11 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-12 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-13 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-14 00:00:00', 5.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-15 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-16 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-17 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-18 00:00:00', 5.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-19 00:00:00', 6.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-20 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-21 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-22 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-23 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-24 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-25 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-26 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-27 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-02-28 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-01 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-02 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-03 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-04 00:00:00', 4.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-05 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-06 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-07 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-08 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-09 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-10 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-11 00:00:00', 5.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-12 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-13 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-14 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-15 00:00:00', 5.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-16 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-17 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-18 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-19 00:00:00', 6.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-20 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-21 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-22 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-23 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-24 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-25 00:00:00', 6.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-26 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-27 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-28 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-29 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-30 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-03-31 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-01 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-02 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-03 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-04 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-05 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-06 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-07 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-08 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-09 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-10 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-11 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-12 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-13 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-14 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-15 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-16 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-17 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-18 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-19 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-20 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-21 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-22 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-23 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-24 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-25 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-26 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-27 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-28 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-29 00:00:00', 4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-04-30 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-01 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-02 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-03 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-04 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-05 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-06 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-07 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-08 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-09 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-10 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-11 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-12 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-13 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-14 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-15 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-16 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-17 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-18 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-19 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-20 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-21 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-22 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-23 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-24 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-25 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-26 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-27 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-28 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-29 00:00:00', 4.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-30 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-05-31 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-01 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-02 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-03 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-04 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-05 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-06 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-07 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-08 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-09 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-10 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-11 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-12 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-13 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-14 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-15 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-16 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-17 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-18 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-19 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-20 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-21 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-22 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-23 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-24 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-25 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-26 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-27 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-28 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-29 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-06-30 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-01 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-02 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-03 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-04 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-05 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-06 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-07 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-08 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-09 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-10 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-11 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-12 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-13 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-14 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-15 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-16 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-17 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-18 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-19 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-20 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-21 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-22 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-23 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-24 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-25 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-26 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-27 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-28 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-29 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-30 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-07-31 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-01 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-02 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-03 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-04 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-05 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-06 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-07 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-08 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-09 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-10 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-11 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-12 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-13 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-14 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-15 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-16 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-17 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-18 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-19 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-20 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-21 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-22 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-23 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-24 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-25 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-26 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-27 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-28 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-29 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-30 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-08-31 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-01 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-02 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-03 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-04 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-05 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-06 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-07 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-08 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-09 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-10 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-11 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-12 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-13 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-14 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-15 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-16 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-17 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-18 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-19 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-20 00:00:00', 4.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-21 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-22 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-23 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-24 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-25 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-26 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-27 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-28 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-29 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-09-30 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-01 00:00:00', 4.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-02 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-03 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-04 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-05 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-06 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-07 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-08 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-09 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-10 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-11 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-12 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-13 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-14 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-15 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-16 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-17 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-18 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-19 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-20 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-21 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-22 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-23 00:00:00', 1.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-24 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-25 00:00:00', 7.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-26 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-27 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-28 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-29 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-30 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-10-31 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-01 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-02 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-03 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-04 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-05 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-06 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-07 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-08 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-09 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-10 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-11 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-12 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-13 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-14 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-15 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-16 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-17 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-18 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-19 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-20 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-21 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-22 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-23 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-24 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-25 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-26 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-27 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-28 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-29 00:00:00', 0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-11-30 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-01 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-02 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-03 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-04 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-05 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-06 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-07 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-08 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-09 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-10 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-11 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-12 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-13 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-14 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-15 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-16 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-17 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-18 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-19 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-20 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-21 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-22 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-23 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-24 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-25 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-26 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-27 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-28 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-29 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-30 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1982-12-31 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-01 00:00:00', 5.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-02 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-03 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-04 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-05 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-06 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-07 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-08 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-09 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-10 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-11 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-12 00:00:00', 4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-13 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-14 00:00:00', 5.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-15 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-16 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-17 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-18 00:00:00', 4.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-19 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-20 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-21 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-22 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-23 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-24 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-25 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-26 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-27 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-28 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-29 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-30 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-01-31 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-01 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-02 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-03 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-04 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-05 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-06 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-07 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-08 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-09 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-10 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-11 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-12 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-13 00:00:00', 1.07400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-14 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-15 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-16 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-17 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-18 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-19 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-20 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-21 00:00:00', 6.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-22 00:00:00', 6.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-23 00:00:00', 5.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-24 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-25 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-26 00:00:00', 5.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-27 00:00:00', 6.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-02-28 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-01 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-02 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-03 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-04 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-05 00:00:00', 6.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-06 00:00:00', 6.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-07 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-08 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-09 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-10 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-11 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-12 00:00:00', 5.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-13 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-14 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-15 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-16 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-17 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-18 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-19 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-20 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-21 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-22 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-23 00:00:00', 5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-24 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-25 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-26 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-27 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-28 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-29 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-30 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-03-31 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-01 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-02 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-03 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-04 00:00:00', 0.828000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-05 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-06 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-07 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-08 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-09 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-10 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-11 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-12 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-13 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-14 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-15 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-16 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-17 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-18 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-19 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-20 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-21 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-22 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-23 00:00:00', 4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-24 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-25 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-26 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-27 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-28 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-29 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-04-30 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-01 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-02 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-03 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-04 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-05 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-06 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-07 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-08 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-09 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-10 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-11 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-12 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-13 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-14 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-15 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-16 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-17 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-18 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-19 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-20 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-21 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-22 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-23 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-24 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-25 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-26 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-27 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-28 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-29 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-30 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-05-31 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-01 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-02 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-03 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-04 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-05 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-06 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-07 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-08 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-09 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-10 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-11 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-12 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-13 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-14 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-15 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-16 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-17 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-18 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-19 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-20 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-21 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-22 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-23 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-24 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-25 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-26 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-27 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-28 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-29 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-06-30 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-01 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-02 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-03 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-04 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-05 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-06 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-07 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-08 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-09 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-10 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-11 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-12 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-13 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-14 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-15 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-16 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-17 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-18 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-19 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-20 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-21 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-22 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-23 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-24 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-25 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-26 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-27 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-28 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-29 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-30 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-07-31 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-01 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-02 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-03 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-04 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-05 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-06 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-07 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-08 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-09 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-10 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-11 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-12 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-13 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-14 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-15 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-16 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-17 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-18 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-19 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-20 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-21 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-22 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-23 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-24 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-25 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-26 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-27 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-28 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-29 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-30 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-08-31 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-01 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-03 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-05 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-07 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-09 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-11 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-13 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-15 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-17 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-19 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-21 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-23 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-25 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-27 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-29 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-01 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-03 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-05 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-07 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-09 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-11 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-13 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-15 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-17 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-19 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-21 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-23 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-25 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-27 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-29 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-30 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-10-31 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-01 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-02 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-03 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-04 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-05 00:00:00', 5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-06 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-07 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-08 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-09 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-10 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-11 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-12 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-13 00:00:00', 5.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-14 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-15 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-16 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-17 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-18 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-19 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-20 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-21 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-22 00:00:00', 4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-23 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-24 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-25 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-26 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-27 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-28 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-29 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-11-30 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-01 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-02 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-03 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-04 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-05 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-06 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-07 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-08 00:00:00', 4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-09 00:00:00', 5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-10 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-11 00:00:00', 5.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-12 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-13 00:00:00', 5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-14 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-15 00:00:00', 6.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-16 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-17 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-18 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-19 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-20 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-21 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-22 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-23 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-24 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-25 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-26 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-27 00:00:00', 4.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-28 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-29 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-30 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1983-12-31 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-01 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-02 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-03 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-04 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-05 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-06 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-07 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-08 00:00:00', 4.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-09 00:00:00', 5.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-10 00:00:00', 4.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-11 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-12 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-13 00:00:00', 5.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-14 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-15 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-16 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-17 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-18 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-19 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-20 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-21 00:00:00', 1.13699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-22 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-23 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-24 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-25 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-26 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-27 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-28 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-29 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-30 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-01-31 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-01 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-02 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-03 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-04 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-05 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-06 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-07 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-08 00:00:00', 6.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-09 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-10 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-11 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-12 00:00:00', 5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-13 00:00:00', 5.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-14 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-15 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-16 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-17 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-18 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-19 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-20 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-21 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-22 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-23 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-24 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-25 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-26 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-27 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-28 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-02-29 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-01 00:00:00', 5.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-02 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-03 00:00:00', 4.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-04 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-05 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-06 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-07 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-08 00:00:00', 4.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-09 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-10 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-11 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-12 00:00:00', 6.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-13 00:00:00', 5.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-14 00:00:00', 4.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-15 00:00:00', 5.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-16 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-17 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-18 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-19 00:00:00', 6.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-20 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-21 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-22 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-23 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-24 00:00:00', 4.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-25 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-26 00:00:00', 6.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-27 00:00:00', 6.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-28 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-29 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-30 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-03-31 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-01 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-02 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-03 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-04 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-05 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-06 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-07 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-08 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-09 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-10 00:00:00', 6.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-11 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-12 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-13 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-14 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-15 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-16 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-17 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-18 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-19 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-20 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-21 00:00:00', 4.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-22 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-23 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-24 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-25 00:00:00', 5.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-26 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-27 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-28 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-29 00:00:00', 4.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-04-30 00:00:00', 5.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-01 00:00:00', 6.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-02 00:00:00', 6.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-03 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-04 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-05 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-06 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-07 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-08 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-09 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-10 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-11 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-12 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-13 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-14 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-15 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-16 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-17 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-18 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-19 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-20 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-21 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-22 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-23 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-24 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-25 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-26 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-27 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-28 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-29 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-30 00:00:00', 5.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-05-31 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-01 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-02 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-03 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-04 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-05 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-06 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-07 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-08 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-09 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-10 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-11 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-12 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-13 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-14 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-15 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-16 00:00:00', 5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-17 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-18 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-19 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-20 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-21 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-22 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-23 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-24 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-25 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-26 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-27 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-28 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-29 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-06-30 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-01 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-02 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-03 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-04 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-05 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-06 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-07 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-08 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-09 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-10 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-11 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-12 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-13 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-14 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-15 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-16 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-17 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-18 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-19 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-20 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-21 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-22 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-23 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-24 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-25 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-26 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-27 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-28 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-29 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-30 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-07-31 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-01 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-02 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-03 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-04 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-05 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-06 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-07 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-08 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-09 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-10 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-11 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-12 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-13 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-14 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-15 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-16 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-17 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-18 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-19 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-20 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-21 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-22 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-23 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-24 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-25 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-26 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-27 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-28 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-29 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-30 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-08-31 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-01 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-02 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-03 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-04 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-05 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-06 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-07 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-08 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-09 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-10 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-11 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-12 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-13 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-14 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-15 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-16 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-17 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-18 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-19 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-20 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-21 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-22 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-23 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-24 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-25 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-26 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-27 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-28 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-29 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-09-30 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-01 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-02 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-03 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-04 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-05 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-06 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-07 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-08 00:00:00', 6.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-09 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-10 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-11 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-12 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-13 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-14 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-15 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-16 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-17 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-18 00:00:00', 5.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-19 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-20 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-21 00:00:00', 5.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-22 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-23 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-24 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-25 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-26 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-27 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-28 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-29 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-30 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-10-31 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-01 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-02 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-03 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-04 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-05 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-06 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-07 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-08 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-09 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-10 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-11 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-12 00:00:00', 5.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-13 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-14 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-15 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-16 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-17 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-18 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-19 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-20 00:00:00', 1.13399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-21 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-22 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-23 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-24 00:00:00', 6.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-25 00:00:00', 5.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-26 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-27 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-28 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-29 00:00:00', 6.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-11-30 00:00:00', 6.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-01 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-02 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-03 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-04 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-05 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-06 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-07 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-08 00:00:00', 4.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-09 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-10 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-11 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-12 00:00:00', 4.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-13 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-14 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-15 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-16 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-17 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-18 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-19 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-20 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-21 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-22 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-23 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-24 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-25 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-26 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-27 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-28 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-29 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-30 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1984-12-31 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-01 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-02 00:00:00', 6.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-03 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-04 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-05 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-06 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-07 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-08 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-09 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-10 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-11 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-12 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-13 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-14 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-15 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-16 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-17 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-18 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-19 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-20 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-21 00:00:00', 6.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-22 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-23 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-24 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-25 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-26 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-27 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-28 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-29 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-30 00:00:00', 4.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-01-31 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-01 00:00:00', 6.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-02 00:00:00', 6.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-03 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-04 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-05 00:00:00', 7.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-06 00:00:00', 6.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-07 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-08 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-09 00:00:00', 6.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-10 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-11 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-12 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-13 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-14 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-15 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-16 00:00:00', 6.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-17 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-18 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-19 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-20 00:00:00', 4.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-21 00:00:00', 5.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-22 00:00:00', 5.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-23 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-24 00:00:00', 5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-25 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-26 00:00:00', 6.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-27 00:00:00', 6.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-02-28 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-01 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-02 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-03 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-04 00:00:00', 5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-05 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-06 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-07 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-08 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-09 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-10 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-11 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-12 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-13 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-14 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-15 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-16 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-17 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-18 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-19 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-20 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-21 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-22 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-23 00:00:00', 3.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-24 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-25 00:00:00', 5.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-26 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-27 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-28 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-29 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-30 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-03-31 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-01 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-02 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-03 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-04 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-05 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-06 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-07 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-08 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-09 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-10 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-11 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-12 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-13 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-14 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-15 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-16 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-17 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-18 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-19 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-20 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-21 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-22 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-23 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-24 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-25 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-26 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-27 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-28 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-29 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-04-30 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-01 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-02 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-03 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-04 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-05 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-06 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-07 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-08 00:00:00', 1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-09 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-10 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-11 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-12 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-13 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-14 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-15 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-16 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-17 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-18 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-19 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-20 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-21 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-22 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-23 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-24 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-25 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-26 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-27 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-28 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-29 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-30 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-05-31 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-01 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-02 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-03 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-04 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-05 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-06 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-07 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-08 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-09 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-10 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-11 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-12 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-13 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-14 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-15 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-16 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-17 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-18 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-19 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-20 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-21 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-22 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-23 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-24 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-25 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-26 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-27 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-28 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-29 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-06-30 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-01 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-02 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-03 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-04 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-05 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-06 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-07 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-08 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-09 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-10 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-11 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-12 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-13 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-14 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-15 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-16 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-17 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-18 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-19 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-20 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-21 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-22 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-23 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-24 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-25 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-26 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-27 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-28 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-29 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-30 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-07-31 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-01 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-02 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-03 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-04 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-05 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-06 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-07 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-08 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-09 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-10 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-11 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-12 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-13 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-14 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-15 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-16 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-17 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-18 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-19 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-20 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-21 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-22 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-23 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-24 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-25 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-26 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-27 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-28 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-29 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-30 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-08-31 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-01 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-02 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-03 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-04 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-05 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-06 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-07 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-08 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-09 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-10 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-11 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-12 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-13 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-14 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-15 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-16 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-17 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-18 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-19 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-20 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-21 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-22 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-23 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-24 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-25 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-26 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-27 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-28 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-29 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-09-30 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-01 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-02 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-03 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-04 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-05 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-06 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-07 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-08 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-09 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-10 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-11 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-12 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-13 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-14 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-15 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-16 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-17 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-18 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-19 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-20 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-21 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-22 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-23 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-24 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-25 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-26 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-27 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-28 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-29 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-30 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-10-31 00:00:00', 6.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-01 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-02 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-03 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-04 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-05 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-06 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-07 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-08 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-09 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-10 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-11 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-12 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-13 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-14 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-15 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-16 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-17 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-18 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-19 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-20 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-21 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-22 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-23 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-24 00:00:00', 0.976000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-25 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-26 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-27 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-28 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-29 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-11-30 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-01 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-02 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-03 00:00:00', 4.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-04 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-05 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-06 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-07 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-08 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-09 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-10 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-11 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-12 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-13 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-14 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-15 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-16 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-17 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-18 00:00:00', 6.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-19 00:00:00', 8.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-20 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-21 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-22 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-23 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-24 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-25 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-26 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-27 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-28 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-29 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-30 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1985-12-31 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-01 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-02 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-03 00:00:00', 4.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-04 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-05 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-06 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-07 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-08 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-09 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-10 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-11 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-12 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-13 00:00:00', 6.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-14 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-15 00:00:00', 6.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-16 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-17 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-18 00:00:00', 6.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-19 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-20 00:00:00', 6.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-21 00:00:00', 6.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-22 00:00:00', 5.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-23 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-24 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-25 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-26 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-27 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-28 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-29 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-30 00:00:00', 5.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-01-31 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-01 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-02 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-03 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-04 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-05 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-06 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-07 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-08 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-09 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-10 00:00:00', 4.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-11 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-12 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-13 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-14 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-15 00:00:00', 5.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-16 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-17 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-18 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-19 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-20 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-21 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-22 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-23 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-24 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-25 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-26 00:00:00', 5.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-27 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-02-28 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-01 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-02 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-03 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-04 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-05 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-06 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-07 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-08 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-09 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-10 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-11 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-12 00:00:00', 6.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-13 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-14 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-15 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-16 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-17 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-18 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-19 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-20 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-21 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-22 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-23 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-24 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-25 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-26 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-27 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-28 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-29 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-30 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-03-31 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-01 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-02 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-03 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-04 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-05 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-06 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-07 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-08 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-09 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-10 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-11 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-12 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-13 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-14 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-15 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-16 00:00:00', 4.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-17 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-18 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-19 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-20 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-21 00:00:00', 4.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-22 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-23 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-24 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-25 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-26 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-27 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-28 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-29 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-04-30 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-01 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-02 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-03 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-04 00:00:00', 5.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-05 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-06 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-07 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-08 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-09 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-10 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-11 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-12 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-13 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-14 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-15 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-16 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-17 00:00:00', 5.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-18 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-19 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-20 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-21 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-22 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-23 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-24 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-25 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-26 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-27 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-28 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-29 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-30 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-01 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-02 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-03 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-04 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-05 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-06 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-07 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-08 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-09 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-10 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-11 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-12 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-13 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-14 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-15 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-16 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-17 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-18 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-19 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-20 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-21 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-22 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-23 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-24 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-25 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-26 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-27 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-28 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-29 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-06-30 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-01 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-02 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-03 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-04 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-05 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-06 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-07 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-08 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-09 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-10 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-11 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-12 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-13 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-14 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-15 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-16 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-17 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-18 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-19 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-20 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-21 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-22 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-23 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-24 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-25 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-26 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-27 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-28 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-29 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-30 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-07-31 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-01 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-02 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-03 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-04 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-05 00:00:00', 5.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-06 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-07 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-08 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-09 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-10 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-11 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-12 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-13 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-14 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-15 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-16 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-17 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-18 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-19 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-20 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-21 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-22 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-23 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-24 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-25 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-26 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-27 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-28 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-29 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-30 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-08-31 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-01 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-02 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-03 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-04 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-05 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-06 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-07 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-08 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-09 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-10 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-11 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-12 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-13 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-14 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-15 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-16 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-17 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-18 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-19 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-20 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-21 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-22 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-23 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-24 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-25 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-26 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-27 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-28 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-29 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-09-30 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-01 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-02 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-03 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-04 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-05 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-06 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-07 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-08 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-09 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-10 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-11 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-12 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-13 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-14 00:00:00', 5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-15 00:00:00', 4.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-16 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-17 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-18 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-19 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-20 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-21 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-22 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-23 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-24 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-25 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-26 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-27 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-28 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-29 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-30 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-10-31 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-01 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-02 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-03 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-04 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-05 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-06 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-07 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-08 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-09 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-10 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-11 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-12 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-13 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-14 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-15 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-16 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-17 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-18 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-19 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-20 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-21 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-22 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-23 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-24 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-25 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-26 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-27 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-28 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-29 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-11-30 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-01 00:00:00', 5.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-02 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-03 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-04 00:00:00', 4.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-05 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-06 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-07 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-08 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-09 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-10 00:00:00', 6.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-11 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-12 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-13 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-14 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-15 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-16 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-17 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-18 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-19 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-20 00:00:00', 6.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-21 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-22 00:00:00', 5.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-23 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-24 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-01 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-02 00:00:00', 5.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-03 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-04 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-05 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-06 00:00:00', 4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-07 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-08 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-09 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-10 00:00:00', 5.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-11 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-12 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-13 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-14 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-15 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-16 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-17 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-18 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-19 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-20 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-21 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-22 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-23 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-24 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-25 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-26 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-27 00:00:00', 5.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-28 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-29 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-30 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-01-31 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-01 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-02 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-03 00:00:00', 4.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-04 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-05 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-06 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-07 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-08 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-09 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-10 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-11 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-12 00:00:00', 5.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-13 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-14 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-15 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-16 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-17 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-18 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-19 00:00:00', 5.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-20 00:00:00', 5.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-21 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-22 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-23 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-24 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-25 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-26 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-27 00:00:00', 4.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-02-28 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-01 00:00:00', 5.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-02 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-03 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-04 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-05 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-06 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-07 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-08 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-09 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-10 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-11 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-12 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-13 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-14 00:00:00', 7.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-15 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-16 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-17 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-18 00:00:00', 4.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-19 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-20 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-21 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-22 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-23 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-24 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-25 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-26 00:00:00', 5.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-27 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-28 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-29 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-30 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-03-31 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-01 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-02 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-03 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-04 00:00:00', 4.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-05 00:00:00', 5.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-06 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-07 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-08 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-09 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-10 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-11 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-12 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-13 00:00:00', 4.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-14 00:00:00', 5.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-15 00:00:00', 5.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-16 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-17 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-18 00:00:00', 6.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-19 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-20 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-21 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-22 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-23 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-24 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-25 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-26 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-27 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-28 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-29 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-04-30 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-01 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-02 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-03 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-04 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-05 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-06 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-07 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-08 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-09 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-10 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-11 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-12 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-13 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-14 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-15 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-16 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-17 00:00:00', 4.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-18 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-19 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-20 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-21 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-22 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-23 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-24 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-25 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-26 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-27 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-28 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-29 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-30 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-05-31 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-01 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-02 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-03 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-04 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-05 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-06 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-07 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-08 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-09 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-10 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-11 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-12 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-13 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-14 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-15 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-16 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-17 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-18 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-19 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-20 00:00:00', 7.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-21 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-22 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-23 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-24 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-25 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-26 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-27 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-28 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-29 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-06-30 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-01 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-02 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-03 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-04 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-05 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-06 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-07 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-08 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-09 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-10 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-11 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-12 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-13 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-14 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-15 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-16 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-17 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-18 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-19 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-20 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-21 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-22 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-23 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-24 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-25 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-26 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-27 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-28 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-29 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-30 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-07-31 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-01 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-02 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-03 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-04 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-05 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-06 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-07 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-08 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-09 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-10 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-11 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-12 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-13 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-14 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-15 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-16 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-17 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-18 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-19 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-20 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-21 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-22 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-23 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-24 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-25 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-26 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-27 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-28 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-29 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-30 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-08-31 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-01 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-02 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-03 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-04 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-05 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-06 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-07 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-08 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-09 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-10 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-11 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-12 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-13 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-14 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-15 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-16 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-17 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-18 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-19 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-20 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-21 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-22 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-23 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-24 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-25 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-26 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-27 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-28 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-29 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-09-30 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-01 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-02 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-03 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-04 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-05 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-06 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-07 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-08 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-09 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-10 00:00:00', 5.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-11 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-12 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-13 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-14 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-15 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-16 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-17 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-18 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-19 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-20 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-21 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-22 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-23 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-24 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-25 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-26 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-27 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-28 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-29 00:00:00', 1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-30 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-10-31 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-01 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-02 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-03 00:00:00', 5.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-04 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-05 00:00:00', 5.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-06 00:00:00', 6.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-07 00:00:00', 6.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-08 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-09 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-10 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-11 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-12 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-13 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-14 00:00:00', 5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-15 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-16 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-17 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-18 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-19 00:00:00', 5.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-20 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-21 00:00:00', 5.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-22 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-23 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-24 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-25 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-26 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-27 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-28 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-29 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-11-30 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-01 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-02 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-03 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-04 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-05 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-06 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-07 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-08 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-09 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-10 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-11 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-12 00:00:00', 5.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-13 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-14 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-15 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-16 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-17 00:00:00', 5.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-18 00:00:00', 5.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-19 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-20 00:00:00', 5.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-21 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-22 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-23 00:00:00', 6.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-24 00:00:00', 5.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-25 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-26 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-27 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-28 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-29 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-30 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1987-12-31 00:00:00', 5.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-01 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-02 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-03 00:00:00', 6.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-04 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-05 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-06 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-07 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-08 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-09 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-10 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-11 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-12 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-13 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-14 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-15 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-16 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-17 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-18 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-19 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-20 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-21 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-22 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-23 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-24 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-25 00:00:00', 5.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-26 00:00:00', 6.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-27 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-28 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-29 00:00:00', 7.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-30 00:00:00', 4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-01-31 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-01 00:00:00', 6.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-02 00:00:00', 7.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-03 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-04 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-05 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-06 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-07 00:00:00', 5.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-08 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-09 00:00:00', 4.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-10 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-11 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-12 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-13 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-14 00:00:00', 1.20599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-15 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-16 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-17 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-18 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-19 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-20 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-21 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-22 00:00:00', 4.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-23 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-24 00:00:00', 6.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-25 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-26 00:00:00', 5.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-27 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-28 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-02-29 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-01 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-02 00:00:00', 6.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-03 00:00:00', 5.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-04 00:00:00', 5.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-05 00:00:00', 6.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-06 00:00:00', 5.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-07 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-08 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-09 00:00:00', 6.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-10 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-11 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-12 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-13 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-14 00:00:00', 5.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-15 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-16 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-17 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-18 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-19 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-20 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-21 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-22 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-23 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-24 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-25 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-26 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-27 00:00:00', 4.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-28 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-29 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-30 00:00:00', 4.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-03-31 00:00:00', 6.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-01 00:00:00', 6.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-02 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-03 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-04 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-05 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-06 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-07 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-08 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-09 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-10 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-11 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-12 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-13 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-14 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-15 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-16 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-17 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-18 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-19 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-20 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-21 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-22 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-23 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-24 00:00:00', 4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-25 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-26 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-27 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-28 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-29 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-04-30 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-01 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-02 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-03 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-04 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-05 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-06 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-07 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-08 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-09 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-10 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-11 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-12 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-13 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-14 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-15 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-16 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-17 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-18 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-19 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-20 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-21 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-22 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-23 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-24 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-25 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-26 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-27 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-28 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-29 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-30 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-05-31 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-01 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-02 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-03 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-04 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-05 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-06 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-07 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-08 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-09 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-10 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-11 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-12 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-13 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-14 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-15 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-16 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-17 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-18 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-19 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-20 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-21 00:00:00', 4.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-22 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-23 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-24 00:00:00', 5.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-25 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-26 00:00:00', 5.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-27 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-28 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-29 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-06-30 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-01 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-02 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-03 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-04 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-05 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-06 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-07 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-08 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-09 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-10 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-11 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-12 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-13 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-14 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-15 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-16 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-17 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-18 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-19 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-20 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-21 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-22 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-23 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-24 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-25 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-26 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-27 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-28 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-29 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-30 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-07-31 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-01 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-02 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-03 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-04 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-05 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-06 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-07 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-08 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-09 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-10 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-11 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-12 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-13 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-14 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-15 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-16 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-17 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-18 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-19 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-20 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-21 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-22 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-23 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-24 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-25 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-26 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-27 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-28 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-29 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-30 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-08-31 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-01 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-02 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-03 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-04 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-05 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-06 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-07 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-08 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-09 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-10 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-11 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-12 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-13 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-14 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-15 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-16 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-17 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-18 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-19 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-20 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-21 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-22 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-23 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-24 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-25 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-26 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-27 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-28 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-29 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-09-30 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-01 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-02 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-03 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-04 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-05 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-06 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-07 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-08 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-09 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-10 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-11 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-12 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-13 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-14 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-15 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-16 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-17 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-18 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-19 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-20 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-21 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-22 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-23 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-24 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-25 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-26 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-27 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-28 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-29 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-30 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-10-31 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-01 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-02 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-03 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-04 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-05 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-06 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-07 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-08 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-09 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-10 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-11 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-12 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-13 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-14 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-15 00:00:00', 6.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-16 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-17 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-18 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-19 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-20 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-21 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-22 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-23 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-24 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-25 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-26 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-27 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-28 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-29 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-11-30 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-01 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-02 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-03 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-04 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-05 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-06 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-07 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-08 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-09 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-10 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-11 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-12 00:00:00', 5.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-13 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-14 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-15 00:00:00', 6.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-16 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-17 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-18 00:00:00', 5.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-19 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-20 00:00:00', 6.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-21 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-22 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-23 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-24 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-25 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-26 00:00:00', 6.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-27 00:00:00', 6.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-28 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-29 00:00:00', 5.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-30 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1988-12-31 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-01 00:00:00', 4.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-02 00:00:00', 5.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-03 00:00:00', 5.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-04 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-05 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-06 00:00:00', 5.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-07 00:00:00', 4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-08 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-09 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-10 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-11 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-12 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-13 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-14 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-15 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-16 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-17 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-18 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-19 00:00:00', 4.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-20 00:00:00', 5.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-21 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-22 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-23 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-24 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-25 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-26 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-27 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-28 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-29 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-30 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-01-31 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-01 00:00:00', 5.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-02 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-03 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-04 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-05 00:00:00', 1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-06 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-07 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-08 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-09 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-10 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-11 00:00:00', 5.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-12 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-13 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-14 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-15 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-16 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-17 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-18 00:00:00', 4.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-19 00:00:00', 6.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-20 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-21 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-22 00:00:00', 6.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-23 00:00:00', 6.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-24 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-25 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-26 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-27 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-02-28 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-01 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-02 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-03 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-04 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-05 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-06 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-07 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-08 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-09 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-10 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-11 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-12 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-13 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-14 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-15 00:00:00', 5.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-16 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-17 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-18 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-19 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-20 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-21 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-22 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-23 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-24 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-25 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-26 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-27 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-28 00:00:00', 5.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-29 00:00:00', 5.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-30 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-03-31 00:00:00', 5.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-01 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-02 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-03 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-04 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-05 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-06 00:00:00', 4.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-07 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-08 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-09 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-10 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-11 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-12 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-13 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-14 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-15 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-16 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-17 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-18 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-19 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-20 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-21 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-22 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-23 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-24 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-25 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-26 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-27 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-28 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-29 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-04-30 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-01 00:00:00', 5.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-02 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-03 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-04 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-05 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-06 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-07 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-08 00:00:00', 5.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-09 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-10 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-11 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-12 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-13 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-14 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-15 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-16 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-17 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-18 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-19 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-20 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-21 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-22 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-23 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-24 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-25 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-26 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-27 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-28 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-29 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-30 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-05-31 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-01 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-02 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-03 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-04 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-05 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-06 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-07 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-08 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-09 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-10 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-11 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-12 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-13 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-14 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-15 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-16 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-17 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-18 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-19 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-20 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-21 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-22 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-23 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-24 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-25 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-26 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-27 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-28 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-29 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-06-30 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-01 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-02 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-03 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-04 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-05 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-06 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-07 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-08 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-09 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-10 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-11 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-12 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-13 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-14 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-15 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-16 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-17 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-18 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-19 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-20 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-21 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-22 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-23 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-24 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-25 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-26 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-27 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-28 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-29 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-30 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-07-31 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-01 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-02 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-03 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-04 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-05 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-06 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-07 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-08 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-09 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-10 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-11 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-12 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-13 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-14 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-15 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-16 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-17 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-18 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-19 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-20 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-21 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-22 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-23 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-24 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-25 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-26 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-27 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-28 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-29 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-30 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-08-31 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-01 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-02 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-03 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-04 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-05 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-06 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-07 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-08 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-09 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-10 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-11 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-12 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-13 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-14 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-15 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-16 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-17 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-18 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-19 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-20 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-21 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-22 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-23 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-24 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-25 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-26 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-27 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-28 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-29 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-09-30 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-01 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-02 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-03 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-04 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-05 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-06 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-07 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-08 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-09 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-10 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-11 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-12 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-13 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-14 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-15 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-16 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-17 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-18 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-19 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-20 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-21 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-22 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-23 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-24 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-25 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-26 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-27 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-28 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-29 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-30 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-10-31 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-01 00:00:00', 6.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-02 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-03 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-04 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-05 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-06 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-07 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-08 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-09 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-10 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-11 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-12 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-13 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-14 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-15 00:00:00', 5.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-16 00:00:00', 6.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-17 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-18 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-19 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-20 00:00:00', 6.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-21 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-22 00:00:00', 5.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-23 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-24 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-25 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-26 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-27 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-28 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-29 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-11-30 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-01 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-02 00:00:00', 4.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-03 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-04 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-05 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-06 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-07 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-08 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-09 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-10 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-11 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-12 00:00:00', 4.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-13 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-14 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-15 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-16 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-17 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-18 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-19 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-20 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-21 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-22 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-23 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-24 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-25 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-26 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-27 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-28 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-29 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-30 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1989-12-31 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-01 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-02 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-03 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-04 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-05 00:00:00', 6.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-06 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-07 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-08 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-09 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-10 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-11 00:00:00', 1.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-12 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-13 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-14 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-15 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-16 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-17 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-18 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-19 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-20 00:00:00', 1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-21 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-22 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-23 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-24 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-25 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-26 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-27 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-28 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-29 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-30 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-01-31 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-01 00:00:00', 4.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-02 00:00:00', 5.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-03 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-04 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-05 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-06 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-07 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-08 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-09 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-10 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-11 00:00:00', 5.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-12 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-13 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-14 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-15 00:00:00', 6.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-16 00:00:00', 7.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-17 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-18 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-19 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-20 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-21 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-22 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-23 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-24 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-25 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-26 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-27 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-02-28 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-01 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-02 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-03 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-04 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-05 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-06 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-07 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-08 00:00:00', 5.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-09 00:00:00', 5.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-10 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-11 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-12 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-13 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-14 00:00:00', 6.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-15 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-16 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-17 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-18 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-19 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-20 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-21 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-22 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-23 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-24 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-25 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-26 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-27 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-28 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-29 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-30 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-03-31 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-01 00:00:00', 4.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-02 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-03 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-04 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-05 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-06 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-07 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-08 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-09 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-10 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-11 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-12 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-13 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-14 00:00:00', 5.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-15 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-16 00:00:00', 6.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-17 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-18 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-19 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-20 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-21 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-22 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-23 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-24 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-25 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-26 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-27 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-28 00:00:00', 4.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-29 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-04-30 00:00:00', 5.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-01 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-02 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-03 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-04 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-05 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-06 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-07 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-08 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-09 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-10 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-11 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-12 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-13 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-14 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-15 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-16 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-17 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-18 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-19 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-20 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-21 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-22 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-23 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-24 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-25 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-26 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-27 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-28 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-29 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-30 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-05-31 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-01 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-02 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-03 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-04 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-05 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-06 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-07 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-08 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-09 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-10 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-11 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-12 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-13 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-14 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-15 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-16 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-17 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-18 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-19 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-20 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-21 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-22 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-23 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-24 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-25 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-26 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-27 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-28 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-29 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-06-30 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-01 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-02 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-03 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-04 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-05 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-06 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-07 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-08 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-09 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-10 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-11 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-12 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-13 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-14 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-15 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-16 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-17 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-18 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-19 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-20 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-21 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-22 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-23 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-24 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-25 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-26 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-27 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-28 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-29 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-30 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-07-31 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-01 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-02 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-03 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-04 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-05 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-06 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-07 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-08 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-09 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-10 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-11 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-12 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-13 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-14 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-15 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-16 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-17 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-18 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-19 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-20 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-21 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-22 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-23 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-24 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-25 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-26 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-27 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-28 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-29 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-30 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-08-31 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-01 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-02 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-03 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-04 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-05 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-06 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-07 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-08 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-09 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-10 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-11 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-12 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-13 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-14 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-15 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-16 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-17 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-18 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-19 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-20 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-21 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-22 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-23 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-24 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-25 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-26 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-27 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-28 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-29 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-09-30 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-01 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-02 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-03 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-04 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-05 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-06 00:00:00', 4.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-07 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-08 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-09 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-10 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-11 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-12 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-13 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-14 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-15 00:00:00', 6.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-16 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-17 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-18 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-19 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-20 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-21 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-22 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-23 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-24 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-25 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-26 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-27 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-28 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-29 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-30 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-10-31 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-01 00:00:00', 5.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-02 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-03 00:00:00', 4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-04 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-05 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-06 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-07 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-08 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-09 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-10 00:00:00', 4.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-11 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-12 00:00:00', 5.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-13 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-14 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-15 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-16 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-17 00:00:00', 1.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-18 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-19 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-20 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-21 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-22 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-23 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-24 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-25 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-26 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-27 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-28 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-29 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-11-30 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-01 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-02 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-03 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-04 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-05 00:00:00', 4.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-06 00:00:00', 5.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-07 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-08 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-09 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-10 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-11 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-12 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-13 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-14 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-15 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-16 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-17 00:00:00', 6.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-18 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-19 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-20 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-21 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-22 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-23 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-24 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-25 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-26 00:00:00', 7.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-27 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-28 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-29 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-30 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1990-12-31 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-01 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-02 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-03 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-04 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-05 00:00:00', 6.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-06 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-07 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-08 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-09 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-10 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-11 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-12 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-13 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-14 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-15 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-16 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-17 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-18 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-19 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-20 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-21 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-22 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-23 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-24 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-25 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-26 00:00:00', 6.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-27 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-28 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-29 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-30 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-01-31 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-01 00:00:00', 6.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-02 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-03 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-04 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-05 00:00:00', 5.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-06 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-07 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-08 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-09 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-10 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-11 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-12 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-13 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-14 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-15 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-16 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-17 00:00:00', 4.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-18 00:00:00', 4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-19 00:00:00', 4.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-20 00:00:00', 5.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-21 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-22 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-23 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-24 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-25 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-26 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-27 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-02-28 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-01 00:00:00', 4.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-02 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-03 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-04 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-05 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-06 00:00:00', 7.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-07 00:00:00', 6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-08 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-09 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-10 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-11 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-12 00:00:00', 6.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-13 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-14 00:00:00', 5.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-15 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-16 00:00:00', 5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-17 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-18 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-19 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-20 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-21 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-22 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-23 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-24 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-25 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-26 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-27 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-28 00:00:00', 4.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-29 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-30 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-03-31 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-01 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-02 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-03 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-04 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-05 00:00:00', 4.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-06 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-07 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-08 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-09 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-10 00:00:00', 6.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-11 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-12 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-13 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-14 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-15 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-16 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-17 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-18 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-19 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-20 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-21 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-22 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-23 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-24 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-25 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-26 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-27 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-28 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-29 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-04-30 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-01 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-02 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-03 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-04 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-05 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-06 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-07 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-08 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-09 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-10 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-11 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-12 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-13 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-14 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-15 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-16 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-17 00:00:00', 6.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-18 00:00:00', 5.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-19 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-20 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-21 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-22 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-23 00:00:00', 6.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-24 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-25 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-26 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-27 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-28 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-29 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-30 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-05-31 00:00:00', 5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-01 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-02 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-03 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-04 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-05 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-06 00:00:00', 5.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-07 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-08 00:00:00', 4.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-09 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-10 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-11 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-12 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-13 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-14 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-15 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-16 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-17 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-18 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-19 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-20 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-21 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-22 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-23 00:00:00', 4.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-24 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-25 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-26 00:00:00', 4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-27 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-28 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-29 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-06-30 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-01 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-02 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-03 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-04 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-05 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-06 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-07 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-08 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-09 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-10 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-11 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-12 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-13 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-14 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-15 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-16 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-17 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-18 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-19 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-20 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-21 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-22 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-23 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-24 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-25 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-26 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-27 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-28 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-29 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-30 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-07-31 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-01 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-02 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-03 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-04 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-05 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-06 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-07 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-08 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-09 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-10 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-11 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-12 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-13 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-14 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-15 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-16 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-17 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-18 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-19 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-20 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-21 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-22 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-23 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-24 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-25 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-26 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-27 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-28 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-29 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-30 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-08-31 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-01 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-02 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-03 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-04 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-05 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-06 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-07 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-08 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-09 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-10 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-11 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-12 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-13 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-14 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-15 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-16 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-17 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-18 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-19 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-20 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-21 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-22 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-23 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-24 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-25 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-26 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-27 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-28 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-29 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-09-30 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-01 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-02 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-03 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-04 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-05 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-06 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-07 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-08 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-09 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-10 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-11 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-12 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-13 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-14 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-15 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-16 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-17 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-18 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-19 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-20 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-21 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-22 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-23 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-24 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-25 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-26 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-27 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-28 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-29 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-30 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-10-31 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-01 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-02 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-03 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-04 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-05 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-06 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-07 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-08 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-09 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-10 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-11 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-12 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-13 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-14 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-15 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-16 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-17 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-18 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-19 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-20 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-21 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-22 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-23 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-24 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-25 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-26 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-27 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-28 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-29 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-11-30 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-01 00:00:00', 6.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-02 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-03 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-04 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-05 00:00:00', 6.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-06 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-07 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-08 00:00:00', 5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-09 00:00:00', 6.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-10 00:00:00', 7.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-11 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-12 00:00:00', 5.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-13 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-14 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-15 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-16 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-17 00:00:00', 5.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-18 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-19 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-20 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-21 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-22 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-23 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-24 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-25 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-26 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-27 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-28 00:00:00', 6.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-29 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-30 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1991-12-31 00:00:00', 5.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-01 00:00:00', 6.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-02 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-03 00:00:00', 8.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-04 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-05 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-06 00:00:00', 5.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-07 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-08 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-09 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-10 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-11 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-12 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-13 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-14 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-15 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-16 00:00:00', 6.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-17 00:00:00', 6.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-18 00:00:00', 5.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-19 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-20 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-21 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-22 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-23 00:00:00', 1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-24 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-25 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-26 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-27 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-28 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-29 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-30 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-01-31 00:00:00', 5.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-01 00:00:00', 4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-02 00:00:00', 6.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-03 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-04 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-05 00:00:00', 5.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-06 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-07 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-08 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-09 00:00:00', 5.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-10 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-11 00:00:00', 7.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-12 00:00:00', 6.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-13 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-14 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-15 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-16 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-17 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-18 00:00:00', 5.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-19 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-20 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-21 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-22 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-23 00:00:00', 6.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-24 00:00:00', 6.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-25 00:00:00', 6.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-26 00:00:00', 6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-27 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-28 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-02-29 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-01 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-02 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-03 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-04 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-05 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-06 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-07 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-08 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-09 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-10 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-11 00:00:00', 5.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-12 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-13 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-14 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-15 00:00:00', 6.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-16 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-17 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-18 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-19 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-20 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-21 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-22 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-23 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-24 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-25 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-26 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-27 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-28 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-29 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-30 00:00:00', 6.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-03-31 00:00:00', 7.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-01 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-02 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-03 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-04 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-05 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-06 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-07 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-08 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-09 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-10 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-11 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-12 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-13 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-14 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-15 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-16 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-17 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-18 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-19 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-20 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-21 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-22 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-23 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-24 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-25 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-26 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-27 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-28 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-29 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-04-30 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-01 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-02 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-03 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-04 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-05 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-06 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-07 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-08 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-09 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-10 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-11 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-12 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-13 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-14 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-15 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-16 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-17 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-18 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-19 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-20 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-21 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-22 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-23 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-24 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-25 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-26 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-27 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-28 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-29 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-30 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-05-31 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-01 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-02 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-03 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-04 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-05 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-06 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-07 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-08 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-09 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-10 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-11 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-12 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-13 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-14 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-15 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-16 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-17 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-18 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-19 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-20 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-21 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-22 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-23 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-24 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-25 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-26 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-27 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-28 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-29 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-06-30 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-01 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-02 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-03 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-04 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-05 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-06 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-07 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-08 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-09 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-10 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-11 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-12 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-13 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-14 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-15 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-16 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-17 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-18 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-19 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-20 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-21 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-22 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-23 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-24 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-25 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-26 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-27 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-28 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-29 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-30 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-07-31 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-01 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-02 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-03 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-04 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-05 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-06 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-07 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-08 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-09 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-10 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-11 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-12 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-13 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-14 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-15 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-16 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-17 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-18 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-19 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-20 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-21 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-22 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-23 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-24 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-25 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-26 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-27 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-28 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-29 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-30 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-08-31 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-01 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-02 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-03 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-04 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-05 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-06 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-07 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-08 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-09 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-10 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-11 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-12 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-13 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-14 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-15 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-16 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-17 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-18 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-19 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-20 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-21 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-22 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-23 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-24 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-25 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-26 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-27 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-28 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-29 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-09-30 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-01 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-02 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-03 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-04 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-05 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-06 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-07 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-08 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-09 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-10 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-11 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-12 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-13 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-14 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-15 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-16 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-17 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-18 00:00:00', 1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-19 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-20 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-21 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-22 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-23 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-24 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-25 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-26 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-27 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-28 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-29 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-30 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-10-31 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-01 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-02 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-03 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-04 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-05 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-06 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-07 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-08 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-09 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-10 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-11 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-12 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-13 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-14 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-15 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-16 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-17 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-18 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-19 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-20 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-21 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-22 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-23 00:00:00', 5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-24 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-25 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-26 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-27 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-28 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-29 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-11-30 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-01 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-02 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-03 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-04 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-05 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-06 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-07 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-08 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-09 00:00:00', 5.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-10 00:00:00', 4.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-11 00:00:00', 5.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-12 00:00:00', 6.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-13 00:00:00', 6.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-14 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-15 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-16 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-17 00:00:00', 5.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-18 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-19 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-20 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-21 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-22 00:00:00', 5.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-23 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-24 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-25 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-26 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-27 00:00:00', 5.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-28 00:00:00', 6.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-29 00:00:00', 5.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-30 00:00:00', 5.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1992-12-31 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-01 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-02 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-03 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-04 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-05 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-06 00:00:00', 5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-07 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-08 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-09 00:00:00', 6.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-10 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-11 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-12 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-13 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-14 00:00:00', 5.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-15 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-16 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-17 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-18 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-19 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-20 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-21 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-22 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-23 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-24 00:00:00', 5.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-25 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-26 00:00:00', 4.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-27 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-28 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-29 00:00:00', 5.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-30 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-01-31 00:00:00', 5.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-01 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-02 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-03 00:00:00', 6.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-04 00:00:00', 6.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-05 00:00:00', 5.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-06 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-07 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-08 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-09 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-10 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-11 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-12 00:00:00', 5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-13 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-14 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-15 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-16 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-17 00:00:00', 4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-18 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-19 00:00:00', 6.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-20 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-21 00:00:00', 6.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-22 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-23 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-24 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-25 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-26 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-27 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-02-28 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-01 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-02 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-03 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-04 00:00:00', 6.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-05 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-06 00:00:00', 7.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-07 00:00:00', 5.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-08 00:00:00', 5.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-09 00:00:00', 5.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-10 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-11 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-12 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-13 00:00:00', 7.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-14 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-15 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-16 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-17 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-18 00:00:00', 1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-19 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-20 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-21 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-22 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-23 00:00:00', 6.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-24 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-25 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-26 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-27 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-28 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-29 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-30 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-03-31 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-01 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-02 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-03 00:00:00', 4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-04 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-05 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-06 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-07 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-08 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-09 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-10 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-11 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-12 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-13 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-14 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-15 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-16 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-17 00:00:00', 5.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-18 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-19 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-20 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-21 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-22 00:00:00', 4.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-23 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-24 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-25 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-26 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-27 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-28 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-29 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-04-30 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-01 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-02 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-03 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-04 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-05 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-06 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-07 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-08 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-09 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-10 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-11 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-12 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-13 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-14 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-15 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-16 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-17 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-18 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-19 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-20 00:00:00', 5.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-21 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-22 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-23 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-24 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-25 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-26 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-27 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-28 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-29 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-30 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-05-31 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-01 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-02 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-03 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-04 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-05 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-06 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-07 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-08 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-09 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-10 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-11 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-12 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-13 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-14 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-15 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-16 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-17 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-18 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-19 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-20 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-21 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-22 00:00:00', 5.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-23 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-24 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-25 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-26 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-27 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-28 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-29 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-06-30 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-01 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-02 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-03 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-04 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-05 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-06 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-07 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-08 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-09 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-10 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-11 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-12 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-13 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-14 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-15 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-16 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-17 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-18 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-19 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-20 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-21 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-22 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-23 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-24 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-25 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-26 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-27 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-28 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-29 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-30 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-07-31 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-01 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-02 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-03 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-04 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-05 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-06 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-07 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-08 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-09 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-10 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-11 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-12 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-13 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-14 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-15 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-16 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-17 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-18 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-19 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-20 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-21 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-22 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-23 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-24 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-25 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-26 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-27 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-28 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-29 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-30 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-08-31 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-01 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-02 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-03 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-04 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-05 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-06 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-07 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-08 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-09 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-10 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-11 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-12 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-13 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-14 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-15 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-16 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-17 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-18 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-19 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-20 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-21 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-22 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-23 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-24 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-25 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-26 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-27 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-28 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-29 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-09-30 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-01 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-02 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-03 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-04 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-05 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-06 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-07 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-08 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-09 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-10 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-11 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-12 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-13 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-14 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-15 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-16 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-17 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-18 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-19 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-20 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-21 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-22 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-23 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-24 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-25 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-26 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-27 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-28 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-29 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-30 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-10-31 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-01 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-02 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-03 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-04 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-05 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-06 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-07 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-08 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-09 00:00:00', 5.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-10 00:00:00', 5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-11 00:00:00', 5.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-12 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-13 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-14 00:00:00', 5.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-15 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-16 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-17 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-18 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-19 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-20 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-21 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-22 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-23 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-24 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-25 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-26 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-27 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-28 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-29 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-11-30 00:00:00', 5.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-01 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-02 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-03 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-04 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-05 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-06 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-07 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-08 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-09 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-10 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-11 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-12 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-13 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-14 00:00:00', 5.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-15 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-16 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-17 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-18 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-19 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-20 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-21 00:00:00', 5.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-22 00:00:00', 5.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-23 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-24 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-25 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-26 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-27 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-28 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-29 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-30 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1993-12-31 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-01 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-02 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-03 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-04 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-05 00:00:00', 6.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-06 00:00:00', 5.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-07 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-08 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-09 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-10 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-11 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-12 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-13 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-14 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-15 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-16 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-17 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-18 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-19 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-20 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-21 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-22 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-23 00:00:00', 5.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-24 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-25 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-26 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-27 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-28 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-29 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-30 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-01-31 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-01 00:00:00', 7.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-02 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-03 00:00:00', 4.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-04 00:00:00', 7.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-05 00:00:00', 5.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-06 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-07 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-08 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-09 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-10 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-11 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-12 00:00:00', 6.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-13 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-14 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-15 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-16 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-17 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-18 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-19 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-20 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-21 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-22 00:00:00', 5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-23 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-24 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-25 00:00:00', 5.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-26 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-27 00:00:00', 6.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-02-28 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-01 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-02 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-03 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-04 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-05 00:00:00', 5.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-06 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-07 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-08 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-09 00:00:00', 3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-10 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-11 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-12 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-13 00:00:00', 7.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-14 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-15 00:00:00', 6.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-16 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-17 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-18 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-19 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-20 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-21 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-22 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-23 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-24 00:00:00', 6.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-25 00:00:00', 5.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-26 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-27 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-28 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-29 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-30 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-03-31 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-01 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-02 00:00:00', 6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-03 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-04 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-05 00:00:00', 7.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-06 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-07 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-08 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-09 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-10 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-11 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-12 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-13 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-14 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-15 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-16 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-17 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-18 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-19 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-20 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-21 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-22 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-23 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-24 00:00:00', 4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-25 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-26 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-27 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-28 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-29 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-04-30 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-01 00:00:00', 5.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-02 00:00:00', 4.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-03 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-04 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-05 00:00:00', 5.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-06 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-07 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-08 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-09 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-10 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-11 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-12 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-13 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-14 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-15 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-16 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-17 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-18 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-19 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-20 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-21 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-22 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-23 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-24 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-25 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-26 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-27 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-28 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-29 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-30 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-05-31 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-01 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-02 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-03 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-04 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-05 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-06 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-07 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-08 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-09 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-10 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-11 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-12 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-13 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-14 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-15 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-16 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-17 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-18 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-19 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-20 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-21 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-22 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-23 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-24 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-25 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-26 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-27 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-28 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-29 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-06-30 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-01 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-02 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-03 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-04 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-05 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-06 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-07 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-08 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-09 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-10 00:00:00', 4.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-11 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-12 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-13 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-14 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-15 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-16 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-17 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-18 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-19 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-20 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-21 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-22 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-23 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-24 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-25 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-26 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-27 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-28 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-29 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-30 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-07-31 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-01 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-02 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-03 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-04 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-05 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-06 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-07 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-08 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-09 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-10 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-11 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-12 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-13 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-14 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-15 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-16 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-17 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-18 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-19 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-20 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-21 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-22 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-23 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-24 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-25 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-26 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-27 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-28 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-29 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-30 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-08-31 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-01 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-02 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-03 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-04 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-05 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-06 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-07 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-08 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-09 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-10 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-11 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-12 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-13 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-14 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-15 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-16 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-17 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-18 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-19 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-20 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-21 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-22 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-23 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-24 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-25 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-26 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-27 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-28 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-29 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-09-30 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-01 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-02 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-03 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-04 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-05 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-06 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-07 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-08 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-09 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-10 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-11 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-12 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-13 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-14 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-15 00:00:00', 4.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-16 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-17 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-18 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-19 00:00:00', 4.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-20 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-21 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-22 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-23 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-24 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-25 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-26 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-27 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-28 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-29 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-30 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-10-31 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-01 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-02 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-03 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-04 00:00:00', 4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-05 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-06 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-07 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-08 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-09 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-10 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-11 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-12 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-13 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-14 00:00:00', 5.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-15 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-16 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-17 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-18 00:00:00', 4.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-19 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-20 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-21 00:00:00', 4.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-22 00:00:00', 5.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-23 00:00:00', 6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-24 00:00:00', 5.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-25 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-26 00:00:00', 6.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-27 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-28 00:00:00', 5.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-29 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-11-30 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-01 00:00:00', 5.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-02 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-03 00:00:00', 5.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-04 00:00:00', 7.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-05 00:00:00', 6.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-06 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-07 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-08 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-09 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-10 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-11 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-12 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-13 00:00:00', 5.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-14 00:00:00', 5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-15 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-16 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-17 00:00:00', 4.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-18 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-19 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-20 00:00:00', 6.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-21 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-22 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-23 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-24 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-25 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-26 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-27 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-28 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-29 00:00:00', 6.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-30 00:00:00', 6.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1994-12-31 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-01 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-02 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-03 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-04 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-05 00:00:00', 5.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-06 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-07 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-08 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-09 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-10 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-11 00:00:00', 5.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-12 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-13 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-14 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-15 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-16 00:00:00', 4.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-17 00:00:00', 6.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-18 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-19 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-20 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-21 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-22 00:00:00', 4.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-23 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-24 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-25 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-26 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-27 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-28 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-29 00:00:00', 5.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-30 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-01-31 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-01 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-02 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-03 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-04 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-05 00:00:00', 7.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-06 00:00:00', 5.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-07 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-08 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-09 00:00:00', 6.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-10 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-11 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-12 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-13 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-14 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-15 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-16 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-17 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-18 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-19 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-20 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-21 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-22 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-23 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-24 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-25 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-26 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-27 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-02-28 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-01 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-02 00:00:00', 5.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-03 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-04 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-05 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-06 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-07 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-08 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-09 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-10 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-11 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-12 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-13 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-14 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-15 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-16 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-17 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-18 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-19 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-20 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-21 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-22 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-23 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-24 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-25 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-26 00:00:00', 6.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-27 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-28 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-29 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-30 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-03-31 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-01 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-02 00:00:00', 5.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-03 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-04 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-05 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-06 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-07 00:00:00', 4.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-08 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-09 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-10 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-11 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-12 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-13 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-14 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-15 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-16 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-17 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-18 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-19 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-20 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-21 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-22 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-23 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-24 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-25 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-26 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-27 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-28 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-29 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-04-30 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-01 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-02 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-03 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-04 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-05 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-06 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-07 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-08 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-09 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-10 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-11 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-12 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-13 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-14 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-15 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-16 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-17 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-18 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-19 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-20 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-21 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-22 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-23 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-24 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-25 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-26 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-27 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-28 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-29 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-30 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-05-31 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-01 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-02 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-03 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-04 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-05 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-06 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-07 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-08 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-09 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-10 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-11 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-12 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-13 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-14 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-15 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-16 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-17 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-18 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-19 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-20 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-21 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-22 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-23 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-24 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-25 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-26 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-27 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-28 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-29 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-06-30 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-01 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-02 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-03 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-04 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-05 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-06 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-07 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-08 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-09 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-10 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-11 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-12 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-13 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-14 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-15 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-16 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-17 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-18 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-19 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-20 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-21 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-22 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-23 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-24 00:00:00', 4.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-25 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-26 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-27 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-28 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-29 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-30 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-07-31 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-01 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-02 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-03 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-04 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-05 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-06 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-07 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-08 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-09 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-10 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-11 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-12 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-13 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-14 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-15 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-16 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-17 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-18 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-19 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-20 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-21 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-22 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-23 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-24 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-25 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-26 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-27 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-28 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-29 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-30 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-08-31 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-01 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-02 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-03 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-04 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-05 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-06 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-07 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-08 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-09 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-10 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-11 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-12 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-13 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-14 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-15 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-16 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-17 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-18 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-19 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-20 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-21 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-22 00:00:00', 5.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-23 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-24 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-25 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-26 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-27 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-28 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-29 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-09-30 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-01 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-02 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-03 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-04 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-05 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-06 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-07 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-08 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-09 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-10 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-11 00:00:00', 4.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-12 00:00:00', 4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-13 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-14 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-15 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-16 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-17 00:00:00', 5.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-18 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-19 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-20 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-21 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-22 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-23 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-24 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-25 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-26 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-27 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-28 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-29 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-30 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-10-31 00:00:00', 4.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-01 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-02 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-03 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-04 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-05 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-06 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-07 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-08 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-09 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-10 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-11 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-12 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-13 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-14 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-15 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-16 00:00:00', 0.705999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-17 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-18 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-19 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-20 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-21 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-22 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-23 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-24 00:00:00', 5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-25 00:00:00', 4.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-26 00:00:00', 5.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-27 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-28 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-29 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-11-30 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-01 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-02 00:00:00', 4.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-03 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-04 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-05 00:00:00', 4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-06 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-07 00:00:00', 1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-08 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-09 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-10 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-11 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-12 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-13 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-14 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-15 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-16 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-17 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-18 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-19 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-20 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-21 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-22 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-23 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-24 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-25 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-26 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-27 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-28 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-29 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-30 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1995-12-31 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-01 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-02 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-03 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-04 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-05 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-06 00:00:00', 6.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-07 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-08 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-09 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-10 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-11 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-12 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-13 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-14 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-15 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-16 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-17 00:00:00', 5.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-18 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-19 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-20 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-21 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-22 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-23 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-24 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-25 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-26 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-27 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-28 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-29 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-30 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-01-31 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-01 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-02 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-03 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-04 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-05 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-06 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-07 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-08 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-09 00:00:00', 4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-10 00:00:00', 6.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-11 00:00:00', 6.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-12 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-13 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-14 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-15 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-16 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-17 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-18 00:00:00', 5.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-19 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-20 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-21 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-22 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-23 00:00:00', 5.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-24 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-25 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-26 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-27 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-28 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-02-29 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-01 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-02 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-03 00:00:00', 6.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-04 00:00:00', 6.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-05 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-06 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-07 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-08 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-09 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-10 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-11 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-12 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-13 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-14 00:00:00', 4.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-15 00:00:00', 5.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-16 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-17 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-18 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-19 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-20 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-21 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-22 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-23 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-24 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-25 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-26 00:00:00', 6.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-27 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-28 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-29 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-30 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-03-31 00:00:00', 6.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-01 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-02 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-03 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-04 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-05 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-06 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-07 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-08 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-09 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-10 00:00:00', 5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-11 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-12 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-13 00:00:00', 7.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-14 00:00:00', 5.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-15 00:00:00', 5.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-16 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-17 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-18 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-19 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-20 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-21 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-22 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-23 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-24 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-25 00:00:00', 5.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-26 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-27 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-28 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-29 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-04-30 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-01 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-02 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-03 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-04 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-05 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-06 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-07 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-08 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-09 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-10 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-11 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-12 00:00:00', 4.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-13 00:00:00', 4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-14 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-15 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-16 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-17 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-18 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-19 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-20 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-21 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-22 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-23 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-24 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-25 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-26 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-27 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-28 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-29 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-30 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-05-31 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-01 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-02 00:00:00', 4.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-03 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-04 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-05 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-06 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-07 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-08 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-09 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-10 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-11 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-12 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-13 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-14 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-15 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-16 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-17 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-18 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-19 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-20 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-21 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-22 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-23 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-24 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-25 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-26 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-27 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-28 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-29 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-06-30 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-01 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-02 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-03 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-04 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-05 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-06 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-07 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-08 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-09 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-10 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-11 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-12 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-13 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-14 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-15 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-16 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-17 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-18 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-19 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-20 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-21 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-22 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-23 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-24 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-25 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-26 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-27 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-28 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-29 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-30 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-07-31 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-01 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-02 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-03 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-04 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-05 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-06 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-07 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-08 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-09 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-10 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-11 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-12 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-13 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-14 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-15 00:00:00', 4.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-16 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-17 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-18 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-19 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-20 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-21 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-22 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-23 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-24 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-25 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-26 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-27 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-28 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-29 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-30 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-08-31 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-01 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-02 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-03 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-04 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-05 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-06 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-07 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-08 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-09 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-10 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-11 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-12 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-13 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-14 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-15 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-16 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-17 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-18 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-19 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-20 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-21 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-22 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-23 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-24 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-25 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-26 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-27 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-28 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-29 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-09-30 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-01 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-02 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-03 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-04 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-05 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-06 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-07 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-08 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-09 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-10 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-11 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-12 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-13 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-14 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-15 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-16 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-17 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-18 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-19 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-20 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-21 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-22 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-23 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-24 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-25 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-26 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-27 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-28 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-29 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-30 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-10-31 00:00:00', 5.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-01 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-02 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-03 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-04 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-05 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-06 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-07 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-08 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-09 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-10 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-11 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-12 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-13 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-14 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-15 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-16 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-17 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-18 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-19 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-20 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-21 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-22 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-23 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-24 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-25 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-26 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-27 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-28 00:00:00', 4.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-29 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-11-30 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-01 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-02 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-03 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-04 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-05 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-06 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-07 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-08 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-09 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-10 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-11 00:00:00', 4.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-12 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-13 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-14 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-15 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-16 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-17 00:00:00', 6.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-18 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-19 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-20 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-21 00:00:00', 5.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-22 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-23 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-24 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-25 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-26 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-27 00:00:00', 6.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-28 00:00:00', 5.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-29 00:00:00', 5.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-30 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1996-12-31 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-01 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-02 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-03 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-04 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-05 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-06 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-07 00:00:00', 5.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-08 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-09 00:00:00', 4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-10 00:00:00', 5.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-11 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-12 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-13 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-14 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-15 00:00:00', 5.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-16 00:00:00', 7.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-17 00:00:00', 6.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-18 00:00:00', 7.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-19 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-20 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-21 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-22 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-23 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-24 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-25 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-26 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-27 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-28 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-29 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-30 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-01-31 00:00:00', 6.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-01 00:00:00', 7.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-02 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-03 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-04 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-05 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-06 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-07 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-08 00:00:00', 5.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-09 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-10 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-11 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-12 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-13 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-14 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-15 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-16 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-17 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-18 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-19 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-20 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-21 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-22 00:00:00', 5.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-23 00:00:00', 5.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-24 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-25 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-26 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-27 00:00:00', 6.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-02-28 00:00:00', 5.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-01 00:00:00', 7.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-02 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-03 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-04 00:00:00', 5.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-05 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-06 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-07 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-08 00:00:00', 6.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-09 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-10 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-11 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-12 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-13 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-14 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-15 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-16 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-17 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-18 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-19 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-20 00:00:00', 5.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-21 00:00:00', 5.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-22 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-23 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-24 00:00:00', 6.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-25 00:00:00', 6.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-26 00:00:00', 4.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-27 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-28 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-29 00:00:00', 5.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-30 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-03-31 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-01 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-02 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-03 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-04 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-05 00:00:00', 5.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-06 00:00:00', 5.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-07 00:00:00', 5.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-08 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-09 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-10 00:00:00', 7.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-11 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-12 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-13 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-14 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-15 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-16 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-17 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-18 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-19 00:00:00', 6.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-20 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-21 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-22 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-23 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-24 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-25 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-26 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-27 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-28 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-29 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-04-30 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-01 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-02 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-03 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-04 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-05 00:00:00', 5.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-06 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-07 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-08 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-09 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-10 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-11 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-12 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-13 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-14 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-15 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-16 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-17 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-18 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-19 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-20 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-21 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-22 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-23 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-24 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-25 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-26 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-27 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-28 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-29 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-30 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-05-31 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-01 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-02 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-03 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-04 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-05 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-06 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-07 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-08 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-09 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-10 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-11 00:00:00', 4.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-12 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-13 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-14 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-15 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-16 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-17 00:00:00', 4.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-18 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-19 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-20 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-21 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-22 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-23 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-24 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-25 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-26 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-27 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-28 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-29 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-06-30 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-01 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-02 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-03 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-04 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-05 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-06 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-07 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-08 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-09 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-10 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-11 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-12 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-13 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-14 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-15 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-16 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-17 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-18 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-19 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-20 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-21 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-22 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-23 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-24 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-25 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-26 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-27 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-28 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-29 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-30 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-07-31 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-01 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-02 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-03 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-04 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-05 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-06 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-07 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-08 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-09 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-10 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-11 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-12 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-13 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-14 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-15 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-16 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-17 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-18 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-19 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-20 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-21 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-22 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-23 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-24 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-25 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-26 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-27 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-28 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-29 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-30 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-08-31 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-01 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-02 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-03 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-04 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-05 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-06 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-07 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-08 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-09 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-10 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-11 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-12 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-13 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-14 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-15 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-16 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-17 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-18 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-19 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-20 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-21 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-22 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-23 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-24 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-25 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-26 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-27 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-28 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-29 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-09-30 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-01 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-02 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-03 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-04 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-05 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-06 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-07 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-08 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-09 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-10 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-11 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-12 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-13 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-14 00:00:00', 4.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-15 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-16 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-17 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-18 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-19 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-20 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-21 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-22 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-23 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-24 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-25 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-26 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-27 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-28 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-29 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-30 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-10-31 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-01 00:00:00', 6.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-02 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-03 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-04 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-05 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-06 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-07 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-08 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-09 00:00:00', 0.944999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-10 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-11 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-12 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-13 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-14 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-15 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-16 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-17 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-18 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-19 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-20 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-21 00:00:00', 5.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-22 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-23 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-24 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-25 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-26 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-27 00:00:00', 4.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-28 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-29 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-11-30 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-01 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-02 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-03 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-04 00:00:00', 4.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-05 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-06 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-07 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-08 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-09 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-10 00:00:00', 5.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-11 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-12 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-13 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-14 00:00:00', 6.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-15 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-16 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-17 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-18 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-19 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-20 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-21 00:00:00', 4.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-22 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-23 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-24 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-25 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-26 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-27 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-28 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-29 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-30 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1997-12-31 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-01 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-02 00:00:00', 5.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-03 00:00:00', 5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-04 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-05 00:00:00', 5.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-06 00:00:00', 6.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-07 00:00:00', 6.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-08 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-09 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-10 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-11 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-12 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-13 00:00:00', 7.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-14 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-15 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-16 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-17 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-18 00:00:00', 6.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-19 00:00:00', 5.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-20 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-21 00:00:00', 5.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-22 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-23 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-24 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-25 00:00:00', 5.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-26 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-27 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-28 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-29 00:00:00', 6.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-30 00:00:00', 6.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-01-31 00:00:00', 5.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-01 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-02 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-03 00:00:00', 5.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-04 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-05 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-06 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-07 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-08 00:00:00', 7.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-09 00:00:00', 5.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-10 00:00:00', 5.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-11 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-12 00:00:00', 6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-13 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-14 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-15 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-16 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-17 00:00:00', 5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-18 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-19 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-20 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-21 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-22 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-23 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-24 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-25 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-26 00:00:00', 5.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-27 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-02-28 00:00:00', 6.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-01 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-02 00:00:00', 6.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-03 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-04 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-05 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-06 00:00:00', 5.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-07 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-08 00:00:00', 5.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-09 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-10 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-11 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-12 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-13 00:00:00', 5.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-14 00:00:00', 5.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-15 00:00:00', 5.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-16 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-17 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-18 00:00:00', 6.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-19 00:00:00', 6.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-20 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-21 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-22 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-23 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-24 00:00:00', 6.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-25 00:00:00', 6.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-26 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-27 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-28 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-29 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-30 00:00:00', 7.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-03-31 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-01 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-02 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-03 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-04 00:00:00', 6.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-05 00:00:00', 5.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-06 00:00:00', 6.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-07 00:00:00', 6.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-08 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-09 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-10 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-11 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-12 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-13 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-14 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-15 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-16 00:00:00', 4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-17 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-18 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-19 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-20 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-21 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-22 00:00:00', 5.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-23 00:00:00', 5.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-24 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-25 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-26 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-27 00:00:00', 4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-28 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-29 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-04-30 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-01 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-02 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-03 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-04 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-05 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-06 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-07 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-08 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-09 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-10 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-11 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-12 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-13 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-14 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-15 00:00:00', 5.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-16 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-17 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-18 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-19 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-20 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-21 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-22 00:00:00', 6.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-23 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-24 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-25 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-26 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-27 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-28 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-29 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-30 00:00:00', 5.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-05-31 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-01 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-02 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-03 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-04 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-05 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-06 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-07 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-08 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-09 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-10 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-11 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-12 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-13 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-14 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-15 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-16 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-17 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-18 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-19 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-20 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-21 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-22 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-23 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-24 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-25 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-26 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-27 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-28 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-29 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-06-30 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-01 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-02 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-03 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-04 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-05 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-06 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-07 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-08 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-09 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-10 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-11 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-12 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-13 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-14 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-15 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-16 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-17 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-18 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-19 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-20 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-21 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-22 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-23 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-24 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-25 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-26 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-27 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-28 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-29 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-30 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-07-31 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-01 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-02 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-03 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-04 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-05 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-06 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-07 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-08 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-09 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-10 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-11 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-12 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-13 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-14 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-15 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-16 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-17 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-18 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-19 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-20 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-21 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-22 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-23 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-24 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-25 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-26 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-27 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-28 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-29 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-30 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-08-31 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-01 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-02 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-03 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-04 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-05 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-06 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-07 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-08 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-09 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-10 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-11 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-12 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-13 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-14 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-15 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-16 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-17 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-18 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-19 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-20 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-21 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-22 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-23 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-24 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-25 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-26 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-27 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-28 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-29 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-09-30 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-01 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-02 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-03 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-04 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-05 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-06 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-07 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-08 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-09 00:00:00', 6.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-10 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-11 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-12 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-13 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-14 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-15 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-16 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-17 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-18 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-19 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-20 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-21 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-22 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-23 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-24 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-25 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-26 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-27 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-28 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-29 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-30 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-10-31 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-01 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-02 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-03 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-04 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-05 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-06 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-07 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-08 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-09 00:00:00', 5.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-10 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-11 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-12 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-13 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-14 00:00:00', 1.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-15 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-16 00:00:00', 4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-17 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-18 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-19 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-20 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-21 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-22 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-23 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-24 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-25 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-26 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-27 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-28 00:00:00', 6.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-29 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-11-30 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-01 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-02 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-03 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-04 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-05 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-06 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-07 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-08 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-09 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-10 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-11 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-12 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-13 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-14 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-15 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-16 00:00:00', 5.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-17 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-18 00:00:00', 5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-19 00:00:00', 4.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-20 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-21 00:00:00', 5.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-22 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-23 00:00:00', 5.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-24 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-25 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-26 00:00:00', 4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-27 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-28 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-29 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-30 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1998-12-31 00:00:00', 5.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-02 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-04 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-06 00:00:00', 6.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-08 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-10 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-12 00:00:00', 7.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-14 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-16 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-18 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-20 00:00:00', 4.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-22 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-24 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-26 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-28 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-30 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-01 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-03 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-05 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-07 00:00:00', 6.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-09 00:00:00', 6.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-11 00:00:00', 8.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-13 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-15 00:00:00', 5.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-17 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-19 00:00:00', 5.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-21 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-23 00:00:00', 4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-25 00:00:00', 6.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-27 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-01 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-03 00:00:00', 7.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-04 00:00:00', 5.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-05 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-06 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-07 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-08 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-09 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-10 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-11 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-12 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-13 00:00:00', 5.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-14 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-15 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-16 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-17 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-18 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-19 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-20 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-21 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-22 00:00:00', 5.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-23 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-24 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-25 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-26 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-27 00:00:00', 5.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-28 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-29 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-30 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-03-31 00:00:00', 5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-01 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-02 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-03 00:00:00', 5.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-04 00:00:00', 6.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-05 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-06 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-07 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-08 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-09 00:00:00', 7.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-10 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-11 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-12 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-13 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-14 00:00:00', 5.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-15 00:00:00', 6.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-16 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-17 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-18 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-19 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-20 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-21 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-22 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-23 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-24 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-25 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-26 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-27 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-28 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-29 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-04-30 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-01 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-02 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-03 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-04 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-05 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-06 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-07 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-08 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-09 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-10 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-11 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-12 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-13 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-14 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-15 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-16 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-17 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-18 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-19 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-20 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-21 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-22 00:00:00', 7.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-23 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-24 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-25 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-26 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-27 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-28 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-29 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-30 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-05-31 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-01 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-02 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-03 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-04 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-05 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-06 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-07 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-08 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-09 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-10 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-11 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-12 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-13 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-14 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-15 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-16 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-17 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-18 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-19 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-20 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-21 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-22 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-23 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-24 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-25 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-26 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-27 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-28 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-29 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-06-30 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-01 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-02 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-03 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-04 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-05 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-06 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-07 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-08 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-09 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-10 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-11 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-12 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-13 00:00:00', 5.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-14 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-15 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-16 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-17 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-18 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-19 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-20 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-21 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-22 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-23 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-24 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-25 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-26 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-27 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-28 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-29 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-30 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-07-31 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-01 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-02 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-03 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-04 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-05 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-06 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-07 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-08 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-09 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-10 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-11 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-12 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-13 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-14 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-15 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-16 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-17 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-18 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-19 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-20 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-21 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-22 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-23 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-24 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-25 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-26 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-27 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-28 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-29 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-30 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-08-31 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-01 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-02 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-03 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-04 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-05 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-06 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-07 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-08 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-09 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-10 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-11 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-12 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-13 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-14 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-15 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-16 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-17 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-18 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-19 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-20 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-21 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-22 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-23 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-24 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-25 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-26 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-27 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-28 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-29 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-09-30 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-01 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-02 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-03 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-04 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-05 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-06 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-07 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-08 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-09 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-10 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-11 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-12 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-13 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-14 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-15 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-16 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-17 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-18 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-19 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-20 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-21 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-22 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-23 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-24 00:00:00', 4.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-25 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-26 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-27 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-28 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-29 00:00:00', 5.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-30 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-10-31 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-01 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-02 00:00:00', 5.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-03 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-04 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-05 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-06 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-07 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-08 00:00:00', 5.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-09 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-10 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-11 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-12 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-13 00:00:00', 4.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-14 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-15 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-16 00:00:00', 5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-17 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-18 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-19 00:00:00', 5.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-20 00:00:00', 6.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-21 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-22 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-23 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-24 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-25 00:00:00', 5.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-26 00:00:00', 6.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-27 00:00:00', 6.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-28 00:00:00', 5.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-29 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-11-30 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-01 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-02 00:00:00', 3.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-03 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-04 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-05 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-06 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-07 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-08 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-09 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-10 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-11 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-12 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-13 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-14 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-15 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-16 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-17 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-18 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-19 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-20 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-21 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-22 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-23 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-24 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-25 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-26 00:00:00', 4.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-27 00:00:00', 5.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-28 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-29 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-30 00:00:00', 5.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '1999-12-31 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-01 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-02 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-03 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-04 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-05 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-06 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-07 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-08 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-09 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-10 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-11 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-12 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-13 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-14 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-15 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-16 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-17 00:00:00', 5.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-18 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-19 00:00:00', 6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-20 00:00:00', 4.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-21 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-22 00:00:00', 5.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-23 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-24 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-25 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-26 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-27 00:00:00', 6.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-28 00:00:00', 6.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-29 00:00:00', 6.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-30 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-01-31 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-01 00:00:00', 4.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-02 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-03 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-04 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-05 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-06 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-07 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-08 00:00:00', 5.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-09 00:00:00', 5.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-10 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-11 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-12 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-13 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-14 00:00:00', 5.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-15 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-16 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-17 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-18 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-19 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-20 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-21 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-22 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-23 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-24 00:00:00', 5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-25 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-26 00:00:00', 5.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-27 00:00:00', 4.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-28 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-02-29 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-01 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-02 00:00:00', 5.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-03 00:00:00', 5.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-04 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-05 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-06 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-07 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-08 00:00:00', 6.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-09 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-10 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-11 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-12 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-13 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-14 00:00:00', 5.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-15 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-16 00:00:00', 6.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-17 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-18 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-19 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-20 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-21 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-22 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-23 00:00:00', 5.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-24 00:00:00', 6.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-25 00:00:00', 5.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-26 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-27 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-28 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-29 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-30 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-03-31 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-01 00:00:00', 4.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-02 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-03 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-04 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-05 00:00:00', 5.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-06 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-07 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-08 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-09 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-10 00:00:00', 5.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-11 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-12 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-13 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-14 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-15 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-16 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-17 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-18 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-19 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-20 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-21 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-22 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-23 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-24 00:00:00', 5.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-25 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-26 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-27 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-28 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-29 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-04-30 00:00:00', 5.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-01 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-02 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-03 00:00:00', 5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-04 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-05 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-06 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-07 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-08 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-09 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-10 00:00:00', 6.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-11 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-12 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-13 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-14 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-15 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-16 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-17 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-18 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-19 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-20 00:00:00', 4.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-21 00:00:00', 5.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-22 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-23 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-24 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-25 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-26 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-27 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-28 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-29 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-30 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-05-31 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-01 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-02 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-03 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-04 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-05 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-06 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-07 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-08 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-09 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-10 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-11 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-12 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-13 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-14 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-15 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-16 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-17 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-18 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-19 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-20 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-21 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-22 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-23 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-24 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-25 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-26 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-27 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-28 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-29 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-06-30 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-01 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-02 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-03 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-04 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-05 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-06 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-07 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-08 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-09 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-10 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-11 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-12 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-13 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-14 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-15 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-16 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-17 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-18 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-19 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-20 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-21 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-22 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-23 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-24 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-25 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-26 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-27 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-28 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-29 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-30 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-07-31 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-01 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-02 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-03 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-04 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-05 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-06 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-07 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-08 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-09 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-10 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-11 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-12 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-13 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-14 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-15 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-16 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-17 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-18 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-19 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-20 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-21 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-22 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-23 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-24 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-25 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-26 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-27 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-28 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-29 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-30 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-08-31 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-01 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-02 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-03 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-04 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-05 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-06 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-07 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-08 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-09 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-10 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-11 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-12 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-13 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-14 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-15 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-16 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-17 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-18 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-19 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-20 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-21 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-22 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-23 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-24 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-25 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-26 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-27 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-28 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-29 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-09-30 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-01 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-02 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-03 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-04 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-05 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-06 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-07 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-08 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-09 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-10 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-11 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-12 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-13 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-14 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-15 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-16 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-17 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-18 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-19 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-20 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-21 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-22 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-23 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-24 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-25 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-26 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-27 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-28 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-29 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-30 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-10-31 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-01 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-02 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-03 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-04 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-05 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-06 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-07 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-08 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-09 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-10 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-11 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-12 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-13 00:00:00', 5.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-14 00:00:00', 4.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-15 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-16 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-17 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-18 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-19 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-20 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-21 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-22 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-23 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-24 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-25 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-26 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-27 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-28 00:00:00', 5.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-29 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-11-30 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-01 00:00:00', 6.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-02 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-03 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-04 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-05 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-06 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-07 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-08 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-09 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-10 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-11 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-12 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-13 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-14 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-15 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-16 00:00:00', 5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-17 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-18 00:00:00', 5.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-19 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-20 00:00:00', 5.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-21 00:00:00', 4.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-22 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-23 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-24 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-25 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-26 00:00:00', 5.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-27 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-28 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-29 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-30 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2000-12-31 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-01 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-02 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-03 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-04 00:00:00', 6.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-05 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-06 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-07 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-08 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-09 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-10 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-11 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-12 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-13 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-14 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-15 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-16 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-17 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-18 00:00:00', 5.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-19 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-20 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-21 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-22 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-23 00:00:00', 5.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-24 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-25 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-26 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-27 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-28 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-29 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-30 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-01-31 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-01 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-02 00:00:00', 5.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-03 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-04 00:00:00', 6.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-05 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-06 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-07 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-08 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-09 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-10 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-11 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-12 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-13 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-14 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-15 00:00:00', 6.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-16 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-17 00:00:00', 5.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-18 00:00:00', 6.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-19 00:00:00', 5.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-20 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-21 00:00:00', 7.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-22 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-23 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-24 00:00:00', 5.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-25 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-26 00:00:00', 4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-27 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-02-28 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-01 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-02 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-03 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-04 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-05 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-06 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-07 00:00:00', 5.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-08 00:00:00', 5.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-09 00:00:00', 6.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-10 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-11 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-12 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-13 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-14 00:00:00', 5.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-15 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-16 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-17 00:00:00', 5.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-18 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-19 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-20 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-21 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-22 00:00:00', 5.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-23 00:00:00', 6.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-24 00:00:00', 5.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-25 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-26 00:00:00', 7.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-27 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-28 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-29 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-30 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-03-31 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-01 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-02 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-03 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-04 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-05 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-06 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-07 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-08 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-09 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-10 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-11 00:00:00', 5.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-12 00:00:00', 5.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-13 00:00:00', 5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-14 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-15 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-16 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-17 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-18 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-19 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-20 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-21 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-22 00:00:00', 5.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-23 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-24 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-25 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-26 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-27 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-28 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-29 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-04-30 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-01 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-02 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-03 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-04 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-05 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-06 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-07 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-08 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-09 00:00:00', 5.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-10 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-11 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-12 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-13 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-14 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-15 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-16 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-17 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-18 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-19 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-20 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-21 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-22 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-23 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-24 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-25 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-26 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-27 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-28 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-29 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-30 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-05-31 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-01 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-02 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-03 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-04 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-05 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-06 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-07 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-08 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-09 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-10 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-11 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-12 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-13 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-14 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-15 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-16 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-17 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-18 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-19 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-20 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-21 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-22 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-23 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-24 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-25 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-26 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-27 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-28 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-29 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-06-30 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-01 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-02 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-03 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-04 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-05 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-06 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-07 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-08 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-09 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-10 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-11 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-12 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-13 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-14 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-15 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-16 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-17 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-18 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-19 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-20 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-21 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-22 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-23 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-24 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-25 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-26 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-27 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-28 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-29 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-30 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-07-31 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-01 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-02 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-03 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-04 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-05 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-06 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-07 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-08 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-09 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-10 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-11 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-12 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-13 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-14 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-15 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-16 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-17 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-18 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-19 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-20 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-21 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-22 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-23 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-24 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-25 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-26 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-27 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-28 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-29 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-30 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-08-31 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-01 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-02 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-03 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-04 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-05 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-06 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-07 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-08 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-09 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-10 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-11 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-12 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-13 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-14 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-15 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-16 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-17 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-18 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-19 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-20 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-21 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-22 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-23 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-24 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-25 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-26 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-27 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-28 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-29 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-09-30 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-01 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-02 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-03 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-04 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-05 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-06 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-07 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-08 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-09 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-10 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-11 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-12 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-13 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-14 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-15 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-16 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-17 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-18 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-19 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-20 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-21 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-22 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-23 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-24 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-25 00:00:00', 6.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-26 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-27 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-28 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-29 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-30 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-10-31 00:00:00', 5.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-01 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-02 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-03 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-04 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-05 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-06 00:00:00', 4.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-07 00:00:00', 5.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-08 00:00:00', 6.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-09 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-10 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-11 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-12 00:00:00', 6.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-13 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-14 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-15 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-16 00:00:00', 5.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-17 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-18 00:00:00', 5.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-19 00:00:00', 4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-20 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-21 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-22 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-23 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-24 00:00:00', 1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-25 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-26 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-27 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-28 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-29 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-11-30 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-01 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-02 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-03 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-04 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-05 00:00:00', 5.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-06 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-07 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-08 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-09 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-10 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-11 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-12 00:00:00', 6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-13 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-14 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-15 00:00:00', 5.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-16 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-17 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-18 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-19 00:00:00', 6.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-20 00:00:00', 6.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-21 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-22 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-23 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-24 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-25 00:00:00', 5.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-26 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-27 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-28 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-29 00:00:00', 6.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-30 00:00:00', 6.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2001-12-31 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-01 00:00:00', 6.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-02 00:00:00', 6.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-03 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-04 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-05 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-06 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-07 00:00:00', 6.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-08 00:00:00', 6.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-09 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-10 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-11 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-12 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-13 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-14 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-15 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-16 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-17 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-18 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-19 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-20 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-21 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-22 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-23 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-24 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-25 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-26 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-27 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-28 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-29 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-30 00:00:00', 5.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-01-31 00:00:00', 5.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-01 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-02 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-03 00:00:00', 6.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-04 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-05 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-06 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-07 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-08 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-09 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-10 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-11 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-12 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-13 00:00:00', 6.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-14 00:00:00', 6.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-15 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-16 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-17 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-18 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-19 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-20 00:00:00', 4.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-21 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-22 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-23 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-24 00:00:00', 6.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-25 00:00:00', 6.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-26 00:00:00', 6.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-27 00:00:00', 7.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-02-28 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-01 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-02 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-03 00:00:00', 5.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-04 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-05 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-06 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-07 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-08 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-09 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-10 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-11 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-12 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-13 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-14 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-15 00:00:00', 6.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-16 00:00:00', 6.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-17 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-18 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-19 00:00:00', 6.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-20 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-21 00:00:00', 6.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-22 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-23 00:00:00', 6.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-24 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-25 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-26 00:00:00', 6.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-27 00:00:00', 5.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-28 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-29 00:00:00', 6.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-30 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-03-31 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-01 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-02 00:00:00', 5.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-03 00:00:00', 6.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-04 00:00:00', 6.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-05 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-06 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-07 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-08 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-09 00:00:00', 4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-10 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-11 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-12 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-13 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-14 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-15 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-16 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-17 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-18 00:00:00', 5.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-19 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-20 00:00:00', 5.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-21 00:00:00', 4.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-22 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-23 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-24 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-25 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-26 00:00:00', 6.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-27 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-28 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-29 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-04-30 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-01 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-02 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-03 00:00:00', 4.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-04 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-05 00:00:00', 5.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-06 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-07 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-08 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-09 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-10 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-11 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-12 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-13 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-14 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-15 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-16 00:00:00', 4.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-17 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-18 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-19 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-20 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-21 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-22 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-23 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-24 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-25 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-26 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-27 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-28 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-29 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-30 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-05-31 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-01 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-02 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-03 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-04 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-05 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-06 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-07 00:00:00', 6.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-08 00:00:00', 5.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-09 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-10 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-11 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-12 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-13 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-14 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-15 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-16 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-17 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-18 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-19 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-20 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-21 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-22 00:00:00', 5.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-23 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-24 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-25 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-26 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-27 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-28 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-29 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-06-30 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-01 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-02 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-03 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-04 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-05 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-06 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-07 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-08 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-09 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-10 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-11 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-12 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-13 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-14 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-15 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-16 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-17 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-18 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-19 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-20 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-21 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-22 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-23 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-24 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-25 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-26 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-27 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-28 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-29 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-30 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-07-31 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-01 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-02 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-03 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-04 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-05 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-06 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-07 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-08 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-09 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-10 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-11 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-12 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-13 00:00:00', 5.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-14 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-15 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-16 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-17 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-18 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-19 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-20 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-21 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-22 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-23 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-24 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-25 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-26 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-27 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-28 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-29 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-30 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-08-31 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-01 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-02 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-03 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-04 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-05 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-06 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-07 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-08 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-09 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-10 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-11 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-12 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-13 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-14 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-15 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-16 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-17 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-18 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-19 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-20 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-21 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-22 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-23 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-24 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-25 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-26 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-27 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-28 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-29 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-09-30 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-01 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-02 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-03 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-04 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-05 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-06 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-07 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-08 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-09 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-10 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-11 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-12 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-13 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-14 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-15 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-16 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-17 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-18 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-19 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-20 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-21 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-22 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-23 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-24 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-25 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-26 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-27 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-28 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-29 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-30 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-10-31 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-01 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-02 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-03 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-04 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-05 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-06 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-07 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-08 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-09 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-10 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-11 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-12 00:00:00', 5.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-13 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-14 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-15 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-16 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-17 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-18 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-19 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-20 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-21 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-22 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-23 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-24 00:00:00', 4.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-25 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-26 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-27 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-28 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-29 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-11-30 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-01 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-02 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-03 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-04 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-05 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-06 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-07 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-08 00:00:00', 5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-09 00:00:00', 6.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-10 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-11 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-12 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-13 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-14 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-15 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-16 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-17 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-18 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-19 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-20 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-21 00:00:00', 6.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-22 00:00:00', 5.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-23 00:00:00', 5.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-24 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-25 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-26 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-27 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-28 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-29 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-30 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2002-12-31 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-01 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-02 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-03 00:00:00', 4.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-04 00:00:00', 5.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-05 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-06 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-07 00:00:00', 6.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-08 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-09 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-10 00:00:00', 5.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-11 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-12 00:00:00', 6.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-13 00:00:00', 6.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-14 00:00:00', 5.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-15 00:00:00', 4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-16 00:00:00', 6.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-17 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-18 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-19 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-20 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-21 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-22 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-23 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-24 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-25 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-26 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-27 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-28 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-29 00:00:00', 6.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-30 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-01-31 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-01 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-02 00:00:00', 6.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-03 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-04 00:00:00', 6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-05 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-06 00:00:00', 5.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-07 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-08 00:00:00', 4.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-09 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-10 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-11 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-12 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-13 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-14 00:00:00', 7.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-15 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-16 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-17 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-18 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-19 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-20 00:00:00', 7.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-21 00:00:00', 5.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-22 00:00:00', 5.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-23 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-24 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-25 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-26 00:00:00', 5.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-27 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-02-28 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-01 00:00:00', 4.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-02 00:00:00', 5.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-03 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-04 00:00:00', 6.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-05 00:00:00', 4.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-06 00:00:00', 5.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-07 00:00:00', 6.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-08 00:00:00', 6.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-09 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-10 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-11 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-12 00:00:00', 5.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-13 00:00:00', 7.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-14 00:00:00', 8.35499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-15 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-16 00:00:00', 5.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-17 00:00:00', 6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-18 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-19 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-20 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-21 00:00:00', 6.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-22 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-23 00:00:00', 5.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-24 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-25 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-26 00:00:00', 6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-27 00:00:00', 6.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-28 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-29 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-30 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-03-31 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-01 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-02 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-03 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-04 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-05 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-06 00:00:00', 5.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-07 00:00:00', 6.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-08 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-09 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-10 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-11 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-12 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-13 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-14 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-15 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-16 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-17 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-18 00:00:00', 6.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-19 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-20 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-21 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-22 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-23 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-24 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-25 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-26 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-27 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-28 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-29 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-04-30 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-01 00:00:00', 5.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-02 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-03 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-04 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-05 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-06 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-07 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-08 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-09 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-10 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-11 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-12 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-13 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-14 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-15 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-16 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-17 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-18 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-19 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-20 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-21 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-22 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-23 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-24 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-25 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-26 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-27 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-28 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-29 00:00:00', 4.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-30 00:00:00', 5.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-05-31 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-01 00:00:00', 4.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-02 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-03 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-04 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-05 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-06 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-07 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-08 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-09 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-10 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-11 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-12 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-13 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-14 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-15 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-16 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-17 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-18 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-19 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-20 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-21 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-22 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-23 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-24 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-25 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-26 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-27 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-28 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-29 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-06-30 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-01 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-02 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-03 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-04 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-05 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-06 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-07 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-08 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-09 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-10 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-11 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-12 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-13 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-14 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-15 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-16 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-17 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-18 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-19 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-20 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-21 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-22 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-23 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-24 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-25 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-26 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-27 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-28 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-29 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-30 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-07-31 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-01 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-02 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-03 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-04 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-05 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-06 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-07 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-08 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-09 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-10 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-11 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-12 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-13 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-14 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-15 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-16 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-17 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-18 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-19 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-20 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-21 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-22 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-23 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-24 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-25 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-26 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-27 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-28 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-29 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-30 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-08-31 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-01 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-02 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-03 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-04 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-05 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-06 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-07 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-08 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-09 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-10 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-11 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-12 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-13 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-14 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-15 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-16 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-17 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-18 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-19 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-20 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-21 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-22 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-23 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-24 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-25 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-26 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-27 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-28 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-29 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-09-30 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-01 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-02 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-03 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-04 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-05 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-06 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-07 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-08 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-09 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-10 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-11 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-12 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-13 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-14 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-15 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-16 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-17 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-18 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-19 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-20 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-21 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-22 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-23 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-24 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-25 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-26 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-27 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-28 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-29 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-30 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-10-31 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-01 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-02 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-03 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-04 00:00:00', 5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-05 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-06 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-07 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-08 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-09 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-10 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-11 00:00:00', 5.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-12 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-13 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-14 00:00:00', 6.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-15 00:00:00', 4.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-16 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-17 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-18 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-19 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-20 00:00:00', 5.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-21 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-22 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-23 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-24 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-25 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-26 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-27 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-28 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-29 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-11-30 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-01 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-02 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-03 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-04 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-05 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-06 00:00:00', 6.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-07 00:00:00', 5.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-08 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-09 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-10 00:00:00', 5.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-11 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-12 00:00:00', 6.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-13 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-14 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-15 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-16 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-17 00:00:00', 5.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-18 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-19 00:00:00', 6.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-20 00:00:00', 5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-21 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-22 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-23 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-24 00:00:00', 5.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-25 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-26 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-27 00:00:00', 5.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-28 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-29 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-30 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2003-12-31 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-01 00:00:00', 0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-02 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-03 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-04 00:00:00', 6.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-05 00:00:00', 4.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-06 00:00:00', 7.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-07 00:00:00', 6.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-08 00:00:00', 7.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-09 00:00:00', 6.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-10 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-11 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-12 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-13 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-14 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-15 00:00:00', 5.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-16 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-17 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-18 00:00:00', 5.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-19 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-20 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-21 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-22 00:00:00', 0.824999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-23 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-24 00:00:00', 5.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-25 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-26 00:00:00', 6.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-27 00:00:00', 6.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-28 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-29 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-30 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-01-31 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-01 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-02 00:00:00', 6.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-03 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-04 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-05 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-06 00:00:00', 7.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-07 00:00:00', 5.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-08 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-09 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-10 00:00:00', 4.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-11 00:00:00', 5.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-12 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-13 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-14 00:00:00', 6.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-15 00:00:00', 8.12800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-16 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-17 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-18 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-19 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-20 00:00:00', 6.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-21 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-22 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-23 00:00:00', 5.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-24 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-25 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-26 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-27 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-28 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-02-29 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-01 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-02 00:00:00', 6.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-03 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-04 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-05 00:00:00', 5.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-06 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-07 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-08 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-09 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-10 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-11 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-12 00:00:00', 6.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-13 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-14 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-15 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-16 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-17 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-18 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-19 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-20 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-21 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-22 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-23 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-24 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-25 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-26 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-27 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-28 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-29 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-30 00:00:00', 4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-03-31 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-01 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-02 00:00:00', 6.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-03 00:00:00', 5.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-04 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-05 00:00:00', 4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-06 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-07 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-08 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-09 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-10 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-11 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-12 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-13 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-14 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-15 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-16 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-17 00:00:00', 4.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-18 00:00:00', 7.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-19 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-20 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-21 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-22 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-23 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-24 00:00:00', 5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-25 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-26 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-27 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-28 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-29 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-04-30 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-01 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-02 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-03 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-04 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-05 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-06 00:00:00', 5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-07 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-08 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-09 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-10 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-11 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-12 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-13 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-14 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-15 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-16 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-17 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-18 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-19 00:00:00', 4.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-20 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-21 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-22 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-23 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-24 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-25 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-26 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-27 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-28 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-29 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-30 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-05-31 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-01 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-02 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-03 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-04 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-05 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-06 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-07 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-08 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-09 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-10 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-11 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-12 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-13 00:00:00', 4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-14 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-15 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-16 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-17 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-18 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-19 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-20 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-21 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-22 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-23 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-24 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-25 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-26 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-27 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-28 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-29 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-06-30 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-01 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-02 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-03 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-04 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-05 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-06 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-07 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-08 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-09 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-10 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-11 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-12 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-13 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-14 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-15 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-16 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-17 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-18 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-19 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-20 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-21 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-22 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-23 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-24 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-25 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-26 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-27 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-28 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-29 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-30 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-07-31 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-01 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-02 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-03 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-04 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-05 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-06 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-07 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-08 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-09 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-10 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-11 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-12 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-13 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-14 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-15 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-16 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-17 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-18 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-19 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-20 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-21 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-22 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-23 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-24 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-25 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-26 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-27 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-28 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-29 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-30 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-08-31 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-01 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-02 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-03 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-04 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-05 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-06 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-07 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-08 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-09 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-10 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-11 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-12 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-13 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-14 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-15 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-16 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-17 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-18 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-19 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-20 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-21 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-22 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-23 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-24 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-25 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-26 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-27 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-28 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-29 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-09-30 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-01 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-02 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-03 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-04 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-05 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-06 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-07 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-08 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-09 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-10 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-11 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-12 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-13 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-14 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-15 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-16 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-17 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-18 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-19 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-20 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-21 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-22 00:00:00', 4.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-23 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-24 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-25 00:00:00', 1.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-26 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-27 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-28 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-29 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-30 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-10-31 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-01 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-02 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-03 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-04 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-05 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-06 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-07 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-08 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-09 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-10 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-11 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-12 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-13 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-14 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-15 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-16 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-17 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-18 00:00:00', 5.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-19 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-20 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-21 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-22 00:00:00', 4.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-23 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-24 00:00:00', 5.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-25 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-26 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-27 00:00:00', 6.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-28 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-29 00:00:00', 4.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-11-30 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-01 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-02 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-03 00:00:00', 5.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-04 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-05 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-06 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-07 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-08 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-09 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-10 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-11 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-12 00:00:00', 6.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-13 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-14 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-15 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-16 00:00:00', 5.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-17 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-18 00:00:00', 5.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-19 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-20 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-21 00:00:00', 5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-22 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-23 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-24 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-25 00:00:00', 5.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-26 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-27 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-28 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-29 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-30 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2004-12-31 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-01 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-02 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-03 00:00:00', 6.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-04 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-05 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-06 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-07 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-08 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-09 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-10 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-11 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-12 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-13 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-14 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-15 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-16 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-17 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-18 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-19 00:00:00', 5.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-20 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-21 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-22 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-23 00:00:00', 6.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-24 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-25 00:00:00', 6.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-26 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-27 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-28 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-29 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-30 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-01-31 00:00:00', 6.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-01 00:00:00', 6.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-02 00:00:00', 5.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-03 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-04 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-05 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-06 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-07 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-08 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-09 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-10 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-11 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-12 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-13 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-14 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-15 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-16 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-17 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-18 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-19 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-20 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-21 00:00:00', 4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-22 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-23 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-24 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-25 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-26 00:00:00', 5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-27 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-02-28 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-01 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-02 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-03 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-04 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-05 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-06 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-07 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-08 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-09 00:00:00', 4.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-10 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-11 00:00:00', 6.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-12 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-13 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-14 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-15 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-16 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-17 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-18 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-19 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-20 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-21 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-22 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-23 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-24 00:00:00', 5.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-25 00:00:00', 5.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-26 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-27 00:00:00', 5.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-28 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-29 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-30 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-03-31 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-01 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-02 00:00:00', 5.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-03 00:00:00', 5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-04 00:00:00', 6.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-05 00:00:00', 8.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-06 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-07 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-08 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-09 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-10 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-11 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-12 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-13 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-14 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-15 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-16 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-17 00:00:00', 4.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-18 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-19 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-20 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-21 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-22 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-23 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-24 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-25 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-26 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-27 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-28 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-29 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-04-30 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-01 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-02 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-03 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-04 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-05 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-06 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-07 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-08 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-09 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-10 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-11 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-12 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-13 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-14 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-15 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-16 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-17 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-18 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-19 00:00:00', 5.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-20 00:00:00', 4.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-21 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-22 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-23 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-24 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-25 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-26 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-27 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-28 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-29 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-30 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-05-31 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-01 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-02 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-03 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-04 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-05 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-06 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-07 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-08 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-09 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-10 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-11 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-12 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-13 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-14 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-15 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-16 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-17 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-18 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-19 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-20 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-21 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-22 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-23 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-24 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-25 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-26 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-27 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-28 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-29 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-06-30 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-01 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-02 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-03 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-04 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-05 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-06 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-07 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-08 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-09 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-10 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-11 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-12 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-13 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-14 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-15 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-16 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-17 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-18 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-19 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-20 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-21 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-22 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-23 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-24 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-25 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-26 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-27 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-28 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-29 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-30 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-07-31 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-01 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-02 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-03 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-04 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-05 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-06 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-07 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-08 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-09 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-10 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-11 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-12 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-13 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-14 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-15 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-16 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-17 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-18 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-19 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-20 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-21 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-22 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-23 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-24 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-25 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-26 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-27 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-28 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-29 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-30 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-08-31 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-01 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-02 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-03 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-04 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-05 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-06 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-07 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-08 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-09 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-10 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-11 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-12 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-13 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-14 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-15 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-16 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-17 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-18 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-19 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-20 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-21 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-22 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-23 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-24 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-25 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-26 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-27 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-28 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-29 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-09-30 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-01 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-02 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-03 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-04 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-05 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-06 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-07 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-08 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-09 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-10 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-11 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-12 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-13 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-14 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-15 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-16 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-17 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-18 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-19 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-20 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-21 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-22 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-23 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-24 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-25 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-26 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-27 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-28 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-29 00:00:00', 4.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-30 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-10-31 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-01 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-02 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-03 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-04 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-05 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-06 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-07 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-08 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-09 00:00:00', 5.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-10 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-11 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-12 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-13 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-14 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-15 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-16 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-17 00:00:00', 5.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-18 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-19 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-20 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-21 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-22 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-23 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-24 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-25 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-26 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-27 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-28 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-29 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-11-30 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-01 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-02 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-03 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-04 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-05 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-06 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-07 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-08 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-09 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-10 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-11 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-12 00:00:00', 0.949000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-13 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-14 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-15 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-16 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-17 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-18 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-19 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-20 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-21 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-22 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-23 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-24 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-25 00:00:00', 5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-26 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-27 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-28 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-29 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-30 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2005-12-31 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-01 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-02 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-03 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-04 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-05 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-06 00:00:00', 5.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-07 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-08 00:00:00', 5.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-09 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-10 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-11 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-12 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-13 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-14 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-15 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-16 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-17 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-18 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-19 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-20 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-21 00:00:00', 5.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-22 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-23 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-24 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-25 00:00:00', 5.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-26 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-27 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-28 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-29 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-30 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-01-31 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-01 00:00:00', 6.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-02 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-03 00:00:00', 6.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-04 00:00:00', 6.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-05 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-06 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-07 00:00:00', 4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-08 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-09 00:00:00', 6.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-10 00:00:00', 5.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-11 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-12 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-13 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-14 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-15 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-16 00:00:00', 5.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-17 00:00:00', 6.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-18 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-19 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-20 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-21 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-22 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-23 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-24 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-25 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-26 00:00:00', 5.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-27 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-02-28 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-01 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-02 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-03 00:00:00', 6.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-04 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-05 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-06 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-07 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-08 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-09 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-10 00:00:00', 5.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-11 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-12 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-13 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-14 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-15 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-16 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-17 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-18 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-19 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-20 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-21 00:00:00', 5.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-22 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-23 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-24 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-25 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-26 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-27 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-28 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-29 00:00:00', 5.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-30 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-03-31 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-01 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-02 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-03 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-04 00:00:00', 6.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-05 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-06 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-07 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-08 00:00:00', 5.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-09 00:00:00', 9.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-10 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-11 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-12 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-13 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-14 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-15 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-16 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-17 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-18 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-19 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-20 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-21 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-22 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-23 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-24 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-25 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-26 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-27 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-28 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-29 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-04-30 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-01 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-02 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-03 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-04 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-05 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-06 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-07 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-08 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-09 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-10 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-11 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-12 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-13 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-14 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-15 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-16 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-17 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-18 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-19 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-20 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-21 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-22 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-23 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-24 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-25 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-26 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-27 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-28 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-29 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-30 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-05-31 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-01 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-02 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-03 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-04 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-05 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-06 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-07 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-08 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-09 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-10 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-11 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-12 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-13 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-14 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-15 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-16 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-17 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-18 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-19 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-20 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-21 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-22 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-23 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-24 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-25 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-26 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-27 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-28 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-29 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-06-30 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-01 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-02 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-03 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-04 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-05 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-06 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-07 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-08 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-09 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-10 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-11 00:00:00', 4.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-12 00:00:00', 5.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-13 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-14 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-15 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-16 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-17 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-18 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-19 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-20 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-21 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-22 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-23 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-24 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-25 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-26 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-27 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-28 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-29 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-30 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-07-31 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-01 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-02 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-03 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-04 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-05 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-06 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-07 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-08 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-09 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-10 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-11 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-12 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-13 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-14 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-15 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-16 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-17 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-18 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-19 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-20 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-21 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-22 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-23 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-24 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-25 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-26 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-27 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-28 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-29 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-30 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-08-31 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-01 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-02 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-03 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-04 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-05 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-06 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-07 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-08 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-09 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-10 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-11 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-12 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-13 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-14 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-15 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-16 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-17 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-18 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-19 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-20 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-21 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-22 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-23 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-24 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-25 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-26 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-27 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-28 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-29 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-09-30 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-01 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-02 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-03 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-04 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-05 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-06 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-07 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-08 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-09 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-10 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-11 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-12 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-13 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-14 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-15 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-16 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-17 00:00:00', 4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-18 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-19 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-20 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-21 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-22 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-23 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-24 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-25 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-26 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-27 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-28 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-29 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-30 00:00:00', 5.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-10-31 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-01 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-02 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-03 00:00:00', 5.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-04 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-05 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-06 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-07 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-08 00:00:00', 4.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-09 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-10 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-11 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-12 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-13 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-14 00:00:00', 4.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-15 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-16 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-17 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-18 00:00:00', 5.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-19 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-20 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-21 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-22 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-23 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-24 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-25 00:00:00', 1.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-26 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-27 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-28 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-29 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-11-30 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-01 00:00:00', 1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-02 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-03 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-04 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-05 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-06 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-07 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-08 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-09 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-10 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-11 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-12 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-13 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-14 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-15 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-16 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-17 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-18 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-19 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-20 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-21 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-22 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-23 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-24 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-25 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-26 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-27 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-28 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-29 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-30 00:00:00', 4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2006-12-31 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-01 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-02 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-03 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-04 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-05 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-06 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-07 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-08 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-09 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-10 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-11 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-12 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-13 00:00:00', 6.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-14 00:00:00', 6.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-15 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-16 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-17 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-18 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-19 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-20 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-21 00:00:00', 5.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-22 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-23 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-24 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-25 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-26 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-27 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-28 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-29 00:00:00', 5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-30 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-01-31 00:00:00', 5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-01 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-02 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-03 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-04 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-05 00:00:00', 6.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-06 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-07 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-08 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-09 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-10 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-11 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-12 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-13 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-14 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-15 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-16 00:00:00', 4.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-17 00:00:00', 5.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-18 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-19 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-20 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-21 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-22 00:00:00', 5.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-23 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-24 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-25 00:00:00', 4.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-26 00:00:00', 5.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-27 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-02-28 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-01 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-02 00:00:00', 5.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-03 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-04 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-05 00:00:00', 5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-06 00:00:00', 5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-07 00:00:00', 6.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-08 00:00:00', 6.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-09 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-10 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-11 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-12 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-13 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-14 00:00:00', 4.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-15 00:00:00', 6.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-16 00:00:00', 6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-17 00:00:00', 4.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-18 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-19 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-20 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-21 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-22 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-23 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-24 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-25 00:00:00', 6.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-26 00:00:00', 6.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-27 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-28 00:00:00', 5.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-29 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-30 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-03-31 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-01 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-02 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-03 00:00:00', 5.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-04 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-05 00:00:00', 5.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-06 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-07 00:00:00', 5.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-08 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-09 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-10 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-11 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-12 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-13 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-14 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-15 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-16 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-17 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-18 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-19 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-20 00:00:00', 5.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-21 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-22 00:00:00', 1.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-23 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-24 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-25 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-26 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-27 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-28 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-29 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-04-30 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-01 00:00:00', 5.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-02 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-03 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-04 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-05 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-06 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-07 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-08 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-09 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-10 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-11 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-12 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-13 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-14 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-15 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-16 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-17 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-18 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-19 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-20 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-21 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-22 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-23 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-24 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-25 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-26 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-27 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-28 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-29 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-30 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-05-31 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-01 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-02 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-03 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-04 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-05 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-06 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-07 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-08 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-09 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-10 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-11 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-12 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-13 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-14 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-15 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-16 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-17 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-18 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-19 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-20 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-21 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-22 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-23 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-24 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-25 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-26 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-27 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-28 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-29 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-06-30 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-01 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-02 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-03 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-04 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-05 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-06 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-07 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-08 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-09 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-10 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-11 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-12 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-13 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-14 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-15 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-16 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-17 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-18 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-19 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-20 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-21 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-22 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-23 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-24 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-25 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-26 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-27 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-28 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-29 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-30 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-07-31 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-01 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-02 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-03 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-04 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-05 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-06 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-07 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-08 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-09 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-10 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-11 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-12 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-13 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-14 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-15 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-16 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-17 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-18 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-19 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-20 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-21 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-22 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-23 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-24 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-25 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-26 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-27 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-28 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-29 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-30 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-08-31 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-01 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-02 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-03 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-04 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-05 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-06 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-07 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-08 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-09 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-10 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-11 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-12 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-13 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-14 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-15 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-16 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-17 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-18 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-19 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-20 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-21 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-22 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-23 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-24 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-25 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-26 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-27 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-28 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-29 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-09-30 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-01 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-02 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-03 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-04 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-05 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-06 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-07 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-08 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-09 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-10 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-11 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-12 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-13 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-14 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-15 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-16 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-17 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-18 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-19 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-20 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-21 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-22 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-23 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-24 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-25 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-26 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-27 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-28 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-29 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-30 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-10-31 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-01 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-02 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-03 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-04 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-05 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-06 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-07 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-08 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-09 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-10 00:00:00', 4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-11 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-12 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-13 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-14 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-15 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-16 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-17 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-18 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-19 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-20 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-21 00:00:00', 6.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-22 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-23 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-24 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-25 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-26 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-27 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-28 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-29 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-11-30 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-01 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-02 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-03 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-04 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-05 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-06 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-07 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-08 00:00:00', 5.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-09 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-10 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-11 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-12 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-13 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-14 00:00:00', 6.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-15 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-16 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-17 00:00:00', 4.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-18 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-19 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-20 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-21 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-22 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-23 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-24 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-25 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-26 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-27 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-28 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-29 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-30 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2007-12-31 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-01 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-02 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-03 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-04 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-05 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-06 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-07 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-08 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-09 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-10 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-11 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-12 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-13 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-14 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-15 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-16 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-17 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-18 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-19 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-20 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-21 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-22 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-23 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-24 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-25 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-26 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-27 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-28 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-29 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-30 00:00:00', 5.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-01-31 00:00:00', 4.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-01 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-02 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-03 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-04 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-05 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-06 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-07 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-08 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-09 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-10 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-11 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-12 00:00:00', 6.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-13 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-14 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-15 00:00:00', 5.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-16 00:00:00', 5.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-17 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-18 00:00:00', 5.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-19 00:00:00', 6.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-20 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-21 00:00:00', 6.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-22 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-23 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-24 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-25 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-26 00:00:00', 6.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-27 00:00:00', 5.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-28 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-02-29 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-01 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-02 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-03 00:00:00', 5.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-04 00:00:00', 7.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-05 00:00:00', 6.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-06 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-07 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-08 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-09 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-10 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-11 00:00:00', 5.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-12 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-13 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-14 00:00:00', 7.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-15 00:00:00', 5.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-16 00:00:00', 7.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-17 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-18 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-19 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-20 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-21 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-22 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-23 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-24 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-25 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-26 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-27 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-28 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-29 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-30 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-03-31 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-01 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-02 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-03 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-04 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-05 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-06 00:00:00', 6.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-07 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-08 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-09 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-10 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-11 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-12 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-13 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-14 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-15 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-16 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-17 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-18 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-19 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-20 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-21 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-22 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-23 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-24 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-25 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-26 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-27 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-28 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-29 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-04-30 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-01 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-02 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-03 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-04 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-05 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-06 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-07 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-08 00:00:00', 5.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-09 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-10 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-11 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-12 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-13 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-14 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-15 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-16 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-17 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-18 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-19 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-20 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-21 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-22 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-23 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-24 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-25 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-26 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-27 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-28 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-29 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-30 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-05-31 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-01 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-02 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-03 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-04 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-05 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-06 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-07 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-08 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-09 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-10 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-11 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-12 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-13 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-14 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-15 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-16 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-17 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-18 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-19 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-20 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-21 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-22 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-23 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-24 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-25 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-26 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-27 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-28 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-29 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-06-30 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-01 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-02 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-03 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-04 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-05 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-06 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-07 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-08 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-09 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-10 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-11 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-12 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-13 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-14 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-15 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-16 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-17 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-18 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-19 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-20 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-21 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-22 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-23 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-24 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-25 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-26 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-27 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-28 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-29 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-30 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-07-31 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-01 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-02 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-03 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-04 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-05 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-06 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-07 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-08 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-09 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-10 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-11 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-12 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-13 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-14 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-15 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-16 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-17 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-18 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-19 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-20 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-21 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-22 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-23 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-24 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-25 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-26 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-27 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-28 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-29 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-30 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-08-31 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-01 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-02 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-03 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-04 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-05 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-06 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-07 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-08 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-09 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-10 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-11 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-12 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-13 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-14 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-15 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-16 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-17 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-18 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-19 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-20 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-21 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-22 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-23 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-24 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-25 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-26 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-27 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-28 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-29 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-09-30 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-01 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-02 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-03 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-04 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-05 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-06 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-07 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-08 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-09 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-10 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-11 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-12 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-13 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-14 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-15 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-16 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-17 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-18 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-19 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-20 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-21 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-22 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-23 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-24 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-25 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-26 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-27 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-28 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-29 00:00:00', 1.02799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-30 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-10-31 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-01 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-02 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-03 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-04 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-05 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-06 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-07 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-08 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-09 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-10 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-11 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-12 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-13 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-14 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-15 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-16 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-17 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-18 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-19 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-20 00:00:00', 5.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-21 00:00:00', 6.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-22 00:00:00', 6.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-23 00:00:00', 6.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-24 00:00:00', 4.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-25 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-26 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-27 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-28 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-29 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-11-30 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-01 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-02 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-03 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-04 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-05 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-06 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-07 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-08 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-09 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-10 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-11 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-12 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-13 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-14 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-15 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-16 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-17 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-18 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-19 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-20 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-21 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-22 00:00:00', 5.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-23 00:00:00', 5.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-24 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-25 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-26 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-27 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-28 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-29 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-30 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2008-12-31 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-01 00:00:00', 6.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-02 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-03 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-04 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-05 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-06 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-07 00:00:00', 5.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-08 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-09 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-10 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-11 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-12 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-13 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-14 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-15 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-16 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-17 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-18 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-19 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-20 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-21 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-22 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-23 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-24 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-25 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-26 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-27 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-28 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-29 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-30 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-01-31 00:00:00', 5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-01 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-02 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-03 00:00:00', 5.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-04 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-05 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-06 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-07 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-08 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-09 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-10 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-11 00:00:00', 6.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-12 00:00:00', 5.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-13 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-14 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-15 00:00:00', 5.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-16 00:00:00', 5.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-17 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-18 00:00:00', 5.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-19 00:00:00', 5.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-20 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-21 00:00:00', 5.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-22 00:00:00', 6.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-23 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-24 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-25 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-26 00:00:00', 4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-27 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-02-28 00:00:00', 7.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-01 00:00:00', 6.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-02 00:00:00', 7.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-03 00:00:00', 6.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-04 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-05 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-06 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-07 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-08 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-09 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-10 00:00:00', 6.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-11 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-12 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-13 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-14 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-15 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-16 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-17 00:00:00', 6.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-18 00:00:00', 5.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-19 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-20 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-21 00:00:00', 5.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-22 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-23 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-24 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-25 00:00:00', 6.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-26 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-27 00:00:00', 1.06700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-28 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-29 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-30 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-03-31 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-01 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-02 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-03 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-04 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-05 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-06 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-07 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-08 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-09 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-10 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-11 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-12 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-13 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-14 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-15 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-16 00:00:00', 5.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-17 00:00:00', 5.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-18 00:00:00', 5.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-19 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-20 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-21 00:00:00', 6.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-22 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-23 00:00:00', 4.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-24 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-25 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-26 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-27 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-28 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-29 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-04-30 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-01 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-02 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-03 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-04 00:00:00', 5.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-05 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-06 00:00:00', 5.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-07 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-08 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-09 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-10 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-11 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-12 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-13 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-14 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-15 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-16 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-17 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-18 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-19 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-20 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-21 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-22 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-23 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-24 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-25 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-26 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-27 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-28 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-29 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-30 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-05-31 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-01 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-02 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-03 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-04 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-05 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-06 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-07 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-08 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-09 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-10 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-11 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-12 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-13 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-14 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-15 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-16 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-17 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-18 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-19 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-20 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-21 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-22 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-23 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-24 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-25 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-26 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-27 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-28 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-29 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-06-30 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-01 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-02 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-03 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-04 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-05 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-06 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-07 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-08 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-09 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-10 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-11 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-12 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-13 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-14 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-15 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-16 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-17 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-18 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-19 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-20 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-21 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-22 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-23 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-24 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-25 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-26 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-27 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-28 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-29 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-30 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-07-31 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-01 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-02 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-03 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-04 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-05 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-06 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-07 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-08 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-09 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-10 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-11 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-12 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-13 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-14 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-15 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-16 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-17 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-18 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-19 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-20 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-21 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-22 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-23 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-24 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-25 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-26 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-27 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-28 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-29 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-30 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-08-31 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-01 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-02 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-03 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-04 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-05 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-06 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-07 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-08 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-09 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-10 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-11 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-12 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-13 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-14 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-15 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-16 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-17 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-18 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-19 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-20 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-21 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-22 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-23 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-24 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-25 00:00:00', 5.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-26 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-27 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-28 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-29 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-09-30 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-01 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-02 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-03 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-04 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-05 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-06 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-07 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-08 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-09 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-10 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-11 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-12 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-13 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-14 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-15 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-16 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-17 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-18 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-19 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-20 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-21 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-22 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-23 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-24 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-25 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-26 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-27 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-28 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-29 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-30 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-10-31 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-01 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-02 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-03 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-04 00:00:00', 5.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-05 00:00:00', 4.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-06 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-07 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-08 00:00:00', 4.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-09 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-10 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-11 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-12 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-13 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-14 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-15 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-16 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-17 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-18 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-19 00:00:00', 5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-20 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-21 00:00:00', 5.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-22 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-23 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-24 00:00:00', 6.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-25 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-26 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-27 00:00:00', 5.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-28 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-29 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-11-30 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-01 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-02 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-03 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-04 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-05 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-06 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-07 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-08 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-09 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-10 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-11 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-12 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-13 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-14 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-15 00:00:00', 5.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-16 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-17 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-18 00:00:00', 5.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-19 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-20 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-21 00:00:00', 5.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-22 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-23 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-24 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-25 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-26 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-27 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-28 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-29 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-30 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2009-12-31 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-01 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-02 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-03 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-04 00:00:00', 5.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-05 00:00:00', 5.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-06 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-07 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-08 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-09 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-10 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-11 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-12 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-13 00:00:00', 4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-14 00:00:00', 6.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-15 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-16 00:00:00', 5.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-17 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-18 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-19 00:00:00', 5.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-20 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-21 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-22 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-23 00:00:00', 4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-24 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-25 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-26 00:00:00', 5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-27 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-28 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-29 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-30 00:00:00', 5.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-01-31 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-01 00:00:00', 5.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-02 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-03 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-04 00:00:00', 6.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-05 00:00:00', 6.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-06 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-07 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-08 00:00:00', 7.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-09 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-10 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-11 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-12 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-13 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-14 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-15 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-16 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-17 00:00:00', 6.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-18 00:00:00', 6.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-19 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-20 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-21 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-22 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-23 00:00:00', 5.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-24 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-25 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-26 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-27 00:00:00', 5.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-02-28 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-01 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-02 00:00:00', 5.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-03 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-04 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-05 00:00:00', 6.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-06 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-07 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-08 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-09 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-10 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-11 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-12 00:00:00', 5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-13 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-14 00:00:00', 6.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-15 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-16 00:00:00', 5.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-17 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-18 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-19 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-20 00:00:00', 6.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-21 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-22 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-23 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-24 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-25 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-26 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-27 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-28 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-29 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-30 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-03-31 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-01 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-02 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-03 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-04 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-05 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-06 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-07 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-08 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-09 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-10 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-11 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-12 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-13 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-14 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-15 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-16 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-17 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-18 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-19 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-20 00:00:00', 6.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-21 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-22 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-23 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-24 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-25 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-26 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-27 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-28 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-29 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-04-30 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-01 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-02 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-03 00:00:00', 5.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-04 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-05 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-06 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-07 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-08 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-09 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-10 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-11 00:00:00', 4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-12 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-13 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-14 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-15 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-16 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-17 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-18 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-19 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-20 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-21 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-22 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-23 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-24 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-25 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-26 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-27 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-28 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-29 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-30 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-05-31 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-01 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-02 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-03 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-04 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-05 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-06 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-07 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-08 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-09 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-10 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-11 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-12 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-13 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-14 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-15 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-16 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-17 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-18 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-19 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-20 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-21 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-22 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-23 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-24 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-25 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-26 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-27 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-28 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-29 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-06-30 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-01 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-02 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-03 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-04 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-05 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-06 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-07 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-08 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-09 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-10 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-11 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-12 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-13 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-14 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-15 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-16 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-17 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-18 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-19 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-20 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-21 00:00:00', 3.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-22 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-23 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-24 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-25 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-26 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-27 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-28 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-29 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-30 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-07-31 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-01 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-02 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-03 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-04 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-05 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-06 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-07 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-08 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-09 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-10 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-11 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-12 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-13 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-14 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-15 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-16 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-17 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-18 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-19 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-20 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-21 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-22 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-23 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-24 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-25 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-26 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-27 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-28 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-29 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-30 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-08-31 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-01 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-02 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-03 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-04 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-05 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-06 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-07 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-08 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-09 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-10 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-11 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-12 00:00:00', 4.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-13 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-14 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-15 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-16 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-17 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-18 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-19 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-20 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-21 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-22 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-23 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-24 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-25 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-26 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-27 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-28 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-29 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-09-30 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-01 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-02 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-03 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-04 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-05 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-06 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-07 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-08 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-09 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-10 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-11 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-12 00:00:00', 5.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-13 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-14 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-15 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-16 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-17 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-18 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-19 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-20 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-21 00:00:00', 5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-22 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-23 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-24 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-25 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-26 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-27 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-28 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-29 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-30 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-10-31 00:00:00', 5.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-01 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-02 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-03 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-04 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-05 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-06 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-07 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-08 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-09 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-10 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-11 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-12 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-13 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-14 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-15 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-16 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-17 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-18 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-19 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-20 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-21 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-22 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-23 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-24 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-25 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-26 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-27 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-28 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-29 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-11-30 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-01 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-02 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-03 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-04 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-05 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-06 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-07 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-08 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-09 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-10 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-11 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-12 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-13 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-14 00:00:00', 4.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-15 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-16 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-17 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-18 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-19 00:00:00', 5.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-20 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-21 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-22 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-23 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-24 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-25 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-26 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-27 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-28 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-29 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-30 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2010-12-31 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-01 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-02 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-03 00:00:00', 1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-04 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-05 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-06 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-07 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-08 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-09 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-10 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-11 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-12 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-13 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-14 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-15 00:00:00', 4.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-16 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-17 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-18 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-19 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-20 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-21 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-22 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-23 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-24 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-25 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-26 00:00:00', 5.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-27 00:00:00', 5.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-28 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-29 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-30 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-01-31 00:00:00', 6.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-01 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-02 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-03 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-04 00:00:00', 5.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-05 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-06 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-07 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-08 00:00:00', 5.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-09 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-10 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-11 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-12 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-13 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-14 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-15 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-16 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-17 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-18 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-19 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-20 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-21 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-22 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-23 00:00:00', 6.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-24 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-25 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-26 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-27 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-02-28 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-01 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-02 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-03 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-04 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-05 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-06 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-07 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-08 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-09 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-10 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-11 00:00:00', 5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-12 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-13 00:00:00', 4.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-14 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-15 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-16 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-17 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-18 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-19 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-20 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-21 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-22 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-23 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-24 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-25 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-26 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-27 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-28 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-29 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-30 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-03-31 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-01 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-02 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-03 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-04 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-05 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-06 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-07 00:00:00', 4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-08 00:00:00', 4.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-09 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-10 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-11 00:00:00', 5.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-12 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-13 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-14 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-15 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-16 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-17 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-18 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-19 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-20 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-21 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-22 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-23 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-24 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-25 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-26 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-27 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-28 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-29 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-04-30 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-01 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-02 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-03 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-04 00:00:00', 4.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-05 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-06 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-07 00:00:00', 5.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-08 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-09 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-10 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-11 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-12 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-13 00:00:00', 5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-14 00:00:00', 4.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-15 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-16 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-17 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-18 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-19 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-20 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-21 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-22 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-23 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-24 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-25 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-26 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-27 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-28 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-29 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-30 00:00:00', 4.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-05-31 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-01 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-02 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-03 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-04 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-05 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-06 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-07 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-08 00:00:00', 3.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-09 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-10 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-11 00:00:00', 5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-12 00:00:00', 4.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-13 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-14 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-15 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-16 00:00:00', 4.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-17 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-18 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-19 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-20 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-21 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-22 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-23 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-24 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-25 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-26 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-27 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-28 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-29 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-06-30 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-01 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-02 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-03 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-04 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-05 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-06 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-07 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-08 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-09 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-10 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-11 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-12 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-13 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-14 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-15 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-16 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-17 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-18 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-19 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-20 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-21 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-22 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-23 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-24 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-25 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-26 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-27 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-28 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-29 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-30 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-07-31 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-01 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-02 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-03 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-04 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-05 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-06 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-07 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-08 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-09 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-10 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-11 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-12 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-13 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-14 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-15 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-16 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-17 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-18 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-19 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-20 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-21 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-22 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-23 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-24 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-25 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-26 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-27 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-28 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-29 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-30 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-08-31 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-01 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-02 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-03 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-04 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-05 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-06 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-07 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-08 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-09 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-10 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-11 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-12 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-13 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-14 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-15 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-16 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-17 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-18 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-19 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-20 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-21 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-22 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-23 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-24 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-25 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-26 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-27 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-28 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-29 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-09-30 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-01 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-02 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-03 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-04 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-05 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-06 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-07 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-08 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-09 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-10 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-11 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-12 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-13 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-14 00:00:00', 5.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-15 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-16 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-17 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-18 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-19 00:00:00', 4.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-20 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-21 00:00:00', 5.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-22 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-23 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-24 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-25 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-26 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-27 00:00:00', 5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-28 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-29 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-30 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-10-31 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-01 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-02 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-03 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-04 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-05 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-06 00:00:00', 5.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-07 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-08 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-09 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-10 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-11 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-12 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-13 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-14 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-15 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-16 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-17 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-18 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-19 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-20 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-21 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-22 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-23 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-24 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-25 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-26 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-27 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-28 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-29 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-11-30 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-01 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-02 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-03 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-04 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-05 00:00:00', 1.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-06 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-07 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-08 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-09 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-10 00:00:00', 5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-11 00:00:00', 5.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-12 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-13 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-14 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-15 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-16 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-17 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-18 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-19 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-20 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-21 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-22 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-23 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-24 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-25 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-26 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-27 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-28 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-29 00:00:00', 4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-30 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2011-12-31 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-01 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-02 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-03 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-04 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-05 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-06 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-07 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-08 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-09 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-10 00:00:00', 4.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-11 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-12 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-13 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-14 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-15 00:00:00', 4.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-16 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-17 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-18 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-19 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-20 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-21 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-22 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-23 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-24 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-25 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-26 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-27 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-28 00:00:00', 5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-29 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-30 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-01-31 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-01 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-02 00:00:00', 5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-03 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-04 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-05 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-06 00:00:00', 1.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-07 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-08 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-09 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-10 00:00:00', 4.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-11 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-12 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-13 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-14 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-15 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-16 00:00:00', 6.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-17 00:00:00', 5.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-18 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-19 00:00:00', 4.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-20 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-21 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-22 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-23 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-24 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-25 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-26 00:00:00', 5.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-27 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-28 00:00:00', 5.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-02-29 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-01 00:00:00', 5.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-02 00:00:00', 5.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-03 00:00:00', 5.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-04 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-05 00:00:00', 6.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-06 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-07 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-08 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-09 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-10 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-11 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-12 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-13 00:00:00', 6.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-14 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-15 00:00:00', 6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-16 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-17 00:00:00', 5.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-18 00:00:00', 5.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-19 00:00:00', 6.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-20 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-21 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-22 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-23 00:00:00', 4.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-24 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-25 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-26 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-27 00:00:00', 5.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-28 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-29 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-30 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-03-31 00:00:00', 5.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-01 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-02 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-03 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-04 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-05 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-06 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-07 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-08 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-09 00:00:00', 4.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-10 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-11 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-12 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-13 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-14 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-15 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-16 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-17 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-18 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-19 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-20 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-21 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-22 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-23 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-24 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-25 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-26 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-27 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-28 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-29 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-04-30 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-01 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-02 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-03 00:00:00', 3.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-04 00:00:00', 4.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-05 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-06 00:00:00', 5.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-07 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-08 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-09 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-10 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-11 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-12 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-13 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-14 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-15 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-16 00:00:00', 4.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-17 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-18 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-19 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-20 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-21 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-22 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-23 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-24 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-25 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-26 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-27 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-28 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-29 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-30 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-05-31 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-01 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-02 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-03 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-04 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-05 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-06 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-07 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-08 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-09 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-10 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-11 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-12 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-13 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-14 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-15 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-16 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-17 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-18 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-19 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-20 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-21 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-22 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-23 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-24 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-25 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-26 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-27 00:00:00', 4.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-28 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-29 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-06-30 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-01 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-02 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-03 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-04 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-05 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-06 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-07 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-08 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-09 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-10 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-11 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-12 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-13 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-14 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-15 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-16 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-17 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-18 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-19 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-20 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-21 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-22 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-23 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-24 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-25 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-26 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-27 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-28 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-29 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-30 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-07-31 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-01 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-02 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-03 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-04 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-05 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-06 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-07 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-08 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-09 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-10 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-11 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-12 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-13 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-14 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-15 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-16 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-17 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-18 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-19 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-20 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-21 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-22 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-23 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-24 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-25 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-26 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-27 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-28 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-29 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-30 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-08-31 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-01 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-02 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-03 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-04 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-05 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-06 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-07 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-08 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-09 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-10 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-11 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-12 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-13 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-14 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-15 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-16 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-17 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-18 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-19 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-20 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-21 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-22 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-23 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-24 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-25 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-26 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-27 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-28 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-29 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-09-30 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-01 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-02 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-03 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-04 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-05 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-06 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-07 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-08 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-09 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-10 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-11 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-12 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-13 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-14 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-15 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-16 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-17 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-18 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-19 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-20 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-21 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-22 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-23 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-24 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-25 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-26 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-27 00:00:00', 5.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-28 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-29 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-30 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-10-31 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-01 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-02 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-03 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-04 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-05 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-06 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-07 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-08 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-09 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-10 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-11 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-12 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-13 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-14 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-15 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-16 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-17 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-18 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-19 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-20 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-21 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-22 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-23 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-24 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-25 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-26 00:00:00', 4.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-27 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-28 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-29 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-11-30 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-01 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-02 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-03 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-04 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-05 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-06 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-07 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-08 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-09 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-10 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-11 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-12 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-13 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-14 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-15 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-16 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-17 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-18 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-19 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-20 00:00:00', 4.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-21 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-22 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-23 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-24 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-25 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-26 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-27 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-28 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-29 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-30 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2012-12-31 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-01 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-02 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-03 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-04 00:00:00', 5.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-05 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-06 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-07 00:00:00', 5.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-08 00:00:00', 4.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-09 00:00:00', 5.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-10 00:00:00', 6.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-11 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-12 00:00:00', 6.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-13 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-14 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-15 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-16 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-17 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-18 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-19 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-20 00:00:00', 5.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-21 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-22 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-23 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-24 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-25 00:00:00', 5.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-26 00:00:00', 6.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-27 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-28 00:00:00', 5.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-29 00:00:00', 5.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-30 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-01-31 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-01 00:00:00', 6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-02 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-03 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-04 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-05 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-06 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-07 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-08 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-09 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-10 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-11 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-12 00:00:00', 5.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-13 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-14 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-15 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-16 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-17 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-18 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-19 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-20 00:00:00', 5.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-21 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-22 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-23 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-24 00:00:00', 5.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-25 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-26 00:00:00', 4.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-27 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-02-28 00:00:00', 6.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-01 00:00:00', 5.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-02 00:00:00', 5.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-03 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-04 00:00:00', 5.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-05 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-06 00:00:00', 4.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-07 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-08 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-09 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-10 00:00:00', 4.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-11 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-12 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-13 00:00:00', 4.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-14 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-15 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-16 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-17 00:00:00', 6.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-18 00:00:00', 4.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-19 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-20 00:00:00', 4.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-21 00:00:00', 4.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-22 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-23 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-24 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-25 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-26 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-27 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-28 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-29 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-30 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-03-31 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-01 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-02 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-03 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-04 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-05 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-06 00:00:00', 5.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-07 00:00:00', 4.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-08 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-09 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-10 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-11 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-12 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-13 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-14 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-15 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-16 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-17 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-18 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-19 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-20 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-21 00:00:00', 5.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-22 00:00:00', 6.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-23 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-24 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-25 00:00:00', 4.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-26 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-27 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-28 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-29 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-04-30 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-01 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-02 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-03 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-04 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-05 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-06 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-07 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-08 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-09 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-10 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-11 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-12 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-13 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-14 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-15 00:00:00', 4.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-16 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-17 00:00:00', 4.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-18 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-19 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-20 00:00:00', 5.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-21 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-22 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-23 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-24 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-25 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-26 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-27 00:00:00', 5.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-28 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-29 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-30 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-05-31 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-01 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-02 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-03 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-04 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-05 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-06 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-07 00:00:00', 4.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-08 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-09 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-10 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-11 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-12 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-13 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-14 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-15 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-16 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-17 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-18 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-19 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-20 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-21 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-22 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-23 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-24 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-25 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-26 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-27 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-28 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-29 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-06-30 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-01 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-02 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-03 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-04 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-05 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-06 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-07 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-08 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-09 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-10 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-11 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-12 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-13 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-14 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-15 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-16 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-17 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-18 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-19 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-20 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-21 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-22 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-23 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-24 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-25 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-26 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-27 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-28 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-29 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-30 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-07-31 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-01 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-02 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-03 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-04 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-05 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-06 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-07 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-08 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-09 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-10 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-11 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-12 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-13 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-14 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-15 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-16 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-17 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-18 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-19 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-20 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-21 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-22 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-23 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-24 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-25 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-26 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-27 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-28 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-29 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-30 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-08-31 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-01 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-02 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-03 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-04 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-05 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-06 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-07 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-08 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-09 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-10 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-11 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-12 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-13 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-14 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-15 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-16 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-17 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-18 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-19 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-20 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-21 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-22 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-23 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-24 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-25 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-26 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-27 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-28 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-29 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-09-30 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-01 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-02 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-03 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-04 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-05 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-06 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-07 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-08 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-09 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-10 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-11 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-12 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-13 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-14 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-15 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-16 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-17 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-18 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-19 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-20 00:00:00', 4.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-21 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-22 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-23 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-24 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-25 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-26 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-27 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-28 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-29 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-30 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-10-31 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-01 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-02 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-03 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-04 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-05 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-06 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-07 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-08 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-09 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-10 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-11 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-12 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-13 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-14 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-15 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-16 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-17 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-18 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-19 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-20 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-21 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-22 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-23 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-24 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-25 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-26 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-27 00:00:00', 4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-28 00:00:00', 5.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-29 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-11-30 00:00:00', 4.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-01 00:00:00', 6.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-02 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-03 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-04 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-05 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-06 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-07 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-08 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-09 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-10 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-11 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-12 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-13 00:00:00', 5.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-14 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-15 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-16 00:00:00', 5.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-17 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-18 00:00:00', 1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-19 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-20 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-21 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-22 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-23 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-24 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-25 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-26 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-27 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-28 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-29 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-30 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2013-12-31 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-01 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-02 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-03 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-04 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-05 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-06 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-07 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-08 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-09 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-10 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-11 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-12 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-13 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-14 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-15 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-16 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-17 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-18 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-19 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-20 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-21 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-22 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-23 00:00:00', 5.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-24 00:00:00', 5.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-25 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-26 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-27 00:00:00', 4.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-28 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-29 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-30 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-01-31 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-01 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-02 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-03 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-04 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-05 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-06 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-07 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-08 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-09 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-10 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-11 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-12 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-13 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-14 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-15 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-16 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-17 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-18 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-19 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-20 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-21 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-22 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-23 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-24 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-25 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-26 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-27 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-02-28 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-01 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-02 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-03 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-04 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-05 00:00:00', 6.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-06 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-07 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-08 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-09 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-10 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-11 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-12 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-13 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-14 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-15 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-16 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-17 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-18 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-19 00:00:00', 5.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-20 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-21 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-22 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-23 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-24 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-25 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-26 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-27 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-28 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-29 00:00:00', 5.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-30 00:00:00', 5.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-03-31 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-01 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-02 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-03 00:00:00', 5.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-04 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-05 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-06 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-07 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-08 00:00:00', 5.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-09 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-10 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-11 00:00:00', 4.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-12 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-13 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-14 00:00:00', 5.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-15 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-16 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-17 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-18 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-19 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-20 00:00:00', 4.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-21 00:00:00', 5.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-22 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-23 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-24 00:00:00', 5.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-25 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-26 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-27 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-28 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-29 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-04-30 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-01 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-02 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-03 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-04 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-05 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-06 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-07 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-08 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-09 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-10 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-11 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-12 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-13 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-14 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-15 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-16 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-17 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-18 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-19 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-20 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-21 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-22 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-23 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-24 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-25 00:00:00', 4.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-26 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-27 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-28 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-29 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-30 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-05-31 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-01 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-02 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-03 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-04 00:00:00', 4.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-05 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-06 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-07 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-08 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-09 00:00:00', 4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-10 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-11 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-12 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-13 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-14 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-15 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-16 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-17 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-18 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-19 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-20 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-21 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-22 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-23 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-24 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-25 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-26 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-27 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-28 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-29 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-06-30 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-01 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-02 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-03 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-04 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-05 00:00:00', 4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-06 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-07 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-08 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-09 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-10 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-11 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-12 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-13 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-14 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-15 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-16 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-17 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-18 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-19 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-20 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-21 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-22 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-23 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-24 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-25 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-26 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-27 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-28 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-29 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-30 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (30, '2014-07-31 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-01 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-02 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-03 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-04 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-05 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-06 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-07 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-08 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-09 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-10 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-11 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-12 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-13 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-14 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-15 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-16 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-17 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-18 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-19 00:00:00', 1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-20 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-21 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-22 00:00:00', 5.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-23 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-24 00:00:00', 5.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-25 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-26 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-27 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-28 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-29 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-30 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-01-31 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-01 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-02 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-03 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-04 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-05 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-06 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-07 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-08 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-09 00:00:00', 5.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-10 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-11 00:00:00', 5.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-12 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-13 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-14 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-15 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-16 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-17 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-18 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-19 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-20 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-21 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-22 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-23 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-24 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-25 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-26 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-27 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-02-28 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-01 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-02 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-03 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-04 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-05 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-06 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-07 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-08 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-09 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-10 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-11 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-12 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-13 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-14 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-15 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-16 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-17 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-18 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-19 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-20 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-21 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-22 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-23 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-24 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-25 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-26 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-27 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-28 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-29 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-30 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-03-31 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-01 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-02 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-03 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-04 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-05 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-06 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-07 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-08 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-09 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-10 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-11 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-12 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-13 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-14 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-15 00:00:00', 5.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-16 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-17 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-18 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-19 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-20 00:00:00', 5.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-21 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-22 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-23 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-24 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-25 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-26 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-27 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-28 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-29 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-04-30 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-01 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-02 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-03 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-04 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-05 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-06 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-07 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-08 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-09 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-10 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-11 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-12 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-13 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-14 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-15 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-16 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-17 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-18 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-19 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-20 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-21 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-22 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-23 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-24 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-25 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-26 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-27 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-28 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-29 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-30 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-05-31 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-01 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-02 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-03 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-04 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-05 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-06 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-07 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-08 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-09 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-10 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-11 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-12 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-13 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-14 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-15 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-16 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-17 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-18 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-19 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-20 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-21 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-22 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-23 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-24 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-25 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-26 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-27 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-28 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-29 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-06-30 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-01 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-02 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-03 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-04 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-05 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-06 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-07 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-08 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-09 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-10 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-11 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-12 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-13 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-14 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-15 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-16 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-17 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-18 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-19 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-20 00:00:00', 5.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-21 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-22 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-23 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-24 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-25 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-26 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-27 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-28 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-29 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-30 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-07-31 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-01 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-02 00:00:00', 4.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-03 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-04 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-05 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-06 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-07 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-08 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-09 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-10 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-11 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-12 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-13 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-14 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-15 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-16 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-17 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-18 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-19 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-20 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-21 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-22 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-23 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-24 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-25 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-26 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-27 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-28 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-29 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-30 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-08-31 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-01 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-02 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-03 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-04 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-05 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-06 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-07 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-08 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-09 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-10 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-11 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-12 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-13 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-14 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-15 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-16 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-17 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-18 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-19 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-20 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-21 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-22 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-23 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-24 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-25 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-26 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-27 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-28 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-29 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-09-30 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-01 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-02 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-03 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-04 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-05 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-06 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-07 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-08 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-09 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-10 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-11 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-12 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-13 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-14 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-15 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-16 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-17 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-18 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-19 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-20 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-21 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-22 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-23 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-24 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-25 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-26 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-27 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-28 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-29 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-30 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-10-31 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-01 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-02 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-03 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-04 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-05 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-06 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-07 00:00:00', 1.32799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-08 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-09 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-10 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-11 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-12 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-13 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-14 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-15 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-16 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-17 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-18 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-19 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-20 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-21 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-22 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-23 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-24 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-25 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-26 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-27 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-28 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-29 00:00:00', 5.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-11-30 00:00:00', 4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-01 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-02 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-03 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-04 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-05 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-06 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-07 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-08 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-09 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-10 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-11 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-12 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-13 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-14 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-15 00:00:00', 4.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-16 00:00:00', 4.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-17 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-18 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-19 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-20 00:00:00', 5.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-21 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-22 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-23 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-24 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-25 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-26 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-27 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-28 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-29 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-30 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1979-12-31 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-01 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-02 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-03 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-04 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-05 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-06 00:00:00', 5.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-07 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-08 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-09 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-10 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-11 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-12 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-13 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-14 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-15 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-16 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-17 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-18 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-19 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-20 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-21 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-22 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-23 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-24 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-25 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-26 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-27 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-28 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-29 00:00:00', 5.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-30 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-01-31 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-01 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-02 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-03 00:00:00', 1.28199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-04 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-05 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-06 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-07 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-08 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-09 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-10 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-11 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-12 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-13 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-14 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-15 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-16 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-17 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-18 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-19 00:00:00', 5.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-20 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-21 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-22 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-23 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-24 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-25 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-26 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-27 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-28 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-02-29 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-01 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-02 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-03 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-04 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-05 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-06 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-07 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-08 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-09 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-10 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-11 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-12 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-13 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-14 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-15 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-16 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-17 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-18 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-19 00:00:00', 6.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-20 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-21 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-22 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-23 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-24 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-25 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-26 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-27 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-28 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-29 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-30 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-03-31 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-01 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-02 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-03 00:00:00', 5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-04 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-05 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-06 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-07 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-08 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-09 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-10 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-11 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-12 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-13 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-14 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-15 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-16 00:00:00', 4.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-17 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-18 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-19 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-20 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-21 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-22 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-23 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-24 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-25 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-26 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-27 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-28 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-29 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-04-30 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-01 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-02 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-03 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-04 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-05 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-06 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-07 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-08 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-09 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-10 00:00:00', 4.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-11 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-12 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-13 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-14 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-15 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-16 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-17 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-18 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-19 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-20 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-21 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-22 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-23 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-24 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-25 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-26 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-27 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-28 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-29 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-30 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-05-31 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-01 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-02 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-03 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-04 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-05 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-06 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-07 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-08 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-09 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-10 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-11 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-12 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-13 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-14 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-15 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-16 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-17 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-18 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-19 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-20 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-21 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-22 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-23 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-24 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-25 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-26 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-27 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-28 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-29 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-06-30 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-01 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-02 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-03 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-04 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-05 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-06 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-07 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-08 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-09 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-10 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-11 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-12 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-13 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-14 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-15 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-16 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-17 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-18 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-19 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-20 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-21 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-22 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-23 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-24 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-25 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-26 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-27 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-28 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-29 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-30 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-07-31 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-01 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-02 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-03 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-04 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-05 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-06 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-07 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-08 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-09 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-10 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-11 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-12 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-13 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-14 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-15 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-16 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-17 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-18 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-19 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-20 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-21 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-22 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-23 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-24 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-25 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-26 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-27 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-28 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-29 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-30 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-08-31 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-01 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-02 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-03 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-04 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-05 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-06 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-07 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-08 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-09 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-10 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-11 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-12 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-13 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-14 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-15 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-16 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-17 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-18 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-19 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-20 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-21 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-22 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-23 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-24 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-25 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-26 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-27 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-28 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-29 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-09-30 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-01 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-02 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-03 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-04 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-05 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-06 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-07 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-08 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-09 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-10 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-11 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-12 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-13 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-14 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-15 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-16 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-17 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-18 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-19 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-20 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-21 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-22 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-23 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-24 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-25 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-26 00:00:00', 1.04100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-27 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-28 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-29 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-30 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-10-31 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-01 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-02 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-03 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-04 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-05 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-06 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-07 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-08 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-09 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-10 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-11 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-12 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-13 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-14 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-15 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-16 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-17 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-18 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-19 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-20 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-21 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-22 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-23 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-24 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-25 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-26 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-27 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-28 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-29 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-11-30 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-01 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-02 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-03 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-04 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-05 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-06 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-07 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-08 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-09 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-10 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-11 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-12 00:00:00', 5.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-13 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-14 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-15 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-16 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-17 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-18 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-19 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-20 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-21 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-22 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-23 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-24 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-25 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-26 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-27 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-28 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-29 00:00:00', 6.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-30 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1980-12-31 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-01 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-02 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-03 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-04 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-05 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-06 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-07 00:00:00', 4.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-08 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-09 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-10 00:00:00', 4.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-11 00:00:00', 5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-12 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-13 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-14 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-15 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-16 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-17 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-18 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-19 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-20 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-21 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-22 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-23 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-24 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-25 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-26 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-27 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-28 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-29 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-30 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-01-31 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-01 00:00:00', 5.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-02 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-03 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-04 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-05 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-06 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-07 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-08 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-09 00:00:00', 5.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-10 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-11 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-12 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-13 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-14 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-15 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-16 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-17 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-18 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-19 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-20 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-21 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-22 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-23 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-24 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-25 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-26 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-27 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-02-28 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-01 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-02 00:00:00', 5.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-03 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-04 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-05 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-06 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-07 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-08 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-09 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-10 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-11 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-12 00:00:00', 5.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-13 00:00:00', 6.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-14 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-15 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-16 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-17 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-18 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-19 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-20 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-21 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-22 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-23 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-24 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-25 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-26 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-27 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-28 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-29 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-30 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-03-31 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-01 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-02 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-03 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-04 00:00:00', 4.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-05 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-06 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-07 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-08 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-09 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-10 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-11 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-12 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-13 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-14 00:00:00', 4.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-15 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-16 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-17 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-18 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-19 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-20 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-21 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-22 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-23 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-24 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-25 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-26 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-27 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-28 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-29 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-04-30 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-01 00:00:00', 5.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-02 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-03 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-04 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-05 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-06 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-07 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-08 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-09 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-10 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-11 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-12 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-13 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-14 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-15 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-16 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-17 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-18 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-19 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-20 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-21 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-22 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-23 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-24 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-25 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-26 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-27 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-28 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-29 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-30 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-05-31 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-01 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-02 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-03 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-04 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-05 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-06 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-07 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-08 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-09 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-10 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-11 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-12 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-13 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-14 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-15 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-16 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-17 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-18 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-19 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-20 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-21 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-22 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-23 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-24 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-25 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-26 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-27 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-28 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-29 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-06-30 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-01 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-02 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-03 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-04 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-05 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-06 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-07 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-08 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-09 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-10 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-11 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-12 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-13 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-14 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-15 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-16 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-17 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-18 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-19 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-20 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-21 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-22 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-23 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-24 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-25 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-26 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-27 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-28 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-29 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-30 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-07-31 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-01 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-02 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-03 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-04 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-05 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-06 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-07 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-08 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-09 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-10 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-11 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-12 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-13 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-14 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-15 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-16 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-17 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-18 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-19 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-20 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-21 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-22 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-23 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-24 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-25 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-26 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-27 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-28 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-29 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-30 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-08-31 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-01 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-02 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-03 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-04 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-05 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-06 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-07 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-08 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-09 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-10 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-11 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-12 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-13 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-14 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-15 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-16 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-17 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-18 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-19 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-20 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-21 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-22 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-23 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-24 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-25 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-26 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-27 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-28 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-29 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-09-30 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-01 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-02 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-03 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-04 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-05 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-06 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-07 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-08 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-09 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-10 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-11 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-12 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-13 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-14 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-15 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-16 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-17 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-18 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-19 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-20 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-21 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-22 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-23 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-24 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-25 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-26 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-27 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-28 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-29 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-30 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-10-31 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-01 00:00:00', 1.15299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-02 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-03 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-04 00:00:00', 5.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-05 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-06 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-07 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-08 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-09 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-10 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-11 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-12 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-13 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-14 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-15 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-16 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-17 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-18 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-19 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-20 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-21 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-22 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-23 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-24 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-25 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-26 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-27 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-28 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-29 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-11-30 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-01 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-02 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-03 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-04 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-05 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-06 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-07 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-08 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-09 00:00:00', 4.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-10 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-11 00:00:00', 4.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-12 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-13 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-14 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-15 00:00:00', 5.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-16 00:00:00', 5.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-17 00:00:00', 5.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-18 00:00:00', 5.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-19 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-20 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-21 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-22 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-23 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-24 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-25 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-26 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-27 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-28 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-29 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-30 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1981-12-31 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-01 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-02 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-03 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-04 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-05 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-06 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-07 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-08 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-09 00:00:00', 5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-10 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-11 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-12 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-13 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-14 00:00:00', 4.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-15 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-16 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-17 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-18 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-19 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-20 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-21 00:00:00', 1.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-22 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-23 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-24 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-25 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-26 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-27 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-28 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-29 00:00:00', 7.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-30 00:00:00', 3.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-01-31 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-01 00:00:00', 6.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-02 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-03 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-04 00:00:00', 5.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-05 00:00:00', 5.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-06 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-07 00:00:00', 4.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-08 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-09 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-10 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-11 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-12 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-13 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-14 00:00:00', 5.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-15 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-16 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-17 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-18 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-19 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-20 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-21 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-22 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-23 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-24 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-25 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-26 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-27 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-02-28 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-01 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-02 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-03 00:00:00', 5.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-04 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-05 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-06 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-07 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-08 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-09 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-10 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-11 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-12 00:00:00', 5.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-13 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-14 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-15 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-16 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-17 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-18 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-19 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-20 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-21 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-22 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-23 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-24 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-25 00:00:00', 5.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-26 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-27 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-28 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-29 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-30 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-03-31 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-01 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-02 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-03 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-04 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-05 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-06 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-07 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-08 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-09 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-10 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-11 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-12 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-13 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-14 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-15 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-16 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-17 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-18 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-19 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-20 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-21 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-22 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-23 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-24 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-25 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-26 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-27 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-28 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-29 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-04-30 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-01 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-02 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-03 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-04 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-05 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-06 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-07 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-08 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-09 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-10 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-11 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-12 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-13 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-14 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-15 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-16 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-17 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-18 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-19 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-20 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-21 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-22 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-23 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-24 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-25 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-26 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-27 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-28 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-29 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-30 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-05-31 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-01 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-02 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-03 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-04 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-05 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-06 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-07 00:00:00', 5.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-08 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-09 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-10 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-11 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-12 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-13 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-14 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-15 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-16 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-17 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-18 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-19 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-20 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-21 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-22 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-23 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-24 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-25 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-26 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-27 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-28 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-29 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-06-30 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-01 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-02 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-03 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-04 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-05 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-06 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-07 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-08 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-09 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-10 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-11 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-12 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-13 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-14 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-15 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-16 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-17 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-18 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-19 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-20 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-21 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-22 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-23 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-24 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-25 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-26 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-27 00:00:00', 4.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-28 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-29 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-30 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-07-31 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-01 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-02 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-03 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-04 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-05 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-06 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-07 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-08 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-09 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-10 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-11 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-12 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-13 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-14 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-15 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-16 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-17 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-18 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-19 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-20 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-21 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-22 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-23 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-24 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-25 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-26 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-27 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-28 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-29 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-30 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-08-31 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-01 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-02 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-03 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-04 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-05 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-06 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-07 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-08 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-09 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-10 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-11 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-12 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-13 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-14 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-15 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-16 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-17 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-18 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-19 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-20 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-21 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-22 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-23 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-24 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-25 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-26 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-27 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-28 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-29 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-09-30 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-01 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-02 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-03 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-04 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-05 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-06 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-07 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-08 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-09 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-10 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-11 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-12 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-13 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-14 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-15 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-16 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-17 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-18 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-19 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-20 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-21 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-22 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-23 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-24 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-25 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-26 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-27 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-28 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-29 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-30 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-10-31 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-01 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-02 00:00:00', 1.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-03 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-04 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-05 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-06 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-07 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-08 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-09 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-10 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-11 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-12 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-13 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-14 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-15 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-16 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-17 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-18 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-19 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-20 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-21 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-22 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-23 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-24 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-25 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-26 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-27 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-28 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-29 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-11-30 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-01 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-02 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-03 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-04 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-05 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-06 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-07 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-08 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-09 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-10 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-11 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-12 00:00:00', 1.18299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-13 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-14 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-15 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-16 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-17 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-18 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-19 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-20 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-21 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-22 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-23 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-24 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-25 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-26 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-27 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-28 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-29 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-30 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1982-12-31 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-01 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-02 00:00:00', 5.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-03 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-04 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-05 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-06 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-07 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-08 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-09 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-10 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-11 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-12 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-13 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-14 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-15 00:00:00', 5.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-16 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-17 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-18 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-19 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-20 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-21 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-22 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-23 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-24 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-25 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-26 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-27 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-28 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-29 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-30 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-01-31 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-01 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-02 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-03 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-04 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-05 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-06 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-07 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-08 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-09 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-10 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-11 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-12 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-13 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-14 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-15 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-16 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-17 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-18 00:00:00', 4.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-19 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-20 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-21 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-22 00:00:00', 5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-23 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-24 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-25 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-26 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-27 00:00:00', 5.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-02-28 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-01 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-02 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-03 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-04 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-05 00:00:00', 5.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-06 00:00:00', 5.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-07 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-08 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-09 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-10 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-11 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-12 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-13 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-14 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-15 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-16 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-17 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-18 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-19 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-20 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-21 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-22 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-23 00:00:00', 5.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-24 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-25 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-26 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-27 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-28 00:00:00', 4.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-29 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-30 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-03-31 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-01 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-02 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-03 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-04 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-05 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-06 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-07 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-08 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-09 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-10 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-11 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-12 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-13 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-14 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-15 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-16 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-17 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-18 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-19 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-20 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-21 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-22 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-23 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-24 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-25 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-26 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-27 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-28 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-29 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-04-30 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-01 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-02 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-03 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-04 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-05 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-06 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-07 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-08 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-09 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-10 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-11 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-12 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-13 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-14 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-15 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-16 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-17 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-18 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-19 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-20 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-21 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-22 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-23 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-24 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-25 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-26 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-27 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-28 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-29 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-30 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-05-31 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-01 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-02 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-03 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-04 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-05 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-06 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-07 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-08 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-09 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-10 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-11 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-12 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-13 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-14 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-15 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-16 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-17 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-18 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-19 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-20 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-21 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-22 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-23 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-24 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-25 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-26 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-27 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-28 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-29 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-06-30 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-01 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-02 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-03 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-04 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-05 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-06 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-07 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-08 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-09 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-10 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-11 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-12 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-13 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-14 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-15 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-16 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-17 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-18 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-19 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-20 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-21 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-22 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-23 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-24 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-25 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-26 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-27 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-28 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-29 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-30 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-07-31 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-01 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-02 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-03 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-04 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-05 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-06 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-07 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-08 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-09 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-10 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-11 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-12 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-13 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-14 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-15 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-16 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-17 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-18 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-19 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-20 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-21 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-22 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-23 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-24 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-25 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-26 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-27 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-28 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-29 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-30 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-08-31 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-01 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-03 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-05 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-07 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-09 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-11 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-13 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-15 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-17 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-19 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-21 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-23 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-25 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-27 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-29 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-01 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-03 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-05 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-07 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-09 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-11 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-13 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-15 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-17 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-19 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-21 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-23 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-25 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-27 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-29 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-30 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-10-31 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-01 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-02 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-03 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-04 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-05 00:00:00', 5.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-06 00:00:00', 4.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-07 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-08 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-09 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-10 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-11 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-12 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-13 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-14 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-15 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-16 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-17 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-18 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-19 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-20 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-21 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-22 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-23 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-24 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-25 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-26 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-27 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-28 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-29 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-11-30 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-01 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-02 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-03 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-04 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-05 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-06 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-07 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-08 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-09 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-10 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-11 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-12 00:00:00', 5.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-13 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-14 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-15 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-16 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-17 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-18 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-19 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-20 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-21 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-22 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-23 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-24 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-25 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-26 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-27 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-28 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-29 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-30 00:00:00', 5.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1983-12-31 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-01 00:00:00', 5.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-02 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-03 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-04 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-05 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-06 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-07 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-08 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-09 00:00:00', 4.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-10 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-11 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-12 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-13 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-14 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-15 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-16 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-17 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-18 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-19 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-20 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-21 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-22 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-23 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-24 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-25 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-26 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-27 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-28 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-29 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-30 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-01-31 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-01 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-02 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-03 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-04 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-05 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-06 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-07 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-08 00:00:00', 6.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-09 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-10 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-11 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-12 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-13 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-14 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-15 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-16 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-17 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-18 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-19 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-20 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-21 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-22 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-23 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-24 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-25 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-26 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-27 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-28 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-02-29 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-01 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-02 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-03 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-04 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-05 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-06 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-07 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-08 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-09 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-10 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-11 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-12 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-13 00:00:00', 4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-14 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-15 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-16 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-17 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-18 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-19 00:00:00', 5.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-20 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-21 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-22 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-23 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-24 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-25 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-26 00:00:00', 5.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-27 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-28 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-29 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-30 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-03-31 00:00:00', 1.00499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-01 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-02 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-03 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-04 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-05 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-06 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-07 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-08 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-09 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-10 00:00:00', 6.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-11 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-12 00:00:00', 5.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-13 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-14 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-15 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-16 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-17 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-18 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-19 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-20 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-21 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-22 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-23 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-24 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-25 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-26 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-27 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-28 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-29 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-04-30 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-01 00:00:00', 5.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-02 00:00:00', 6.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-03 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-04 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-05 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-06 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-07 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-08 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-09 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-10 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-11 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-12 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-13 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-14 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-15 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-16 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-17 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-18 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-19 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-20 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-21 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-22 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-23 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-24 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-25 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-26 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-27 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-28 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-29 00:00:00', 4.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-30 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-05-31 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-01 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-02 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-03 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-04 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-05 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-06 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-07 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-08 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-09 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-10 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-11 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-12 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-13 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-14 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-15 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-16 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-17 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-18 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-19 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-20 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-21 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-22 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-23 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-24 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-25 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-26 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-27 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-28 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-29 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-06-30 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-01 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-02 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-03 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-04 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-05 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-06 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-07 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-08 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-09 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-10 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-11 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-12 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-13 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-14 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-15 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-16 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-17 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-18 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-19 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-20 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-21 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-22 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-23 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-24 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-25 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-26 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-27 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-28 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-29 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-30 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-07-31 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-01 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-02 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-03 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-04 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-05 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-06 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-07 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-08 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-09 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-10 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-11 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-12 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-13 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-14 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-15 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-16 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-17 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-18 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-19 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-20 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-21 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-22 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-23 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-24 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-25 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-26 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-27 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-28 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-29 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-30 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-08-31 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-01 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-02 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-03 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-04 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-05 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-06 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-07 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-08 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-09 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-10 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-11 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-12 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-13 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-14 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-15 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-16 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-17 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-18 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-19 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-20 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-21 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-22 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-23 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-24 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-25 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-26 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-27 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-28 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-29 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-09-30 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-01 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-02 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-03 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-04 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-05 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-06 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-07 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-08 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-09 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-10 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-11 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-12 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-13 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-14 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-15 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-16 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-17 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-18 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-19 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-20 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-21 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-22 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-23 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-24 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-25 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-26 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-27 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-28 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-29 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-30 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-10-31 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-01 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-02 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-03 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-04 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-05 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-06 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-07 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-08 00:00:00', 1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-09 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-10 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-11 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-12 00:00:00', 5.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-13 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-14 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-15 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-16 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-17 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-18 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-19 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-20 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-21 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-22 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-23 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-24 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-25 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-26 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-27 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-28 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-29 00:00:00', 5.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-11-30 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-01 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-02 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-03 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-04 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-05 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-06 00:00:00', 1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-07 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-08 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-09 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-10 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-11 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-12 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-13 00:00:00', 4.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-14 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-15 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-16 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-17 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-18 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-19 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-20 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-21 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-22 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-23 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-24 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-25 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-26 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-27 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-28 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-29 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-30 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1984-12-31 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-01 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-02 00:00:00', 5.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-03 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-04 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-05 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-06 00:00:00', 4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-07 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-08 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-09 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-10 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-11 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-12 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-13 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-14 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-15 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-16 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-17 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-18 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-19 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-20 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-21 00:00:00', 6.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-22 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-23 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-24 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-25 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-26 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-27 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-28 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-29 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-30 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-01-31 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-01 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-02 00:00:00', 5.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-03 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-04 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-05 00:00:00', 5.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-06 00:00:00', 6.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-07 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-08 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-09 00:00:00', 6.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-10 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-11 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-12 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-13 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-14 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-15 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-16 00:00:00', 5.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-17 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-18 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-19 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-20 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-21 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-22 00:00:00', 5.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-23 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-24 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-25 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-26 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-27 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-02-28 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-01 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-02 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-03 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-04 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-05 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-06 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-07 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-08 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-09 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-10 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-11 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-12 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-13 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-14 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-15 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-16 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-17 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-18 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-19 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-20 00:00:00', 5.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-21 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-22 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-23 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-24 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-25 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-26 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-27 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-28 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-29 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-30 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-03-31 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-01 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-02 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-03 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-04 00:00:00', 4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-05 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-06 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-07 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-08 00:00:00', 4.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-09 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-10 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-11 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-12 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-13 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-14 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-15 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-16 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-17 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-18 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-19 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-20 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-21 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-22 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-23 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-24 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-25 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-26 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-27 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-28 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-29 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-04-30 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-01 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-02 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-03 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-04 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-05 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-06 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-07 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-08 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-09 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-10 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-11 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-12 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-13 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-14 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-15 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-16 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-17 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-18 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-19 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-20 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-21 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-22 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-23 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-24 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-25 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-26 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-27 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-28 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-29 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-30 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-05-31 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-01 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-02 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-03 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-04 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-05 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-06 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-07 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-08 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-09 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-10 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-11 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-12 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-13 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-14 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-15 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-16 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-17 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-18 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-19 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-20 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-21 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-22 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-23 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-24 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-25 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-26 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-27 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-28 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-29 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-06-30 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-01 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-02 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-03 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-04 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-05 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-06 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-07 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-08 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-09 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-10 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-11 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-12 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-13 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-14 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-15 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-16 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-17 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-18 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-19 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-20 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-21 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-22 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-23 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-24 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-25 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-26 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-27 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-28 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-29 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-30 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-07-31 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-01 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-02 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-03 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-04 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-05 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-06 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-07 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-08 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-09 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-10 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-11 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-12 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-13 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-14 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-15 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-16 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-17 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-18 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-19 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-20 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-21 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-22 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-23 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-24 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-25 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-26 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-27 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-28 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-29 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-30 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-08-31 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-01 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-02 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-03 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-04 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-05 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-06 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-07 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-08 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-09 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-10 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-11 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-12 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-13 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-14 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-15 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-16 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-17 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-18 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-19 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-20 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-21 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-22 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-23 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-24 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-25 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-26 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-27 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-28 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-29 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-09-30 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-01 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-02 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-03 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-04 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-05 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-06 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-07 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-08 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-09 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-10 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-11 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-12 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-13 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-14 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-15 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-16 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-17 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-18 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-19 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-20 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-21 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-22 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-23 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-24 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-25 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-26 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-27 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-28 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-29 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-30 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-10-31 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-01 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-02 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-03 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-04 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-05 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-06 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-07 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-08 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-09 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-10 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-11 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-12 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-13 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-14 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-15 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-16 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-17 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-18 00:00:00', 0.893999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-19 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-20 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-21 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-22 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-23 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-24 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-25 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-26 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-27 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-28 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-29 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-11-30 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-01 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-02 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-03 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-04 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-05 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-06 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-07 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-08 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-09 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-10 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-11 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-12 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-13 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-14 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-15 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-16 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-17 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-18 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-19 00:00:00', 6.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-20 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-21 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-22 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-23 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-24 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-25 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-26 00:00:00', 1.25899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-27 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-28 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-29 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-30 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1985-12-31 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-01 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-02 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-03 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-04 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-05 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-06 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-07 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-08 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-09 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-10 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-11 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-12 00:00:00', 5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-13 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-14 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-15 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-16 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-17 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-18 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-19 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-20 00:00:00', 6.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-21 00:00:00', 6.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-22 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-23 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-24 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-25 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-26 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-27 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-28 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-29 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-30 00:00:00', 5.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-01-31 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-01 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-02 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-03 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-04 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-05 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-06 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-07 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-08 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-09 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-10 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-11 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-12 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-13 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-14 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-15 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-16 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-17 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-18 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-19 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-20 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-21 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-22 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-23 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-24 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-25 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-26 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-27 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-02-28 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-01 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-02 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-03 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-04 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-05 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-06 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-07 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-08 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-09 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-10 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-11 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-12 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-13 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-14 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-15 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-16 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-17 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-18 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-19 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-20 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-21 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-22 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-23 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-24 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-25 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-26 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-27 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-28 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-29 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-30 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-03-31 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-01 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-02 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-03 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-04 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-05 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-06 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-07 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-08 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-09 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-10 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-11 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-12 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-13 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-14 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-15 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-16 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-17 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-18 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-19 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-20 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-21 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-22 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-23 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-24 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-25 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-26 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-27 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-28 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-29 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-04-30 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-01 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-02 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-03 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-04 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-05 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-06 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-07 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-08 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-09 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-10 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-11 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-12 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-13 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-14 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-15 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-16 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-17 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-18 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-19 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-20 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-21 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-22 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-23 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-24 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-25 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-26 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-27 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-28 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-29 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-30 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-01 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-02 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-03 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-04 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-05 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-06 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-07 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-08 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-09 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-10 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-11 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-12 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-13 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-14 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-15 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-16 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-17 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-18 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-19 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-20 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-21 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-22 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-23 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-24 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-25 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-26 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-27 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-28 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-29 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-06-30 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-01 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-02 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-03 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-04 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-05 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-06 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-07 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-08 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-09 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-10 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-11 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-12 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-13 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-14 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-15 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-16 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-17 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-18 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-19 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-20 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-21 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-22 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-23 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-24 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-25 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-26 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-27 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-28 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-29 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-30 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-07-31 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-01 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-02 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-03 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-04 00:00:00', 5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-05 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-06 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-07 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-08 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-09 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-10 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-11 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-12 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-13 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-14 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-15 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-16 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-17 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-18 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-19 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-20 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-21 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-22 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-23 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-24 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-25 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-26 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-27 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-28 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-29 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-30 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-08-31 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-01 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-02 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-03 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-04 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-05 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-06 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-07 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-08 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-09 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-10 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-11 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-12 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-13 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-14 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-15 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-16 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-17 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-18 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-19 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-20 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-21 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-22 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-23 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-24 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-25 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-26 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-27 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-28 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-29 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-09-30 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-01 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-02 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-03 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-04 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-05 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-06 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-07 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-08 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-09 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-10 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-11 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-12 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-13 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-14 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-15 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-16 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-17 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-18 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-19 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-20 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-21 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-22 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-23 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-24 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-25 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-26 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-27 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-28 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-29 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-30 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-10-31 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-01 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-02 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-03 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-04 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-05 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-06 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-07 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-08 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-09 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-10 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-11 00:00:00', 4.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-12 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-13 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-14 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-15 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-16 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-17 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-18 00:00:00', 1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-19 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-20 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-21 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-22 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-23 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-24 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-25 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-26 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-27 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-28 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-29 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-11-30 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-01 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-02 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-03 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-04 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-05 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-06 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-07 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-08 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-09 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-10 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-11 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-12 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-13 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-14 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-15 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-16 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-17 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-18 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-19 00:00:00', 5.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-20 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-21 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-22 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-23 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-24 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-01 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-02 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-03 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-04 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-05 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-06 00:00:00', 4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-07 00:00:00', 5.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-08 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-09 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-10 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-11 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-12 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-13 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-14 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-15 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-16 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-17 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-18 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-19 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-20 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-21 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-22 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-23 00:00:00', 5.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-24 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-25 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-26 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-27 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-28 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-29 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-30 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-01-31 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-01 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-02 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-03 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-04 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-05 00:00:00', 4.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-06 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-07 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-08 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-09 00:00:00', 5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-10 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-11 00:00:00', 5.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-12 00:00:00', 4.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-13 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-14 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-15 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-16 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-17 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-18 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-19 00:00:00', 5.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-20 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-21 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-22 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-23 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-24 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-25 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-26 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-27 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-02-28 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-01 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-02 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-03 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-04 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-05 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-06 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-07 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-08 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-09 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-10 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-11 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-12 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-13 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-14 00:00:00', 6.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-15 00:00:00', 4.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-16 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-17 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-18 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-19 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-20 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-21 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-22 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-23 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-24 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-25 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-26 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-27 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-28 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-29 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-30 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-03-31 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-01 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-02 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-03 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-04 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-05 00:00:00', 4.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-06 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-07 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-08 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-09 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-10 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-11 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-12 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-13 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-14 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-15 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-16 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-17 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-18 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-19 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-20 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-21 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-22 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-23 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-24 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-25 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-26 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-27 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-28 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-29 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-04-30 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-01 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-02 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-03 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-04 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-05 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-06 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-07 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-08 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-09 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-10 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-11 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-12 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-13 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-14 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-15 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-16 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-17 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-18 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-19 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-20 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-21 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-22 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-23 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-24 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-25 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-26 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-27 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-28 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-29 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-30 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-05-31 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-01 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-02 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-03 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-04 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-05 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-06 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-07 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-08 00:00:00', 4.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-09 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-10 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-11 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-12 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-13 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-14 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-15 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-16 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-17 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-18 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-19 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-20 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-21 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-22 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-23 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-24 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-25 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-26 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-27 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-28 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-29 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-06-30 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-01 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-02 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-03 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-04 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-05 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-06 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-07 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-08 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-09 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-10 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-11 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-12 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-13 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-14 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-15 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-16 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-17 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-18 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-19 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-20 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-21 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-22 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-23 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-24 00:00:00', 5.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-25 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-26 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-27 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-28 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-29 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-30 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-07-31 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-01 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-02 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-03 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-04 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-05 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-06 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-07 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-08 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-09 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-10 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-11 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-12 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-13 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-14 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-15 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-16 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-17 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-18 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-19 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-20 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-21 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-22 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-23 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-24 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-25 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-26 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-27 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-28 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-29 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-30 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-08-31 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-01 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-02 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-03 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-04 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-05 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-06 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-07 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-08 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-09 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-10 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-11 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-12 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-13 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-14 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-15 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-16 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-17 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-18 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-19 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-20 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-21 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-22 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-23 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-24 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-25 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-26 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-27 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-28 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-29 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-09-30 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-01 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-02 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-03 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-04 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-05 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-06 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-07 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-08 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-09 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-10 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-11 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-12 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-13 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-14 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-15 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-16 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-17 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-18 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-19 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-20 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-21 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-22 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-23 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-24 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-25 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-26 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-27 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-28 00:00:00', 1.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-29 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-30 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-10-31 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-01 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-02 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-03 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-04 00:00:00', 5.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-05 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-06 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-07 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-08 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-09 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-10 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-11 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-12 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-13 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-14 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-15 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-16 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-17 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-18 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-19 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-20 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-21 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-22 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-23 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-24 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-25 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-26 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-27 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-28 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-29 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-11-30 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-01 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-02 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-03 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-04 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-05 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-06 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-07 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-08 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-09 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-10 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-11 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-12 00:00:00', 4.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-13 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-14 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-15 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-16 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-17 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-18 00:00:00', 4.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-19 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-20 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-21 00:00:00', 4.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-22 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-23 00:00:00', 5.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-24 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-25 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-26 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-27 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-28 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-29 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-30 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1987-12-31 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-01 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-02 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-03 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-04 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-05 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-06 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-07 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-08 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-09 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-10 00:00:00', 1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-11 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-12 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-13 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-14 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-15 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-16 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-17 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-18 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-19 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-20 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-21 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-22 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-23 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-24 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-25 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-26 00:00:00', 5.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-27 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-28 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-29 00:00:00', 6.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-30 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-01-31 00:00:00', 6.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-01 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-02 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-03 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-04 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-05 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-06 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-07 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-08 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-09 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-10 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-11 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-12 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-13 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-14 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-15 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-16 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-17 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-18 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-19 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-20 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-21 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-22 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-23 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-24 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-25 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-26 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-27 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-28 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-02-29 00:00:00', 5.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-01 00:00:00', 5.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-02 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-03 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-04 00:00:00', 4.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-05 00:00:00', 6.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-06 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-07 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-08 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-09 00:00:00', 5.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-10 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-11 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-12 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-13 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-14 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-15 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-16 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-17 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-18 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-19 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-20 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-21 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-22 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-23 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-24 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-25 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-26 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-27 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-28 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-29 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-30 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-03-31 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-01 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-02 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-03 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-04 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-05 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-06 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-07 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-08 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-09 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-10 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-11 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-12 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-13 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-14 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-15 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-16 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-17 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-18 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-19 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-20 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-21 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-22 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-23 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-24 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-25 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-26 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-27 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-28 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-29 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-04-30 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-01 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-02 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-03 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-04 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-05 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-06 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-07 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-08 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-09 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-10 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-11 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-12 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-13 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-14 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-15 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-16 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-17 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-18 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-19 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-20 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-21 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-22 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-23 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-24 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-25 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-26 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-27 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-28 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-29 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-30 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-05-31 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-01 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-02 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-03 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-04 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-05 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-06 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-07 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-08 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-09 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-10 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-11 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-12 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-13 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-14 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-15 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-16 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-17 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-18 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-19 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-20 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-21 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-22 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-23 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-24 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-25 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-26 00:00:00', 4.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-27 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-28 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-29 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-06-30 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-01 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-02 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-03 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-04 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-05 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-06 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-07 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-08 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-09 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-10 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-11 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-12 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-13 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-14 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-15 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-16 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-17 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-18 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-19 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-20 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-21 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-22 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-23 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-24 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-25 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-26 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-27 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-28 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-29 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-30 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-07-31 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-01 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-02 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-03 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-04 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-05 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-06 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-07 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-08 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-09 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-10 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-11 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-12 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-13 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-14 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-15 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-16 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-17 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-18 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-19 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-20 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-21 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-22 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-23 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-24 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-25 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-26 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-27 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-28 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-29 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-30 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-08-31 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-01 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-02 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-03 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-04 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-05 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-06 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-07 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-08 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-09 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-10 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-11 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-12 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-13 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-14 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-15 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-16 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-17 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-18 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-19 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-20 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-21 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-22 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-23 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-24 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-25 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-26 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-27 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-28 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-29 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-09-30 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-01 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-02 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-03 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-04 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-05 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-06 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-07 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-08 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-09 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-10 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-11 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-12 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-13 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-14 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-15 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-16 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-17 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-18 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-19 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-20 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-21 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-22 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-23 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-24 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-25 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-26 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-27 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-28 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-29 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-30 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-10-31 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-01 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-02 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-03 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-04 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-05 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-06 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-07 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-08 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-09 00:00:00', 4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-10 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-11 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-12 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-13 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-14 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-15 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-16 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-17 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-18 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-19 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-20 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-21 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-22 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-23 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-24 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-25 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-26 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-27 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-28 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-29 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-11-30 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-01 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-02 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-03 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-04 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-05 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-06 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-07 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-08 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-09 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-10 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-11 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-12 00:00:00', 5.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-13 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-14 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-15 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-16 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-17 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-18 00:00:00', 5.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-19 00:00:00', 5.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-20 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-21 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-22 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-23 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-24 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-25 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-26 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-27 00:00:00', 6.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-28 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-29 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-30 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1988-12-31 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-01 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-02 00:00:00', 4.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-03 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-04 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-05 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-06 00:00:00', 5.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-07 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-08 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-09 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-10 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-11 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-12 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-13 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-14 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-15 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-16 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-17 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-18 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-19 00:00:00', 4.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-20 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-21 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-22 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-23 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-24 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-25 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-26 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-27 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-28 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-29 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-30 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-01-31 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-01 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-02 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-03 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-04 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-05 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-06 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-07 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-08 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-09 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-10 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-11 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-12 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-13 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-14 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-15 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-16 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-17 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-18 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-19 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-20 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-21 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-22 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-23 00:00:00', 5.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-24 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-25 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-26 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-27 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-02-28 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-01 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-02 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-03 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-04 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-05 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-06 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-07 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-08 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-09 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-10 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-11 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-12 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-13 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-14 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-15 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-16 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-17 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-18 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-19 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-20 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-21 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-22 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-23 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-24 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-25 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-26 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-27 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-28 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-29 00:00:00', 5.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-30 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-03-31 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-01 00:00:00', 4.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-02 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-03 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-04 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-05 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-06 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-07 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-08 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-09 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-10 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-11 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-12 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-13 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-14 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-15 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-16 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-17 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-18 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-19 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-20 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-21 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-22 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-23 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-24 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-25 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-26 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-27 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-28 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-29 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-04-30 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-01 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-02 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-03 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-04 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-05 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-06 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-07 00:00:00', 5.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-08 00:00:00', 5.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-09 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-10 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-11 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-12 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-13 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-14 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-15 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-16 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-17 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-18 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-19 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-20 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-21 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-22 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-23 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-24 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-25 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-26 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-27 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-28 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-29 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-30 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-05-31 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-01 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-02 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-03 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-04 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-05 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-06 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-07 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-08 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-09 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-10 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-11 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-12 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-13 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-14 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-15 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-16 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-17 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-18 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-19 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-20 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-21 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-22 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-23 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-24 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-25 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-26 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-27 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-28 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-29 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-06-30 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-01 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-02 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-03 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-04 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-05 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-06 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-07 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-08 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-09 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-10 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-11 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-12 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-13 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-14 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-15 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-16 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-17 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-18 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-19 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-20 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-21 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-22 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-23 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-24 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-25 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-26 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-27 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-28 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-29 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-30 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-07-31 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-01 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-02 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-03 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-04 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-05 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-06 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-07 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-08 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-09 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-10 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-11 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-12 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-13 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-14 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-15 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-16 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-17 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-18 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-19 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-20 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-21 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-22 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-23 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-24 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-25 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-26 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-27 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-28 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-29 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-30 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-08-31 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-01 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-02 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-03 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-04 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-05 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-06 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-07 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-08 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-09 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-10 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-11 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-12 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-13 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-14 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-15 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-16 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-17 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-18 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-19 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-20 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-21 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-22 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-23 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-24 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-25 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-26 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-27 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-28 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-29 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-09-30 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-01 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-02 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-03 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-04 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-05 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-06 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-07 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-08 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-09 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-10 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-11 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-12 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-13 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-14 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-15 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-16 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-17 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-18 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-19 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-20 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-21 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-22 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-23 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-24 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-25 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-26 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-27 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-28 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-29 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-30 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-10-31 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-01 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-02 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-03 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-04 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-05 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-06 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-07 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-08 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-09 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-10 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-11 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-12 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-13 00:00:00', 1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-14 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-15 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-16 00:00:00', 5.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-17 00:00:00', 4.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-18 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-19 00:00:00', 5.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-20 00:00:00', 5.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-21 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-22 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-23 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-24 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-25 00:00:00', 5.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-26 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-27 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-28 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-29 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-11-30 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-01 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-02 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-03 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-04 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-05 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-06 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-07 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-08 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-09 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-10 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-11 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-12 00:00:00', 4.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-13 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-14 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-15 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-16 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-17 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-18 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-19 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-20 00:00:00', 1.11000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-21 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-22 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-23 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-24 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-25 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-26 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-27 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-28 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-29 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-30 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1989-12-31 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-01 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-02 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-03 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-04 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-05 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-06 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-07 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-08 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-09 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-10 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-11 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-12 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-13 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-14 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-15 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-16 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-17 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-18 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-19 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-20 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-21 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-22 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-23 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-24 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-25 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-26 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-27 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-28 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-29 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-30 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-01-31 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-01 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-02 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-03 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-04 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-05 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-06 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-07 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-08 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-09 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-10 00:00:00', 5.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-11 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-12 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-13 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-14 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-15 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-16 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-17 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-18 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-19 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-20 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-21 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-22 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-23 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-24 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-25 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-26 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-27 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-02-28 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-01 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-02 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-03 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-04 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-05 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-06 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-07 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-08 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-09 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-10 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-11 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-12 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-13 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-14 00:00:00', 5.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-15 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-16 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-17 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-18 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-19 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-20 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-21 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-22 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-23 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-24 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-25 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-26 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-27 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-28 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-29 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-30 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-03-31 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-01 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-02 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-03 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-04 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-05 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-06 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-07 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-08 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-09 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-10 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-11 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-12 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-13 00:00:00', 4.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-14 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-15 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-16 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-17 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-18 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-19 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-20 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-21 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-22 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-23 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-24 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-25 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-26 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-27 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-28 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-29 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-04-30 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-01 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-02 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-03 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-04 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-05 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-06 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-07 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-08 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-09 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-10 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-11 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-12 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-13 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-14 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-15 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-16 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-17 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-18 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-19 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-20 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-21 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-22 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-23 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-24 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-25 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-26 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-27 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-28 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-29 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-30 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-05-31 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-01 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-02 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-03 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-04 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-05 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-06 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-07 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-08 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-09 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-10 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-11 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-12 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-13 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-14 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-15 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-16 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-17 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-18 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-19 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-20 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-21 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-22 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-23 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-24 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-25 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-26 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-27 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-28 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-29 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-06-30 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-01 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-02 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-03 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-04 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-05 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-06 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-07 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-08 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-09 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-10 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-11 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-12 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-13 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-14 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-15 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-16 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-17 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-18 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-19 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-20 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-21 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-22 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-23 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-24 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-25 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-26 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-27 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-28 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-29 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-30 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-07-31 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-01 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-02 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-03 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-04 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-05 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-06 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-07 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-08 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-09 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-10 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-11 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-12 00:00:00', 5.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-13 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-14 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-15 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-16 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-17 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-18 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-19 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-20 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-21 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-22 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-23 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-24 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-25 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-26 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-27 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-28 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-29 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-30 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-08-31 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-01 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-02 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-03 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-04 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-05 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-06 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-07 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-08 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-09 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-10 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-11 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-12 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-13 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-14 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-15 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-16 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-17 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-18 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-19 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-20 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-21 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-22 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-23 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-24 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-25 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-26 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-27 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-28 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-29 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-09-30 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-01 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-02 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-03 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-04 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-05 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-06 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-07 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-08 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-09 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-10 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-11 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-12 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-13 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-14 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-15 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-16 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-17 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-18 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-19 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-20 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-21 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-22 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-23 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-24 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-25 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-26 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-27 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-28 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-29 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-30 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-10-31 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-01 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-02 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-03 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-04 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-05 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-06 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-07 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-08 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-09 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-10 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-11 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-12 00:00:00', 4.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-13 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-14 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-15 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-16 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-17 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-18 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-19 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-20 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-21 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-22 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-23 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-24 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-25 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-26 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-27 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-28 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-29 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-11-30 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-01 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-02 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-03 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-04 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-05 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-06 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-07 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-08 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-09 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-10 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-11 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-12 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-13 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-14 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-15 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-16 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-17 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-18 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-19 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-20 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-21 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-22 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-23 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-24 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-25 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-26 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-27 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-28 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-29 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-30 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1990-12-31 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-01 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-02 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-03 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-04 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-05 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-06 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-07 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-08 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-09 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-10 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-11 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-12 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-13 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-14 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-15 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-16 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-17 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-18 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-19 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-20 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-21 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-22 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-23 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-24 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-25 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-26 00:00:00', 5.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-27 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-28 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-29 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-30 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-01-31 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-01 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-02 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-03 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-04 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-05 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-06 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-07 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-08 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-09 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-10 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-11 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-12 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-13 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-14 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-15 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-16 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-17 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-18 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-19 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-20 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-21 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-22 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-23 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-24 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-25 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-26 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-27 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-02-28 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-01 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-02 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-03 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-04 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-05 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-06 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-07 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-08 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-09 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-10 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-11 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-12 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-13 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-14 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-15 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-16 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-17 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-18 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-19 00:00:00', 4.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-20 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-21 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-22 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-23 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-24 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-25 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-26 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-27 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-28 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-29 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-30 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-03-31 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-01 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-02 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-03 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-04 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-05 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-06 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-07 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-08 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-09 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-10 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-11 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-12 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-13 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-14 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-15 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-16 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-17 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-18 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-19 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-20 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-21 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-22 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-23 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-24 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-25 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-26 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-27 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-28 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-29 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-04-30 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-01 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-02 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-03 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-04 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-05 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-06 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-07 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-08 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-09 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-10 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-11 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-12 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-13 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-14 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-15 00:00:00', 4.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-16 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-17 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-18 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-19 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-20 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-21 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-22 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-23 00:00:00', 5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-24 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-25 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-26 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-27 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-28 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-29 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-30 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-05-31 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-01 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-02 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-03 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-04 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-05 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-06 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-07 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-08 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-09 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-10 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-11 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-12 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-13 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-14 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-15 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-16 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-17 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-18 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-19 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-20 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-21 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-22 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-23 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-24 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-25 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-26 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-27 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-28 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-29 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-06-30 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-01 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-02 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-03 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-04 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-05 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-06 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-07 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-08 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-09 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-10 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-11 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-12 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-13 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-14 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-15 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-16 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-17 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-18 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-19 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-20 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-21 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-22 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-23 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-24 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-25 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-26 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-27 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-28 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-29 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-30 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-07-31 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-01 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-02 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-03 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-04 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-05 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-06 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-07 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-08 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-09 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-10 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-11 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-12 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-13 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-14 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-15 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-16 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-17 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-18 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-19 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-20 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-21 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-22 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-23 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-24 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-25 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-26 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-27 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-28 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-29 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-30 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-08-31 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-01 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-02 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-03 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-04 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-05 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-06 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-07 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-08 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-09 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-10 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-11 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-12 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-13 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-14 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-15 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-16 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-17 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-18 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-19 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-20 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-21 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-22 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-23 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-24 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-25 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-26 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-27 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-28 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-29 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-09-30 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-01 00:00:00', 1.0700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-02 00:00:00', 1.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-03 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-04 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-05 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-06 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-07 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-08 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-09 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-10 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-11 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-12 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-13 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-14 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-15 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-16 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-17 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-18 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-19 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-20 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-21 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-22 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-23 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-24 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-25 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-26 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-27 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-28 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-29 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-30 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-10-31 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-01 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-02 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-03 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-04 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-05 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-06 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-07 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-08 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-09 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-10 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-11 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-12 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-13 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-14 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-15 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-16 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-17 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-18 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-19 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-20 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-21 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-22 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-23 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-24 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-25 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-26 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-27 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-28 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-29 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-11-30 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-01 00:00:00', 6.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-02 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-03 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-04 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-05 00:00:00', 5.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-06 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-07 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-08 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-09 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-10 00:00:00', 6.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-11 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-12 00:00:00', 4.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-13 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-14 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-15 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-16 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-17 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-18 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-19 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-20 00:00:00', 1.14600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-21 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-22 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-23 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-24 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-25 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-26 00:00:00', 4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-27 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-28 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-29 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-30 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1991-12-31 00:00:00', 4.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-01 00:00:00', 5.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-02 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-03 00:00:00', 6.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-04 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-05 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-06 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-07 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-08 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-09 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-10 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-11 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-12 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-13 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-14 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-15 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-16 00:00:00', 5.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-17 00:00:00', 6.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-18 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-19 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-20 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-21 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-22 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-23 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-24 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-25 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-26 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-27 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-28 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-29 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-30 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-01-31 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-01 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-02 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-03 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-04 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-05 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-06 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-07 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-08 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-09 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-10 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-11 00:00:00', 6.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-12 00:00:00', 4.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-13 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-14 00:00:00', 5.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-15 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-16 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-17 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-18 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-19 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-20 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-21 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-22 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-23 00:00:00', 5.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-24 00:00:00', 5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-25 00:00:00', 6.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-26 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-27 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-28 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-02-29 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-01 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-02 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-03 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-04 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-05 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-06 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-07 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-08 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-09 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-10 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-11 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-12 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-13 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-14 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-15 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-16 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-17 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-18 00:00:00', 0.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-19 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-20 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-21 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-22 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-23 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-24 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-25 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-26 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-27 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-28 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-29 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-30 00:00:00', 5.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-03-31 00:00:00', 6.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-01 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-02 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-03 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-04 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-05 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-06 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-07 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-08 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-09 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-10 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-11 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-12 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-13 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-14 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-15 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-16 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-17 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-18 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-19 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-20 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-21 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-22 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-23 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-24 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-25 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-26 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-27 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-28 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-29 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-04-30 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-01 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-02 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-03 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-04 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-05 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-06 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-07 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-08 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-09 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-10 00:00:00', 4.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-11 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-12 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-13 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-14 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-15 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-16 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-17 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-18 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-19 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-20 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-21 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-22 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-23 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-24 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-25 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-26 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-27 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-28 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-29 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-30 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-05-31 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-01 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-02 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-03 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-04 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-05 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-06 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-07 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-08 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-09 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-10 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-11 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-12 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-13 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-14 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-15 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-16 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-17 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-18 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-19 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-20 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-21 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-22 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-23 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-24 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-25 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-26 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-27 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-28 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-29 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-06-30 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-01 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-02 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-03 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-04 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-05 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-06 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-07 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-08 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-09 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-10 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-11 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-12 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-13 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-14 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-15 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-16 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-17 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-18 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-19 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-20 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-21 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-22 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-23 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-24 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-25 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-26 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-27 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-28 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-29 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-30 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-07-31 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-01 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-02 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-03 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-04 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-05 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-06 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-07 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-08 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-09 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-10 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-11 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-12 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-13 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-14 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-15 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-16 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-17 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-18 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-19 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-20 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-21 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-22 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-23 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-24 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-25 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-26 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-27 00:00:00', 4.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-28 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-29 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-30 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-08-31 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-01 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-02 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-03 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-04 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-05 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-06 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-07 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-08 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-09 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-10 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-11 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-12 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-13 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-14 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-15 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-16 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-17 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-18 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-19 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-20 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-21 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-22 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-23 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-24 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-25 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-26 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-27 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-28 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-29 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-09-30 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-01 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-02 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-03 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-04 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-05 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-06 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-07 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-08 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-09 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-10 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-11 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-12 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-13 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-14 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-15 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-16 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-17 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-18 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-19 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-20 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-21 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-22 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-23 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-24 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-25 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-26 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-27 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-28 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-29 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-30 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-10-31 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-01 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-02 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-03 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-04 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-05 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-06 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-07 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-08 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-09 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-10 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-11 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-12 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-13 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-14 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-15 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-16 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-17 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-18 00:00:00', 0.982999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-19 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-20 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-21 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-22 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-23 00:00:00', 5.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-24 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-25 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-26 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-27 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-28 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-29 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-11-30 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-01 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-02 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-03 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-04 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-05 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-06 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-07 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-08 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-09 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-10 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-11 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-12 00:00:00', 4.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-13 00:00:00', 5.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-14 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-15 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-16 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-17 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-18 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-19 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-20 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-21 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-22 00:00:00', 4.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-23 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-24 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-25 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-26 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-27 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-28 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-29 00:00:00', 4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-30 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1992-12-31 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-01 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-02 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-03 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-04 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-05 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-06 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-07 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-08 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-09 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-10 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-11 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-12 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-13 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-14 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-15 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-16 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-17 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-18 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-19 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-20 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-21 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-22 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-23 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-24 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-25 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-26 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-27 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-28 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-29 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-30 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-01-31 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-01 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-02 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-03 00:00:00', 5.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-04 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-05 00:00:00', 4.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-06 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-07 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-08 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-09 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-10 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-11 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-12 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-13 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-14 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-15 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-16 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-17 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-18 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-19 00:00:00', 5.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-20 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-21 00:00:00', 5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-22 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-23 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-24 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-25 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-26 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-27 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-02-28 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-01 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-02 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-03 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-04 00:00:00', 5.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-05 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-06 00:00:00', 5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-07 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-08 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-09 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-10 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-11 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-12 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-13 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-14 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-15 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-16 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-17 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-18 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-19 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-20 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-21 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-22 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-23 00:00:00', 4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-24 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-25 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-26 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-27 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-28 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-29 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-30 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-03-31 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-01 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-02 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-03 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-04 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-05 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-06 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-07 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-08 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-09 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-10 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-11 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-12 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-13 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-14 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-15 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-16 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-17 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-18 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-19 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-20 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-21 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-22 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-23 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-24 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-25 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-26 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-27 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-28 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-29 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-04-30 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-01 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-02 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-03 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-04 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-05 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-06 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-07 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-08 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-09 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-10 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-11 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-12 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-13 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-14 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-15 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-16 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-17 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-18 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-19 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-20 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-21 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-22 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-23 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-24 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-25 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-26 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-27 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-28 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-29 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-30 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-05-31 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-01 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-02 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-03 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-04 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-05 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-06 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-07 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-08 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-09 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-10 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-11 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-12 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-13 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-14 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-15 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-16 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-17 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-18 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-19 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-20 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-21 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-22 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-23 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-24 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-25 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-26 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-27 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-28 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-29 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-06-30 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-01 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-02 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-03 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-04 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-05 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-06 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-07 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-08 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-09 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-10 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-11 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-12 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-13 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-14 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-15 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-16 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-17 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-18 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-19 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-20 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-21 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-22 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-23 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-24 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-25 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-26 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-27 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-28 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-29 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-30 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-07-31 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-01 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-02 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-03 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-04 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-05 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-06 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-07 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-08 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-09 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-10 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-11 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-12 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-13 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-14 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-15 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-16 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-17 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-18 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-19 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-20 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-21 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-22 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-23 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-24 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-25 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-26 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-27 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-28 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-29 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-30 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-08-31 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-01 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-02 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-03 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-04 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-05 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-06 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-07 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-08 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-09 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-10 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-11 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-12 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-13 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-14 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-15 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-16 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-17 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-18 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-19 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-20 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-21 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-22 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-23 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-24 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-25 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-26 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-27 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-28 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-29 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-09-30 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-01 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-02 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-03 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-04 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-05 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-06 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-07 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-08 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-09 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-10 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-11 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-12 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-13 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-14 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-15 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-16 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-17 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-18 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-19 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-20 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-21 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-22 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-23 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-24 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-25 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-26 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-27 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-28 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-29 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-30 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-10-31 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-01 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-02 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-03 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-04 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-05 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-06 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-07 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-08 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-09 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-10 00:00:00', 5.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-11 00:00:00', 4.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-12 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-13 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-14 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-15 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-16 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-17 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-18 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-19 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-20 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-21 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-22 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-23 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-24 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-25 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-26 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-27 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-28 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-29 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-11-30 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-01 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-02 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-03 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-04 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-05 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-06 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-07 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-08 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-09 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-10 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-11 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-12 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-13 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-14 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-15 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-16 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-17 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-18 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-19 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-20 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-21 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-22 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-23 00:00:00', 4.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-24 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-25 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-26 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-27 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-28 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-29 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-30 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1993-12-31 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-01 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-02 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-03 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-04 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-05 00:00:00', 5.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-06 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-07 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-08 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-09 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-10 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-11 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-12 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-13 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-14 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-15 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-16 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-17 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-18 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-19 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-20 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-21 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-22 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-23 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-24 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-25 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-26 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-27 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-28 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-29 00:00:00', 4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-30 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-01-31 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-01 00:00:00', 6.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-02 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-03 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-04 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-05 00:00:00', 5.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-06 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-07 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-08 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-09 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-10 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-11 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-12 00:00:00', 5.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-13 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-14 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-15 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-16 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-17 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-18 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-19 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-20 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-21 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-22 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-23 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-24 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-25 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-26 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-27 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-02-28 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-01 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-02 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-03 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-04 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-05 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-06 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-07 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-08 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-09 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-10 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-11 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-12 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-13 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-14 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-15 00:00:00', 5.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-16 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-17 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-18 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-19 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-20 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-21 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-22 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-23 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-24 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-25 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-26 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-27 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-28 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-29 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-30 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-03-31 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-01 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-02 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-03 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-04 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-05 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-06 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-07 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-08 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-09 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-10 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-11 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-12 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-13 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-14 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-15 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-16 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-17 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-18 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-19 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-20 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-21 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-22 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-23 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-24 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-25 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-26 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-27 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-28 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-29 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-04-30 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-01 00:00:00', 5.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-02 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-03 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-04 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-05 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-06 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-07 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-08 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-09 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-10 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-11 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-12 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-13 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-14 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-15 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-16 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-17 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-18 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-19 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-20 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-21 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-22 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-23 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-24 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-25 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-26 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-27 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-28 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-29 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-30 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-05-31 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-01 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-02 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-03 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-04 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-05 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-06 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-07 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-08 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-09 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-10 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-11 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-12 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-13 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-14 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-15 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-16 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-17 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-18 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-19 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-20 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-21 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-22 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-23 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-24 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-25 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-26 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-27 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-28 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-29 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-06-30 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-01 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-02 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-03 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-04 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-05 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-06 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-07 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-08 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-09 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-10 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-11 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-12 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-13 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-14 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-15 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-16 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-17 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-18 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-19 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-20 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-21 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-22 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-23 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-24 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-25 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-26 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-27 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-28 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-29 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-30 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-07-31 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-01 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-02 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-03 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-04 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-05 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-06 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-07 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-08 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-09 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-10 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-11 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-12 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-13 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-14 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-15 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-16 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-17 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-18 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-19 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-20 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-21 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-22 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-23 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-24 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-25 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-26 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-27 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-28 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-29 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-30 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-08-31 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-01 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-02 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-03 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-04 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-05 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-06 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-07 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-08 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-09 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-10 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-11 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-12 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-13 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-14 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-15 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-16 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-17 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-18 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-19 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-20 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-21 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-22 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-23 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-24 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-25 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-26 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-27 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-28 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-29 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-09-30 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-01 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-02 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-03 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-04 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-05 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-06 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-07 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-08 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-09 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-10 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-11 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-12 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-13 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-14 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-15 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-16 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-17 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-18 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-19 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-20 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-21 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-22 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-23 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-24 00:00:00', 1.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-25 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-26 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-27 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-28 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-29 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-30 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-10-31 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-01 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-02 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-03 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-04 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-05 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-06 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-07 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-08 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-09 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-10 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-11 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-12 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-13 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-14 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-15 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-16 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-17 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-18 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-19 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-20 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-21 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-22 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-23 00:00:00', 4.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-24 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-25 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-26 00:00:00', 5.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-27 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-28 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-29 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-11-30 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-01 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-02 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-03 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-04 00:00:00', 6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-05 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-06 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-07 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-08 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-09 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-10 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-11 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-12 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-13 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-14 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-15 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-16 00:00:00', 4.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-17 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-18 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-19 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-20 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-21 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-22 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-23 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-24 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-25 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-26 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-27 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-28 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-29 00:00:00', 5.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-30 00:00:00', 4.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1994-12-31 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-01 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-02 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-03 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-04 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-05 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-06 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-07 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-08 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-09 00:00:00', 1.09099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-10 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-11 00:00:00', 5.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-12 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-13 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-14 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-15 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-16 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-17 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-18 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-19 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-20 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-21 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-22 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-23 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-24 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-25 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-26 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-27 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-28 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-29 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-30 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-01-31 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-01 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-02 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-03 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-04 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-05 00:00:00', 5.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-06 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-07 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-08 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-09 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-10 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-11 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-12 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-13 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-14 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-15 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-16 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-17 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-18 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-19 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-20 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-21 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-22 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-23 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-24 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-25 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-26 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-27 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-02-28 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-01 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-02 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-03 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-04 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-05 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-06 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-07 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-08 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-09 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-10 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-11 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-12 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-13 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-14 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-15 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-16 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-17 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-18 00:00:00', 4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-19 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-20 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-21 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-22 00:00:00', 0.935000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-23 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-24 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-25 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-26 00:00:00', 5.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-27 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-28 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-29 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-30 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-03-31 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-01 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-02 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-03 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-04 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-05 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-06 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-07 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-08 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-09 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-10 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-11 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-12 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-13 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-14 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-15 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-16 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-17 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-18 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-19 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-20 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-21 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-22 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-23 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-24 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-25 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-26 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-27 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-28 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-29 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-04-30 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-01 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-02 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-03 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-04 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-05 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-06 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-07 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-08 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-09 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-10 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-11 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-12 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-13 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-14 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-15 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-16 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-17 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-18 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-19 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-20 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-21 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-22 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-23 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-24 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-25 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-26 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-27 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-28 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-29 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-30 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-05-31 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-01 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-02 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-03 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-04 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-05 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-06 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-07 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-08 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-09 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-10 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-11 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-12 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-13 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-14 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-15 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-16 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-17 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-18 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-19 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-20 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-21 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-22 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-23 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-24 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-25 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-26 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-27 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-28 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-29 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-06-30 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-01 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-02 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-03 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-04 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-05 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-06 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-07 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-08 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-09 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-10 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-11 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-12 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-13 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-14 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-15 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-16 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-17 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-18 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-19 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-20 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-21 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-22 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-23 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-24 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-25 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-26 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-27 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-28 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-29 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-30 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-07-31 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-01 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-02 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-03 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-04 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-05 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-06 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-07 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-08 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-09 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-10 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-11 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-12 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-13 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-14 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-15 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-16 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-17 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-18 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-19 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-20 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-21 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-22 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-23 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-24 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-25 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-26 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-27 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-28 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-29 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-30 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-08-31 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-01 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-02 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-03 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-04 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-05 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-06 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-07 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-08 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-09 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-10 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-11 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-12 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-13 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-14 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-15 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-16 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-17 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-18 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-19 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-20 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-21 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-22 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-23 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-24 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-25 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-26 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-27 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-28 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-29 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-09-30 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-01 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-02 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-03 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-04 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-05 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-06 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-07 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-08 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-09 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-10 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-11 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-12 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-13 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-14 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-15 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-16 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-17 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-18 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-19 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-20 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-21 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-22 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-23 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-24 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-25 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-26 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-27 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-28 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-29 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-30 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-10-31 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-01 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-02 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-03 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-04 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-05 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-06 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-07 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-08 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-09 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-10 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-11 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-12 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-13 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-14 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-15 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-16 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-17 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-18 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-19 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-20 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-21 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-22 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-23 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-24 00:00:00', 5.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-25 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-26 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-27 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-28 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-29 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-11-30 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-01 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-02 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-03 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-04 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-05 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-06 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-07 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-08 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-09 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-10 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-11 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-12 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-13 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-14 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-15 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-16 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-17 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-18 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-19 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-20 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-21 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-22 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-23 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-24 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-25 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-26 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-27 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-28 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-29 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-30 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1995-12-31 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-01 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-02 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-03 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-04 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-05 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-06 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-07 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-08 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-09 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-10 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-11 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-12 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-13 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-14 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-15 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-16 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-17 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-18 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-19 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-20 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-21 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-22 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-23 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-24 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-25 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-26 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-27 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-28 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-29 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-30 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-01-31 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-01 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-02 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-03 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-04 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-05 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-06 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-07 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-08 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-09 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-10 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-11 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-12 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-13 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-14 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-15 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-16 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-17 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-18 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-19 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-20 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-21 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-22 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-23 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-24 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-25 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-26 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-27 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-28 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-02-29 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-01 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-02 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-03 00:00:00', 4.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-04 00:00:00', 4.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-05 00:00:00', 4.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-06 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-07 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-08 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-09 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-10 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-11 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-12 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-13 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-14 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-15 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-16 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-17 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-18 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-19 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-20 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-21 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-22 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-23 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-24 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-25 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-26 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-27 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-28 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-29 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-30 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-03-31 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-01 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-02 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-03 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-04 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-05 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-06 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-07 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-08 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-09 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-10 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-11 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-12 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-13 00:00:00', 6.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-14 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-15 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-16 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-17 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-18 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-19 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-20 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-21 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-22 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-23 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-24 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-25 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-26 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-27 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-28 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-29 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-04-30 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-01 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-02 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-03 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-04 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-05 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-06 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-07 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-08 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-09 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-10 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-11 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-12 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-13 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-14 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-15 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-16 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-17 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-18 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-19 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-20 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-21 00:00:00', 0.913999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-22 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-23 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-24 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-25 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-26 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-27 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-28 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-29 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-30 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-05-31 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-01 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-02 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-03 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-04 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-05 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-06 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-07 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-08 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-09 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-10 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-11 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-12 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-13 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-14 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-15 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-16 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-17 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-18 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-19 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-20 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-21 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-22 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-23 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-24 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-25 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-26 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-27 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-28 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-29 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-06-30 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-01 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-02 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-03 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-04 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-05 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-06 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-07 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-08 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-09 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-10 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-11 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-12 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-13 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-14 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-15 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-16 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-17 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-18 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-19 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-20 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-21 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-22 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-23 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-24 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-25 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-26 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-27 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-28 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-29 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-30 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-07-31 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-01 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-02 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-03 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-04 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-05 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-06 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-07 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-08 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-09 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-10 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-11 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-12 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-13 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-14 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-15 00:00:00', 5.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-16 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-17 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-18 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-19 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-20 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-21 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-22 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-23 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-24 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-25 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-26 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-27 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-28 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-29 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-30 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-08-31 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-01 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-02 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-03 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-04 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-05 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-06 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-07 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-08 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-09 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-10 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-11 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-12 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-13 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-14 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-15 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-16 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-17 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-18 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-19 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-20 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-21 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-22 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-23 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-24 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-25 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-26 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-27 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-28 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-29 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-09-30 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-01 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-02 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-03 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-04 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-05 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-06 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-07 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-08 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-09 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-10 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-11 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-12 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-13 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-14 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-15 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-16 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-17 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-18 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-19 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-20 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-21 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-22 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-23 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-24 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-25 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-26 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-27 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-28 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-29 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-30 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-10-31 00:00:00', 4.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-01 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-02 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-03 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-04 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-05 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-06 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-07 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-08 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-09 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-10 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-11 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-12 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-13 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-14 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-15 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-16 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-17 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-18 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-19 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-20 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-21 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-22 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-23 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-24 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-25 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-26 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-27 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-28 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-29 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-11-30 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-01 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-02 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-03 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-04 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-05 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-06 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-07 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-08 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-09 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-10 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-11 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-12 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-13 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-14 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-15 00:00:00', 4.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-16 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-17 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-18 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-19 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-20 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-21 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-22 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-23 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-24 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-25 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-26 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-27 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-28 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-29 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-30 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1996-12-31 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-01 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-02 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-03 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-04 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-05 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-06 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-07 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-08 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-09 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-10 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-11 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-12 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-13 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-14 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-15 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-16 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-17 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-18 00:00:00', 5.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-19 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-20 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-21 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-22 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-23 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-24 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-25 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-26 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-27 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-28 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-29 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-30 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-01-31 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-01 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-02 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-03 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-04 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-05 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-06 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-07 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-08 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-09 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-10 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-11 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-12 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-13 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-14 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-15 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-16 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-17 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-18 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-19 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-20 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-21 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-22 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-23 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-24 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-25 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-26 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-27 00:00:00', 4.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-02-28 00:00:00', 4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-01 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-02 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-03 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-04 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-05 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-06 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-07 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-08 00:00:00', 5.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-09 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-10 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-11 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-12 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-13 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-14 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-15 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-16 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-17 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-18 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-19 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-20 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-21 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-22 00:00:00', 4.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-23 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-24 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-25 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-26 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-27 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-28 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-29 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-30 00:00:00', 4.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-03-31 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-01 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-02 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-03 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-04 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-05 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-06 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-07 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-08 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-09 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-10 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-11 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-12 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-13 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-14 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-15 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-16 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-17 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-18 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-19 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-20 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-21 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-22 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-23 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-24 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-25 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-26 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-27 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-28 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-29 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-04-30 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-01 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-02 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-03 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-04 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-05 00:00:00', 6.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-06 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-07 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-08 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-09 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-10 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-11 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-12 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-13 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-14 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-15 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-16 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-17 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-18 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-19 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-20 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-21 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-22 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-23 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-24 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-25 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-26 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-27 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-28 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-29 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-30 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-05-31 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-01 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-02 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-03 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-04 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-05 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-06 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-07 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-08 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-09 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-10 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-11 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-12 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-13 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-14 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-15 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-16 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-17 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-18 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-19 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-20 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-21 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-22 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-23 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-24 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-25 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-26 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-27 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-28 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-29 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-06-30 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-01 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-02 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-03 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-04 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-05 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-06 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-07 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-08 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-09 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-10 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-11 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-12 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-13 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-14 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-15 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-16 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-17 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-18 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-19 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-20 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-21 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-22 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-23 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-24 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-25 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-26 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-27 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-28 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-29 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-30 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-07-31 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-01 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-02 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-03 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-04 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-05 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-06 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-07 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-08 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-09 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-10 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-11 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-12 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-13 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-14 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-15 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-16 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-17 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-18 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-19 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-20 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-21 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-22 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-23 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-24 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-25 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-26 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-27 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-28 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-29 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-30 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-08-31 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-01 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-02 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-03 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-04 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-05 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-06 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-07 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-08 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-09 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-10 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-11 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-12 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-13 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-14 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-15 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-16 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-17 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-18 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-19 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-20 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-21 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-22 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-23 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-24 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-25 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-26 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-27 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-28 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-29 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-09-30 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-01 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-02 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-03 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-04 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-05 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-06 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-07 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-08 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-09 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-10 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-11 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-12 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-13 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-14 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-15 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-16 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-17 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-18 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-19 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-20 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-21 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-22 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-23 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-24 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-25 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-26 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-27 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-28 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-29 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-30 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-10-31 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-01 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-02 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-03 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-04 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-05 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-06 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-07 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-08 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-09 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-10 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-11 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-12 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-13 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-14 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-15 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-16 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-17 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-18 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-19 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-20 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-21 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-22 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-23 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-24 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-25 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-26 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-27 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-28 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-29 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-11-30 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-01 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-02 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-03 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-04 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-05 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-06 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-07 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-08 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-09 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-10 00:00:00', 5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-11 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-12 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-13 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-14 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-15 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-16 00:00:00', 4.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-17 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-18 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-19 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-20 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-21 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-22 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-23 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-24 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-25 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-26 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-27 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-28 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-29 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-30 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1997-12-31 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-01 00:00:00', 4.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-02 00:00:00', 4.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-03 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-04 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-05 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-06 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-07 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-08 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-09 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-10 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-11 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-12 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-13 00:00:00', 6.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-14 00:00:00', 5.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-15 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-16 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-17 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-18 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-19 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-20 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-21 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-22 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-23 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-24 00:00:00', 4.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-25 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-26 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-27 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-28 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-29 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-30 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-01-31 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-01 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-02 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-03 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-04 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-05 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-06 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-07 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-08 00:00:00', 6.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-09 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-10 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-11 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-12 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-13 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-14 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-15 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-16 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-17 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-18 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-19 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-20 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-21 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-22 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-23 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-24 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-25 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-26 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-27 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-02-28 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-01 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-02 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-03 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-04 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-05 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-06 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-07 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-08 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-09 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-10 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-11 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-12 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-13 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-14 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-15 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-16 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-17 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-18 00:00:00', 5.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-19 00:00:00', 4.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-20 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-21 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-22 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-23 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-24 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-25 00:00:00', 5.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-26 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-27 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-28 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-29 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-30 00:00:00', 6.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-03-31 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-01 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-02 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-03 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-04 00:00:00', 5.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-05 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-06 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-07 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-08 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-09 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-10 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-11 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-12 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-13 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-14 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-15 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-16 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-17 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-18 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-19 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-20 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-21 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-22 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-23 00:00:00', 4.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-24 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-25 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-26 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-27 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-28 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-29 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-04-30 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-01 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-02 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-03 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-04 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-05 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-06 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-07 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-08 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-09 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-10 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-11 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-12 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-13 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-14 00:00:00', 4.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-15 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-16 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-17 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-18 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-19 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-20 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-21 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-22 00:00:00', 5.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-23 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-24 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-25 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-26 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-27 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-28 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-29 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-30 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-05-31 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-01 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-02 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-03 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-04 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-05 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-06 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-07 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-08 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-09 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-10 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-11 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-12 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-13 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-14 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-15 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-16 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-17 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-18 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-19 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-20 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-21 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-22 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-23 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-24 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-25 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-26 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-27 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-28 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-29 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-06-30 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-01 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-02 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-03 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-04 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-05 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-06 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-07 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-08 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-09 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-10 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-11 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-12 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-13 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-14 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-15 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-16 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-17 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-18 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-19 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-20 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-21 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-22 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-23 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-24 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-25 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-26 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-27 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-28 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-29 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-30 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-07-31 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-01 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-02 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-03 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-04 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-05 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-06 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-07 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-08 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-09 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-10 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-11 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-12 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-13 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-14 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-15 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-16 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-17 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-18 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-19 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-20 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-21 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-22 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-23 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-24 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-25 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-26 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-27 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-28 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-29 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-30 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-08-31 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-01 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-02 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-03 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-04 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-05 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-06 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-07 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-08 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-09 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-10 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-11 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-12 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-13 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-14 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-15 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-16 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-17 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-18 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-19 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-20 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-21 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-22 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-23 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-24 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-25 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-26 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-27 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-28 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-29 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-09-30 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-01 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-02 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-03 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-04 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-05 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-06 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-07 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-08 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-09 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-10 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-11 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-12 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-13 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-14 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-15 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-16 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-17 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-18 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-19 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-20 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-21 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-22 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-23 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-24 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-25 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-26 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-27 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-28 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-29 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-30 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-10-31 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-01 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-02 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-03 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-04 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-05 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-06 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-07 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-08 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-09 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-10 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-11 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-12 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-13 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-14 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-15 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-16 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-17 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-18 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-19 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-20 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-21 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-22 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-23 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-24 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-25 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-26 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-27 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-28 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-29 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-11-30 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-01 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-02 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-03 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-04 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-05 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-06 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-07 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-08 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-09 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-10 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-11 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-12 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-13 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-14 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-15 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-16 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-17 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-18 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-19 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-20 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-21 00:00:00', 5.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-22 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-23 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-24 00:00:00', 5.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-25 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-26 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-27 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-28 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-29 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-30 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1998-12-31 00:00:00', 4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-02 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-04 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-06 00:00:00', 5.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-08 00:00:00', 5.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-10 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-12 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-14 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-16 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-18 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-20 00:00:00', 4.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-22 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-24 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-26 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-28 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-30 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-01 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-03 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-05 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-07 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-09 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-11 00:00:00', 6.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-13 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-15 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-17 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-19 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-21 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-23 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-25 00:00:00', 5.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-27 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-01 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-03 00:00:00', 5.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-04 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-05 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-06 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-07 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-08 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-09 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-10 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-11 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-12 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-13 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-14 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-15 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-16 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-17 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-18 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-19 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-20 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-21 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-22 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-23 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-24 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-25 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-26 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-27 00:00:00', 5.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-28 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-29 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-30 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-03-31 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-01 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-02 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-03 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-04 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-05 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-06 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-07 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-08 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-09 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-10 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-11 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-12 00:00:00', 1.10300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-13 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-14 00:00:00', 4.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-15 00:00:00', 4.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-16 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-17 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-18 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-19 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-20 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-21 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-22 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-23 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-24 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-25 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-26 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-27 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-28 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-29 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-04-30 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-01 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-02 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-03 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-04 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-05 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-06 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-07 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-08 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-09 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-10 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-11 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-12 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-13 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-14 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-15 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-16 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-17 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-18 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-19 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-20 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-21 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-22 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-23 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-24 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-25 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-26 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-27 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-28 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-29 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-30 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-05-31 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-01 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-02 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-03 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-04 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-05 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-06 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-07 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-08 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-09 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-10 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-11 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-12 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-13 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-14 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-15 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-16 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-17 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-18 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-19 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-20 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-21 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-22 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-23 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-24 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-25 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-26 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-27 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-28 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-29 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-06-30 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-01 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-02 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-03 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-04 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-05 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-06 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-07 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-08 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-09 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-10 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-11 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-12 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-13 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-14 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-15 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-16 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-17 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-18 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-19 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-20 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-21 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-22 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-23 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-24 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-25 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-26 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-27 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-28 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-29 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-30 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-07-31 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-01 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-02 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-03 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-04 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-05 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-06 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-07 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-08 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-09 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-10 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-11 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-12 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-13 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-14 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-15 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-16 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-17 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-18 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-19 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-20 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-21 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-22 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-23 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-24 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-25 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-26 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-27 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-28 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-29 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-30 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-08-31 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-01 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-02 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-03 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-04 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-05 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-06 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-07 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-08 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-09 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-10 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-11 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-12 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-13 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-14 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-15 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-16 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-17 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-18 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-19 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-20 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-21 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-22 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-23 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-24 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-25 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-26 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-27 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-28 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-29 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-09-30 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-01 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-02 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-03 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-04 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-05 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-06 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-07 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-08 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-09 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-10 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-11 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-12 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-13 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-14 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-15 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-16 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-17 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-18 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-19 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-20 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-21 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-22 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-23 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-24 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-25 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-26 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-27 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-28 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-29 00:00:00', 4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-30 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-10-31 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-01 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-02 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-03 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-04 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-05 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-06 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-07 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-08 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-09 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-10 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-11 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-12 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-13 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-14 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-15 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-16 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-17 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-18 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-19 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-20 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-21 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-22 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-23 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-24 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-25 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-26 00:00:00', 5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-27 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-28 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-29 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-11-30 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-01 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-02 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-03 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-04 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-05 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-06 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-07 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-08 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-09 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-10 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-11 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-12 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-13 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-14 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-15 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-16 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-17 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-18 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-19 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-20 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-21 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-22 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-23 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-24 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-25 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-26 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-27 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-28 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-29 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-30 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '1999-12-31 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-01 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-02 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-03 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-04 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-05 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-06 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-07 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-08 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-09 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-10 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-11 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-12 00:00:00', 0.973999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-13 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-14 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-15 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-16 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-17 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-18 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-19 00:00:00', 4.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-20 00:00:00', 4.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-21 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-22 00:00:00', 4.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-23 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-24 00:00:00', 1.27100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-25 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-26 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-27 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-28 00:00:00', 5.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-29 00:00:00', 5.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-30 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-01-31 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-01 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-02 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-03 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-04 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-05 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-06 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-07 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-08 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-09 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-10 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-11 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-12 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-13 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-14 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-15 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-16 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-17 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-18 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-19 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-20 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-21 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-22 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-23 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-24 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-25 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-26 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-27 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-28 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-02-29 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-01 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-02 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-03 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-04 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-05 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-06 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-07 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-08 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-09 00:00:00', 5.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-10 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-11 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-12 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-13 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-14 00:00:00', 5.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-15 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-16 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-17 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-18 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-19 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-20 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-21 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-22 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-23 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-24 00:00:00', 6.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-25 00:00:00', 5.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-26 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-27 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-28 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-29 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-30 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-03-31 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-01 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-02 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-03 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-04 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-05 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-06 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-07 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-08 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-09 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-10 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-11 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-12 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-13 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-14 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-15 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-16 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-17 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-18 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-19 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-20 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-21 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-22 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-23 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-24 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-25 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-26 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-27 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-28 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-29 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-04-30 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-01 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-02 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-03 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-04 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-05 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-06 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-07 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-08 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-09 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-10 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-11 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-12 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-13 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-14 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-15 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-16 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-17 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-18 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-19 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-20 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-21 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-22 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-23 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-24 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-25 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-26 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-27 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-28 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-29 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-30 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-05-31 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-01 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-02 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-03 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-04 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-05 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-06 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-07 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-08 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-09 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-10 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-11 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-12 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-13 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-14 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-15 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-16 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-17 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-18 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-19 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-20 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-21 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-22 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-23 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-24 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-25 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-26 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-27 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-28 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-29 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-06-30 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-01 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-02 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-03 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-04 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-05 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-06 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-07 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-08 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-09 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-10 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-11 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-12 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-13 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-14 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-15 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-16 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-17 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-18 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-19 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-20 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-21 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-22 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-23 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-24 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-25 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-26 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-27 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-28 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-29 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-30 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-07-31 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-01 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-02 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-03 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-04 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-05 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-06 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-07 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-08 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-09 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-10 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-11 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-12 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-13 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-14 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-15 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-16 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-17 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-18 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-19 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-20 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-21 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-22 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-23 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-24 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-25 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-26 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-27 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-28 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-29 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-30 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-08-31 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-01 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-02 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-03 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-04 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-05 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-06 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-07 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-08 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-09 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-10 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-11 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-12 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-13 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-14 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-15 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-16 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-17 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-18 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-19 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-20 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-21 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-22 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-23 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-24 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-25 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-26 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-27 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-28 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-29 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-09-30 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-01 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-02 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-03 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-04 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-05 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-06 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-07 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-08 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-09 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-10 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-11 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-12 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-13 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-14 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-15 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-16 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-17 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-18 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-19 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-20 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-21 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-22 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-23 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-24 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-25 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-26 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-27 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-28 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-29 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-30 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-10-31 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-01 00:00:00', 1.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-02 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-03 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-04 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-05 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-06 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-07 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-08 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-09 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-10 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-11 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-12 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-13 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-14 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-15 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-16 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-17 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-18 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-19 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-20 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-21 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-22 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-23 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-24 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-25 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-26 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-27 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-28 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-29 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-11-30 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-01 00:00:00', 5.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-02 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-03 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-04 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-05 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-06 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-07 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-08 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-09 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-10 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-11 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-12 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-13 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-14 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-15 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-16 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-17 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-18 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-19 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-20 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-21 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-22 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-23 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-24 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-25 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-26 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-27 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-28 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-29 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-30 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2000-12-31 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-01 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-02 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-03 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-04 00:00:00', 4.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-05 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-06 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-07 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-08 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-09 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-10 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-11 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-12 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-13 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-14 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-15 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-16 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-17 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-18 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-19 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-20 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-21 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-22 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-23 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-24 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-25 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-26 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-27 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-28 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-29 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-30 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-01-31 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-01 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-02 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-03 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-04 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-05 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-06 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-07 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-08 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-09 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-10 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-11 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-12 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-13 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-14 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-15 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-16 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-17 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-18 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-19 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-20 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-21 00:00:00', 6.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-22 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-23 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-24 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-25 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-26 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-27 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-02-28 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-01 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-02 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-03 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-04 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-05 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-06 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-07 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-08 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-09 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-10 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-11 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-12 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-13 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-14 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-15 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-16 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-17 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-18 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-19 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-20 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-21 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-22 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-23 00:00:00', 4.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-24 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-25 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-26 00:00:00', 5.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-27 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-28 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-29 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-30 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-03-31 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-01 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-02 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-03 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-04 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-05 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-06 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-07 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-08 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-09 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-10 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-11 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-12 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-13 00:00:00', 5.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-14 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-15 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-16 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-17 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-18 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-19 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-20 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-21 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-22 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-23 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-24 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-25 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-26 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-27 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-28 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-29 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-04-30 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-01 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-02 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-03 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-04 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-05 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-06 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-07 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-08 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-09 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-10 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-11 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-12 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-13 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-14 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-15 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-16 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-17 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-18 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-19 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-20 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-21 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-22 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-23 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-24 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-25 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-26 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-27 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-28 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-29 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-30 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-05-31 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-01 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-02 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-03 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-04 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-05 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-06 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-07 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-08 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-09 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-10 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-11 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-12 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-13 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-14 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-15 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-16 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-17 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-18 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-19 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-20 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-21 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-22 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-23 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-24 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-25 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-26 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-27 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-28 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-29 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-06-30 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-01 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-02 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-03 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-04 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-05 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-06 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-07 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-08 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-09 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-10 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-11 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-12 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-13 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-14 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-15 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-16 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-17 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-18 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-19 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-20 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-21 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-22 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-23 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-24 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-25 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-26 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-27 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-28 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-29 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-30 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-07-31 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-01 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-02 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-03 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-04 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-05 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-06 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-07 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-08 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-09 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-10 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-11 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-12 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-13 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-14 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-15 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-16 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-17 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-18 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-19 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-20 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-21 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-22 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-23 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-24 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-25 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-26 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-27 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-28 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-29 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-30 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-08-31 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-01 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-02 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-03 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-04 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-05 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-06 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-07 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-08 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-09 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-10 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-11 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-12 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-13 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-14 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-15 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-16 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-17 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-18 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-19 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-20 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-21 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-22 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-23 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-24 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-25 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-26 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-27 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-28 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-29 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-09-30 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-01 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-02 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-03 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-04 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-05 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-06 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-07 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-08 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-09 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-10 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-11 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-12 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-13 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-14 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-15 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-16 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-17 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-18 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-19 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-20 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-21 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-22 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-23 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-24 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-25 00:00:00', 5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-26 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-27 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-28 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-29 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-30 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-10-31 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-01 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-02 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-03 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-04 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-05 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-06 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-07 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-08 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-09 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-10 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-11 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-12 00:00:00', 5.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-13 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-14 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-15 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-16 00:00:00', 4.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-17 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-18 00:00:00', 5.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-19 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-20 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-21 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-22 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-23 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-24 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-25 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-26 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-27 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-28 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-29 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-11-30 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-01 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-02 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-03 00:00:00', 1.09099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-04 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-05 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-06 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-07 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-08 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-09 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-10 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-11 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-12 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-13 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-14 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-15 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-16 00:00:00', 4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-17 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-18 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-19 00:00:00', 5.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-20 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-21 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-22 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-23 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-24 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-25 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-26 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-27 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-28 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-29 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-30 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2001-12-31 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-01 00:00:00', 5.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-02 00:00:00', 5.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-03 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-04 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-05 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-06 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-07 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-08 00:00:00', 5.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-09 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-10 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-11 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-12 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-13 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-14 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-15 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-16 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-17 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-18 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-19 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-20 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-21 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-22 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-23 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-24 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-25 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-26 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-27 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-28 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-29 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-30 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-01-31 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-01 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-02 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-03 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-04 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-05 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-06 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-07 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-08 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-09 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-10 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-11 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-12 00:00:00', 4.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-13 00:00:00', 5.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-14 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-15 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-16 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-17 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-18 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-19 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-20 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-21 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-22 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-23 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-24 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-25 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-26 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-27 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-02-28 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-01 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-02 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-03 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-04 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-05 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-06 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-07 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-08 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-09 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-10 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-11 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-12 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-13 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-14 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-15 00:00:00', 4.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-16 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-17 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-18 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-19 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-20 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-21 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-22 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-23 00:00:00', 4.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-24 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-25 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-26 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-27 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-28 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-29 00:00:00', 6.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-30 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-03-31 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-01 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-02 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-03 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-04 00:00:00', 6.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-05 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-06 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-07 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-08 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-09 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-10 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-11 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-12 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-13 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-14 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-15 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-16 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-17 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-18 00:00:00', 4.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-19 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-20 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-21 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-22 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-23 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-24 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-25 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-26 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-27 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-28 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-29 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-04-30 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-01 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-02 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-03 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-04 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-05 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-06 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-07 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-08 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-09 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-10 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-11 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-12 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-13 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-14 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-15 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-16 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-17 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-18 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-19 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-20 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-21 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-22 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-23 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-24 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-25 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-26 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-27 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-28 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-29 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-30 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-05-31 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-01 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-02 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-03 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-04 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-05 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-06 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-07 00:00:00', 4.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-08 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-09 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-10 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-11 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-12 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-13 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-14 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-15 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-16 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-17 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-18 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-19 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-20 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-21 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-22 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-23 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-24 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-25 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-26 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-27 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-28 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-29 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-06-30 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-01 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-02 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-03 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-04 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-05 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-06 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-07 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-08 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-09 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-10 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-11 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-12 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-13 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-14 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-15 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-16 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-17 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-18 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-19 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-20 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-21 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-22 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-23 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-24 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-25 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-26 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-27 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-28 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-29 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-30 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-07-31 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-01 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-02 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-03 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-04 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-05 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-06 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-07 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-08 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-09 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-10 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-11 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-12 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-13 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-14 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-15 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-16 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-17 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-18 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-19 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-20 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-21 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-22 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-23 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-24 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-25 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-26 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-27 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-28 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-29 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-30 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-08-31 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-01 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-02 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-03 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-04 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-05 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-06 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-07 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-08 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-09 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-10 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-11 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-12 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-13 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-14 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-15 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-16 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-17 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-18 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-19 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-20 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-21 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-22 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-23 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-24 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-25 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-26 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-27 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-28 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-29 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-09-30 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-01 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-02 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-03 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-04 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-05 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-06 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-07 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-08 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-09 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-10 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-11 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-12 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-13 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-14 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-15 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-16 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-17 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-18 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-19 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-20 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-21 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-22 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-23 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-24 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-25 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-26 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-27 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-28 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-29 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-30 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-10-31 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-01 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-02 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-03 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-04 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-05 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-06 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-07 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-08 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-09 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-10 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-11 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-12 00:00:00', 4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-13 00:00:00', 4.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-14 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-15 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-16 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-17 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-18 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-19 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-20 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-21 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-22 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-23 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-24 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-25 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-26 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-27 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-28 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-29 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-11-30 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-01 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-02 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-03 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-04 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-05 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-06 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-07 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-08 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-09 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-10 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-11 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-12 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-13 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-14 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-15 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-16 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-17 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-18 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-19 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-20 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-21 00:00:00', 5.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-22 00:00:00', 5.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-23 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-24 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-25 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-26 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-27 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-28 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-29 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-30 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2002-12-31 00:00:00', 4.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-01 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-02 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-03 00:00:00', 3.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-04 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-05 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-06 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-07 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-08 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-09 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-10 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-11 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-12 00:00:00', 4.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-13 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-14 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-15 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-16 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-17 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-18 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-19 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-20 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-21 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-22 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-23 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-24 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-25 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-26 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-27 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-28 00:00:00', 4.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-29 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-30 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-01-31 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-01 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-02 00:00:00', 5.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-03 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-04 00:00:00', 5.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-05 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-06 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-07 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-08 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-09 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-10 00:00:00', 4.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-11 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-12 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-13 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-14 00:00:00', 5.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-15 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-16 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-17 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-18 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-19 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-20 00:00:00', 5.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-21 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-22 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-23 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-24 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-25 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-26 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-27 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-02-28 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-01 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-02 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-03 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-04 00:00:00', 5.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-05 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-06 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-07 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-08 00:00:00', 5.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-09 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-10 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-11 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-12 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-13 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-14 00:00:00', 6.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-15 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-16 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-17 00:00:00', 5.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-18 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-19 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-20 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-21 00:00:00', 5.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-22 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-23 00:00:00', 4.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-24 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-25 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-26 00:00:00', 6.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-27 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-28 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-29 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-30 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-03-31 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-01 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-02 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-03 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-04 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-05 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-06 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-07 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-08 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-09 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-10 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-11 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-12 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-13 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-14 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-15 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-16 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-17 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-18 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-19 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-20 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-21 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-22 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-23 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-24 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-25 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-26 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-27 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-28 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-29 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-04-30 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-01 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-02 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-03 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-04 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-05 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-06 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-07 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-08 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-09 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-10 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-11 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-12 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-13 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-14 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-15 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-16 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-17 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-18 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-19 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-20 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-21 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-22 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-23 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-24 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-25 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-26 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-27 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-28 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-29 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-30 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-05-31 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-01 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-02 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-03 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-04 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-05 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-06 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-07 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-08 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-09 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-10 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-11 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-12 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-13 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-14 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-15 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-16 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-17 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-18 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-19 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-20 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-21 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-22 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-23 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-24 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-25 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-26 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-27 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-28 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-29 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-06-30 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-01 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-02 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-03 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-04 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-05 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-06 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-07 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-08 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-09 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-10 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-11 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-12 00:00:00', 4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-13 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-14 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-15 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-16 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-17 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-18 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-19 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-20 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-21 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-22 00:00:00', 5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-23 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-24 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-25 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-26 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-27 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-28 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-29 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-30 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-07-31 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-01 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-02 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-03 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-04 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-05 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-06 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-07 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-08 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-09 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-10 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-11 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-12 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-13 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-14 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-15 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-16 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-17 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-18 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-19 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-20 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-21 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-22 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-23 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-24 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-25 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-26 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-27 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-28 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-29 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-30 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-08-31 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-01 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-02 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-03 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-04 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-05 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-06 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-07 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-08 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-09 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-10 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-11 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-12 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-13 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-14 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-15 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-16 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-17 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-18 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-19 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-20 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-21 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-22 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-23 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-24 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-25 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-26 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-27 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-28 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-29 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-09-30 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-01 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-02 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-03 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-04 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-05 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-06 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-07 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-08 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-09 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-10 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-11 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-12 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-13 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-14 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-15 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-16 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-17 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-18 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-19 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-20 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-21 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-22 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-23 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-24 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-25 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-26 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-27 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-28 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-29 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-30 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-10-31 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-01 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-02 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-03 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-04 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-05 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-06 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-07 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-08 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-09 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-10 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-11 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-12 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-13 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-14 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-15 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-16 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-17 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-18 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-19 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-20 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-21 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-22 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-23 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-24 00:00:00', 4.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-25 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-26 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-27 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-28 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-29 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-11-30 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-01 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-02 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-03 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-04 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-05 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-06 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-07 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-08 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-09 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-10 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-11 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-12 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-13 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-14 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-15 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-16 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-17 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-18 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-19 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-20 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-21 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-22 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-23 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-24 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-25 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-26 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-27 00:00:00', 4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-28 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-29 00:00:00', 1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-30 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2003-12-31 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-01 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-02 00:00:00', 4.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-03 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-04 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-05 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-06 00:00:00', 5.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-07 00:00:00', 4.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-08 00:00:00', 5.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-09 00:00:00', 5.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-10 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-11 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-12 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-13 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-14 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-15 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-16 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-17 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-18 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-19 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-20 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-21 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-22 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-23 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-24 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-25 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-26 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-27 00:00:00', 4.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-28 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-29 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-30 00:00:00', 1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-01-31 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-01 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-02 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-03 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-04 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-05 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-06 00:00:00', 5.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-07 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-08 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-09 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-10 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-11 00:00:00', 5.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-12 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-13 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-14 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-15 00:00:00', 6.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-16 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-17 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-18 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-19 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-20 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-21 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-22 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-23 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-24 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-25 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-26 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-27 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-28 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-02-29 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-01 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-02 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-03 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-04 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-05 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-06 00:00:00', 5.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-07 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-08 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-09 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-10 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-11 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-12 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-13 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-14 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-15 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-16 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-17 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-18 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-19 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-20 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-21 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-22 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-23 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-24 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-25 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-26 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-27 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-28 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-29 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-30 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-03-31 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-01 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-02 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-03 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-04 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-05 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-06 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-07 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-08 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-09 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-10 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-11 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-12 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-13 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-14 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-15 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-16 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-17 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-18 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-19 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-20 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-21 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-22 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-23 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-24 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-25 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-26 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-27 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-28 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-29 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-04-30 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-01 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-02 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-03 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-04 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-05 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-06 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-07 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-08 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-09 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-10 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-11 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-12 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-13 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-14 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-15 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-16 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-17 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-18 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-19 00:00:00', 4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-20 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-21 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-22 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-23 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-24 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-25 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-26 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-27 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-28 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-29 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-30 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-05-31 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-01 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-02 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-03 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-04 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-05 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-06 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-07 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-08 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-09 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-10 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-11 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-12 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-13 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-14 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-15 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-16 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-17 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-18 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-19 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-20 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-21 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-22 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-23 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-24 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-25 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-26 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-27 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-28 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-29 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-06-30 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-01 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-02 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-03 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-04 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-05 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-06 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-07 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-08 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-09 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-10 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-11 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-12 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-13 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-14 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-15 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-16 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-17 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-18 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-19 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-20 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-21 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-22 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-23 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-24 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-25 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-26 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-27 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-28 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-29 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-30 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-07-31 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-01 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-02 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-03 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-04 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-05 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-06 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-07 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-08 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-09 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-10 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-11 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-12 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-13 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-14 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-15 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-16 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-17 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-18 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-19 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-20 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-21 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-22 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-23 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-24 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-25 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-26 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-27 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-28 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-29 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-30 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-08-31 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-01 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-02 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-03 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-04 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-05 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-06 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-07 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-08 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-09 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-10 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-11 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-12 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-13 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-14 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-15 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-16 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-17 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-18 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-19 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-20 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-21 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-22 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-23 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-24 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-25 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-26 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-27 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-28 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-29 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-09-30 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-01 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-02 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-03 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-04 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-05 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-06 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-07 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-08 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-09 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-10 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-11 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-12 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-13 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-14 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-15 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-16 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-17 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-18 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-19 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-20 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-21 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-22 00:00:00', 4.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-23 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-24 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-25 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-26 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-27 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-28 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-29 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-30 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-10-31 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-01 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-02 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-03 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-04 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-05 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-06 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-07 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-08 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-09 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-10 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-11 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-12 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-13 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-14 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-15 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-16 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-17 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-18 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-19 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-20 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-21 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-22 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-23 00:00:00', 5.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-24 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-25 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-26 00:00:00', 4.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-27 00:00:00', 5.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-28 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-29 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-11-30 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-01 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-02 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-03 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-04 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-05 00:00:00', 4.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-06 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-07 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-08 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-09 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-10 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-11 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-12 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-13 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-14 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-15 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-16 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-17 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-18 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-19 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-20 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-21 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-22 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-23 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-24 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-25 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-26 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-27 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-28 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-29 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-30 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2004-12-31 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-01 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-02 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-03 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-04 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-05 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-06 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-07 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-08 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-09 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-10 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-11 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-12 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-13 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-14 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-15 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-16 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-17 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-18 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-19 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-20 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-21 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-22 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-23 00:00:00', 5.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-24 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-25 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-26 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-27 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-28 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-29 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-30 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-01-31 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-01 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-02 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-03 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-04 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-05 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-06 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-07 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-08 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-09 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-10 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-11 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-12 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-13 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-14 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-15 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-16 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-17 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-18 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-19 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-20 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-21 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-22 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-23 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-24 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-25 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-26 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-27 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-02-28 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-01 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-02 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-03 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-04 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-05 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-06 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-07 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-08 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-09 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-10 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-11 00:00:00', 5.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-12 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-13 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-14 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-15 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-16 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-17 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-18 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-19 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-20 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-21 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-22 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-23 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-24 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-25 00:00:00', 4.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-26 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-27 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-28 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-29 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-30 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-03-31 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-01 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-02 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-03 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-04 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-05 00:00:00', 5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-06 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-07 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-08 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-09 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-10 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-11 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-12 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-13 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-14 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-15 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-16 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-17 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-18 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-19 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-20 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-21 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-22 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-23 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-24 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-25 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-26 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-27 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-28 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-29 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-04-30 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-01 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-02 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-03 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-04 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-05 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-06 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-07 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-08 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-09 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-10 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-11 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-12 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-13 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-14 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-15 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-16 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-17 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-18 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-19 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-20 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-21 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-22 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-23 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-24 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-25 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-26 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-27 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-28 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-29 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-30 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-05-31 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-01 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-02 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-03 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-04 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-05 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-06 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-07 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-08 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-09 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-10 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-11 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-12 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-13 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-14 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-15 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-16 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-17 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-18 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-19 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-20 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-21 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-22 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-23 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-24 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-25 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-26 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-27 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-28 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-29 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-06-30 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-01 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-02 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-03 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-04 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-05 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-06 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-07 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-08 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-09 00:00:00', 4.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-10 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-11 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-12 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-13 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-14 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-15 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-16 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-17 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-18 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-19 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-20 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-21 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-22 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-23 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-24 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-25 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-26 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-27 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-28 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-29 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-30 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-07-31 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-01 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-02 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-03 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-04 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-05 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-06 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-07 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-08 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-09 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-10 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-11 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-12 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-13 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-14 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-15 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-16 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-17 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-18 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-19 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-20 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-21 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-22 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-23 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-24 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-25 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-26 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-27 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-28 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-29 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-30 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-08-31 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-01 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-02 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-03 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-04 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-05 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-06 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-07 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-08 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-09 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-10 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-11 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-12 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-13 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-14 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-15 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-16 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-17 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-18 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-19 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-20 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-21 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-22 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-23 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-24 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-25 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-26 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-27 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-28 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-29 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-09-30 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-01 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-02 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-03 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-04 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-05 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-06 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-07 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-08 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-09 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-10 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-11 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-12 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-13 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-14 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-15 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-16 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-17 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-18 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-19 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-20 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-21 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-22 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-23 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-24 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-25 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-26 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-27 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-28 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-29 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-30 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-10-31 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-01 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-02 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-03 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-04 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-05 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-06 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-07 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-08 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-09 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-10 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-11 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-12 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-13 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-14 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-15 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-16 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-17 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-18 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-19 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-20 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-21 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-22 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-23 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-24 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-25 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-26 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-27 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-28 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-29 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-11-30 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-01 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-02 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-03 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-04 00:00:00', 4.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-05 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-06 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-07 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-08 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-09 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-10 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-11 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-12 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-13 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-14 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-15 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-16 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-17 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-18 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-19 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-20 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-21 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-22 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-23 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-24 00:00:00', 5.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-25 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-26 00:00:00', 4.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-27 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-28 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-29 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-30 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2005-12-31 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-01 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-02 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-03 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-04 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-05 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-06 00:00:00', 4.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-07 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-08 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-09 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-10 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-11 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-12 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-13 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-14 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-15 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-16 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-17 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-18 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-19 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-20 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-21 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-22 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-23 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-24 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-25 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-26 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-27 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-28 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-29 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-30 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-01-31 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-01 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-02 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-03 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-04 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-05 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-06 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-07 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-08 00:00:00', 4.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-09 00:00:00', 5.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-10 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-11 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-12 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-13 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-14 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-15 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-16 00:00:00', 5.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-17 00:00:00', 4.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-18 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-19 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-20 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-21 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-22 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-23 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-24 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-25 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-26 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-27 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-02-28 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-01 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-02 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-03 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-04 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-05 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-06 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-07 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-08 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-09 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-10 00:00:00', 5.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-11 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-12 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-13 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-14 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-15 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-16 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-17 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-18 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-19 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-20 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-21 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-22 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-23 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-24 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-25 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-26 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-27 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-28 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-29 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-30 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-03-31 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-01 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-02 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-03 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-04 00:00:00', 5.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-05 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-06 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-07 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-08 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-09 00:00:00', 6.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-10 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-11 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-12 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-13 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-14 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-15 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-16 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-17 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-18 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-19 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-20 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-21 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-22 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-23 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-24 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-25 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-26 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-27 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-28 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-29 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-04-30 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-01 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-02 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-03 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-04 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-05 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-06 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-07 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-08 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-09 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-10 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-11 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-12 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-13 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-14 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-15 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-16 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-17 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-18 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-19 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-20 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-21 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-22 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-23 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-24 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-25 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-26 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-27 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-28 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-29 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-30 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-05-31 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-01 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-02 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-03 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-04 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-05 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-06 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-07 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-08 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-09 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-10 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-11 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-12 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-13 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-14 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-15 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-16 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-17 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-18 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-19 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-20 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-21 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-22 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-23 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-24 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-25 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-26 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-27 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-28 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-29 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-06-30 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-01 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-02 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-03 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-04 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-05 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-06 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-07 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-08 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-09 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-10 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-11 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-12 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-13 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-14 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-15 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-16 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-17 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-18 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-19 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-20 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-21 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-22 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-23 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-24 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-25 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-26 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-27 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-28 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-29 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-30 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-07-31 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-01 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-02 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-03 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-04 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-05 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-06 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-07 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-08 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-09 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-10 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-11 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-12 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-13 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-14 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-15 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-16 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-17 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-18 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-19 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-20 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-21 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-22 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-23 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-24 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-25 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-26 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-27 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-28 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-29 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-30 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-08-31 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-01 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-02 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-03 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-04 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-05 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-06 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-07 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-08 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-09 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-10 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-11 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-12 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-13 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-14 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-15 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-16 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-17 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-18 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-19 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-20 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-21 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-22 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-23 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-24 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-25 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-26 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-27 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-28 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-29 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-09-30 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-01 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-02 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-03 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-04 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-05 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-06 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-07 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-08 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-09 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-10 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-11 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-12 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-13 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-14 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-15 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-16 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-17 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-18 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-19 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-20 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-21 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-22 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-23 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-24 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-25 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-26 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-27 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-28 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-29 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-30 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-10-31 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-01 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-02 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-03 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-04 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-05 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-06 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-07 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-08 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-09 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-10 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-11 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-12 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-13 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-14 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-15 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-16 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-17 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-18 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-19 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-20 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-21 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-22 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-23 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-24 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-25 00:00:00', 1.1390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-26 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-27 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-28 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-29 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-11-30 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-01 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-02 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-03 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-04 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-05 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-06 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-07 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-08 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-09 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-10 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-11 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-12 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-13 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-14 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-15 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-16 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-17 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-18 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-19 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-20 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-21 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-22 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-23 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-24 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-25 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-26 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-27 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-28 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-29 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-30 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2006-12-31 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-01 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-02 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-03 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-04 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-05 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-06 00:00:00', 5.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-07 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-08 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-09 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-10 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-11 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-12 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-13 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-14 00:00:00', 5.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-15 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-16 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-17 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-18 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-19 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-20 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-21 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-22 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-23 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-24 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-25 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-26 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-27 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-28 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-29 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-30 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-01-31 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-01 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-02 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-03 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-04 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-05 00:00:00', 5.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-06 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-07 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-08 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-09 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-10 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-11 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-12 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-13 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-14 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-15 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-16 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-17 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-18 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-19 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-20 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-21 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-22 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-23 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-24 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-25 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-26 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-27 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-02-28 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-01 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-02 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-03 00:00:00', 1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-04 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-05 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-06 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-07 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-08 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-09 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-10 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-11 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-12 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-13 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-14 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-15 00:00:00', 5.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-16 00:00:00', 5.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-17 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-18 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-19 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-20 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-21 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-22 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-23 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-24 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-25 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-26 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-27 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-28 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-29 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-30 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-03-31 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-01 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-02 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-03 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-04 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-05 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-06 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-07 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-08 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-09 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-10 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-11 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-12 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-13 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-14 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-15 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-16 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-17 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-18 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-19 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-20 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-21 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-22 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-23 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-24 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-25 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-26 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-27 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-28 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-29 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-04-30 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-01 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-02 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-03 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-04 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-05 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-06 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-07 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-08 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-09 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-10 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-11 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-12 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-13 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-14 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-15 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-16 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-17 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-18 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-19 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-20 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-21 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-22 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-23 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-24 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-25 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-26 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-27 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-28 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-29 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-30 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-05-31 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-01 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-02 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-03 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-04 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-05 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-06 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-07 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-08 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-09 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-10 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-11 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-12 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-13 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-14 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-15 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-16 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-17 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-18 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-19 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-20 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-21 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-22 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-23 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-24 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-25 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-26 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-27 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-28 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-29 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-06-30 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-01 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-02 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-03 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-04 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-05 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-06 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-07 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-08 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-09 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-10 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-11 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-12 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-13 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-14 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-15 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-16 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-17 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-18 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-19 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-20 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-21 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-22 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-23 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-24 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-25 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-26 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-27 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-28 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-29 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-30 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-07-31 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-01 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-02 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-03 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-04 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-05 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-06 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-07 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-08 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-09 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-10 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-11 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-12 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-13 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-14 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-15 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-16 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-17 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-18 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-19 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-20 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-21 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-22 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-23 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-24 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-25 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-26 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-27 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-28 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-29 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-30 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-08-31 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-01 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-02 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-03 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-04 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-05 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-06 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-07 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-08 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-09 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-10 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-11 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-12 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-13 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-14 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-15 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-16 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-17 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-18 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-19 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-20 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-21 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-22 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-23 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-24 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-25 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-26 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-27 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-28 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-29 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-09-30 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-01 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-02 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-03 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-04 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-05 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-06 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-07 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-08 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-09 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-10 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-11 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-12 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-13 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-14 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-15 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-16 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-17 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-18 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-19 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-20 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-21 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-22 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-23 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-24 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-25 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-26 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-27 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-28 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-29 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-30 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-10-31 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-01 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-02 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-03 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-04 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-05 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-06 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-07 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-08 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-09 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-10 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-11 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-12 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-13 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-14 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-15 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-16 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-17 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-18 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-19 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-20 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-21 00:00:00', 4.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-22 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-23 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-24 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-25 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-26 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-27 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-28 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-29 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-11-30 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-01 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-02 00:00:00', 4.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-03 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-04 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-05 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-06 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-07 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-08 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-09 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-10 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-11 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-12 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-13 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-14 00:00:00', 5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-15 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-16 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-17 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-18 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-19 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-20 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-21 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-22 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-23 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-24 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-25 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-26 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-27 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-28 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-29 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-30 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2007-12-31 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-01 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-02 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-03 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-04 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-05 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-06 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-07 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-08 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-09 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-10 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-11 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-12 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-13 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-14 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-15 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-16 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-17 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-18 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-19 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-20 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-21 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-22 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-23 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-24 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-25 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-26 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-27 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-28 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-29 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-30 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-01-31 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-01 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-02 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-03 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-04 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-05 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-06 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-07 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-08 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-09 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-10 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-11 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-12 00:00:00', 5.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-13 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-14 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-15 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-16 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-17 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-18 00:00:00', 5.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-19 00:00:00', 5.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-20 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-21 00:00:00', 5.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-22 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-23 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-24 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-25 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-26 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-27 00:00:00', 4.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-28 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-02-29 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-01 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-02 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-03 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-04 00:00:00', 5.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-05 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-06 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-07 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-08 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-09 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-10 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-11 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-12 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-13 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-14 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-15 00:00:00', 5.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-16 00:00:00', 6.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-17 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-18 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-19 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-20 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-21 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-22 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-23 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-24 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-25 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-26 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-27 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-28 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-29 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-30 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-03-31 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-01 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-02 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-03 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-04 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-05 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-06 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-07 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-08 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-09 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-10 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-11 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-12 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-13 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-14 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-15 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-16 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-17 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-18 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-19 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-20 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-21 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-22 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-23 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-24 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-25 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-26 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-27 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-28 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-29 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-04-30 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-01 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-02 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-03 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-04 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-05 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-06 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-07 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-08 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-09 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-10 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-11 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-12 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-13 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-14 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-15 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-16 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-17 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-18 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-19 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-20 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-21 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-22 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-23 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-24 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-25 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-26 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-27 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-28 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-29 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-30 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-05-31 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-01 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-02 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-03 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-04 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-05 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-06 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-07 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-08 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-09 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-10 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-11 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-12 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-13 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-14 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-15 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-16 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-17 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-18 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-19 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-20 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-21 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-22 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-23 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-24 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-25 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-26 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-27 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-28 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-29 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-06-30 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-01 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-02 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-03 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-04 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-05 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-06 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-07 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-08 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-09 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-10 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-11 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-12 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-13 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-14 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-15 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-16 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-17 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-18 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-19 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-20 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-21 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-22 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-23 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-24 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-25 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-26 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-27 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-28 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-29 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-30 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-07-31 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-01 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-02 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-03 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-04 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-05 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-06 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-07 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-08 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-09 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-10 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-11 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-12 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-13 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-14 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-15 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-16 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-17 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-18 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-19 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-20 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-21 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-22 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-23 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-24 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-25 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-26 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-27 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-28 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-29 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-30 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-08-31 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-01 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-02 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-03 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-04 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-05 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-06 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-07 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-08 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-09 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-10 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-11 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-12 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-13 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-14 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-15 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-16 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-17 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-18 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-19 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-20 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-21 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-22 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-23 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-24 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-25 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-26 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-27 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-28 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-29 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-09-30 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-01 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-02 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-03 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-04 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-05 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-06 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-07 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-08 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-09 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-10 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-11 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-12 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-13 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-14 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-15 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-16 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-17 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-18 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-19 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-20 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-21 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-22 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-23 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-24 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-25 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-26 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-27 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-28 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-29 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-30 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-10-31 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-01 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-02 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-03 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-04 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-05 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-06 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-07 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-08 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-09 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-10 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-11 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-12 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-13 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-14 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-15 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-16 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-17 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-18 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-19 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-20 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-21 00:00:00', 5.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-22 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-23 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-24 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-25 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-26 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-27 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-28 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-29 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-11-30 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-01 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-02 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-03 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-04 00:00:00', 1.10099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-05 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-06 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-07 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-08 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-09 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-10 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-11 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-12 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-13 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-14 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-15 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-16 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-17 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-18 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-19 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-20 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-21 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-22 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-23 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-24 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-25 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-26 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-27 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-28 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-29 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-30 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2008-12-31 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-01 00:00:00', 5.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-02 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-03 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-04 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-05 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-06 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-07 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-08 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-09 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-10 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-11 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-12 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-13 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-14 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-15 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-16 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-17 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-18 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-19 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-20 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-21 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-22 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-23 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-24 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-25 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-26 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-27 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-28 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-29 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-30 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-01-31 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-01 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-02 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-03 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-04 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-05 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-06 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-07 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-08 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-09 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-10 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-11 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-12 00:00:00', 4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-13 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-14 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-15 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-16 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-17 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-18 00:00:00', 4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-19 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-20 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-21 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-22 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-23 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-24 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-25 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-26 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-27 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-02-28 00:00:00', 5.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-01 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-02 00:00:00', 5.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-03 00:00:00', 5.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-04 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-05 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-06 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-07 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-08 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-09 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-10 00:00:00', 5.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-11 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-12 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-13 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-14 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-15 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-16 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-17 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-18 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-19 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-20 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-21 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-22 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-23 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-24 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-25 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-26 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-27 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-28 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-29 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-30 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-03-31 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-01 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-02 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-03 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-04 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-05 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-06 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-07 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-08 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-09 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-10 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-11 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-12 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-13 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-14 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-15 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-16 00:00:00', 5.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-17 00:00:00', 4.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-18 00:00:00', 5.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-19 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-20 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-21 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-22 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-23 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-24 00:00:00', 4.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-25 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-26 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-27 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-28 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-29 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-04-30 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-01 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-02 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-03 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-04 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-05 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-06 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-07 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-08 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-09 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-10 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-11 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-12 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-13 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-14 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-15 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-16 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-17 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-18 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-19 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-20 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-21 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-22 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-23 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-24 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-25 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-26 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-27 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-28 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-29 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-30 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-05-31 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-01 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-02 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-03 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-04 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-05 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-06 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-07 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-08 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-09 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-10 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-11 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-12 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-13 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-14 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-15 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-16 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-17 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-18 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-19 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-20 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-21 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-22 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-23 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-24 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-25 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-26 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-27 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-28 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-29 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-06-30 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-01 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-02 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-03 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-04 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-05 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-06 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-07 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-08 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-09 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-10 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-11 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-12 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-13 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-14 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-15 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-16 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-17 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-18 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-19 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-20 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-21 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-22 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-23 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-24 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-25 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-26 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-27 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-28 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-29 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-30 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-07-31 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-01 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-02 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-03 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-04 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-05 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-06 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-07 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-08 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-09 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-10 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-11 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-12 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-13 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-14 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-15 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-16 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-17 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-18 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-19 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-20 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-21 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-22 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-23 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-24 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-25 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-26 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-27 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-28 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-29 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-30 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-08-31 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-01 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-02 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-03 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-04 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-05 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-06 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-07 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-08 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-09 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-10 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-11 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-12 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-13 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-14 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-15 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-16 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-17 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-18 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-19 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-20 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-21 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-22 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-23 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-24 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-25 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-26 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-27 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-28 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-29 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-09-30 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-01 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-02 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-03 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-04 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-05 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-06 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-07 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-08 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-09 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-10 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-11 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-12 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-13 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-14 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-15 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-16 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-17 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-18 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-19 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-20 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-21 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-22 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-23 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-24 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-25 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-26 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-27 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-28 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-29 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-30 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-10-31 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-01 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-02 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-03 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-04 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-05 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-06 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-07 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-08 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-09 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-10 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-11 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-12 00:00:00', 0.949999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-13 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-14 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-15 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-16 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-17 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-18 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-19 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-20 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-21 00:00:00', 4.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-22 00:00:00', 4.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-23 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-24 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-25 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-26 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-27 00:00:00', 4.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-28 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-29 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-11-30 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-01 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-02 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-03 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-04 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-05 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-06 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-07 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-08 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-09 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-10 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-11 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-12 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-13 00:00:00', 4.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-14 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-15 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-16 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-17 00:00:00', 5.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-18 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-19 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-20 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-21 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-22 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-23 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-24 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-25 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-26 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-27 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-28 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-29 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-30 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2009-12-31 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-01 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-02 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-03 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-04 00:00:00', 4.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-05 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-06 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-07 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-08 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-09 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-10 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-11 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-12 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-13 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-14 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-15 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-16 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-17 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-18 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-19 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-20 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-21 00:00:00', 4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-22 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-23 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-24 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-25 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-26 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-27 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-28 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-29 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-30 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-01-31 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-01 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-02 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-03 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-04 00:00:00', 4.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-05 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-06 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-07 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-08 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-09 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-10 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-11 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-12 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-13 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-14 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-15 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-16 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-17 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-18 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-19 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-20 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-21 00:00:00', 4.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-22 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-23 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-24 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-25 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-26 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-27 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-02-28 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-01 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-02 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-03 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-04 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-05 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-06 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-07 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-08 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-09 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-10 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-11 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-12 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-13 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-14 00:00:00', 4.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-15 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-16 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-17 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-18 00:00:00', 4.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-19 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-20 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-21 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-22 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-23 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-24 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-25 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-26 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-27 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-28 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-29 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-30 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-03-31 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-01 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-02 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-03 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-04 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-05 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-06 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-07 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-08 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-09 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-10 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-11 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-12 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-13 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-14 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-15 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-16 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-17 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-18 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-19 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-20 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-21 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-22 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-23 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-24 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-25 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-26 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-27 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-28 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-29 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-04-30 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-01 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-02 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-03 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-04 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-05 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-06 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-07 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-08 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-09 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-10 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-11 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-12 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-13 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-14 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-15 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-16 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-17 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-18 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-19 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-20 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-21 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-22 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-23 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-24 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-25 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-26 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-27 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-28 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-29 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-30 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-05-31 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-01 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-02 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-03 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-04 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-05 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-06 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-07 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-08 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-09 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-10 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-11 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-12 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-13 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-14 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-15 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-16 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-17 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-18 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-19 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-20 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-21 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-22 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-23 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-24 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-25 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-26 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-27 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-28 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-29 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-06-30 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-01 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-02 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-03 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-04 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-05 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-06 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-07 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-08 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-09 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-10 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-11 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-12 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-13 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-14 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-15 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-16 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-17 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-18 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-19 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-20 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-21 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-22 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-23 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-24 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-25 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-26 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-27 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-28 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-29 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-30 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-07-31 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-01 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-02 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-03 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-04 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-05 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-06 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-07 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-08 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-09 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-10 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-11 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-12 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-13 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-14 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-15 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-16 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-17 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-18 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-19 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-20 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-21 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-22 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-23 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-24 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-25 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-26 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-27 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-28 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-29 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-30 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-08-31 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-01 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-02 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-03 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-04 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-05 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-06 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-07 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-08 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-09 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-10 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-11 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-12 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-13 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-14 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-15 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-16 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-17 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-18 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-19 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-20 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-21 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-22 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-23 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-24 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-25 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-26 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-27 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-28 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-29 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-09-30 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-01 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-02 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-03 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-04 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-05 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-06 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-07 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-08 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-09 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-10 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-11 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-12 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-13 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-14 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-15 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-16 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-17 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-18 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-19 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-20 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-21 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-22 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-23 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-24 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-25 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-26 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-27 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-28 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-29 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-30 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-10-31 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-01 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-02 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-03 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-04 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-05 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-06 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-07 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-08 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-09 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-10 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-11 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-12 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-13 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-14 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-15 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-16 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-17 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-18 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-19 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-20 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-21 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-22 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-23 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-24 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-25 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-26 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-27 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-28 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-29 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-11-30 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-01 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-02 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-03 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-04 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-05 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-06 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-07 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-08 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-09 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-10 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-11 00:00:00', 4.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-12 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-13 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-14 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-15 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-16 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-17 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-18 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-19 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-20 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-21 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-22 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-23 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-24 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-25 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-26 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-27 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-28 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-29 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-30 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2010-12-31 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-01 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-02 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-03 00:00:00', 1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-04 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-05 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-06 00:00:00', 1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-07 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-08 00:00:00', 1.32799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-09 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-10 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-11 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-12 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-13 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-14 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-15 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-16 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-17 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-18 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-19 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-20 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-21 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-22 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-23 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-24 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-25 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-26 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-27 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-28 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-29 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-30 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-01-31 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-01 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-02 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-03 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-04 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-05 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-06 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-07 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-08 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-09 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-10 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-11 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-12 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-13 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-14 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-15 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-16 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-17 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-18 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-19 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-20 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-21 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-22 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-23 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-24 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-25 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-26 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-27 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-02-28 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-01 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-02 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-03 00:00:00', 1.10399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-04 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-05 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-06 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-07 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-08 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-09 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-10 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-11 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-12 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-13 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-14 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-15 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-16 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-17 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-18 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-19 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-20 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-21 00:00:00', 1.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-22 00:00:00', 1.14900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-23 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-24 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-25 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-26 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-27 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-28 00:00:00', 1.16299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-29 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-30 00:00:00', 1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-03-31 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-01 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-02 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-03 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-04 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-05 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-06 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-07 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-08 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-09 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-10 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-11 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-12 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-13 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-14 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-15 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-16 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-17 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-18 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-19 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-20 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-21 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-22 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-23 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-24 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-25 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-26 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-27 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-28 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-29 00:00:00', 1.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-04-30 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-01 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-02 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-03 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-04 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-05 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-06 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-07 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-08 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-09 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-10 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-11 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-12 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-13 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-14 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-15 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-16 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-17 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-18 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-19 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-20 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-21 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-22 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-23 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-24 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-25 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-26 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-27 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-28 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-29 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-30 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-05-31 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-01 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-02 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-03 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-04 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-05 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-06 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-07 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-08 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-09 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-10 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-11 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-12 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-13 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-14 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-15 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-16 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-17 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-18 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-19 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-20 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-21 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-22 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-23 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-24 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-25 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-26 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-27 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-28 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-29 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-06-30 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-01 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-02 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-03 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-04 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-05 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-06 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-07 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-08 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-09 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-10 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-11 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-12 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-13 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-14 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-15 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-16 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-17 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-18 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-19 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-20 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-21 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-22 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-23 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-24 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-25 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-26 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-27 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-28 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-29 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-30 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-07-31 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-01 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-02 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-03 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-04 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-05 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-06 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-07 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-08 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-09 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-10 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-11 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-12 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-13 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-14 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-15 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-16 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-17 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-18 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-19 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-20 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-21 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-22 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-23 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-24 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-25 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-26 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-27 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-28 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-29 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-30 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-08-31 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-01 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-02 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-03 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-04 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-05 00:00:00', 0.972999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-06 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-07 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-08 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-09 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-10 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-11 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-12 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-13 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-14 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-15 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-16 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-17 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-18 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-19 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-20 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-21 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-22 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-23 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-24 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-25 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-26 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-27 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-28 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-29 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-09-30 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-01 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-02 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-03 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-04 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-05 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-06 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-07 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-08 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-09 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-10 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-11 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-12 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-13 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-14 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-15 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-16 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-17 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-18 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-19 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-20 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-21 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-22 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-23 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-24 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-25 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-26 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-27 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-28 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-29 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-30 00:00:00', 1.11000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-10-31 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-01 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-02 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-03 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-04 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-05 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-06 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-07 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-08 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-09 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-10 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-11 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-12 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-13 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-14 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-15 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-16 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-17 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-18 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-19 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-20 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-21 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-22 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-23 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-24 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-25 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-26 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-27 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-28 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-29 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-11-30 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-01 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-02 00:00:00', 1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-03 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-04 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-05 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-06 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-07 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-08 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-09 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-10 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-11 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-12 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-13 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-14 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-15 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-16 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-17 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-18 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-19 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-20 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-21 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-22 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-23 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-24 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-25 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-26 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-27 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-28 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-29 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-30 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2011-12-31 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-01 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-02 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-03 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-04 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-05 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-06 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-07 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-08 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-09 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-10 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-11 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-12 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-13 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-14 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-15 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-16 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-17 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-18 00:00:00', 1.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-19 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-20 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-21 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-22 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-23 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-24 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-25 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-26 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-27 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-28 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-29 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-30 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-01-31 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-01 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-02 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-03 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-04 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-05 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-06 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-07 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-08 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-09 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-10 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-11 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-12 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-13 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-14 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-15 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-16 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-17 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-18 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-19 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-20 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-21 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-22 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-23 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-24 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-25 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-26 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-27 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-28 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-02-29 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-01 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-02 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-03 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-04 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-05 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-06 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-07 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-08 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-09 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-10 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-11 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-12 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-13 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-14 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-15 00:00:00', 3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-16 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-17 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-18 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-19 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-20 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-21 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-22 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-23 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-24 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-25 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-26 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-27 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-28 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-29 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-30 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-03-31 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-01 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-02 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-03 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-04 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-05 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-06 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-07 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-08 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-09 00:00:00', 1.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-10 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-11 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-12 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-13 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-14 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-15 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-16 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-17 00:00:00', 1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-18 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-19 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-20 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-21 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-22 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-23 00:00:00', 1.0700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-24 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-25 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-26 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-27 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-28 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-29 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-04-30 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-01 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-02 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-03 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-04 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-05 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-06 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-07 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-08 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-09 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-10 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-11 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-12 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-13 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-14 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-15 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-16 00:00:00', 0.958000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-17 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-18 00:00:00', 1.0700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-19 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-20 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-21 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-22 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-23 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-24 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-25 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-26 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-27 00:00:00', 1.10099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-28 00:00:00', 1.00499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-29 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-30 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-05-31 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-01 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-02 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-03 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-04 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-05 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-06 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-07 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-08 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-09 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-10 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-11 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-12 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-13 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-14 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-15 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-16 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-17 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-18 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-19 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-20 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-21 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-22 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-23 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-24 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-25 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-26 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-27 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-28 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-29 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-06-30 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-01 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-02 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-03 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-04 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-05 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-06 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-07 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-08 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-09 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-10 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-11 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-12 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-13 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-14 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-15 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-16 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-17 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-18 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-19 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-20 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-21 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-22 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-23 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-24 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-25 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-26 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-27 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-28 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-29 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-30 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-07-31 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-01 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-02 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-03 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-04 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-05 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-06 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-07 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-08 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-09 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-10 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-11 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-12 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-13 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-14 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-15 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-16 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-17 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-18 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-19 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-20 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-21 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-22 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-23 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-24 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-25 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-26 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-27 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-28 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-29 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-30 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-08-31 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-01 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-02 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-03 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-04 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-05 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-06 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-07 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-08 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-09 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-10 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-11 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-12 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-13 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-14 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-15 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-16 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-17 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-18 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-19 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-20 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-21 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-22 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-23 00:00:00', 1.04100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-24 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-25 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-26 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-27 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-28 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-29 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-09-30 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-01 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-02 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-03 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-04 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-05 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-06 00:00:00', 1.00800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-07 00:00:00', 1.18299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-08 00:00:00', 1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-09 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-10 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-11 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-12 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-13 00:00:00', 1.16900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-14 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-15 00:00:00', 0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-16 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-17 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-18 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-19 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-20 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-21 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-22 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-23 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-24 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-25 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-26 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-27 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-28 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-29 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-30 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-10-31 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-01 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-02 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-03 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-04 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-05 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-06 00:00:00', 1.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-07 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-08 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-09 00:00:00', 1.13399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-10 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-11 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-12 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-13 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-14 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-15 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-16 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-17 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-18 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-19 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-20 00:00:00', 0.938000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-21 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-22 00:00:00', 1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-23 00:00:00', 1.02100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-24 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-25 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-26 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-27 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-28 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-29 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-11-30 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-01 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-02 00:00:00', 1.25899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-03 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-04 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-05 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-06 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-07 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-08 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-09 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-10 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-11 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-12 00:00:00', 1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-13 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-14 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-15 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-16 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-17 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-18 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-19 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-20 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-21 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-22 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-23 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-24 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-25 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-26 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-27 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-28 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-29 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-30 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2012-12-31 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-01 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-02 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-03 00:00:00', 1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-04 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-05 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-06 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-07 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-08 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-09 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-10 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-11 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-12 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-13 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-14 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-15 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-16 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-17 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-18 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-19 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-20 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-21 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-22 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-23 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-24 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-25 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-26 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-27 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-28 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-29 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-30 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-01-31 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-01 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-02 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-03 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-04 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-05 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-06 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-07 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-08 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-09 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-10 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-11 00:00:00', 1.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-12 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-13 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-14 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-15 00:00:00', 1.03799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-16 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-17 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-18 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-19 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-20 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-21 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-22 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-23 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-24 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-25 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-26 00:00:00', 0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-27 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-02-28 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-01 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-02 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-03 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-04 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-05 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-06 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-07 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-08 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-09 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-10 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-11 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-12 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-13 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-14 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-15 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-16 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-17 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-18 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-19 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-20 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-21 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-22 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-23 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-24 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-25 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-26 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-27 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-28 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-29 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-30 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-03-31 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-01 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-02 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-03 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-04 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-05 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-06 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-07 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-08 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-09 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-10 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-11 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-12 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-13 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-14 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-15 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-16 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-17 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-18 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-19 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-20 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-21 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-22 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-23 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-24 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-25 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-26 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-27 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-28 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-29 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-04-30 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-01 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-02 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-03 00:00:00', 1.10399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-04 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-05 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-06 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-07 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-08 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-09 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-10 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-11 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-12 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-13 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-14 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-15 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-16 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-17 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-18 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-19 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-20 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-21 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-22 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-23 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-24 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-25 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-26 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-27 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-28 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-29 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-30 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-05-31 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-01 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-02 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-03 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-04 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-05 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-06 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-07 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-08 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-09 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-10 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-11 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-12 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-13 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-14 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-15 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-16 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-17 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-18 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-19 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-20 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-21 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-22 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-23 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-24 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-25 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-26 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-27 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-28 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-29 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-06-30 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-01 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-02 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-03 00:00:00', 1.28199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-04 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-05 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-06 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-07 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-08 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-09 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-10 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-11 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-12 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-13 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-14 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-15 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-16 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-17 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-18 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-19 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-20 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-21 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-22 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-23 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-24 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-25 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-26 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-27 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-28 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-29 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-30 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-07-31 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-01 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-02 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-03 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-04 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-05 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-06 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-07 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-08 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-09 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-10 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-11 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-12 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-13 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-14 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-15 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-16 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-17 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-18 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-19 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-20 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-21 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-22 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-23 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-24 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-25 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-26 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-27 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-28 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-29 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-30 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-08-31 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-01 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-02 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-03 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-04 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-05 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-06 00:00:00', 1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-07 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-08 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-09 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-10 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-11 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-12 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-13 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-14 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-15 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-16 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-17 00:00:00', 1.14900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-18 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-19 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-20 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-21 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-22 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-23 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-24 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-25 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-26 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-27 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-28 00:00:00', 1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-29 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-09-30 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-01 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-02 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-03 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-04 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-05 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-06 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-07 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-08 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-09 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-10 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-11 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-12 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-13 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-14 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-15 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-16 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-17 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-18 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-19 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-20 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-21 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-22 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-23 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-24 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-25 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-26 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-27 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-28 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-29 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-30 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-10-31 00:00:00', 1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-01 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-02 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-03 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-04 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-05 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-06 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-07 00:00:00', 0.922999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-08 00:00:00', 0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-09 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-10 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-11 00:00:00', 1.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-12 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-13 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-14 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-15 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-16 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-17 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-18 00:00:00', 1.13699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-19 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-20 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-21 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-22 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-23 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-24 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-25 00:00:00', 1.12699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-26 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-27 00:00:00', 1.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-28 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-29 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-11-30 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-01 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-02 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-03 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-04 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-05 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-06 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-07 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-08 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-09 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-10 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-11 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-12 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-13 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-14 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-15 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-16 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-17 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-18 00:00:00', 1.16900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-19 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-20 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-21 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-22 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-23 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-24 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-25 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-26 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-27 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-28 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-29 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-30 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2013-12-31 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-01 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-02 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-03 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-04 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-05 00:00:00', 0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-06 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-07 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-08 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-09 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-10 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-11 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-12 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-13 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-14 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-15 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-16 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-17 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-18 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-19 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-20 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-21 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-22 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-23 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-24 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-25 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-26 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-27 00:00:00', 0.954999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-28 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-29 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-30 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-01-31 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-01 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-02 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-03 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-04 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-05 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-06 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-07 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-08 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-09 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-10 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-11 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-12 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-13 00:00:00', 1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-14 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-15 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-16 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-17 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-18 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-19 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-20 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-21 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-22 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-23 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-24 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-25 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-26 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-27 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-02-28 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-01 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-02 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-03 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-04 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-05 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-06 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-07 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-08 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-09 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-10 00:00:00', 1.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-11 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-12 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-13 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-14 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-15 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-16 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-17 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-18 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-19 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-20 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-21 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-22 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-23 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-24 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-25 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-26 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-27 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-28 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-29 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-30 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-03-31 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-01 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-02 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-03 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-04 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-05 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-06 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-07 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-08 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-09 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-10 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-11 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-12 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-13 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-14 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-15 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-16 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-17 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-18 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-19 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-20 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-21 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-22 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-23 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-24 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-25 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-26 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-27 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-28 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-29 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-04-30 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-01 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-02 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-03 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-04 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-05 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-06 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-07 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-08 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-09 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-10 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-11 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-12 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-13 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-14 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-15 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-16 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-17 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-18 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-19 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-20 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-21 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-22 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-23 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-24 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-25 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-26 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-27 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-28 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-29 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-30 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-05-31 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-01 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-02 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-03 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-04 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-05 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-06 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-07 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-08 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-09 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-10 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-11 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-12 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-13 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-14 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-15 00:00:00', 1.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-16 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-17 00:00:00', 1.10099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-18 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-19 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-20 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-21 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-22 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-23 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-24 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-25 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-26 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-27 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-28 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-29 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-06-30 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-01 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-02 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-03 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-04 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-05 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-06 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-07 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-08 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-09 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-10 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-11 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-12 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-13 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-14 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-15 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-16 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-17 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-18 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-19 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-20 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-21 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-22 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-23 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-24 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-25 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-26 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-27 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-28 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-29 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-30 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (31, '2014-07-31 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-01 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-02 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-03 00:00:00', 6.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-04 00:00:00', 7.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-05 00:00:00', 6.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-06 00:00:00', 5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-07 00:00:00', 8.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-08 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-09 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-10 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-11 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-12 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-13 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-14 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-15 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-16 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-17 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-18 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-19 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-20 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-21 00:00:00', 6.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-22 00:00:00', 7.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-23 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-24 00:00:00', 7.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-25 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-26 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-27 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-28 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-29 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-30 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-01-31 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-01 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-02 00:00:00', 6.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-03 00:00:00', 6.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-04 00:00:00', 5.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-05 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-06 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-07 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-08 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-09 00:00:00', 7.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-10 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-11 00:00:00', 7.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-12 00:00:00', 6.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-13 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-14 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-15 00:00:00', 4.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-16 00:00:00', 6.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-17 00:00:00', 6.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-18 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-19 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-20 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-21 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-22 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-23 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-24 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-25 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-26 00:00:00', 6.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-27 00:00:00', 5.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-02-28 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-01 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-02 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-03 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-04 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-05 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-06 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-07 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-08 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-09 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-10 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-11 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-12 00:00:00', 5.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-13 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-14 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-15 00:00:00', 5.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-16 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-17 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-18 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-19 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-20 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-21 00:00:00', 5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-22 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-23 00:00:00', 5.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-24 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-25 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-26 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-27 00:00:00', 6.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-28 00:00:00', 6.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-29 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-30 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-03-31 00:00:00', 5.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-01 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-02 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-03 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-04 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-05 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-06 00:00:00', 5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-07 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-08 00:00:00', 5.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-09 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-10 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-11 00:00:00', 6.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-12 00:00:00', 6.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-13 00:00:00', 7.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-14 00:00:00', 4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-15 00:00:00', 6.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-16 00:00:00', 7.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-17 00:00:00', 6.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-18 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-19 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-20 00:00:00', 7.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-21 00:00:00', 7.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-22 00:00:00', 7.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-23 00:00:00', 8.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-24 00:00:00', 6.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-25 00:00:00', 6.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-26 00:00:00', 7.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-27 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-28 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-29 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-04-30 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-01 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-02 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-03 00:00:00', 5.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-04 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-05 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-06 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-07 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-08 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-09 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-10 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-11 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-12 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-13 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-14 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-15 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-16 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-17 00:00:00', 6.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-18 00:00:00', 5.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-19 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-20 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-21 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-22 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-23 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-24 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-25 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-26 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-27 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-28 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-29 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-30 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-05-31 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-01 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-02 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-03 00:00:00', 6.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-04 00:00:00', 6.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-05 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-06 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-07 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-08 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-09 00:00:00', 5.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-10 00:00:00', 4.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-11 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-12 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-13 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-14 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-15 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-16 00:00:00', 5.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-17 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-18 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-19 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-20 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-21 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-22 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-23 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-24 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-25 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-26 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-27 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-28 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-29 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-06-30 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-01 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-02 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-03 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-04 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-05 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-06 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-07 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-08 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-09 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-10 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-11 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-12 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-13 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-14 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-15 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-16 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-17 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-18 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-19 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-20 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-21 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-22 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-23 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-24 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-25 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-26 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-27 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-28 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-29 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-30 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-07-31 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-01 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-02 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-03 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-04 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-05 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-06 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-07 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-08 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-09 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-10 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-11 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-12 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-13 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-14 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-15 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-16 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-17 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-18 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-19 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-20 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-21 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-22 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-23 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-24 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-25 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-26 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-27 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-28 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-29 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-30 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-08-31 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-01 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-02 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-03 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-04 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-05 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-06 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-07 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-08 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-09 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-10 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-11 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-12 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-13 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-14 00:00:00', 3.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-15 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-16 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-17 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-18 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-19 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-20 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-21 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-22 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-23 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-24 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-25 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-26 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-27 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-28 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-29 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-09-30 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-01 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-02 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-03 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-04 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-05 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-06 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-07 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-08 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-09 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-10 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-11 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-12 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-13 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-14 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-15 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-16 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-17 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-18 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-19 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-20 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-21 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-22 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-23 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-24 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-25 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-26 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-27 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-28 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-29 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-30 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-10-31 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-01 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-02 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-03 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-04 00:00:00', 4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-05 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-06 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-07 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-08 00:00:00', 0.930999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-09 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-10 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-11 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-12 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-13 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-14 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-15 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-16 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-17 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-18 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-19 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-20 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-21 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-22 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-23 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-24 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-25 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-26 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-27 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-28 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-29 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-11-30 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-01 00:00:00', 8.00100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-02 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-03 00:00:00', 5.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-04 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-05 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-06 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-07 00:00:00', 6.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-08 00:00:00', 7.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-09 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-10 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-11 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-12 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-13 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-14 00:00:00', 5.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-15 00:00:00', 4.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-16 00:00:00', 6.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-17 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-18 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-19 00:00:00', 4.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-20 00:00:00', 6.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-21 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-22 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-23 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-24 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-25 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-26 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-27 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-28 00:00:00', 6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-29 00:00:00', 4.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-30 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1979-12-31 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-01 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-02 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-03 00:00:00', 5.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-04 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-05 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-06 00:00:00', 7.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-07 00:00:00', 7.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-08 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-09 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-10 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-11 00:00:00', 6.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-12 00:00:00', 6.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-13 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-14 00:00:00', 8.15200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-15 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-16 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-17 00:00:00', 6.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-18 00:00:00', 5.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-19 00:00:00', 5.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-20 00:00:00', 5.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-21 00:00:00', 7.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-22 00:00:00', 7.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-23 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-24 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-25 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-26 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-27 00:00:00', 5.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-28 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-29 00:00:00', 7.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-30 00:00:00', 6.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-01-31 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-01 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-02 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-03 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-04 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-05 00:00:00', 6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-06 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-07 00:00:00', 5.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-08 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-09 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-10 00:00:00', 5.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-11 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-12 00:00:00', 7.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-13 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-14 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-15 00:00:00', 4.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-16 00:00:00', 5.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-17 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-18 00:00:00', 7.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-19 00:00:00', 6.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-20 00:00:00', 4.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-21 00:00:00', 5.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-22 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-23 00:00:00', 6.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-24 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-25 00:00:00', 7.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-26 00:00:00', 4.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-27 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-28 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-02-29 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-01 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-02 00:00:00', 7.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-03 00:00:00', 6.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-04 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-05 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-06 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-07 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-08 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-09 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-10 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-11 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-12 00:00:00', 5.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-13 00:00:00', 6.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-14 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-15 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-16 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-17 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-18 00:00:00', 4.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-19 00:00:00', 7.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-20 00:00:00', 5.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-21 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-22 00:00:00', 4.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-23 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-24 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-25 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-26 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-27 00:00:00', 6.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-28 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-29 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-30 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-03-31 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-01 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-02 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-03 00:00:00', 6.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-04 00:00:00', 6.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-05 00:00:00', 6.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-06 00:00:00', 5.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-07 00:00:00', 5.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-08 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-09 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-10 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-11 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-12 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-13 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-14 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-15 00:00:00', 5.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-16 00:00:00', 6.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-17 00:00:00', 7.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-18 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-19 00:00:00', 5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-20 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-21 00:00:00', 4.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-22 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-23 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-24 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-25 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-26 00:00:00', 5.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-27 00:00:00', 6.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-28 00:00:00', 6.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-29 00:00:00', 7.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-04-30 00:00:00', 6.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-01 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-02 00:00:00', 5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-03 00:00:00', 5.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-04 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-05 00:00:00', 4.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-06 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-07 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-08 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-09 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-10 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-11 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-12 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-13 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-14 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-15 00:00:00', 5.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-16 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-17 00:00:00', 4.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-18 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-19 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-20 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-21 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-22 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-23 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-24 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-25 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-26 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-27 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-28 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-29 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-30 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-05-31 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-01 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-02 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-03 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-04 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-05 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-06 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-07 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-08 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-09 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-10 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-11 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-12 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-13 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-14 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-15 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-16 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-17 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-18 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-19 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-20 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-21 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-22 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-23 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-24 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-25 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-26 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-27 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-28 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-29 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-06-30 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-01 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-02 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-03 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-04 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-05 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-06 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-07 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-08 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-09 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-10 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-11 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-12 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-13 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-14 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-15 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-16 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-17 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-18 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-19 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-20 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-21 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-22 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-23 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-24 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-25 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-26 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-27 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-28 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-29 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-30 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-07-31 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-01 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-02 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-03 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-04 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-05 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-06 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-07 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-08 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-09 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-10 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-11 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-12 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-13 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-14 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-15 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-16 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-17 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-18 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-19 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-20 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-21 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-22 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-23 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-24 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-25 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-26 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-27 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-28 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-29 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-30 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-08-31 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-01 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-02 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-03 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-04 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-05 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-06 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-07 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-08 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-09 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-10 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-11 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-12 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-13 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-14 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-15 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-16 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-17 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-18 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-19 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-20 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-21 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-22 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-23 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-24 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-25 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-26 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-27 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-28 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-29 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-09-30 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-01 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-02 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-03 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-04 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-05 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-06 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-07 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-08 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-09 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-10 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-11 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-12 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-13 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-14 00:00:00', 5.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-15 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-16 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-17 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-18 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-19 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-20 00:00:00', 5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-21 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-22 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-23 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-24 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-25 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-26 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-27 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-28 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-29 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-30 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-10-31 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-01 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-02 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-03 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-04 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-05 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-06 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-07 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-08 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-09 00:00:00', 4.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-10 00:00:00', 4.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-11 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-12 00:00:00', 6.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-13 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-14 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-15 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-16 00:00:00', 6.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-17 00:00:00', 6.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-18 00:00:00', 5.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-19 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-20 00:00:00', 4.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-21 00:00:00', 5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-22 00:00:00', 5.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-23 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-24 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-25 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-26 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-27 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-28 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-29 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-11-30 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-01 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-02 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-03 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-04 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-05 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-06 00:00:00', 6.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-07 00:00:00', 6.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-08 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-09 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-10 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-11 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-12 00:00:00', 7.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-13 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-14 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-15 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-16 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-17 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-18 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-19 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-20 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-21 00:00:00', 0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-22 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-23 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-24 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-25 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-26 00:00:00', 6.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-27 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-28 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-29 00:00:00', 6.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-30 00:00:00', 6.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1980-12-31 00:00:00', 6.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-01 00:00:00', 5.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-02 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-03 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-04 00:00:00', 6.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-05 00:00:00', 5.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-06 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-07 00:00:00', 5.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-08 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-09 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-10 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-11 00:00:00', 6.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-12 00:00:00', 6.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-13 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-14 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-15 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-16 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-17 00:00:00', 6.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-18 00:00:00', 6.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-19 00:00:00', 6.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-20 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-21 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-22 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-23 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-24 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-25 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-26 00:00:00', 7.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-27 00:00:00', 6.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-28 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-29 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-30 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-01-31 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-01 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-02 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-03 00:00:00', 6.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-04 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-05 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-06 00:00:00', 4.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-07 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-08 00:00:00', 4.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-09 00:00:00', 6.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-10 00:00:00', 6.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-11 00:00:00', 6.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-12 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-13 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-14 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-15 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-16 00:00:00', 6.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-17 00:00:00', 7.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-18 00:00:00', 6.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-19 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-20 00:00:00', 6.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-21 00:00:00', 5.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-22 00:00:00', 5.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-23 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-24 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-25 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-26 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-27 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-02-28 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-01 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-02 00:00:00', 7.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-03 00:00:00', 6.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-04 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-05 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-06 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-07 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-08 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-09 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-10 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-11 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-12 00:00:00', 7.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-13 00:00:00', 7.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-14 00:00:00', 6.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-15 00:00:00', 6.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-16 00:00:00', 5.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-17 00:00:00', 5.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-18 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-19 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-20 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-21 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-22 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-23 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-24 00:00:00', 4.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-25 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-26 00:00:00', 4.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-27 00:00:00', 6.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-28 00:00:00', 7.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-29 00:00:00', 5.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-30 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-03-31 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-01 00:00:00', 5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-02 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-03 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-04 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-05 00:00:00', 6.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-06 00:00:00', 7.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-07 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-08 00:00:00', 6.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-09 00:00:00', 7.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-10 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-11 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-12 00:00:00', 6.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-13 00:00:00', 6.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-14 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-15 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-16 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-17 00:00:00', 5.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-18 00:00:00', 5.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-19 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-20 00:00:00', 1.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-21 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-22 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-23 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-24 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-25 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-26 00:00:00', 5.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-27 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-28 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-29 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-04-30 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-01 00:00:00', 5.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-02 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-03 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-04 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-05 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-06 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-07 00:00:00', 4.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-08 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-09 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-10 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-11 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-12 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-13 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-14 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-15 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-16 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-17 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-18 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-19 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-20 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-21 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-22 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-23 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-24 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-25 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-26 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-27 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-28 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-29 00:00:00', 3.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-30 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-05-31 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-01 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-02 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-03 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-04 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-05 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-06 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-07 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-08 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-09 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-10 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-11 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-12 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-13 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-14 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-15 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-16 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-17 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-18 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-19 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-20 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-21 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-22 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-23 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-24 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-25 00:00:00', 4.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-26 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-27 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-28 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-29 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-06-30 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-01 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-02 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-03 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-04 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-05 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-06 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-07 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-08 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-09 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-10 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-11 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-12 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-13 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-14 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-15 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-16 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-17 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-18 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-19 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-20 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-21 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-22 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-23 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-24 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-25 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-26 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-27 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-28 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-29 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-30 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-07-31 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-01 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-02 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-03 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-04 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-05 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-06 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-07 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-08 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-09 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-10 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-11 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-12 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-13 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-14 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-15 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-16 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-17 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-18 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-19 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-20 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-21 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-22 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-23 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-24 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-25 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-26 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-27 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-28 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-29 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-30 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-08-31 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-01 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-02 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-03 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-04 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-05 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-06 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-07 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-08 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-09 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-10 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-11 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-12 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-13 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-14 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-15 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-16 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-17 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-18 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-19 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-20 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-21 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-22 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-23 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-24 00:00:00', 1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-25 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-26 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-27 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-28 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-29 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-09-30 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-01 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-02 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-03 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-04 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-05 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-06 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-07 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-08 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-09 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-10 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-11 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-12 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-13 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-14 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-15 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-16 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-17 00:00:00', 5.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-18 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-19 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-20 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-21 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-22 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-23 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-24 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-25 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-26 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-27 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-28 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-29 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-30 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-10-31 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-01 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-02 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-03 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-04 00:00:00', 5.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-05 00:00:00', 4.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-06 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-07 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-08 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-09 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-10 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-11 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-12 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-13 00:00:00', 5.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-14 00:00:00', 5.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-15 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-16 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-17 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-18 00:00:00', 5.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-19 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-20 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-21 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-22 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-23 00:00:00', 5.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-24 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-25 00:00:00', 4.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-26 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-27 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-28 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-29 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-11-30 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-01 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-02 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-03 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-04 00:00:00', 7.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-05 00:00:00', 7.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-06 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-07 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-08 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-09 00:00:00', 5.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-10 00:00:00', 6.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-11 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-12 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-13 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-14 00:00:00', 6.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-15 00:00:00', 7.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-16 00:00:00', 7.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-17 00:00:00', 6.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-18 00:00:00', 6.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-19 00:00:00', 6.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-20 00:00:00', 6.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-21 00:00:00', 6.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-22 00:00:00', 7.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-23 00:00:00', 6.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-24 00:00:00', 6.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-25 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-26 00:00:00', 6.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-27 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-28 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-29 00:00:00', 6.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-30 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1981-12-31 00:00:00', 6.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-01 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-02 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-03 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-04 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-05 00:00:00', 5.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-06 00:00:00', 6.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-07 00:00:00', 6.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-08 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-09 00:00:00', 6.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-10 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-11 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-12 00:00:00', 5.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-13 00:00:00', 5.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-14 00:00:00', 7.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-15 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-16 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-17 00:00:00', 6.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-18 00:00:00', 5.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-19 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-20 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-21 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-22 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-23 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-24 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-25 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-26 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-27 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-28 00:00:00', 6.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-29 00:00:00', 9.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-30 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-01-31 00:00:00', 6.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-01 00:00:00', 8.57400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-02 00:00:00', 5.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-03 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-04 00:00:00', 6.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-05 00:00:00', 7.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-06 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-07 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-08 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-09 00:00:00', 6.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-10 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-11 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-12 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-13 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-14 00:00:00', 7.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-15 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-16 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-17 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-18 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-19 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-20 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-21 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-22 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-23 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-24 00:00:00', 5.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-25 00:00:00', 5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-26 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-27 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-02-28 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-01 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-02 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-03 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-04 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-05 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-06 00:00:00', 1.16299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-07 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-08 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-09 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-10 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-11 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-12 00:00:00', 6.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-13 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-14 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-15 00:00:00', 5.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-16 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-17 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-18 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-19 00:00:00', 7.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-20 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-21 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-22 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-23 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-24 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-25 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-26 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-27 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-28 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-29 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-30 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-03-31 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-01 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-02 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-03 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-04 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-05 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-06 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-07 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-08 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-09 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-10 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-11 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-12 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-13 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-14 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-15 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-16 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-17 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-18 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-19 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-20 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-21 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-22 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-23 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-24 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-25 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-26 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-27 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-28 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-29 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-04-30 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-01 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-02 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-03 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-04 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-05 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-06 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-07 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-08 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-09 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-10 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-11 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-12 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-13 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-14 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-15 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-16 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-17 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-18 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-19 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-20 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-21 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-22 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-23 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-24 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-25 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-26 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-27 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-28 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-29 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-30 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-05-31 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-01 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-02 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-03 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-04 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-05 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-06 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-07 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-08 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-09 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-10 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-11 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-12 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-13 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-14 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-15 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-16 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-17 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-18 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-19 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-20 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-21 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-22 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-23 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-24 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-25 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-26 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-27 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-28 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-29 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-06-30 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-01 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-02 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-03 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-04 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-05 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-06 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-07 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-08 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-09 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-10 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-11 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-12 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-13 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-14 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-15 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-16 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-17 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-18 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-19 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-20 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-21 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-22 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-23 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-24 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-25 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-26 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-27 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-28 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-29 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-30 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-07-31 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-01 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-02 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-03 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-04 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-05 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-06 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-07 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-08 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-09 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-10 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-11 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-12 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-13 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-14 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-15 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-16 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-17 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-18 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-19 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-20 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-21 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-22 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-23 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-24 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-25 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-26 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-27 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-28 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-29 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-30 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-08-31 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-01 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-02 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-03 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-04 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-05 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-06 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-07 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-08 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-09 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-10 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-11 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-12 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-13 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-14 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-15 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-16 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-17 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-18 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-19 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-20 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-21 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-22 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-23 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-24 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-25 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-26 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-27 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-28 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-29 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-09-30 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-01 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-02 00:00:00', 5.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-03 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-04 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-05 00:00:00', 4.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-06 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-07 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-08 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-09 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-10 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-11 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-12 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-13 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-14 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-15 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-16 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-17 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-18 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-19 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-20 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-21 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-22 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-23 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-24 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-25 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-26 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-27 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-28 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-29 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-30 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-10-31 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-01 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-02 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-03 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-04 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-05 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-06 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-07 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-08 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-09 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-10 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-11 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-12 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-13 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-14 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-15 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-16 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-17 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-18 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-19 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-20 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-21 00:00:00', 4.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-22 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-23 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-24 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-25 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-26 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-27 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-28 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-29 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-11-30 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-01 00:00:00', 1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-02 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-03 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-04 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-05 00:00:00', 5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-06 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-07 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-08 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-09 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-10 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-11 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-12 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-13 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-14 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-15 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-16 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-17 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-18 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-19 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-20 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-21 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-22 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-23 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-24 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-25 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-26 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-27 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-28 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-29 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-30 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1982-12-31 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-01 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-02 00:00:00', 6.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-03 00:00:00', 5.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-04 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-05 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-06 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-07 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-08 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-09 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-10 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-11 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-12 00:00:00', 4.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-13 00:00:00', 6.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-14 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-15 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-16 00:00:00', 5.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-17 00:00:00', 5.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-18 00:00:00', 6.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-19 00:00:00', 5.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-20 00:00:00', 6.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-21 00:00:00', 6.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-22 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-23 00:00:00', 6.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-24 00:00:00', 6.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-25 00:00:00', 5.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-26 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-27 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-28 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-29 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-30 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-01-31 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-01 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-02 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-03 00:00:00', 4.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-04 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-05 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-06 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-07 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-08 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-09 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-10 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-11 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-12 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-13 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-14 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-15 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-16 00:00:00', 4.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-17 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-18 00:00:00', 6.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-19 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-20 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-21 00:00:00', 5.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-22 00:00:00', 6.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-23 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-24 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-25 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-26 00:00:00', 6.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-27 00:00:00', 7.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-02-28 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-01 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-02 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-03 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-04 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-05 00:00:00', 6.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-06 00:00:00', 7.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-07 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-08 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-09 00:00:00', 6.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-10 00:00:00', 5.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-11 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-12 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-13 00:00:00', 5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-14 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-15 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-16 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-17 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-18 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-19 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-20 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-21 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-22 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-23 00:00:00', 5.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-24 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-25 00:00:00', 1.32799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-26 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-27 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-28 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-29 00:00:00', 5.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-30 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-03-31 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-01 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-02 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-03 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-04 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-05 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-06 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-07 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-08 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-09 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-10 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-11 00:00:00', 4.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-12 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-13 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-14 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-15 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-16 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-17 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-18 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-19 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-20 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-21 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-22 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-23 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-24 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-25 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-26 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-27 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-28 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-29 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-04-30 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-01 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-02 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-03 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-04 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-05 00:00:00', 5.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-06 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-07 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-08 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-09 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-10 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-11 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-12 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-13 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-14 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-15 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-16 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-17 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-18 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-19 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-20 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-21 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-22 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-23 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-24 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-25 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-26 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-27 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-28 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-29 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-30 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-05-31 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-01 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-02 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-03 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-04 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-05 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-06 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-07 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-08 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-09 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-10 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-11 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-12 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-13 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-14 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-15 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-16 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-17 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-18 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-19 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-20 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-21 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-22 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-23 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-24 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-25 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-26 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-27 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-28 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-29 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-06-30 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-01 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-02 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-03 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-04 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-05 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-06 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-07 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-08 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-09 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-10 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-11 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-12 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-13 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-14 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-15 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-16 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-17 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-18 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-19 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-20 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-21 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-22 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-23 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-24 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-25 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-26 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-27 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-28 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-29 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-30 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-07-31 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-01 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-02 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-03 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-04 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-05 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-06 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-07 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-08 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-09 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-10 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-11 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-12 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-13 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-14 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-15 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-16 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-17 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-18 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-19 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-20 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-21 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-22 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-23 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-24 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-25 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-26 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-27 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-28 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-29 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-30 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-08-31 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-01 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-03 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-05 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-07 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-09 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-11 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-13 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-15 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-17 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-19 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-21 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-23 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-25 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-27 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-29 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-01 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-03 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-05 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-07 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-09 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-11 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-13 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-15 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-17 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-19 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-21 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-23 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-25 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-27 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-29 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-30 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-10-31 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-01 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-02 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-03 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-04 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-05 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-06 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-07 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-08 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-09 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-10 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-11 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-12 00:00:00', 5.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-13 00:00:00', 6.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-14 00:00:00', 5.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-15 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-16 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-17 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-18 00:00:00', 5.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-19 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-20 00:00:00', 4.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-21 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-22 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-23 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-24 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-25 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-26 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-27 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-28 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-29 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-11-30 00:00:00', 5.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-01 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-02 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-03 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-04 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-05 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-06 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-07 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-08 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-09 00:00:00', 6.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-10 00:00:00', 5.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-11 00:00:00', 5.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-12 00:00:00', 6.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-13 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-14 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-15 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-16 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-17 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-18 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-19 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-20 00:00:00', 1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-21 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-22 00:00:00', 1.0140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-23 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-24 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-25 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-26 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-27 00:00:00', 5.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-28 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-29 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-30 00:00:00', 6.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1983-12-31 00:00:00', 5.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-01 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-02 00:00:00', 7.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-03 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-04 00:00:00', 5.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-05 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-06 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-07 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-08 00:00:00', 5.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-09 00:00:00', 7.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-10 00:00:00', 5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-11 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-12 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-13 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-14 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-15 00:00:00', 5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-16 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-17 00:00:00', 5.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-18 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-19 00:00:00', 4.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-20 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-21 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-22 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-23 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-24 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-25 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-26 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-27 00:00:00', 4.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-28 00:00:00', 4.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-29 00:00:00', 5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-30 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-01-31 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-01 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-02 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-03 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-04 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-05 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-06 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-07 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-08 00:00:00', 7.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-09 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-10 00:00:00', 4.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-11 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-12 00:00:00', 7.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-13 00:00:00', 6.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-14 00:00:00', 6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-15 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-16 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-17 00:00:00', 1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-18 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-19 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-20 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-21 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-22 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-23 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-24 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-25 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-26 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-27 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-28 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-02-29 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-01 00:00:00', 6.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-02 00:00:00', 6.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-03 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-04 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-05 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-06 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-07 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-08 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-09 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-10 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-11 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-12 00:00:00', 5.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-13 00:00:00', 5.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-14 00:00:00', 4.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-15 00:00:00', 5.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-16 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-17 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-18 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-19 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-20 00:00:00', 5.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-21 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-22 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-23 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-24 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-25 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-26 00:00:00', 6.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-27 00:00:00', 6.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-28 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-29 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-30 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-03-31 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-01 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-02 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-03 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-04 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-05 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-06 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-07 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-08 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-09 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-10 00:00:00', 7.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-11 00:00:00', 5.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-12 00:00:00', 6.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-13 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-14 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-15 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-16 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-17 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-18 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-19 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-20 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-21 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-22 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-23 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-24 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-25 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-26 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-27 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-28 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-29 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-04-30 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-01 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-02 00:00:00', 6.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-03 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-04 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-05 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-06 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-07 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-08 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-09 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-10 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-11 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-12 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-13 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-14 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-15 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-16 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-17 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-18 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-19 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-20 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-21 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-22 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-23 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-24 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-25 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-26 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-27 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-28 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-29 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-30 00:00:00', 5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-05-31 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-01 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-02 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-03 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-04 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-05 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-06 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-07 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-08 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-09 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-10 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-11 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-12 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-13 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-14 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-15 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-16 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-17 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-18 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-19 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-20 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-21 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-22 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-23 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-24 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-25 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-26 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-27 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-28 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-29 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-06-30 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-01 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-02 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-03 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-04 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-05 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-06 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-07 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-08 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-09 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-10 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-11 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-12 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-13 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-14 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-15 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-16 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-17 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-18 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-19 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-20 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-21 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-22 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-23 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-24 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-25 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-26 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-27 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-28 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-29 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-30 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-07-31 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-01 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-02 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-03 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-04 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-05 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-06 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-07 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-08 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-09 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-10 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-11 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-12 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-13 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-14 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-15 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-16 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-17 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-18 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-19 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-20 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-21 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-22 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-23 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-24 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-25 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-26 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-27 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-28 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-29 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-30 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-08-31 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-01 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-02 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-03 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-04 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-05 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-06 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-07 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-08 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-09 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-10 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-11 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-12 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-13 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-14 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-15 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-16 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-17 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-18 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-19 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-20 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-21 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-22 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-23 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-24 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-25 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-26 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-27 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-28 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-29 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-09-30 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-01 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-02 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-03 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-04 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-05 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-06 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-07 00:00:00', 5.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-08 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-09 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-10 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-11 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-12 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-13 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-14 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-15 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-16 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-17 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-18 00:00:00', 5.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-19 00:00:00', 5.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-20 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-21 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-22 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-23 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-24 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-25 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-26 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-27 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-28 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-29 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-30 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-10-31 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-01 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-02 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-03 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-04 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-05 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-06 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-07 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-08 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-09 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-10 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-11 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-12 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-13 00:00:00', 5.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-14 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-15 00:00:00', 4.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-16 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-17 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-18 00:00:00', 5.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-19 00:00:00', 5.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-20 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-21 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-22 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-23 00:00:00', 5.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-24 00:00:00', 5.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-25 00:00:00', 5.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-26 00:00:00', 6.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-27 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-28 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-29 00:00:00', 6.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-11-30 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-01 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-02 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-03 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-04 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-05 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-06 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-07 00:00:00', 5.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-08 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-09 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-10 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-11 00:00:00', 4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-12 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-13 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-14 00:00:00', 6.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-15 00:00:00', 5.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-16 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-17 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-18 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-19 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-20 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-21 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-22 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-23 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-24 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-25 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-26 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-27 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-28 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-29 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-30 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1984-12-31 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-01 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-02 00:00:00', 7.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-03 00:00:00', 7.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-04 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-05 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-06 00:00:00', 6.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-07 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-08 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-09 00:00:00', 5.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-10 00:00:00', 5.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-11 00:00:00', 6.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-12 00:00:00', 6.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-13 00:00:00', 5.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-14 00:00:00', 5.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-15 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-16 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-17 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-18 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-19 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-20 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-21 00:00:00', 7.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-22 00:00:00', 6.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-23 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-24 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-25 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-26 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-27 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-28 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-29 00:00:00', 5.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-30 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-01-31 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-01 00:00:00', 7.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-02 00:00:00', 7.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-03 00:00:00', 6.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-04 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-05 00:00:00', 6.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-06 00:00:00', 7.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-07 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-08 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-09 00:00:00', 7.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-10 00:00:00', 5.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-11 00:00:00', 6.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-12 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-13 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-14 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-15 00:00:00', 5.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-16 00:00:00', 6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-17 00:00:00', 5.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-18 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-19 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-20 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-21 00:00:00', 6.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-22 00:00:00', 7.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-23 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-24 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-25 00:00:00', 6.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-26 00:00:00', 8.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-27 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-02-28 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-01 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-02 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-03 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-04 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-05 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-06 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-07 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-08 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-09 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-10 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-11 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-12 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-13 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-14 00:00:00', 4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-15 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-16 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-17 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-18 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-19 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-20 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-21 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-22 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-23 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-24 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-25 00:00:00', 7.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-26 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-27 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-28 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-29 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-30 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-03-31 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-01 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-02 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-03 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-04 00:00:00', 5.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-05 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-06 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-07 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-08 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-09 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-10 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-11 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-12 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-13 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-14 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-15 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-16 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-17 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-18 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-19 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-20 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-21 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-22 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-23 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-24 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-25 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-26 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-27 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-28 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-29 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-04-30 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-01 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-02 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-03 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-04 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-05 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-06 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-07 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-08 00:00:00', 1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-09 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-10 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-11 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-12 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-13 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-14 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-15 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-16 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-17 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-18 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-19 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-20 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-21 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-22 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-23 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-24 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-25 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-26 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-27 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-28 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-29 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-30 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-05-31 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-01 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-02 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-03 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-04 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-05 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-06 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-07 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-08 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-09 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-10 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-11 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-12 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-13 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-14 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-15 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-16 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-17 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-18 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-19 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-20 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-21 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-22 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-23 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-24 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-25 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-26 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-27 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-28 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-29 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-06-30 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-01 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-02 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-03 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-04 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-05 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-06 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-07 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-08 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-09 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-10 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-11 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-12 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-13 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-14 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-15 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-16 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-17 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-18 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-19 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-20 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-21 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-22 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-23 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-24 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-25 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-26 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-27 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-28 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-29 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-30 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-07-31 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-01 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-02 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-03 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-04 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-05 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-06 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-07 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-08 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-09 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-10 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-11 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-12 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-13 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-14 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-15 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-16 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-17 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-18 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-19 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-20 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-21 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-22 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-23 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-24 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-25 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-26 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-27 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-28 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-29 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-30 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-08-31 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-01 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-02 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-03 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-04 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-05 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-06 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-07 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-08 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-09 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-10 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-11 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-12 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-13 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-14 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-15 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-16 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-17 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-18 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-19 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-20 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-21 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-22 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-23 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-24 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-25 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-26 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-27 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-28 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-29 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-09-30 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-01 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-02 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-03 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-04 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-05 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-06 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-07 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-08 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-09 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-10 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-11 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-12 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-13 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-14 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-15 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-16 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-17 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-18 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-19 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-20 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-21 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-22 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-23 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-24 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-25 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-26 00:00:00', 4.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-27 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-28 00:00:00', 6.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-29 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-30 00:00:00', 5.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-10-31 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-01 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-02 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-03 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-04 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-05 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-06 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-07 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-08 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-09 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-10 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-11 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-12 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-13 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-14 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-15 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-16 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-17 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-18 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-19 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-20 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-21 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-22 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-23 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-24 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-25 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-26 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-27 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-28 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-29 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-11-30 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-01 00:00:00', 6.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-02 00:00:00', 5.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-03 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-04 00:00:00', 5.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-05 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-06 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-07 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-08 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-09 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-10 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-11 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-12 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-13 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-14 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-15 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-16 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-17 00:00:00', 7.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-18 00:00:00', 7.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-19 00:00:00', 9.08600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-20 00:00:00', 6.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-21 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-22 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-23 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-24 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-25 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-26 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-27 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-28 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-29 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-30 00:00:00', 6.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1985-12-31 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-01 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-02 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-03 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-04 00:00:00', 5.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-05 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-06 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-07 00:00:00', 4.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-08 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-09 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-10 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-11 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-12 00:00:00', 6.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-13 00:00:00', 7.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-14 00:00:00', 6.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-15 00:00:00', 7.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-16 00:00:00', 6.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-17 00:00:00', 4.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-18 00:00:00', 6.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-19 00:00:00', 5.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-20 00:00:00', 7.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-21 00:00:00', 8.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-22 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-23 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-24 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-25 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-26 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-27 00:00:00', 5.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-28 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-29 00:00:00', 1.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-30 00:00:00', 6.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-01-31 00:00:00', 5.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-01 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-02 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-03 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-04 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-05 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-06 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-07 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-08 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-09 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-10 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-11 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-12 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-13 00:00:00', 1.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-14 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-15 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-16 00:00:00', 6.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-17 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-18 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-19 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-20 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-21 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-22 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-23 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-24 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-25 00:00:00', 4.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-26 00:00:00', 5.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-27 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-02-28 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-01 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-02 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-03 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-04 00:00:00', 4.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-05 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-06 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-07 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-08 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-09 00:00:00', 4.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-10 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-11 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-12 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-13 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-14 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-15 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-16 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-17 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-18 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-19 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-20 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-21 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-22 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-23 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-24 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-25 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-26 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-27 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-28 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-29 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-30 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-03-31 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-01 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-02 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-03 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-04 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-05 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-06 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-07 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-08 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-09 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-10 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-11 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-12 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-13 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-14 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-15 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-16 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-17 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-18 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-19 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-20 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-21 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-22 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-23 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-24 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-25 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-26 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-27 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-28 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-29 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-04-30 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-01 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-02 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-03 00:00:00', 4.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-04 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-05 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-06 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-07 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-08 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-09 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-10 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-11 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-12 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-13 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-14 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-15 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-16 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-17 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-18 00:00:00', 1.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-19 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-20 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-21 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-22 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-23 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-24 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-25 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-26 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-27 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-28 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-29 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-30 00:00:00', 4.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-01 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-02 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-03 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-04 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-05 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-06 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-07 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-08 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-09 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-10 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-11 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-12 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-13 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-14 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-15 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-16 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-17 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-18 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-19 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-20 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-21 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-22 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-23 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-24 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-25 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-26 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-27 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-28 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-29 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-06-30 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-01 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-02 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-03 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-04 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-05 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-06 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-07 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-08 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-09 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-10 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-11 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-12 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-13 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-14 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-15 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-16 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-17 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-18 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-19 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-20 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-21 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-22 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-23 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-24 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-25 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-26 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-27 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-28 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-29 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-30 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-07-31 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-01 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-02 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-03 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-04 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-05 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-06 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-07 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-08 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-09 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-10 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-11 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-12 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-13 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-14 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-15 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-16 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-17 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-18 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-19 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-20 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-21 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-22 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-23 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-24 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-25 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-26 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-27 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-28 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-29 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-30 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-08-31 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-01 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-02 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-03 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-04 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-05 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-06 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-07 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-08 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-09 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-10 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-11 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-12 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-13 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-14 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-15 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-16 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-17 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-18 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-19 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-20 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-21 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-22 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-23 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-24 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-25 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-26 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-27 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-28 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-29 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-09-30 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-01 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-02 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-03 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-04 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-05 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-06 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-07 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-08 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-09 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-10 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-11 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-12 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-13 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-14 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-15 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-16 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-17 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-18 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-19 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-20 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-21 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-22 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-23 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-24 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-25 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-26 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-27 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-28 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-29 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-30 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-10-31 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-01 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-02 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-03 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-04 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-05 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-06 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-07 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-08 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-09 00:00:00', 5.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-10 00:00:00', 5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-11 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-12 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-13 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-14 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-15 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-16 00:00:00', 4.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-17 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-18 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-19 00:00:00', 4.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-20 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-21 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-22 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-23 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-24 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-25 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-26 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-27 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-28 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-29 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-11-30 00:00:00', 5.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-01 00:00:00', 6.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-02 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-03 00:00:00', 5.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-04 00:00:00', 5.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-05 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-06 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-07 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-08 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-09 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-10 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-11 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-12 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-13 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-14 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-15 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-16 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-17 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-18 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-19 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-20 00:00:00', 7.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-21 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-22 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-23 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-24 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-01 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-02 00:00:00', 6.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-03 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-04 00:00:00', 5.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-05 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-06 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-07 00:00:00', 6.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-08 00:00:00', 4.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-09 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-10 00:00:00', 5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-11 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-12 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-13 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-14 00:00:00', 5.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-15 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-16 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-17 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-18 00:00:00', 5.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-19 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-20 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-21 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-22 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-23 00:00:00', 6.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-24 00:00:00', 6.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-25 00:00:00', 6.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-26 00:00:00', 6.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-27 00:00:00', 7.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-28 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-29 00:00:00', 5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-30 00:00:00', 4.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-01-31 00:00:00', 5.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-01 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-02 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-03 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-04 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-05 00:00:00', 6.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-06 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-07 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-08 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-09 00:00:00', 6.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-10 00:00:00', 6.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-11 00:00:00', 6.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-12 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-13 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-14 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-15 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-16 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-17 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-18 00:00:00', 5.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-19 00:00:00', 6.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-20 00:00:00', 6.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-21 00:00:00', 5.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-22 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-23 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-24 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-25 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-26 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-27 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-02-28 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-01 00:00:00', 6.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-02 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-03 00:00:00', 5.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-04 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-05 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-06 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-07 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-08 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-09 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-10 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-11 00:00:00', 5.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-12 00:00:00', 5.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-13 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-14 00:00:00', 8.14000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-15 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-16 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-17 00:00:00', 5.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-18 00:00:00', 6.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-19 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-20 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-21 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-22 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-23 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-24 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-25 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-26 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-27 00:00:00', 6.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-28 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-29 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-30 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-03-31 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-01 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-02 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-03 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-04 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-05 00:00:00', 6.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-06 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-07 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-08 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-09 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-10 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-11 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-12 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-13 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-14 00:00:00', 5.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-15 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-16 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-17 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-18 00:00:00', 6.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-19 00:00:00', 6.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-20 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-21 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-22 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-23 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-24 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-25 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-26 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-27 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-28 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-29 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-04-30 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-01 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-02 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-03 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-04 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-05 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-06 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-07 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-08 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-09 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-10 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-11 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-12 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-13 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-14 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-15 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-16 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-17 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-18 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-19 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-20 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-21 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-22 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-23 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-24 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-25 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-26 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-27 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-28 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-29 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-30 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-05-31 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-01 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-02 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-03 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-04 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-05 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-06 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-07 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-08 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-09 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-10 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-11 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-12 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-13 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-14 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-15 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-16 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-17 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-18 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-19 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-20 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-21 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-22 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-23 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-24 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-25 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-26 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-27 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-28 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-29 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-06-30 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-01 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-02 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-03 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-04 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-05 00:00:00', 0.947000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-06 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-07 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-08 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-09 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-10 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-11 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-12 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-13 00:00:00', 4.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-14 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-15 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-16 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-17 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-18 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-19 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-20 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-21 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-22 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-23 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-24 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-25 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-26 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-27 00:00:00', 4.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-28 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-29 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-30 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-07-31 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-01 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-02 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-03 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-04 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-05 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-06 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-07 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-08 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-09 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-10 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-11 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-12 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-13 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-14 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-15 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-16 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-17 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-18 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-19 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-20 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-21 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-22 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-23 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-24 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-25 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-26 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-27 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-28 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-29 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-30 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-08-31 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-01 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-02 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-03 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-04 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-05 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-06 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-07 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-08 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-09 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-10 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-11 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-12 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-13 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-14 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-15 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-16 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-17 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-18 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-19 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-20 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-21 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-22 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-23 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-24 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-25 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-26 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-27 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-28 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-29 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-09-30 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-01 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-02 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-03 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-04 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-05 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-06 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-07 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-08 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-09 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-10 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-11 00:00:00', 1.08399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-12 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-13 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-14 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-15 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-16 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-17 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-18 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-19 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-20 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-21 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-22 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-23 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-24 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-25 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-26 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-27 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-28 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-29 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-30 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-10-31 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-01 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-02 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-03 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-04 00:00:00', 5.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-05 00:00:00', 6.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-06 00:00:00', 6.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-07 00:00:00', 7.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-08 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-09 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-10 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-11 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-12 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-13 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-14 00:00:00', 5.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-15 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-16 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-17 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-18 00:00:00', 4.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-19 00:00:00', 6.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-20 00:00:00', 6.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-21 00:00:00', 6.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-22 00:00:00', 6.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-23 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-24 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-25 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-26 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-27 00:00:00', 1.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-28 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-29 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-11-30 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-01 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-02 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-03 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-04 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-05 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-06 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-07 00:00:00', 6.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-08 00:00:00', 6.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-09 00:00:00', 6.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-10 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-11 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-12 00:00:00', 6.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-13 00:00:00', 6.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-14 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-15 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-16 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-17 00:00:00', 6.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-18 00:00:00', 6.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-19 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-20 00:00:00', 6.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-21 00:00:00', 7.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-22 00:00:00', 6.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-23 00:00:00', 7.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-24 00:00:00', 7.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-25 00:00:00', 6.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-26 00:00:00', 7.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-27 00:00:00', 6.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-28 00:00:00', 6.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-29 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-30 00:00:00', 6.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1987-12-31 00:00:00', 7.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-01 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-02 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-03 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-04 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-05 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-06 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-07 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-08 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-09 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-10 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-11 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-12 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-13 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-14 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-15 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-16 00:00:00', 5.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-17 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-18 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-19 00:00:00', 6.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-20 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-21 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-22 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-23 00:00:00', 5.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-24 00:00:00', 5.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-25 00:00:00', 6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-26 00:00:00', 7.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-27 00:00:00', 6.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-28 00:00:00', 4.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-29 00:00:00', 8.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-30 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-01-31 00:00:00', 7.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-01 00:00:00', 8.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-02 00:00:00', 8.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-03 00:00:00', 6.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-04 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-05 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-06 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-07 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-08 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-09 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-10 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-11 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-12 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-13 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-14 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-15 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-16 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-17 00:00:00', 6.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-18 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-19 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-20 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-21 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-22 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-23 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-24 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-25 00:00:00', 5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-26 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-27 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-28 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-02-29 00:00:00', 5.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-01 00:00:00', 6.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-02 00:00:00', 6.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-03 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-04 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-05 00:00:00', 6.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-06 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-07 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-08 00:00:00', 5.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-09 00:00:00', 6.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-10 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-11 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-12 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-13 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-14 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-15 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-16 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-17 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-18 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-19 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-20 00:00:00', 4.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-21 00:00:00', 6.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-22 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-23 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-24 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-25 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-26 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-27 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-28 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-29 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-30 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-03-31 00:00:00', 6.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-01 00:00:00', 7.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-02 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-03 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-04 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-05 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-06 00:00:00', 5.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-07 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-08 00:00:00', 4.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-09 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-10 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-11 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-12 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-13 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-14 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-15 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-16 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-17 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-18 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-19 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-20 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-21 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-22 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-23 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-24 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-25 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-26 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-27 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-28 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-29 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-04-30 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-01 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-02 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-03 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-04 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-05 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-06 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-07 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-08 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-09 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-10 00:00:00', 4.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-11 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-12 00:00:00', 4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-13 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-14 00:00:00', 6.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-15 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-16 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-17 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-18 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-19 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-20 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-21 00:00:00', 4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-22 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-23 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-24 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-25 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-26 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-27 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-28 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-29 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-30 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-05-31 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-01 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-02 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-03 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-04 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-05 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-06 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-07 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-08 00:00:00', 4.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-09 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-10 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-11 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-12 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-13 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-14 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-15 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-16 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-17 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-18 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-19 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-20 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-21 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-22 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-23 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-24 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-25 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-26 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-27 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-28 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-29 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-06-30 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-01 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-02 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-03 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-04 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-05 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-06 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-07 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-08 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-09 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-10 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-11 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-12 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-13 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-14 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-15 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-16 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-17 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-18 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-19 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-20 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-21 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-22 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-23 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-24 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-25 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-26 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-27 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-28 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-29 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-30 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-07-31 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-01 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-02 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-03 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-04 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-05 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-06 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-07 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-08 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-09 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-10 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-11 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-12 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-13 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-14 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-15 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-16 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-17 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-18 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-19 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-20 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-21 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-22 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-23 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-24 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-25 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-26 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-27 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-28 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-29 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-30 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-08-31 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-01 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-02 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-03 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-04 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-05 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-06 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-07 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-08 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-09 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-10 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-11 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-12 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-13 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-14 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-15 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-16 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-17 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-18 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-19 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-20 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-21 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-22 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-23 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-24 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-25 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-26 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-27 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-28 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-29 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-09-30 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-01 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-02 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-03 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-04 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-05 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-06 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-07 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-08 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-09 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-10 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-11 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-12 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-13 00:00:00', 4.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-14 00:00:00', 5.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-15 00:00:00', 5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-16 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-17 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-18 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-19 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-20 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-21 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-22 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-23 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-24 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-25 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-26 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-27 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-28 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-29 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-30 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-10-31 00:00:00', 5.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-01 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-02 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-03 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-04 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-05 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-06 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-07 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-08 00:00:00', 5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-09 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-10 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-11 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-12 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-13 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-14 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-15 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-16 00:00:00', 4.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-17 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-18 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-19 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-20 00:00:00', 6.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-21 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-22 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-23 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-24 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-25 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-26 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-27 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-28 00:00:00', 5.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-29 00:00:00', 7.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-11-30 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-01 00:00:00', 5.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-02 00:00:00', 5.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-03 00:00:00', 4.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-04 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-05 00:00:00', 4.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-06 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-07 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-08 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-09 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-10 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-11 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-12 00:00:00', 7.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-13 00:00:00', 5.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-14 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-15 00:00:00', 7.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-16 00:00:00', 6.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-17 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-18 00:00:00', 6.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-19 00:00:00', 6.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-20 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-21 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-22 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-23 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-24 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-25 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-26 00:00:00', 7.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-27 00:00:00', 7.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-28 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-29 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-30 00:00:00', 4.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1988-12-31 00:00:00', 6.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-01 00:00:00', 6.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-02 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-03 00:00:00', 7.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-04 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-05 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-06 00:00:00', 6.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-07 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-08 00:00:00', 6.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-09 00:00:00', 6.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-10 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-11 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-12 00:00:00', 5.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-13 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-14 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-15 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-16 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-17 00:00:00', 6.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-18 00:00:00', 5.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-19 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-20 00:00:00', 6.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-21 00:00:00', 5.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-22 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-23 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-24 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-25 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-26 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-27 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-28 00:00:00', 4.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-29 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-30 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-01-31 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-01 00:00:00', 7.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-02 00:00:00', 5.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-03 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-04 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-05 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-06 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-07 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-08 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-09 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-10 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-11 00:00:00', 6.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-12 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-13 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-14 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-15 00:00:00', 4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-16 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-17 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-18 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-19 00:00:00', 6.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-20 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-21 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-22 00:00:00', 7.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-23 00:00:00', 7.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-24 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-25 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-26 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-27 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-02-28 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-01 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-02 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-03 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-04 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-05 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-06 00:00:00', 5.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-07 00:00:00', 4.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-08 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-09 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-10 00:00:00', 4.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-11 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-12 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-13 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-14 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-15 00:00:00', 5.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-16 00:00:00', 6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-17 00:00:00', 4.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-18 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-19 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-20 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-21 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-22 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-23 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-24 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-25 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-26 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-27 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-28 00:00:00', 5.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-29 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-30 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-03-31 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-01 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-02 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-03 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-04 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-05 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-06 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-07 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-08 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-09 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-10 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-11 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-12 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-13 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-14 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-15 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-16 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-17 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-18 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-19 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-20 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-21 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-22 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-23 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-24 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-25 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-26 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-27 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-28 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-29 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-04-30 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-01 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-02 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-03 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-04 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-05 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-06 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-07 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-08 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-09 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-10 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-11 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-12 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-13 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-14 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-15 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-16 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-17 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-18 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-19 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-20 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-21 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-22 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-23 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-24 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-25 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-26 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-27 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-28 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-29 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-30 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-05-31 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-01 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-02 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-03 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-04 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-05 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-06 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-07 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-08 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-09 00:00:00', 4.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-10 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-11 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-12 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-13 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-14 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-15 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-16 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-17 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-18 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-19 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-20 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-21 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-22 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-23 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-24 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-25 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-26 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-27 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-28 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-29 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-06-30 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-01 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-02 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-03 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-04 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-05 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-06 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-07 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-08 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-09 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-10 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-11 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-12 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-13 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-14 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-15 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-16 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-17 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-18 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-19 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-20 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-21 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-22 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-23 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-24 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-25 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-26 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-27 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-28 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-29 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-30 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-07-31 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-01 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-02 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-03 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-04 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-05 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-06 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-07 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-08 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-09 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-10 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-11 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-12 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-13 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-14 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-15 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-16 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-17 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-18 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-19 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-20 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-21 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-22 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-23 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-24 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-25 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-26 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-27 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-28 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-29 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-30 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-08-31 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-01 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-02 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-03 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-04 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-05 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-06 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-07 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-08 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-09 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-10 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-11 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-12 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-13 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-14 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-15 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-16 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-17 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-18 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-19 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-20 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-21 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-22 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-23 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-24 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-25 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-26 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-27 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-28 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-29 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-09-30 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-01 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-02 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-03 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-04 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-05 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-06 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-07 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-08 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-09 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-10 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-11 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-12 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-13 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-14 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-15 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-16 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-17 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-18 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-19 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-20 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-21 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-22 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-23 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-24 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-25 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-26 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-27 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-28 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-29 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-30 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-10-31 00:00:00', 5.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-01 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-02 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-03 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-04 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-05 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-06 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-07 00:00:00', 5.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-08 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-09 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-10 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-11 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-12 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-13 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-14 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-15 00:00:00', 5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-16 00:00:00', 6.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-17 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-18 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-19 00:00:00', 5.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-20 00:00:00', 7.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-21 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-22 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-23 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-24 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-25 00:00:00', 7.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-26 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-27 00:00:00', 5.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-28 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-29 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-11-30 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-01 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-02 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-03 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-04 00:00:00', 6.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-05 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-06 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-07 00:00:00', 5.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-08 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-09 00:00:00', 6.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-10 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-11 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-12 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-13 00:00:00', 5.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-14 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-15 00:00:00', 6.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-16 00:00:00', 5.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-17 00:00:00', 5.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-18 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-19 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-20 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-21 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-22 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-23 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-24 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-25 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-26 00:00:00', 5.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-27 00:00:00', 5.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-28 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-29 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-30 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1989-12-31 00:00:00', 6.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-01 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-02 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-03 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-04 00:00:00', 5.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-05 00:00:00', 7.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-06 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-07 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-08 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-09 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-10 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-11 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-12 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-13 00:00:00', 5.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-14 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-15 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-16 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-17 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-18 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-19 00:00:00', 5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-20 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-21 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-22 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-23 00:00:00', 6.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-24 00:00:00', 6.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-25 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-26 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-27 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-28 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-29 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-30 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-01-31 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-01 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-02 00:00:00', 6.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-03 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-04 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-05 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-06 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-07 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-08 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-09 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-10 00:00:00', 6.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-11 00:00:00', 7.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-12 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-13 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-14 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-15 00:00:00', 7.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-16 00:00:00', 8.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-17 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-18 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-19 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-20 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-21 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-22 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-23 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-24 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-25 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-26 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-27 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-02-28 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-01 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-02 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-03 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-04 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-05 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-06 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-07 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-08 00:00:00', 6.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-09 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-10 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-11 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-12 00:00:00', 5.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-13 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-14 00:00:00', 6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-15 00:00:00', 5.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-16 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-17 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-18 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-19 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-20 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-21 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-22 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-23 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-24 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-25 00:00:00', 4.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-26 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-27 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-28 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-29 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-30 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-03-31 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-01 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-02 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-03 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-04 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-05 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-06 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-07 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-08 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-09 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-10 00:00:00', 4.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-11 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-12 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-13 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-14 00:00:00', 6.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-15 00:00:00', 5.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-16 00:00:00', 6.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-17 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-18 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-19 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-20 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-21 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-22 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-23 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-24 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-25 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-26 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-27 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-28 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-29 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-04-30 00:00:00', 6.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-01 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-02 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-03 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-04 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-05 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-06 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-07 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-08 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-09 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-10 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-11 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-12 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-13 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-14 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-15 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-16 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-17 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-18 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-19 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-20 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-21 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-22 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-23 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-24 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-25 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-26 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-27 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-28 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-29 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-30 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-05-31 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-01 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-02 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-03 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-04 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-05 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-06 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-07 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-08 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-09 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-10 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-11 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-12 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-13 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-14 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-15 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-16 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-17 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-18 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-19 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-20 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-21 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-22 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-23 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-24 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-25 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-26 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-27 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-28 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-29 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-06-30 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-01 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-02 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-03 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-04 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-05 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-06 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-07 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-08 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-09 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-10 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-11 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-12 00:00:00', 4.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-13 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-14 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-15 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-16 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-17 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-18 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-19 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-20 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-21 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-22 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-23 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-24 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-25 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-26 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-27 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-28 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-29 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-30 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-07-31 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-01 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-02 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-03 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-04 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-05 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-06 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-07 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-08 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-09 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-10 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-11 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-12 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-13 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-14 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-15 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-16 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-17 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-18 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-19 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-20 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-21 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-22 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-23 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-24 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-25 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-26 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-27 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-28 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-29 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-30 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-08-31 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-01 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-02 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-03 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-04 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-05 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-06 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-07 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-08 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-09 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-10 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-11 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-12 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-13 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-14 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-15 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-16 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-17 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-18 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-19 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-20 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-21 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-22 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-23 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-24 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-25 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-26 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-27 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-28 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-29 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-09-30 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-01 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-02 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-03 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-04 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-05 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-06 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-07 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-08 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-09 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-10 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-11 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-12 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-13 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-14 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-15 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-16 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-17 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-18 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-19 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-20 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-21 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-22 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-23 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-24 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-25 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-26 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-27 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-28 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-29 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-30 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-10-31 00:00:00', 4.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-01 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-02 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-03 00:00:00', 5.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-04 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-05 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-06 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-07 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-08 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-09 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-10 00:00:00', 5.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-11 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-12 00:00:00', 6.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-13 00:00:00', 6.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-14 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-15 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-16 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-17 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-18 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-19 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-20 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-21 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-22 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-23 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-24 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-25 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-26 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-27 00:00:00', 4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-28 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-29 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-11-30 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-01 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-02 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-03 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-04 00:00:00', 5.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-05 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-06 00:00:00', 6.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-07 00:00:00', 5.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-08 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-09 00:00:00', 5.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-10 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-11 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-12 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-13 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-14 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-15 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-16 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-17 00:00:00', 6.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-18 00:00:00', 7.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-19 00:00:00', 6.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-20 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-21 00:00:00', 6.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-22 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-23 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-24 00:00:00', 5.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-25 00:00:00', 6.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-26 00:00:00', 6.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-27 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-28 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-29 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-30 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1990-12-31 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-01 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-02 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-03 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-04 00:00:00', 5.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-05 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-06 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-07 00:00:00', 6.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-08 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-09 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-10 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-11 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-12 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-13 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-14 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-15 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-16 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-17 00:00:00', 5.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-18 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-19 00:00:00', 5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-20 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-21 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-22 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-23 00:00:00', 5.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-24 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-25 00:00:00', 6.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-26 00:00:00', 7.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-27 00:00:00', 6.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-28 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-29 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-30 00:00:00', 5.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-01-31 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-01 00:00:00', 7.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-02 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-03 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-04 00:00:00', 6.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-05 00:00:00', 5.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-06 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-07 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-08 00:00:00', 7.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-09 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-10 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-11 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-12 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-13 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-14 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-15 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-16 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-17 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-18 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-19 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-20 00:00:00', 6.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-21 00:00:00', 6.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-22 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-23 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-24 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-25 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-26 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-27 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-02-28 00:00:00', 5.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-01 00:00:00', 6.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-02 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-03 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-04 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-05 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-06 00:00:00', 7.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-07 00:00:00', 7.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-08 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-09 00:00:00', 4.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-10 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-11 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-12 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-13 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-14 00:00:00', 5.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-15 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-16 00:00:00', 6.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-17 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-18 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-19 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-20 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-21 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-22 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-23 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-24 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-25 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-26 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-27 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-28 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-29 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-30 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-03-31 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-01 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-02 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-03 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-04 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-05 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-06 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-07 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-08 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-09 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-10 00:00:00', 5.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-11 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-12 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-13 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-14 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-15 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-16 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-17 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-18 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-19 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-20 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-21 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-22 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-23 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-24 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-25 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-26 00:00:00', 3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-27 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-28 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-29 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-04-30 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-01 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-02 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-03 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-04 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-05 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-06 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-07 00:00:00', 4.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-08 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-09 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-10 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-11 00:00:00', 4.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-12 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-13 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-14 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-15 00:00:00', 5.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-16 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-17 00:00:00', 5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-18 00:00:00', 5.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-19 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-20 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-21 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-22 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-23 00:00:00', 6.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-24 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-25 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-26 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-27 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-28 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-29 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-30 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-05-31 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-01 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-02 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-03 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-04 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-05 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-06 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-07 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-08 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-09 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-10 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-11 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-12 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-13 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-14 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-15 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-16 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-17 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-18 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-19 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-20 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-21 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-22 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-23 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-24 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-25 00:00:00', 4.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-26 00:00:00', 4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-27 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-28 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-29 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-06-30 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-01 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-02 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-03 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-04 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-05 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-06 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-07 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-08 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-09 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-10 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-11 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-12 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-13 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-14 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-15 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-16 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-17 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-18 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-19 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-20 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-21 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-22 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-23 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-24 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-25 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-26 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-27 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-28 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-29 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-30 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-07-31 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-01 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-02 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-03 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-04 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-05 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-06 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-07 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-08 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-09 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-10 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-11 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-12 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-13 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-14 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-15 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-16 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-17 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-18 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-19 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-20 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-21 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-22 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-23 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-24 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-25 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-26 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-27 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-28 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-29 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-30 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-08-31 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-01 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-02 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-03 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-04 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-05 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-06 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-07 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-08 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-09 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-10 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-11 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-12 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-13 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-14 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-15 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-16 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-17 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-18 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-19 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-20 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-21 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-22 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-23 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-24 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-25 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-26 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-27 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-28 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-29 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-09-30 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-01 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-02 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-03 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-04 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-05 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-06 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-07 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-08 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-09 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-10 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-11 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-12 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-13 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-14 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-15 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-16 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-17 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-18 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-19 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-20 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-21 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-22 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-23 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-24 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-25 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-26 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-27 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-28 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-29 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-30 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-10-31 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-01 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-02 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-03 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-04 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-05 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-06 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-07 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-08 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-09 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-10 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-11 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-12 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-13 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-14 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-15 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-16 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-17 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-18 00:00:00', 5.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-19 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-20 00:00:00', 6.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-21 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-22 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-23 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-24 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-25 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-26 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-27 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-28 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-29 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-11-30 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-01 00:00:00', 6.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-02 00:00:00', 7.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-03 00:00:00', 6.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-04 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-05 00:00:00', 7.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-06 00:00:00', 6.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-07 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-08 00:00:00', 5.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-09 00:00:00', 5.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-10 00:00:00', 7.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-11 00:00:00', 5.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-12 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-13 00:00:00', 6.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-14 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-15 00:00:00', 6.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-16 00:00:00', 5.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-17 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-18 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-19 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-20 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-21 00:00:00', 1.00800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-22 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-23 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-24 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-25 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-26 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-27 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-28 00:00:00', 6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-29 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-30 00:00:00', 5.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1991-12-31 00:00:00', 6.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-01 00:00:00', 8.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-02 00:00:00', 6.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-03 00:00:00', 8.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-04 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-05 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-06 00:00:00', 5.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-07 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-08 00:00:00', 5.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-09 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-10 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-11 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-12 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-13 00:00:00', 5.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-14 00:00:00', 6.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-15 00:00:00', 4.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-16 00:00:00', 7.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-17 00:00:00', 8.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-18 00:00:00', 7.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-19 00:00:00', 7.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-20 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-21 00:00:00', 4.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-22 00:00:00', 6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-23 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-24 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-25 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-26 00:00:00', 5.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-27 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-28 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-29 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-30 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-01-31 00:00:00', 7.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-01 00:00:00', 5.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-02 00:00:00', 6.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-03 00:00:00', 6.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-04 00:00:00', 5.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-05 00:00:00', 6.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-06 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-07 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-08 00:00:00', 5.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-09 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-10 00:00:00', 7.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-11 00:00:00', 8.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-12 00:00:00', 4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-13 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-14 00:00:00', 6.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-15 00:00:00', 7.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-16 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-17 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-18 00:00:00', 6.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-19 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-20 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-21 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-22 00:00:00', 5.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-23 00:00:00', 6.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-24 00:00:00', 7.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-25 00:00:00', 7.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-26 00:00:00', 6.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-27 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-28 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-02-29 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-01 00:00:00', 6.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-02 00:00:00', 6.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-03 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-04 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-05 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-06 00:00:00', 5.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-07 00:00:00', 6.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-08 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-09 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-10 00:00:00', 5.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-11 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-12 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-13 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-14 00:00:00', 5.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-15 00:00:00', 7.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-16 00:00:00', 5.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-17 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-18 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-19 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-20 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-21 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-22 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-23 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-24 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-25 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-26 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-27 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-28 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-29 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-30 00:00:00', 6.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-03-31 00:00:00', 7.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-01 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-02 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-03 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-04 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-05 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-06 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-07 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-08 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-09 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-10 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-11 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-12 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-13 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-14 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-15 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-16 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-17 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-18 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-19 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-20 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-21 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-22 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-23 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-24 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-25 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-26 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-27 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-28 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-29 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-04-30 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-01 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-02 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-03 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-04 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-05 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-06 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-07 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-08 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-09 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-10 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-11 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-12 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-13 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-14 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-15 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-16 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-17 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-18 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-19 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-20 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-21 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-22 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-23 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-24 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-25 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-26 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-27 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-28 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-29 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-30 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-05-31 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-01 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-02 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-03 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-04 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-05 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-06 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-07 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-08 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-09 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-10 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-11 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-12 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-13 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-14 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-15 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-16 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-17 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-18 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-19 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-20 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-21 00:00:00', 4.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-22 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-23 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-24 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-25 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-26 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-27 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-28 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-29 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-06-30 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-01 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-02 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-03 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-04 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-05 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-06 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-07 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-08 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-09 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-10 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-11 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-12 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-13 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-14 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-15 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-16 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-17 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-18 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-19 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-20 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-21 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-22 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-23 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-24 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-25 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-26 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-27 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-28 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-29 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-30 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-07-31 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-01 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-02 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-03 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-04 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-05 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-06 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-07 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-08 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-09 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-10 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-11 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-12 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-13 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-14 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-15 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-16 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-17 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-18 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-19 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-20 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-21 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-22 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-23 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-24 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-25 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-26 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-27 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-28 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-29 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-30 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-08-31 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-01 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-02 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-03 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-04 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-05 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-06 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-07 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-08 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-09 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-10 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-11 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-12 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-13 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-14 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-15 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-16 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-17 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-18 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-19 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-20 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-21 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-22 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-23 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-24 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-25 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-26 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-27 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-28 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-29 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-09-30 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-01 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-02 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-03 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-04 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-05 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-06 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-07 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-08 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-09 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-10 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-11 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-12 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-13 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-14 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-15 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-16 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-17 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-18 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-19 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-20 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-21 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-22 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-23 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-24 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-25 00:00:00', 4.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-26 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-27 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-28 00:00:00', 5.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-29 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-30 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-10-31 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-01 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-02 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-03 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-04 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-05 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-06 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-07 00:00:00', 5.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-08 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-09 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-10 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-11 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-12 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-13 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-14 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-15 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-16 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-17 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-18 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-19 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-20 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-21 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-22 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-23 00:00:00', 5.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-24 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-25 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-26 00:00:00', 6.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-27 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-28 00:00:00', 5.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-29 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-11-30 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-01 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-02 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-03 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-04 00:00:00', 5.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-05 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-06 00:00:00', 4.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-07 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-08 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-09 00:00:00', 6.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-10 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-11 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-12 00:00:00', 6.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-13 00:00:00', 7.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-14 00:00:00', 7.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-15 00:00:00', 6.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-16 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-17 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-18 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-19 00:00:00', 5.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-20 00:00:00', 6.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-21 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-22 00:00:00', 7.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-23 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-24 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-25 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-26 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-27 00:00:00', 6.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-28 00:00:00', 8.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-29 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-30 00:00:00', 7.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1992-12-31 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-01 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-02 00:00:00', 4.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-03 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-04 00:00:00', 5.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-05 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-06 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-07 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-08 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-09 00:00:00', 7.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-10 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-11 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-12 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-13 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-14 00:00:00', 5.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-15 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-16 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-17 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-18 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-19 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-20 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-21 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-22 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-23 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-24 00:00:00', 6.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-25 00:00:00', 6.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-26 00:00:00', 6.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-27 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-28 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-29 00:00:00', 6.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-30 00:00:00', 6.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-01-31 00:00:00', 7.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-01 00:00:00', 7.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-02 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-03 00:00:00', 7.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-04 00:00:00', 7.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-05 00:00:00', 7.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-06 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-07 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-08 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-09 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-10 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-11 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-12 00:00:00', 7.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-13 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-14 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-15 00:00:00', 5.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-16 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-17 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-18 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-19 00:00:00', 7.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-20 00:00:00', 5.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-21 00:00:00', 6.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-22 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-23 00:00:00', 4.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-24 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-25 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-26 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-27 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-02-28 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-01 00:00:00', 5.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-02 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-03 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-04 00:00:00', 8.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-05 00:00:00', 4.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-06 00:00:00', 7.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-07 00:00:00', 5.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-08 00:00:00', 6.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-09 00:00:00', 6.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-10 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-11 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-12 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-13 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-14 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-15 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-16 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-17 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-18 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-19 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-20 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-21 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-22 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-23 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-24 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-25 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-26 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-27 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-28 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-29 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-30 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-03-31 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-01 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-02 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-03 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-04 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-05 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-06 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-07 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-08 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-09 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-10 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-11 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-12 00:00:00', 4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-13 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-14 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-15 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-16 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-17 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-18 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-19 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-20 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-21 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-22 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-23 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-24 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-25 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-26 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-27 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-28 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-29 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-04-30 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-01 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-02 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-03 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-04 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-05 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-06 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-07 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-08 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-09 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-10 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-11 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-12 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-13 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-14 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-15 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-16 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-17 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-18 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-19 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-20 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-21 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-22 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-23 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-24 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-25 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-26 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-27 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-28 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-29 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-30 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-05-31 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-01 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-02 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-03 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-04 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-05 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-06 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-07 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-08 00:00:00', 4.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-09 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-10 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-11 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-12 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-13 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-14 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-15 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-16 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-17 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-18 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-19 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-20 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-21 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-22 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-23 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-24 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-25 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-26 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-27 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-28 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-29 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-06-30 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-01 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-02 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-03 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-04 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-05 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-06 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-07 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-08 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-09 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-10 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-11 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-12 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-13 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-14 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-15 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-16 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-17 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-18 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-19 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-20 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-21 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-22 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-23 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-24 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-25 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-26 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-27 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-28 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-29 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-30 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-07-31 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-01 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-02 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-03 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-04 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-05 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-06 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-07 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-08 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-09 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-10 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-11 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-12 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-13 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-14 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-15 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-16 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-17 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-18 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-19 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-20 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-21 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-22 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-23 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-24 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-25 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-26 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-27 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-28 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-29 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-30 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-08-31 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-01 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-02 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-03 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-04 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-05 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-06 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-07 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-08 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-09 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-10 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-11 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-12 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-13 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-14 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-15 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-16 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-17 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-18 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-19 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-20 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-21 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-22 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-23 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-24 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-25 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-26 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-27 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-28 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-29 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-09-30 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-01 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-02 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-03 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-04 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-05 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-06 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-07 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-08 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-09 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-10 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-11 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-12 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-13 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-14 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-15 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-16 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-17 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-18 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-19 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-20 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-21 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-22 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-23 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-24 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-25 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-26 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-27 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-28 00:00:00', 4.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-29 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-30 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-10-31 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-01 00:00:00', 5.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-02 00:00:00', 5.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-03 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-04 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-05 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-06 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-07 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-08 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-09 00:00:00', 6.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-10 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-11 00:00:00', 6.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-12 00:00:00', 6.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-13 00:00:00', 6.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-14 00:00:00', 6.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-15 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-16 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-17 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-18 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-19 00:00:00', 5.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-20 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-21 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-22 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-23 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-24 00:00:00', 5.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-25 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-26 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-27 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-28 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-29 00:00:00', 5.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-11-30 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-01 00:00:00', 5.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-02 00:00:00', 6.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-03 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-04 00:00:00', 5.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-05 00:00:00', 8.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-06 00:00:00', 5.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-07 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-08 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-09 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-10 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-11 00:00:00', 5.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-12 00:00:00', 5.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-13 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-14 00:00:00', 5.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-15 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-16 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-17 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-18 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-19 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-20 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-21 00:00:00', 5.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-22 00:00:00', 7.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-23 00:00:00', 6.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-24 00:00:00', 5.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-25 00:00:00', 6.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-26 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-27 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-28 00:00:00', 4.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-29 00:00:00', 6.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-30 00:00:00', 6.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1993-12-31 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-01 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-02 00:00:00', 5.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-03 00:00:00', 6.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-04 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-05 00:00:00', 7.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-06 00:00:00', 6.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-07 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-08 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-09 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-10 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-11 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-12 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-13 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-14 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-15 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-16 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-17 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-18 00:00:00', 1.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-19 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-20 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-21 00:00:00', 8.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-22 00:00:00', 6.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-23 00:00:00', 7.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-24 00:00:00', 4.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-25 00:00:00', 7.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-26 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-27 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-28 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-29 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-30 00:00:00', 6.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-01-31 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-01 00:00:00', 7.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-02 00:00:00', 6.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-03 00:00:00', 7.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-04 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-05 00:00:00', 5.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-06 00:00:00', 6.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-07 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-08 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-09 00:00:00', 6.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-10 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-11 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-12 00:00:00', 7.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-13 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-14 00:00:00', 6.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-15 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-16 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-17 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-18 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-19 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-20 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-21 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-22 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-23 00:00:00', 6.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-24 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-25 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-26 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-27 00:00:00', 6.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-02-28 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-01 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-02 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-03 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-04 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-05 00:00:00', 5.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-06 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-07 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-08 00:00:00', 6.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-09 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-10 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-11 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-12 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-13 00:00:00', 6.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-14 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-15 00:00:00', 7.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-16 00:00:00', 6.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-17 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-18 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-19 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-20 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-21 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-22 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-23 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-24 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-25 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-26 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-27 00:00:00', 5.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-28 00:00:00', 5.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-29 00:00:00', 4.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-30 00:00:00', 4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-03-31 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-01 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-02 00:00:00', 5.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-03 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-04 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-05 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-06 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-07 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-08 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-09 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-10 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-11 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-12 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-13 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-14 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-15 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-16 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-17 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-18 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-19 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-20 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-21 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-22 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-23 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-24 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-25 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-26 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-27 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-28 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-29 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-04-30 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-01 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-02 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-03 00:00:00', 5.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-04 00:00:00', 6.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-05 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-06 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-07 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-08 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-09 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-10 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-11 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-12 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-13 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-14 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-15 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-16 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-17 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-18 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-19 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-20 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-21 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-22 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-23 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-24 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-25 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-26 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-27 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-28 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-29 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-30 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-05-31 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-01 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-02 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-03 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-04 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-05 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-06 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-07 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-08 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-09 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-10 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-11 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-12 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-13 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-14 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-15 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-16 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-17 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-18 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-19 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-20 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-21 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-22 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-23 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-24 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-25 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-26 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-27 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-28 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-29 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-06-30 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-01 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-02 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-03 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-04 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-05 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-06 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-07 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-08 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-09 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-10 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-11 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-12 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-13 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-14 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-15 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-16 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-17 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-18 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-19 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-20 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-21 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-22 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-23 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-24 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-25 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-26 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-27 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-28 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-29 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-30 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-07-31 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-01 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-02 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-03 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-04 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-05 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-06 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-07 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-08 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-09 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-10 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-11 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-12 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-13 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-14 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-15 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-16 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-17 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-18 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-19 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-20 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-21 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-22 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-23 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-24 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-25 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-26 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-27 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-28 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-29 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-30 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-08-31 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-01 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-02 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-03 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-04 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-05 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-06 00:00:00', 1.11699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-07 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-08 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-09 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-10 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-11 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-12 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-13 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-14 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-15 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-16 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-17 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-18 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-19 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-20 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-21 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-22 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-23 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-24 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-25 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-26 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-27 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-28 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-29 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-09-30 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-01 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-02 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-03 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-04 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-05 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-06 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-07 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-08 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-09 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-10 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-11 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-12 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-13 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-14 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-15 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-16 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-17 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-18 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-19 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-20 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-21 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-22 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-23 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-24 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-25 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-26 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-27 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-28 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-29 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-30 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-10-31 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-01 00:00:00', 4.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-02 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-03 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-04 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-05 00:00:00', 5.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-06 00:00:00', 6.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-07 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-08 00:00:00', 5.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-09 00:00:00', 5.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-10 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-11 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-12 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-13 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-14 00:00:00', 6.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-15 00:00:00', 6.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-16 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-17 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-18 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-19 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-20 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-21 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-22 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-23 00:00:00', 7.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-24 00:00:00', 7.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-25 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-26 00:00:00', 7.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-27 00:00:00', 4.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-28 00:00:00', 5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-29 00:00:00', 6.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-11-30 00:00:00', 6.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-01 00:00:00', 7.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-02 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-03 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-04 00:00:00', 8.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-05 00:00:00', 6.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-06 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-07 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-08 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-09 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-10 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-11 00:00:00', 5.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-12 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-13 00:00:00', 7.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-14 00:00:00', 7.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-15 00:00:00', 6.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-16 00:00:00', 6.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-17 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-18 00:00:00', 6.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-19 00:00:00', 6.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-20 00:00:00', 7.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-21 00:00:00', 6.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-22 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-23 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-24 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-25 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-26 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-27 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-28 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-29 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-30 00:00:00', 6.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1994-12-31 00:00:00', 4.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-01 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-02 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-03 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-04 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-05 00:00:00', 4.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-06 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-07 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-08 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-09 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-10 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-11 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-12 00:00:00', 6.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-13 00:00:00', 6.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-14 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-15 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-16 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-17 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-18 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-19 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-20 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-21 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-22 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-23 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-24 00:00:00', 5.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-25 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-26 00:00:00', 7.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-27 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-28 00:00:00', 5.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-29 00:00:00', 6.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-30 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-01-31 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-01 00:00:00', 5.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-02 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-03 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-04 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-05 00:00:00', 8.13300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-06 00:00:00', 7.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-07 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-08 00:00:00', 7.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-09 00:00:00', 7.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-10 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-11 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-12 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-13 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-14 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-15 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-16 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-17 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-18 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-19 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-20 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-21 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-22 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-23 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-24 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-25 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-26 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-27 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-02-28 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-01 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-02 00:00:00', 5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-03 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-04 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-05 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-06 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-07 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-08 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-09 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-10 00:00:00', 5.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-11 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-12 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-13 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-14 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-15 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-16 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-17 00:00:00', 5.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-18 00:00:00', 6.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-19 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-20 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-21 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-22 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-23 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-24 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-25 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-26 00:00:00', 6.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-27 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-28 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-29 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-30 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-03-31 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-01 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-02 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-03 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-04 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-05 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-06 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-07 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-08 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-09 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-10 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-11 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-12 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-13 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-14 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-15 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-16 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-17 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-18 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-19 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-20 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-21 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-22 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-23 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-24 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-25 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-26 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-27 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-28 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-29 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-04-30 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-01 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-02 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-03 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-04 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-05 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-06 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-07 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-08 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-09 00:00:00', 5.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-10 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-11 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-12 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-13 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-14 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-15 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-16 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-17 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-18 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-19 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-20 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-21 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-22 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-23 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-24 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-25 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-26 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-27 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-28 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-29 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-30 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-05-31 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-01 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-02 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-03 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-04 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-05 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-06 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-07 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-08 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-09 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-10 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-11 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-12 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-13 00:00:00', 5.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-14 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-15 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-16 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-17 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-18 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-19 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-20 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-21 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-22 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-23 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-24 00:00:00', 5.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-25 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-26 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-27 00:00:00', 4.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-28 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-29 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-06-30 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-01 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-02 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-03 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-04 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-05 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-06 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-07 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-08 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-09 00:00:00', 5.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-10 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-11 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-12 00:00:00', 4.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-13 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-14 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-15 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-16 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-17 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-18 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-19 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-20 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-21 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-22 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-23 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-24 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-25 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-26 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-27 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-28 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-29 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-30 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-07-31 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-01 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-02 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-03 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-04 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-05 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-06 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-07 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-08 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-09 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-10 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-11 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-12 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-13 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-14 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-15 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-16 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-17 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-18 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-19 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-20 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-21 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-22 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-23 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-24 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-25 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-26 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-27 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-28 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-29 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-30 00:00:00', 5.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-08-31 00:00:00', 5.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-01 00:00:00', 4.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-02 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-03 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-04 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-05 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-06 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-07 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-08 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-09 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-10 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-11 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-12 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-13 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-14 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-15 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-16 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-17 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-18 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-19 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-20 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-21 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-22 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-23 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-24 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-25 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-26 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-27 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-28 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-29 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-09-30 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-01 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-02 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-03 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-04 00:00:00', 5.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-05 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-06 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-07 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-08 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-09 00:00:00', 4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-10 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-11 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-12 00:00:00', 5.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-13 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-14 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-15 00:00:00', 5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-16 00:00:00', 5.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-17 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-18 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-19 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-20 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-21 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-22 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-23 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-24 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-25 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-26 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-27 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-28 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-29 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-30 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-10-31 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-01 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-02 00:00:00', 5.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-03 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-04 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-05 00:00:00', 4.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-06 00:00:00', 5.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-07 00:00:00', 4.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-08 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-09 00:00:00', 5.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-10 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-11 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-12 00:00:00', 6.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-13 00:00:00', 5.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-14 00:00:00', 6.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-15 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-16 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-17 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-18 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-19 00:00:00', 5.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-20 00:00:00', 6.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-21 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-22 00:00:00', 5.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-23 00:00:00', 5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-24 00:00:00', 6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-25 00:00:00', 5.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-26 00:00:00', 7.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-27 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-28 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-29 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-11-30 00:00:00', 5.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-01 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-02 00:00:00', 5.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-03 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-04 00:00:00', 6.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-05 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-06 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-07 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-08 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-09 00:00:00', 4.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-10 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-11 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-12 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-13 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-14 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-15 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-16 00:00:00', 6.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-17 00:00:00', 7.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-18 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-19 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-20 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-21 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-22 00:00:00', 5.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-23 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-24 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-25 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-26 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-27 00:00:00', 4.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-28 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-29 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-30 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1995-12-31 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-01 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-02 00:00:00', 4.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-03 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-04 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-05 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-06 00:00:00', 7.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-07 00:00:00', 7.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-08 00:00:00', 5.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-09 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-10 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-11 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-12 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-13 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-14 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-15 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-16 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-17 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-18 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-19 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-20 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-21 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-22 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-23 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-24 00:00:00', 5.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-25 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-26 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-27 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-28 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-29 00:00:00', 6.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-30 00:00:00', 6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-01-31 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-01 00:00:00', 6.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-02 00:00:00', 7.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-03 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-04 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-05 00:00:00', 7.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-06 00:00:00', 7.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-07 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-08 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-09 00:00:00', 4.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-10 00:00:00', 7.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-11 00:00:00', 8.13300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-12 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-13 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-14 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-15 00:00:00', 5.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-16 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-17 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-18 00:00:00', 5.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-19 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-20 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-21 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-22 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-23 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-24 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-25 00:00:00', 6.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-26 00:00:00', 5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-27 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-28 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-02-29 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-01 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-02 00:00:00', 6.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-03 00:00:00', 7.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-04 00:00:00', 7.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-05 00:00:00', 7.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-06 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-07 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-08 00:00:00', 5.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-09 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-10 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-11 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-12 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-13 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-14 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-15 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-16 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-17 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-18 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-19 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-20 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-21 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-22 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-23 00:00:00', 5.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-24 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-25 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-26 00:00:00', 6.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-27 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-28 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-29 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-30 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-03-31 00:00:00', 5.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-01 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-02 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-03 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-04 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-05 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-06 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-07 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-08 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-09 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-10 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-11 00:00:00', 5.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-12 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-13 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-14 00:00:00', 6.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-15 00:00:00', 6.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-16 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-17 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-18 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-19 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-20 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-21 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-22 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-23 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-24 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-25 00:00:00', 6.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-26 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-27 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-28 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-29 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-04-30 00:00:00', 1.05799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-01 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-02 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-03 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-04 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-05 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-06 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-07 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-08 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-09 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-10 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-11 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-12 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-13 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-14 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-15 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-16 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-17 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-18 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-19 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-20 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-21 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-22 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-23 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-24 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-25 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-26 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-27 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-28 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-29 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-30 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-05-31 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-01 00:00:00', 4.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-02 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-03 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-04 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-05 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-06 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-07 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-08 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-09 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-10 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-11 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-12 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-13 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-14 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-15 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-16 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-17 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-18 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-19 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-20 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-21 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-22 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-23 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-24 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-25 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-26 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-27 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-28 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-29 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-06-30 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-01 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-02 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-03 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-04 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-05 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-06 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-07 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-08 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-09 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-10 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-11 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-12 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-13 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-14 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-15 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-16 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-17 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-18 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-19 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-20 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-21 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-22 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-23 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-24 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-25 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-26 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-27 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-28 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-29 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-30 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-07-31 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-01 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-02 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-03 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-04 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-05 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-06 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-07 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-08 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-09 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-10 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-11 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-12 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-13 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-14 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-15 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-16 00:00:00', 1.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-17 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-18 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-19 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-20 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-21 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-22 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-23 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-24 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-25 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-26 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-27 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-28 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-29 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-30 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-08-31 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-01 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-02 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-03 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-04 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-05 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-06 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-07 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-08 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-09 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-10 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-11 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-12 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-13 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-14 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-15 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-16 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-17 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-18 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-19 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-20 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-21 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-22 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-23 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-24 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-25 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-26 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-27 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-28 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-29 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-09-30 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-01 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-02 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-03 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-04 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-05 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-06 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-07 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-08 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-09 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-10 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-11 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-12 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-13 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-14 00:00:00', 5.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-15 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-16 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-17 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-18 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-19 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-20 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-21 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-22 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-23 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-24 00:00:00', 4.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-25 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-26 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-27 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-28 00:00:00', 5.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-29 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-30 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-10-31 00:00:00', 5.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-01 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-02 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-03 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-04 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-05 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-06 00:00:00', 5.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-07 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-08 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-09 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-10 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-11 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-12 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-13 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-14 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-15 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-16 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-17 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-18 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-19 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-20 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-21 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-22 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-23 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-24 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-25 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-26 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-27 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-28 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-29 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-11-30 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-01 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-02 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-03 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-04 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-05 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-06 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-07 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-08 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-09 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-10 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-11 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-12 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-13 00:00:00', 6.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-14 00:00:00', 5.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-15 00:00:00', 6.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-16 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-17 00:00:00', 7.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-18 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-19 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-20 00:00:00', 6.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-21 00:00:00', 6.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-22 00:00:00', 6.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-23 00:00:00', 6.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-24 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-25 00:00:00', 6.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-26 00:00:00', 7.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-27 00:00:00', 6.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-28 00:00:00', 7.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-29 00:00:00', 6.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-30 00:00:00', 6.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1996-12-31 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-01 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-02 00:00:00', 5.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-03 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-04 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-05 00:00:00', 6.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-06 00:00:00', 6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-07 00:00:00', 6.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-08 00:00:00', 6.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-09 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-10 00:00:00', 6.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-11 00:00:00', 6.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-12 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-13 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-14 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-15 00:00:00', 6.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-16 00:00:00', 8.36900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-17 00:00:00', 7.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-18 00:00:00', 6.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-19 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-20 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-21 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-22 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-23 00:00:00', 5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-24 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-25 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-26 00:00:00', 5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-27 00:00:00', 4.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-28 00:00:00', 7.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-29 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-30 00:00:00', 6.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-01-31 00:00:00', 7.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-01 00:00:00', 7.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-02 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-03 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-04 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-05 00:00:00', 6.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-06 00:00:00', 7.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-07 00:00:00', 5.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-08 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-09 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-10 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-11 00:00:00', 5.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-12 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-13 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-14 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-15 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-16 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-17 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-18 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-19 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-20 00:00:00', 5.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-21 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-22 00:00:00', 6.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-23 00:00:00', 7.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-24 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-25 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-26 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-27 00:00:00', 6.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-02-28 00:00:00', 7.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-01 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-02 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-03 00:00:00', 6.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-04 00:00:00', 6.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-05 00:00:00', 6.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-06 00:00:00', 5.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-07 00:00:00', 5.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-08 00:00:00', 7.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-09 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-10 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-11 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-12 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-13 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-14 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-15 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-16 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-17 00:00:00', 6.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-18 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-19 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-20 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-21 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-22 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-23 00:00:00', 6.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-24 00:00:00', 6.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-25 00:00:00', 6.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-26 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-27 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-28 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-29 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-30 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-03-31 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-01 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-02 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-03 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-04 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-05 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-06 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-07 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-08 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-09 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-10 00:00:00', 7.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-11 00:00:00', 7.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-12 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-13 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-14 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-15 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-16 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-17 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-18 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-19 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-20 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-21 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-22 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-23 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-24 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-25 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-26 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-27 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-28 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-29 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-04-30 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-01 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-02 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-03 00:00:00', 4.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-04 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-05 00:00:00', 5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-06 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-07 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-08 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-09 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-10 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-11 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-12 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-13 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-14 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-15 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-16 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-17 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-18 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-19 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-20 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-21 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-22 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-23 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-24 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-25 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-26 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-27 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-28 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-29 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-30 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-05-31 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-01 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-02 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-03 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-04 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-05 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-06 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-07 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-08 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-09 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-10 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-11 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-12 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-13 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-14 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-15 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-16 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-17 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-18 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-19 00:00:00', 4.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-20 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-21 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-22 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-23 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-24 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-25 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-26 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-27 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-28 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-29 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-06-30 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-01 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-02 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-03 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-04 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-05 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-06 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-07 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-08 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-09 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-10 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-11 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-12 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-13 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-14 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-15 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-16 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-17 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-18 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-19 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-20 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-21 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-22 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-23 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-24 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-25 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-26 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-27 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-28 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-29 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-30 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-07-31 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-01 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-02 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-03 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-04 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-05 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-06 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-07 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-08 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-09 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-10 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-11 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-12 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-13 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-14 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-15 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-16 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-17 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-18 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-19 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-20 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-21 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-22 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-23 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-24 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-25 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-26 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-27 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-28 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-29 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-30 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-08-31 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-01 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-02 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-03 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-04 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-05 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-06 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-07 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-08 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-09 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-10 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-11 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-12 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-13 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-14 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-15 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-16 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-17 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-18 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-19 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-20 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-21 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-22 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-23 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-24 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-25 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-26 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-27 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-28 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-29 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-09-30 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-01 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-02 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-03 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-04 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-05 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-06 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-07 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-08 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-09 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-10 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-11 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-12 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-13 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-14 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-15 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-16 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-17 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-18 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-19 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-20 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-21 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-22 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-23 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-24 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-25 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-26 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-27 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-28 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-29 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-30 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-10-31 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-01 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-02 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-03 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-04 00:00:00', 6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-05 00:00:00', 6.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-06 00:00:00', 4.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-07 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-08 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-09 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-10 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-11 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-12 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-13 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-14 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-15 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-16 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-17 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-18 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-19 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-20 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-21 00:00:00', 6.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-22 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-23 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-24 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-25 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-26 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-27 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-28 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-29 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-11-30 00:00:00', 4.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-01 00:00:00', 5.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-02 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-03 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-04 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-05 00:00:00', 6.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-06 00:00:00', 5.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-07 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-08 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-09 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-10 00:00:00', 6.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-11 00:00:00', 6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-12 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-13 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-14 00:00:00', 6.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-15 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-16 00:00:00', 5.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-17 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-18 00:00:00', 5.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-19 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-20 00:00:00', 5.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-21 00:00:00', 6.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-22 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-23 00:00:00', 4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-24 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-25 00:00:00', 6.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-26 00:00:00', 6.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-27 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-28 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-29 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-30 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1997-12-31 00:00:00', 5.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-01 00:00:00', 6.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-02 00:00:00', 7.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-03 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-04 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-05 00:00:00', 6.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-06 00:00:00', 7.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-07 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-08 00:00:00', 5.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-09 00:00:00', 7.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-10 00:00:00', 6.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-11 00:00:00', 5.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-12 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-13 00:00:00', 7.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-14 00:00:00', 5.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-15 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-16 00:00:00', 4.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-17 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-18 00:00:00', 7.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-19 00:00:00', 7.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-20 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-21 00:00:00', 6.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-22 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-23 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-24 00:00:00', 7.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-25 00:00:00', 8.33899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-26 00:00:00', 8.12600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-27 00:00:00', 6.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-28 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-29 00:00:00', 8.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-30 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-01-31 00:00:00', 7.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-01 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-02 00:00:00', 6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-03 00:00:00', 5.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-04 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-05 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-06 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-07 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-08 00:00:00', 8.14299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-09 00:00:00', 6.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-10 00:00:00', 6.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-11 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-12 00:00:00', 8.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-13 00:00:00', 8.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-14 00:00:00', 6.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-15 00:00:00', 7.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-16 00:00:00', 6.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-17 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-18 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-19 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-20 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-21 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-22 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-23 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-24 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-25 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-26 00:00:00', 5.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-27 00:00:00', 5.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-02-28 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-01 00:00:00', 6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-02 00:00:00', 6.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-03 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-04 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-05 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-06 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-07 00:00:00', 5.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-08 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-09 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-10 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-11 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-12 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-13 00:00:00', 5.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-14 00:00:00', 7.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-15 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-16 00:00:00', 6.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-17 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-18 00:00:00', 7.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-19 00:00:00', 6.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-20 00:00:00', 5.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-21 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-22 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-23 00:00:00', 4.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-24 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-25 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-26 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-27 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-28 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-29 00:00:00', 5.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-30 00:00:00', 6.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-03-31 00:00:00', 7.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-01 00:00:00', 5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-02 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-03 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-04 00:00:00', 6.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-05 00:00:00', 6.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-06 00:00:00', 6.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-07 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-08 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-09 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-10 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-11 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-12 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-13 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-14 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-15 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-16 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-17 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-18 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-19 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-20 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-21 00:00:00', 4.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-22 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-23 00:00:00', 6.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-24 00:00:00', 5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-25 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-26 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-27 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-28 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-29 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-04-30 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-01 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-02 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-03 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-04 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-05 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-06 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-07 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-08 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-09 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-10 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-11 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-12 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-13 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-14 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-15 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-16 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-17 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-18 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-19 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-20 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-21 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-22 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-23 00:00:00', 4.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-24 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-25 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-26 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-27 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-28 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-29 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-30 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-05-31 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-01 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-02 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-03 00:00:00', 4.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-04 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-05 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-06 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-07 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-08 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-09 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-10 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-11 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-12 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-13 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-14 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-15 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-16 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-17 00:00:00', 4.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-18 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-19 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-20 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-21 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-22 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-23 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-24 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-25 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-26 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-27 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-28 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-29 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-06-30 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-01 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-02 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-03 00:00:00', 4.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-04 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-05 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-06 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-07 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-08 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-09 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-10 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-11 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-12 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-13 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-14 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-15 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-16 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-17 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-18 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-19 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-20 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-21 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-22 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-23 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-24 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-25 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-26 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-27 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-28 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-29 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-30 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-07-31 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-01 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-02 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-03 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-04 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-05 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-06 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-07 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-08 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-09 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-10 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-11 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-12 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-13 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-14 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-15 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-16 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-17 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-18 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-19 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-20 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-21 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-22 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-23 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-24 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-25 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-26 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-27 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-28 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-29 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-30 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-08-31 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-01 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-02 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-03 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-04 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-05 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-06 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-07 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-08 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-09 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-10 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-11 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-12 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-13 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-14 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-15 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-16 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-17 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-18 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-19 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-20 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-21 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-22 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-23 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-24 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-25 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-26 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-27 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-28 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-29 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-09-30 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-01 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-02 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-03 00:00:00', 4.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-04 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-05 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-06 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-07 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-08 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-09 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-10 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-11 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-12 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-13 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-14 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-15 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-16 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-17 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-18 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-19 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-20 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-21 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-22 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-23 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-24 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-25 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-26 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-27 00:00:00', 5.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-28 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-29 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-30 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-10-31 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-01 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-02 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-03 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-04 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-05 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-06 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-07 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-08 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-09 00:00:00', 5.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-10 00:00:00', 5.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-11 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-12 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-13 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-14 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-15 00:00:00', 4.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-16 00:00:00', 5.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-17 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-18 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-19 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-20 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-21 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-22 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-23 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-24 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-25 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-26 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-27 00:00:00', 6.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-28 00:00:00', 7.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-29 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-11-30 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-01 00:00:00', 6.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-02 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-03 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-04 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-05 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-06 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-07 00:00:00', 6.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-08 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-09 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-10 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-11 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-12 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-13 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-14 00:00:00', 5.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-15 00:00:00', 5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-16 00:00:00', 6.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-17 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-18 00:00:00', 7.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-19 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-20 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-21 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-22 00:00:00', 6.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-23 00:00:00', 6.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-24 00:00:00', 7.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-25 00:00:00', 5.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-26 00:00:00', 6.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-27 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-28 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-29 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-30 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1998-12-31 00:00:00', 7.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-02 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-04 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-06 00:00:00', 7.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-08 00:00:00', 7.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-10 00:00:00', 7.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-12 00:00:00', 8.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-14 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-16 00:00:00', 6.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-18 00:00:00', 6.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-20 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-22 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-24 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-26 00:00:00', 6.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-28 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-30 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-01 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-03 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-05 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-07 00:00:00', 6.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-09 00:00:00', 7.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-11 00:00:00', 8.78699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-13 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-15 00:00:00', 6.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-17 00:00:00', 6.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-19 00:00:00', 5.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-21 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-23 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-25 00:00:00', 6.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-27 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-01 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-03 00:00:00', 7.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-04 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-05 00:00:00', 1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-06 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-07 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-08 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-09 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-10 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-11 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-12 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-13 00:00:00', 6.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-14 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-15 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-16 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-17 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-18 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-19 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-20 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-21 00:00:00', 6.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-22 00:00:00', 5.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-23 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-24 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-25 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-26 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-27 00:00:00', 6.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-28 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-29 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-30 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-03-31 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-01 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-02 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-03 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-04 00:00:00', 6.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-05 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-06 00:00:00', 6.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-07 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-08 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-09 00:00:00', 7.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-10 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-11 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-12 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-13 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-14 00:00:00', 5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-15 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-16 00:00:00', 5.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-17 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-18 00:00:00', 6.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-19 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-20 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-21 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-22 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-23 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-24 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-25 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-26 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-27 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-28 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-29 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-04-30 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-01 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-02 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-03 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-04 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-05 00:00:00', 5.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-06 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-07 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-08 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-09 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-10 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-11 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-12 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-13 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-14 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-15 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-16 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-17 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-18 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-19 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-20 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-21 00:00:00', 4.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-22 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-23 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-24 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-25 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-26 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-27 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-28 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-29 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-30 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-05-31 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-01 00:00:00', 3.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-02 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-03 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-04 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-05 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-06 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-07 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-08 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-09 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-10 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-11 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-12 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-13 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-14 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-15 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-16 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-17 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-18 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-19 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-20 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-21 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-22 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-23 00:00:00', 5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-24 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-25 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-26 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-27 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-28 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-29 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-06-30 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-01 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-02 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-03 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-04 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-05 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-06 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-07 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-08 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-09 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-10 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-11 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-12 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-13 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-14 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-15 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-16 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-17 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-18 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-19 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-20 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-21 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-22 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-23 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-24 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-25 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-26 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-27 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-28 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-29 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-30 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-07-31 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-01 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-02 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-03 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-04 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-05 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-06 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-07 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-08 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-09 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-10 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-11 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-12 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-13 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-14 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-15 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-16 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-17 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-18 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-19 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-20 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-21 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-22 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-23 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-24 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-25 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-26 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-27 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-28 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-29 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-30 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-08-31 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-01 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-02 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-03 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-04 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-05 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-06 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-07 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-08 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-09 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-10 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-11 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-12 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-13 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-14 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-15 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-16 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-17 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-18 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-19 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-20 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-21 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-22 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-23 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-24 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-25 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-26 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-27 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-28 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-29 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-09-30 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-01 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-02 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-03 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-04 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-05 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-06 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-07 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-08 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-09 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-10 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-11 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-12 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-13 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-14 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-15 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-16 00:00:00', 4.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-17 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-18 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-19 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-20 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-21 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-22 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-23 00:00:00', 5.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-24 00:00:00', 5.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-25 00:00:00', 5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-26 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-27 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-28 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-29 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-30 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-10-31 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-01 00:00:00', 5.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-02 00:00:00', 4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-03 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-04 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-05 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-06 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-07 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-08 00:00:00', 6.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-09 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-10 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-11 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-12 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-13 00:00:00', 5.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-14 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-15 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-16 00:00:00', 5.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-17 00:00:00', 6.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-18 00:00:00', 5.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-19 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-20 00:00:00', 7.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-21 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-22 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-23 00:00:00', 6.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-24 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-25 00:00:00', 5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-26 00:00:00', 7.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-27 00:00:00', 7.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-28 00:00:00', 8.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-29 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-11-30 00:00:00', 0.842000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-01 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-02 00:00:00', 4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-03 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-04 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-05 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-06 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-07 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-08 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-09 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-10 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-11 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-12 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-13 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-14 00:00:00', 5.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-15 00:00:00', 6.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-16 00:00:00', 6.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-17 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-18 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-19 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-20 00:00:00', 5.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-21 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-22 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-23 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-24 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-25 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-26 00:00:00', 5.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-27 00:00:00', 7.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-28 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-29 00:00:00', 7.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-30 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '1999-12-31 00:00:00', 5.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-01 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-02 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-03 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-04 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-05 00:00:00', 5.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-06 00:00:00', 7.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-07 00:00:00', 6.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-08 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-09 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-10 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-11 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-12 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-13 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-14 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-15 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-16 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-17 00:00:00', 7.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-18 00:00:00', 5.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-19 00:00:00', 6.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-20 00:00:00', 6.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-21 00:00:00', 6.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-22 00:00:00', 7.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-23 00:00:00', 7.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-24 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-25 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-26 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-27 00:00:00', 7.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-28 00:00:00', 8.04800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-29 00:00:00', 7.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-30 00:00:00', 5.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-01-31 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-01 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-02 00:00:00', 7.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-03 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-04 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-05 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-06 00:00:00', 4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-07 00:00:00', 6.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-08 00:00:00', 6.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-09 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-10 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-11 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-12 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-13 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-14 00:00:00', 7.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-15 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-16 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-17 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-18 00:00:00', 4.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-19 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-20 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-21 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-22 00:00:00', 5.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-23 00:00:00', 5.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-24 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-25 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-26 00:00:00', 6.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-27 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-28 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-02-29 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-01 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-02 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-03 00:00:00', 5.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-04 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-05 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-06 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-07 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-08 00:00:00', 6.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-09 00:00:00', 6.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-10 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-11 00:00:00', 5.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-12 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-13 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-14 00:00:00', 7.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-15 00:00:00', 7.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-16 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-17 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-18 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-19 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-20 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-21 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-22 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-23 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-24 00:00:00', 6.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-25 00:00:00', 6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-26 00:00:00', 5.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-27 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-28 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-29 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-30 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-03-31 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-01 00:00:00', 5.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-02 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-03 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-04 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-05 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-06 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-07 00:00:00', 5.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-08 00:00:00', 5.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-09 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-10 00:00:00', 5.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-11 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-12 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-13 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-14 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-15 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-16 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-17 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-18 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-19 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-20 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-21 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-22 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-23 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-24 00:00:00', 5.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-25 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-26 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-27 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-28 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-29 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-04-30 00:00:00', 5.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-01 00:00:00', 6.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-02 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-03 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-04 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-05 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-06 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-07 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-08 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-09 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-10 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-11 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-12 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-13 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-14 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-15 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-16 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-17 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-18 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-19 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-20 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-21 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-22 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-23 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-24 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-25 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-26 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-27 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-28 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-29 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-30 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-05-31 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-01 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-02 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-03 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-04 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-05 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-06 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-07 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-08 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-09 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-10 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-11 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-12 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-13 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-14 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-15 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-16 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-17 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-18 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-19 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-20 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-21 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-22 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-23 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-24 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-25 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-26 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-27 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-28 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-29 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-06-30 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-01 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-02 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-03 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-04 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-05 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-06 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-07 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-08 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-09 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-10 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-11 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-12 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-13 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-14 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-15 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-16 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-17 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-18 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-19 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-20 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-21 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-22 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-23 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-24 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-25 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-26 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-27 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-28 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-29 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-30 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-07-31 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-01 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-02 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-03 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-04 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-05 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-06 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-07 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-08 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-09 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-10 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-11 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-12 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-13 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-14 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-15 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-16 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-17 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-18 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-19 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-20 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-21 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-22 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-23 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-24 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-25 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-26 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-27 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-28 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-29 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-30 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-08-31 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-01 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-02 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-03 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-04 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-05 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-06 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-07 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-08 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-09 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-10 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-11 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-12 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-13 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-14 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-15 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-16 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-17 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-18 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-19 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-20 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-21 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-22 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-23 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-24 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-25 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-26 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-27 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-28 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-29 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-09-30 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-01 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-02 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-03 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-04 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-05 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-06 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-07 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-08 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-09 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-10 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-11 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-12 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-13 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-14 00:00:00', 5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-15 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-16 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-17 00:00:00', 4.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-18 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-19 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-20 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-21 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-22 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-23 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-24 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-25 00:00:00', 5.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-26 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-27 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-28 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-29 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-30 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-10-31 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-01 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-02 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-03 00:00:00', 4.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-04 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-05 00:00:00', 4.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-06 00:00:00', 4.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-07 00:00:00', 4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-08 00:00:00', 1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-09 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-10 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-11 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-12 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-13 00:00:00', 5.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-14 00:00:00', 6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-15 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-16 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-17 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-18 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-19 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-20 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-21 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-22 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-23 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-24 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-25 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-26 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-27 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-28 00:00:00', 7.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-29 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-11-30 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-01 00:00:00', 6.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-02 00:00:00', 5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-03 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-04 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-05 00:00:00', 5.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-06 00:00:00', 5.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-07 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-08 00:00:00', 5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-09 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-10 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-11 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-12 00:00:00', 5.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-13 00:00:00', 6.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-14 00:00:00', 6.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-15 00:00:00', 7.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-16 00:00:00', 6.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-17 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-18 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-19 00:00:00', 5.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-20 00:00:00', 6.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-21 00:00:00', 6.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-22 00:00:00', 7.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-23 00:00:00', 5.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-24 00:00:00', 6.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-25 00:00:00', 7.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-26 00:00:00', 7.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-27 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-28 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-29 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-30 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2000-12-31 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-01 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-02 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-03 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-04 00:00:00', 6.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-05 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-06 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-07 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-08 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-09 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-10 00:00:00', 4.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-11 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-12 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-13 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-14 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-15 00:00:00', 7.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-16 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-17 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-18 00:00:00', 6.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-19 00:00:00', 7.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-20 00:00:00', 6.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-21 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-22 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-23 00:00:00', 6.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-24 00:00:00', 6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-25 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-26 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-27 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-28 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-29 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-30 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-01-31 00:00:00', 0.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-01 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-02 00:00:00', 6.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-03 00:00:00', 6.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-04 00:00:00', 7.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-05 00:00:00', 7.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-06 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-07 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-08 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-09 00:00:00', 4.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-10 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-11 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-12 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-13 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-14 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-15 00:00:00', 7.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-16 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-17 00:00:00', 6.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-18 00:00:00', 7.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-19 00:00:00', 7.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-20 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-21 00:00:00', 8.61900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-22 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-23 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-24 00:00:00', 6.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-25 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-26 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-27 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-02-28 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-01 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-02 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-03 00:00:00', 4.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-04 00:00:00', 5.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-05 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-06 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-07 00:00:00', 6.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-08 00:00:00', 6.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-09 00:00:00', 6.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-10 00:00:00', 6.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-11 00:00:00', 4.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-12 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-13 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-14 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-15 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-16 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-17 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-18 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-19 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-20 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-21 00:00:00', 4.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-22 00:00:00', 5.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-23 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-24 00:00:00', 6.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-25 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-26 00:00:00', 7.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-27 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-28 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-29 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-30 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-03-31 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-01 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-02 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-03 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-04 00:00:00', 4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-05 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-06 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-07 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-08 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-09 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-10 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-11 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-12 00:00:00', 5.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-13 00:00:00', 6.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-14 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-15 00:00:00', 5.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-16 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-17 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-18 00:00:00', 5.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-19 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-20 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-21 00:00:00', 4.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-22 00:00:00', 5.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-23 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-24 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-25 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-26 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-27 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-28 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-29 00:00:00', 4.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-04-30 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-01 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-02 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-03 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-04 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-05 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-06 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-07 00:00:00', 4.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-08 00:00:00', 5.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-09 00:00:00', 6.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-10 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-11 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-12 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-13 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-14 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-15 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-16 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-17 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-18 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-19 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-20 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-21 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-22 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-23 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-24 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-25 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-26 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-27 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-28 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-29 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-30 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-05-31 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-01 00:00:00', 4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-02 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-03 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-04 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-05 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-06 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-07 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-08 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-09 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-10 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-11 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-12 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-13 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-14 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-15 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-16 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-17 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-18 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-19 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-20 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-21 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-22 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-23 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-24 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-25 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-26 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-27 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-28 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-29 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-06-30 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-01 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-02 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-03 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-04 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-05 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-06 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-07 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-08 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-09 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-10 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-11 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-12 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-13 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-14 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-15 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-16 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-17 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-18 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-19 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-20 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-21 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-22 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-23 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-24 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-25 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-26 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-27 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-28 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-29 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-30 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-07-31 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-01 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-02 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-03 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-04 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-05 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-06 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-07 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-08 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-09 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-10 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-11 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-12 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-13 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-14 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-15 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-16 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-17 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-18 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-19 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-20 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-21 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-22 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-23 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-24 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-25 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-26 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-27 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-28 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-29 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-30 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-08-31 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-01 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-02 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-03 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-04 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-05 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-06 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-07 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-08 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-09 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-10 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-11 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-12 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-13 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-14 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-15 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-16 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-17 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-18 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-19 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-20 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-21 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-22 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-23 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-24 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-25 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-26 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-27 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-28 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-29 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-09-30 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-01 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-02 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-03 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-04 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-05 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-06 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-07 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-08 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-09 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-10 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-11 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-12 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-13 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-14 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-15 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-16 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-17 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-18 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-19 00:00:00', 5.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-20 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-21 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-22 00:00:00', 6.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-23 00:00:00', 5.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-24 00:00:00', 5.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-25 00:00:00', 6.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-26 00:00:00', 5.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-27 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-28 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-29 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-30 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-10-31 00:00:00', 6.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-01 00:00:00', 5.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-02 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-03 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-04 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-05 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-06 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-07 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-08 00:00:00', 7.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-09 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-10 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-11 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-12 00:00:00', 6.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-13 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-14 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-15 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-16 00:00:00', 6.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-17 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-18 00:00:00', 6.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-19 00:00:00', 6.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-20 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-21 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-22 00:00:00', 6.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-23 00:00:00', 5.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-24 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-25 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-26 00:00:00', 5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-27 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-28 00:00:00', 5.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-29 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-11-30 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-01 00:00:00', 4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-02 00:00:00', 4.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-03 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-04 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-05 00:00:00', 6.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-06 00:00:00', 6.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-07 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-08 00:00:00', 4.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-09 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-10 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-11 00:00:00', 5.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-12 00:00:00', 7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-13 00:00:00', 6.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-14 00:00:00', 6.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-15 00:00:00', 6.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-16 00:00:00', 6.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-17 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-18 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-19 00:00:00', 7.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-20 00:00:00', 7.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-21 00:00:00', 7.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-22 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-23 00:00:00', 6.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-24 00:00:00', 6.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-25 00:00:00', 7.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-26 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-27 00:00:00', 6.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-28 00:00:00', 6.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-29 00:00:00', 7.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-30 00:00:00', 7.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2001-12-31 00:00:00', 6.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-01 00:00:00', 7.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-02 00:00:00', 7.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-03 00:00:00', 4.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-04 00:00:00', 5.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-05 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-06 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-07 00:00:00', 7.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-08 00:00:00', 7.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-09 00:00:00', 6.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-10 00:00:00', 5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-11 00:00:00', 5.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-12 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-13 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-14 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-15 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-16 00:00:00', 5.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-17 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-18 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-19 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-20 00:00:00', 5.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-21 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-22 00:00:00', 6.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-23 00:00:00', 5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-24 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-25 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-26 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-27 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-28 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-29 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-30 00:00:00', 6.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-01-31 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-01 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-02 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-03 00:00:00', 7.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-04 00:00:00', 5.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-05 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-06 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-07 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-08 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-09 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-10 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-11 00:00:00', 6.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-12 00:00:00', 7.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-13 00:00:00', 8.34500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-14 00:00:00', 8.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-15 00:00:00', 5.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-16 00:00:00', 5.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-17 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-18 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-19 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-20 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-21 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-22 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-23 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-24 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-25 00:00:00', 7.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-26 00:00:00', 7.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-27 00:00:00', 7.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-02-28 00:00:00', 7.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-01 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-02 00:00:00', 4.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-03 00:00:00', 5.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-04 00:00:00', 5.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-05 00:00:00', 5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-06 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-07 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-08 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-09 00:00:00', 6.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-10 00:00:00', 6.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-11 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-12 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-13 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-14 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-15 00:00:00', 6.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-16 00:00:00', 7.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-17 00:00:00', 6.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-18 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-19 00:00:00', 6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-20 00:00:00', 5.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-21 00:00:00', 6.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-22 00:00:00', 6.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-23 00:00:00', 6.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-24 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-25 00:00:00', 5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-26 00:00:00', 6.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-27 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-28 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-29 00:00:00', 7.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-30 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-03-31 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-01 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-02 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-03 00:00:00', 6.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-04 00:00:00', 7.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-05 00:00:00', 6.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-06 00:00:00', 5.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-07 00:00:00', 5.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-08 00:00:00', 6.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-09 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-10 00:00:00', 3.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-11 00:00:00', 5.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-12 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-13 00:00:00', 6.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-14 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-15 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-16 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-17 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-18 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-19 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-20 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-21 00:00:00', 6.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-22 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-23 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-24 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-25 00:00:00', 4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-26 00:00:00', 6.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-27 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-28 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-29 00:00:00', 5.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-04-30 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-01 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-02 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-03 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-04 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-05 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-06 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-07 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-08 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-09 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-10 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-11 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-12 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-13 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-14 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-15 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-16 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-17 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-18 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-19 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-20 00:00:00', 4.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-21 00:00:00', 4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-22 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-23 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-24 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-25 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-26 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-27 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-28 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-29 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-30 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-05-31 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-01 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-02 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-03 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-04 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-05 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-06 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-07 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-08 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-09 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-10 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-11 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-12 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-13 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-14 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-15 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-16 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-17 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-18 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-19 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-20 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-21 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-22 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-23 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-24 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-25 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-26 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-27 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-28 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-29 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-06-30 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-01 00:00:00', 4.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-02 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-03 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-04 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-05 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-06 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-07 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-08 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-09 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-10 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-11 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-12 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-13 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-14 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-15 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-16 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-17 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-18 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-19 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-20 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-21 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-22 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-23 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-24 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-25 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-26 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-27 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-28 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-29 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-30 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-07-31 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-01 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-02 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-03 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-04 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-05 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-06 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-07 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-08 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-09 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-10 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-11 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-12 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-13 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-14 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-15 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-16 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-17 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-18 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-19 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-20 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-21 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-22 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-23 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-24 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-25 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-26 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-27 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-28 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-29 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-30 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-08-31 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-01 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-02 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-03 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-04 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-05 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-06 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-07 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-08 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-09 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-10 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-11 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-12 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-13 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-14 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-15 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-16 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-17 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-18 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-19 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-20 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-21 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-22 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-23 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-24 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-25 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-26 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-27 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-28 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-29 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-09-30 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-01 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-02 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-03 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-04 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-05 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-06 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-07 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-08 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-09 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-10 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-11 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-12 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-13 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-14 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-15 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-16 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-17 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-18 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-19 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-20 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-21 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-22 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-23 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-24 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-25 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-26 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-27 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-28 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-29 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-30 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-10-31 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-01 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-02 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-03 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-04 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-05 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-06 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-07 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-08 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-09 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-10 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-11 00:00:00', 5.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-12 00:00:00', 6.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-13 00:00:00', 6.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-14 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-15 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-16 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-17 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-18 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-19 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-20 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-21 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-22 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-23 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-24 00:00:00', 5.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-25 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-26 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-27 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-28 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-29 00:00:00', 5.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-11-30 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-01 00:00:00', 6.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-02 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-03 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-04 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-05 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-06 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-07 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-08 00:00:00', 6.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-09 00:00:00', 8.06499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-10 00:00:00', 7.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-11 00:00:00', 6.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-12 00:00:00', 5.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-13 00:00:00', 7.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-14 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-15 00:00:00', 4.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-16 00:00:00', 6.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-17 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-18 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-19 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-20 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-21 00:00:00', 8.17800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-22 00:00:00', 8.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-23 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-24 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-25 00:00:00', 7.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-26 00:00:00', 6.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-27 00:00:00', 7.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-28 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-29 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-30 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2002-12-31 00:00:00', 4.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-01 00:00:00', 4.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-02 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-03 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-04 00:00:00', 6.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-05 00:00:00', 6.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-06 00:00:00', 5.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-07 00:00:00', 6.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-08 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-09 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-10 00:00:00', 6.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-11 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-12 00:00:00', 6.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-13 00:00:00', 7.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-14 00:00:00', 7.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-15 00:00:00', 7.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-16 00:00:00', 8.31499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-17 00:00:00', 6.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-18 00:00:00', 6.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-19 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-20 00:00:00', 4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-21 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-22 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-23 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-24 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-25 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-26 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-27 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-28 00:00:00', 6.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-29 00:00:00', 7.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-30 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-01-31 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-01 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-02 00:00:00', 6.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-03 00:00:00', 6.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-04 00:00:00', 7.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-05 00:00:00', 7.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-06 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-07 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-08 00:00:00', 5.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-09 00:00:00', 6.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-10 00:00:00', 6.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-11 00:00:00', 6.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-12 00:00:00', 6.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-13 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-14 00:00:00', 8.30799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-15 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-16 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-17 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-18 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-19 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-20 00:00:00', 7.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-21 00:00:00', 6.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-22 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-23 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-24 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-25 00:00:00', 5.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-26 00:00:00', 6.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-27 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-02-28 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-01 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-02 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-03 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-04 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-05 00:00:00', 4.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-06 00:00:00', 5.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-07 00:00:00', 6.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-08 00:00:00', 7.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-09 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-10 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-11 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-12 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-13 00:00:00', 7.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-14 00:00:00', 6.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-15 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-16 00:00:00', 5.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-17 00:00:00', 6.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-18 00:00:00', 5.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-19 00:00:00', 6.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-20 00:00:00', 8.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-21 00:00:00', 8.10299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-22 00:00:00', 6.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-23 00:00:00', 6.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-24 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-25 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-26 00:00:00', 7.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-27 00:00:00', 7.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-28 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-29 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-30 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-03-31 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-01 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-02 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-03 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-04 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-05 00:00:00', 5.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-06 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-07 00:00:00', 5.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-08 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-09 00:00:00', 4.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-10 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-11 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-12 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-13 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-14 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-15 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-16 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-17 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-18 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-19 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-20 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-21 00:00:00', 5.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-22 00:00:00', 5.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-23 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-24 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-25 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-26 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-27 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-28 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-29 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-04-30 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-01 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-02 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-03 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-04 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-05 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-06 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-07 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-08 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-09 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-10 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-11 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-12 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-13 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-14 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-15 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-16 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-17 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-18 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-19 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-20 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-21 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-22 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-23 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-24 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-25 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-26 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-27 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-28 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-29 00:00:00', 4.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-30 00:00:00', 5.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-05-31 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-01 00:00:00', 4.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-02 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-03 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-04 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-05 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-06 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-07 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-08 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-09 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-10 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-11 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-12 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-13 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-14 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-15 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-16 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-17 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-18 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-19 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-20 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-21 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-22 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-23 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-24 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-25 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-26 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-27 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-28 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-29 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-06-30 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-01 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-02 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-03 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-04 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-05 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-06 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-07 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-08 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-09 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-10 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-11 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-12 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-13 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-14 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-15 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-16 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-17 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-18 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-19 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-20 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-21 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-22 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-23 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-24 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-25 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-26 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-27 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-28 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-29 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-30 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-07-31 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-01 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-02 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-03 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-04 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-05 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-06 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-07 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-08 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-09 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-10 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-11 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-12 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-13 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-14 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-15 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-16 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-17 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-18 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-19 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-20 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-21 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-22 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-23 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-24 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-25 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-26 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-27 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-28 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-29 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-30 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-08-31 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-01 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-02 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-03 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-04 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-05 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-06 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-07 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-08 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-09 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-10 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-11 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-12 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-13 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-14 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-15 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-16 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-17 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-18 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-19 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-20 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-21 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-22 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-23 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-24 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-25 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-26 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-27 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-28 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-29 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-09-30 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-01 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-02 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-03 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-04 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-05 00:00:00', 5.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-06 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-07 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-08 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-09 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-10 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-11 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-12 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-13 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-14 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-15 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-16 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-17 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-18 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-19 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-20 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-21 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-22 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-23 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-24 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-25 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-26 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-27 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-28 00:00:00', 5.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-29 00:00:00', 5.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-30 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-10-31 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-01 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-02 00:00:00', 6.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-03 00:00:00', 6.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-04 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-05 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-06 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-07 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-08 00:00:00', 4.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-09 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-10 00:00:00', 5.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-11 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-12 00:00:00', 6.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-13 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-14 00:00:00', 6.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-15 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-16 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-17 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-18 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-19 00:00:00', 5.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-20 00:00:00', 7.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-21 00:00:00', 6.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-22 00:00:00', 7.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-23 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-24 00:00:00', 5.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-25 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-26 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-27 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-28 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-29 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-11-30 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-01 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-02 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-03 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-04 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-05 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-06 00:00:00', 7.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-07 00:00:00', 7.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-08 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-09 00:00:00', 6.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-10 00:00:00', 7.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-11 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-12 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-13 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-14 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-15 00:00:00', 4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-16 00:00:00', 5.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-17 00:00:00', 6.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-18 00:00:00', 6.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-19 00:00:00', 7.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-20 00:00:00', 7.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-21 00:00:00', 6.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-22 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-23 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-24 00:00:00', 6.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-25 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-26 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-27 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-28 00:00:00', 6.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-29 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-30 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2003-12-31 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-01 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-02 00:00:00', 5.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-03 00:00:00', 6.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-04 00:00:00', 7.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-05 00:00:00', 5.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-06 00:00:00', 8.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-07 00:00:00', 6.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-08 00:00:00', 7.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-09 00:00:00', 8.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-10 00:00:00', 6.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-11 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-12 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-13 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-14 00:00:00', 7.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-15 00:00:00', 6.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-16 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-17 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-18 00:00:00', 5.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-19 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-20 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-21 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-22 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-23 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-24 00:00:00', 7.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-25 00:00:00', 5.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-26 00:00:00', 6.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-27 00:00:00', 7.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-28 00:00:00', 5.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-29 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-30 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-01-31 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-01 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-02 00:00:00', 6.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-03 00:00:00', 5.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-04 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-05 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-06 00:00:00', 7.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-07 00:00:00', 7.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-08 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-09 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-10 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-11 00:00:00', 6.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-12 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-13 00:00:00', 5.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-14 00:00:00', 7.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-15 00:00:00', 9.08800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-16 00:00:00', 7.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-17 00:00:00', 5.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-18 00:00:00', 6.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-19 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-20 00:00:00', 8.06000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-21 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-22 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-23 00:00:00', 6.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-24 00:00:00', 7.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-25 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-26 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-27 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-28 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-02-29 00:00:00', 5.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-01 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-02 00:00:00', 6.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-03 00:00:00', 5.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-04 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-05 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-06 00:00:00', 6.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-07 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-08 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-09 00:00:00', 1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-10 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-11 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-12 00:00:00', 7.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-13 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-14 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-15 00:00:00', 5.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-16 00:00:00', 6.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-17 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-18 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-19 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-20 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-21 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-22 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-23 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-24 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-25 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-26 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-27 00:00:00', 4.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-28 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-29 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-30 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-03-31 00:00:00', 6.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-01 00:00:00', 5.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-02 00:00:00', 6.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-03 00:00:00', 5.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-04 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-05 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-06 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-07 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-08 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-09 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-10 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-11 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-12 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-13 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-14 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-15 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-16 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-17 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-18 00:00:00', 5.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-19 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-20 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-21 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-22 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-23 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-24 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-25 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-26 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-27 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-28 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-29 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-04-30 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-01 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-02 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-03 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-04 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-05 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-06 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-07 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-08 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-09 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-10 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-11 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-12 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-13 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-14 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-15 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-16 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-17 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-18 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-19 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-20 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-21 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-22 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-23 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-24 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-25 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-26 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-27 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-28 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-29 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-30 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-05-31 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-01 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-02 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-03 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-04 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-05 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-06 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-07 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-08 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-09 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-10 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-11 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-12 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-13 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-14 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-15 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-16 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-17 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-18 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-19 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-20 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-21 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-22 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-23 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-24 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-25 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-26 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-27 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-28 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-29 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-06-30 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-01 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-02 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-03 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-04 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-05 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-06 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-07 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-08 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-09 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-10 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-11 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-12 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-13 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-14 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-15 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-16 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-17 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-18 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-19 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-20 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-21 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-22 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-23 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-24 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-25 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-26 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-27 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-28 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-29 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-30 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-07-31 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-01 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-02 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-03 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-04 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-05 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-06 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-07 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-08 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-09 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-10 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-11 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-12 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-13 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-14 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-15 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-16 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-17 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-18 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-19 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-20 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-21 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-22 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-23 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-24 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-25 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-26 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-27 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-28 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-29 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-30 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-08-31 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-01 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-02 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-03 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-04 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-05 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-06 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-07 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-08 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-09 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-10 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-11 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-12 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-13 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-14 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-15 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-16 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-17 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-18 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-19 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-20 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-21 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-22 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-23 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-24 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-25 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-26 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-27 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-28 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-29 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-09-30 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-01 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-02 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-03 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-04 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-05 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-06 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-07 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-08 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-09 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-10 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-11 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-12 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-13 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-14 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-15 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-16 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-17 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-18 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-19 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-20 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-21 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-22 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-23 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-24 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-25 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-26 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-27 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-28 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-29 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-30 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-10-31 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-01 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-02 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-03 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-04 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-05 00:00:00', 4.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-06 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-07 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-08 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-09 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-10 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-11 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-12 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-13 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-14 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-15 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-16 00:00:00', 4.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-17 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-18 00:00:00', 6.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-19 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-20 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-21 00:00:00', 5.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-22 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-23 00:00:00', 5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-24 00:00:00', 6.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-25 00:00:00', 5.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-26 00:00:00', 6.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-27 00:00:00', 7.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-28 00:00:00', 7.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-29 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-11-30 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-01 00:00:00', 6.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-02 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-03 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-04 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-05 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-06 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-07 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-08 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-09 00:00:00', 6.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-10 00:00:00', 6.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-11 00:00:00', 6.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-12 00:00:00', 7.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-13 00:00:00', 7.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-14 00:00:00', 6.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-15 00:00:00', 7.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-16 00:00:00', 7.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-17 00:00:00', 6.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-18 00:00:00', 4.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-19 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-20 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-21 00:00:00', 6.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-22 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-23 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-24 00:00:00', 5.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-25 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-26 00:00:00', 6.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-27 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-28 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-29 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-30 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2004-12-31 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-01 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-02 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-03 00:00:00', 6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-04 00:00:00', 8.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-05 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-06 00:00:00', 6.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-07 00:00:00', 6.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-08 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-09 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-10 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-11 00:00:00', 5.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-12 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-13 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-14 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-15 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-16 00:00:00', 5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-17 00:00:00', 4.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-18 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-19 00:00:00', 6.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-20 00:00:00', 7.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-21 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-22 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-23 00:00:00', 7.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-24 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-25 00:00:00', 7.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-26 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-27 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-28 00:00:00', 5.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-29 00:00:00', 6.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-30 00:00:00', 5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-01-31 00:00:00', 7.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-01 00:00:00', 8.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-02 00:00:00', 6.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-03 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-04 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-05 00:00:00', 6.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-06 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-07 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-08 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-09 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-10 00:00:00', 6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-11 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-12 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-13 00:00:00', 5.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-14 00:00:00', 5.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-15 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-16 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-17 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-18 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-19 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-20 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-21 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-22 00:00:00', 6.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-23 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-24 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-25 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-26 00:00:00', 6.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-27 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-02-28 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-01 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-02 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-03 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-04 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-05 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-06 00:00:00', 5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-07 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-08 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-09 00:00:00', 5.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-10 00:00:00', 5.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-11 00:00:00', 6.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-12 00:00:00', 6.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-13 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-14 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-15 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-16 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-17 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-18 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-19 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-20 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-21 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-22 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-23 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-24 00:00:00', 5.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-25 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-26 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-27 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-28 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-29 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-30 00:00:00', 5.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-03-31 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-01 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-02 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-03 00:00:00', 6.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-04 00:00:00', 7.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-05 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-06 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-07 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-08 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-09 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-10 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-11 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-12 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-13 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-14 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-15 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-16 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-17 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-18 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-19 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-20 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-21 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-22 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-23 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-24 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-25 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-26 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-27 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-28 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-29 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-04-30 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-01 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-02 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-03 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-04 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-05 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-06 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-07 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-08 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-09 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-10 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-11 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-12 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-13 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-14 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-15 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-16 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-17 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-18 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-19 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-20 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-21 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-22 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-23 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-24 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-25 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-26 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-27 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-28 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-29 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-30 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-05-31 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-01 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-02 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-03 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-04 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-05 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-06 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-07 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-08 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-09 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-10 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-11 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-12 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-13 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-14 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-15 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-16 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-17 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-18 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-19 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-20 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-21 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-22 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-23 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-24 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-25 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-26 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-27 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-28 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-29 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-06-30 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-01 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-02 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-03 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-04 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-05 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-06 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-07 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-08 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-09 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-10 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-11 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-12 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-13 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-14 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-15 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-16 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-17 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-18 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-19 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-20 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-21 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-22 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-23 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-24 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-25 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-26 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-27 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-28 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-29 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-30 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-07-31 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-01 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-02 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-03 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-04 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-05 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-06 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-07 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-08 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-09 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-10 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-11 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-12 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-13 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-14 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-15 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-16 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-17 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-18 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-19 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-20 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-21 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-22 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-23 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-24 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-25 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-26 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-27 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-28 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-29 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-30 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-08-31 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-01 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-02 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-03 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-04 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-05 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-06 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-07 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-08 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-09 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-10 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-11 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-12 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-13 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-14 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-15 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-16 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-17 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-18 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-19 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-20 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-21 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-22 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-23 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-24 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-25 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-26 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-27 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-28 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-29 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-09-30 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-01 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-02 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-03 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-04 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-05 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-06 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-07 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-08 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-09 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-10 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-11 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-12 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-13 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-14 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-15 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-16 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-17 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-18 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-19 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-20 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-21 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-22 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-23 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-24 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-25 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-26 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-27 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-28 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-29 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-30 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-10-31 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-01 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-02 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-03 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-04 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-05 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-06 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-07 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-08 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-09 00:00:00', 6.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-10 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-11 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-12 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-13 00:00:00', 5.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-14 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-15 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-16 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-17 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-18 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-19 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-20 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-21 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-22 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-23 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-24 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-25 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-26 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-27 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-28 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-29 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-11-30 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-01 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-02 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-03 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-04 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-05 00:00:00', 4.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-06 00:00:00', 5.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-07 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-08 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-09 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-10 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-11 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-12 00:00:00', 1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-13 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-14 00:00:00', 4.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-15 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-16 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-17 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-18 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-19 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-20 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-21 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-22 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-23 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-24 00:00:00', 6.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-25 00:00:00', 7.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-26 00:00:00', 6.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-27 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-28 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-29 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-30 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2005-12-31 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-01 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-02 00:00:00', 1.16299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-03 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-04 00:00:00', 5.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-05 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-06 00:00:00', 6.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-07 00:00:00', 6.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-08 00:00:00', 7.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-09 00:00:00', 6.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-10 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-11 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-12 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-13 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-14 00:00:00', 6.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-15 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-16 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-17 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-18 00:00:00', 5.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-19 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-20 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-21 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-22 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-23 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-24 00:00:00', 6.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-25 00:00:00', 6.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-26 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-27 00:00:00', 5.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-28 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-29 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-30 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-01-31 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-01 00:00:00', 8.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-02 00:00:00', 7.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-03 00:00:00', 8.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-04 00:00:00', 7.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-05 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-06 00:00:00', 5.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-07 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-08 00:00:00', 6.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-09 00:00:00', 7.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-10 00:00:00', 7.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-11 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-12 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-13 00:00:00', 6.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-14 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-15 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-16 00:00:00', 6.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-17 00:00:00', 7.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-18 00:00:00', 5.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-19 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-20 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-21 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-22 00:00:00', 4.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-23 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-24 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-25 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-26 00:00:00', 5.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-27 00:00:00', 6.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-02-28 00:00:00', 6.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-01 00:00:00', 5.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-02 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-03 00:00:00', 7.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-04 00:00:00', 6.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-05 00:00:00', 5.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-06 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-07 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-08 00:00:00', 5.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-09 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-10 00:00:00', 5.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-11 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-12 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-13 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-14 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-15 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-16 00:00:00', 5.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-17 00:00:00', 6.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-18 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-19 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-20 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-21 00:00:00', 5.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-22 00:00:00', 1.13699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-23 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-24 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-25 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-26 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-27 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-28 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-29 00:00:00', 6.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-30 00:00:00', 6.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-03-31 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-01 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-02 00:00:00', 4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-03 00:00:00', 4.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-04 00:00:00', 6.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-05 00:00:00', 4.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-06 00:00:00', 5.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-07 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-08 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-09 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-10 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-11 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-12 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-13 00:00:00', 5.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-14 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-15 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-16 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-17 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-18 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-19 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-20 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-21 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-22 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-23 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-24 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-25 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-26 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-27 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-28 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-29 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-04-30 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-01 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-02 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-03 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-04 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-05 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-06 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-07 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-08 00:00:00', 4.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-09 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-10 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-11 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-12 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-13 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-14 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-15 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-16 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-17 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-18 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-19 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-20 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-21 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-22 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-23 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-24 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-25 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-26 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-27 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-28 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-29 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-30 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-05-31 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-01 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-02 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-03 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-04 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-05 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-06 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-07 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-08 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-09 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-10 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-11 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-12 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-13 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-14 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-15 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-16 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-17 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-18 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-19 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-20 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-21 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-22 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-23 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-24 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-25 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-26 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-27 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-28 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-29 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-06-30 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-01 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-02 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-03 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-04 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-05 00:00:00', 4.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-06 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-07 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-08 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-09 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-10 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-11 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-12 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-13 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-14 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-15 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-16 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-17 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-18 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-19 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-20 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-21 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-22 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-23 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-24 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-25 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-26 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-27 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-28 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-29 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-30 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-07-31 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-01 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-02 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-03 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-04 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-05 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-06 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-07 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-08 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-09 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-10 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-11 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-12 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-13 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-14 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-15 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-16 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-17 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-18 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-19 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-20 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-21 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-22 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-23 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-24 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-25 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-26 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-27 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-28 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-29 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-30 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-08-31 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-01 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-02 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-03 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-04 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-05 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-06 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-07 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-08 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-09 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-10 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-11 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-12 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-13 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-14 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-15 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-16 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-17 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-18 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-19 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-20 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-21 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-22 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-23 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-24 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-25 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-26 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-27 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-28 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-29 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-09-30 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-01 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-02 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-03 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-04 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-05 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-06 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-07 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-08 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-09 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-10 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-11 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-12 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-13 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-14 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-15 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-16 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-17 00:00:00', 5.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-18 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-19 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-20 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-21 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-22 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-23 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-24 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-25 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-26 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-27 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-28 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-29 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-30 00:00:00', 4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-10-31 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-01 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-02 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-03 00:00:00', 5.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-04 00:00:00', 4.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-05 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-06 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-07 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-08 00:00:00', 5.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-09 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-10 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-11 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-12 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-13 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-14 00:00:00', 5.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-15 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-16 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-17 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-18 00:00:00', 6.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-19 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-20 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-21 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-22 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-23 00:00:00', 4.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-24 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-25 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-26 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-27 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-28 00:00:00', 6.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-29 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-11-30 00:00:00', 5.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-01 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-02 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-03 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-04 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-05 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-06 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-07 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-08 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-09 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-10 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-11 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-12 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-13 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-14 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-15 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-16 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-17 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-18 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-19 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-20 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-21 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-22 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-23 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-24 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-25 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-26 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-27 00:00:00', 7.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-28 00:00:00', 6.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-29 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-30 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2006-12-31 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-01 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-02 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-03 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-04 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-05 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-06 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-07 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-08 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-09 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-10 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-11 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-12 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-13 00:00:00', 6.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-14 00:00:00', 7.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-15 00:00:00', 6.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-16 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-17 00:00:00', 7.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-18 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-19 00:00:00', 5.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-20 00:00:00', 5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-21 00:00:00', 6.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-22 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-23 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-24 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-25 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-26 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-27 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-28 00:00:00', 6.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-29 00:00:00', 6.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-30 00:00:00', 6.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-01-31 00:00:00', 7.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-01 00:00:00', 7.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-02 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-03 00:00:00', 6.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-04 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-05 00:00:00', 7.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-06 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-07 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-08 00:00:00', 7.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-09 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-10 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-11 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-12 00:00:00', 0.982999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-13 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-14 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-15 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-16 00:00:00', 5.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-17 00:00:00', 5.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-18 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-19 00:00:00', 0.930999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-20 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-21 00:00:00', 4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-22 00:00:00', 7.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-23 00:00:00', 6.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-24 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-25 00:00:00', 6.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-26 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-27 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-02-28 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-01 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-02 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-03 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-04 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-05 00:00:00', 5.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-06 00:00:00', 5.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-07 00:00:00', 6.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-08 00:00:00', 5.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-09 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-10 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-11 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-12 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-13 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-14 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-15 00:00:00', 7.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-16 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-17 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-18 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-19 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-20 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-21 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-22 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-23 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-24 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-25 00:00:00', 7.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-26 00:00:00', 6.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-27 00:00:00', 7.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-28 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-29 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-30 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-03-31 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-01 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-02 00:00:00', 5.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-03 00:00:00', 6.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-04 00:00:00', 6.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-05 00:00:00', 6.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-06 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-07 00:00:00', 6.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-08 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-09 00:00:00', 5.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-10 00:00:00', 5.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-11 00:00:00', 4.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-12 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-13 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-14 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-15 00:00:00', 5.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-16 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-17 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-18 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-19 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-20 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-21 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-22 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-23 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-24 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-25 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-26 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-27 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-28 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-29 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-04-30 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-01 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-02 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-03 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-04 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-05 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-06 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-07 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-08 00:00:00', 1.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-09 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-10 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-11 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-12 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-13 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-14 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-15 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-16 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-17 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-18 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-19 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-20 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-21 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-22 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-23 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-24 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-25 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-26 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-27 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-28 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-29 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-30 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-05-31 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-01 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-02 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-03 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-04 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-05 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-06 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-07 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-08 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-09 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-10 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-11 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-12 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-13 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-14 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-15 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-16 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-17 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-18 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-19 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-20 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-21 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-22 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-23 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-24 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-25 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-26 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-27 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-28 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-29 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-06-30 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-01 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-02 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-03 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-04 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-05 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-06 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-07 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-08 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-09 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-10 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-11 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-12 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-13 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-14 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-15 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-16 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-17 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-18 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-19 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-20 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-21 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-22 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-23 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-24 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-25 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-26 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-27 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-28 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-29 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-30 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-07-31 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-01 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-02 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-03 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-04 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-05 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-06 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-07 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-08 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-09 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-10 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-11 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-12 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-13 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-14 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-15 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-16 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-17 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-18 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-19 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-20 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-21 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-22 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-23 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-24 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-25 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-26 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-27 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-28 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-29 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-30 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-08-31 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-01 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-02 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-03 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-04 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-05 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-06 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-07 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-08 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-09 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-10 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-11 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-12 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-13 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-14 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-15 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-16 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-17 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-18 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-19 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-20 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-21 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-22 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-23 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-24 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-25 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-26 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-27 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-28 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-29 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-09-30 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-01 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-02 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-03 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-04 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-05 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-06 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-07 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-08 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-09 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-10 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-11 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-12 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-13 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-14 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-15 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-16 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-17 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-18 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-19 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-20 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-21 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-22 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-23 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-24 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-25 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-26 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-27 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-28 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-29 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-30 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-10-31 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-01 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-02 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-03 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-04 00:00:00', 5.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-05 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-06 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-07 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-08 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-09 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-10 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-11 00:00:00', 6.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-12 00:00:00', 6.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-13 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-14 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-15 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-16 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-17 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-18 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-19 00:00:00', 6.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-20 00:00:00', 4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-21 00:00:00', 6.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-22 00:00:00', 7.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-23 00:00:00', 4.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-24 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-25 00:00:00', 5.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-26 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-27 00:00:00', 4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-28 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-29 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-11-30 00:00:00', 4.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-01 00:00:00', 1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-02 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-03 00:00:00', 7.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-04 00:00:00', 6.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-05 00:00:00', 7.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-06 00:00:00', 6.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-07 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-08 00:00:00', 6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-09 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-10 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-11 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-12 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-13 00:00:00', 5.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-14 00:00:00', 7.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-15 00:00:00', 6.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-16 00:00:00', 7.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-17 00:00:00', 6.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-18 00:00:00', 5.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-19 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-20 00:00:00', 7.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-21 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-22 00:00:00', 8.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-23 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-24 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-25 00:00:00', 5.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-26 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-27 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-28 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-29 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-30 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2007-12-31 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-01 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-02 00:00:00', 7.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-03 00:00:00', 6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-04 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-05 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-06 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-07 00:00:00', 4.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-08 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-09 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-10 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-11 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-12 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-13 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-14 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-15 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-16 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-17 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-18 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-19 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-20 00:00:00', 4.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-21 00:00:00', 4.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-22 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-23 00:00:00', 4.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-24 00:00:00', 5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-25 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-26 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-27 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-28 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-29 00:00:00', 4.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-30 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-01-31 00:00:00', 6.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-01 00:00:00', 5.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-02 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-03 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-04 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-05 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-06 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-07 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-08 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-09 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-10 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-11 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-12 00:00:00', 7.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-13 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-14 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-15 00:00:00', 7.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-16 00:00:00', 5.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-17 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-18 00:00:00', 6.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-19 00:00:00', 7.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-20 00:00:00', 8.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-21 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-22 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-23 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-24 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-25 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-26 00:00:00', 6.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-27 00:00:00', 7.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-28 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-02-29 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-01 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-02 00:00:00', 5.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-03 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-04 00:00:00', 7.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-05 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-06 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-07 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-08 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-09 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-10 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-11 00:00:00', 5.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-12 00:00:00', 6.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-13 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-14 00:00:00', 6.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-15 00:00:00', 7.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-16 00:00:00', 6.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-17 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-18 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-19 00:00:00', 4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-20 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-21 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-22 00:00:00', 5.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-23 00:00:00', 4.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-24 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-25 00:00:00', 4.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-26 00:00:00', 4.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-27 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-28 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-29 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-30 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-03-31 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-01 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-02 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-03 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-04 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-05 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-06 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-07 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-08 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-09 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-10 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-11 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-12 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-13 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-14 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-15 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-16 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-17 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-18 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-19 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-20 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-21 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-22 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-23 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-24 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-25 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-26 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-27 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-28 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-29 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-04-30 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-01 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-02 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-03 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-04 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-05 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-06 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-07 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-08 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-09 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-10 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-11 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-12 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-13 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-14 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-15 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-16 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-17 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-18 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-19 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-20 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-21 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-22 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-23 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-24 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-25 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-26 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-27 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-28 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-29 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-30 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-05-31 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-01 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-02 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-03 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-04 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-05 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-06 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-07 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-08 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-09 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-10 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-11 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-12 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-13 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-14 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-15 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-16 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-17 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-18 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-19 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-20 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-21 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-22 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-23 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-24 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-25 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-26 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-27 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-28 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-29 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-06-30 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-01 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-02 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-03 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-04 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-05 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-06 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-07 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-08 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-09 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-10 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-11 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-12 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-13 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-14 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-15 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-16 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-17 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-18 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-19 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-20 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-21 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-22 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-23 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-24 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-25 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-26 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-27 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-28 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-29 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-30 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-07-31 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-01 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-02 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-03 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-04 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-05 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-06 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-07 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-08 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-09 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-10 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-11 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-12 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-13 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-14 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-15 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-16 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-17 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-18 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-19 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-20 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-21 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-22 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-23 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-24 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-25 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-26 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-27 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-28 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-29 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-30 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-08-31 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-01 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-02 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-03 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-04 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-05 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-06 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-07 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-08 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-09 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-10 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-11 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-12 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-13 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-14 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-15 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-16 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-17 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-18 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-19 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-20 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-21 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-22 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-23 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-24 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-25 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-26 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-27 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-28 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-29 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-09-30 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-01 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-02 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-03 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-04 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-05 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-06 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-07 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-08 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-09 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-10 00:00:00', 5.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-11 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-12 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-13 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-14 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-15 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-16 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-17 00:00:00', 4.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-18 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-19 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-20 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-21 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-22 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-23 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-24 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-25 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-26 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-27 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-28 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-29 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-30 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-10-31 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-01 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-02 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-03 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-04 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-05 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-06 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-07 00:00:00', 6.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-08 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-09 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-10 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-11 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-12 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-13 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-14 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-15 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-16 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-17 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-18 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-19 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-20 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-21 00:00:00', 7.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-22 00:00:00', 6.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-23 00:00:00', 7.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-24 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-25 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-26 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-27 00:00:00', 6.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-28 00:00:00', 7.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-29 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-11-30 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-01 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-02 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-03 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-04 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-05 00:00:00', 1.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-06 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-07 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-08 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-09 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-10 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-11 00:00:00', 4.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-12 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-13 00:00:00', 5.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-14 00:00:00', 5.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-15 00:00:00', 7.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-16 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-17 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-18 00:00:00', 1.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-19 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-20 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-21 00:00:00', 6.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-22 00:00:00', 7.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-23 00:00:00', 6.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-24 00:00:00', 7.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-25 00:00:00', 7.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-26 00:00:00', 5.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-27 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-28 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-29 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-30 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2008-12-31 00:00:00', 6.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-01 00:00:00', 7.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-02 00:00:00', 6.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-03 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-04 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-05 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-06 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-07 00:00:00', 5.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-08 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-09 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-10 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-11 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-12 00:00:00', 6.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-13 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-14 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-15 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-16 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-17 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-18 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-19 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-20 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-21 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-22 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-23 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-24 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-25 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-26 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-27 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-28 00:00:00', 6.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-29 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-30 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-01-31 00:00:00', 7.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-01 00:00:00', 7.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-02 00:00:00', 6.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-03 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-04 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-05 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-06 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-07 00:00:00', 6.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-08 00:00:00', 6.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-09 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-10 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-11 00:00:00', 7.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-12 00:00:00', 5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-13 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-14 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-15 00:00:00', 6.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-16 00:00:00', 6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-17 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-18 00:00:00', 7.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-19 00:00:00', 4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-20 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-21 00:00:00', 6.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-22 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-23 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-24 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-25 00:00:00', 4.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-26 00:00:00', 4.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-27 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-02-28 00:00:00', 6.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-01 00:00:00', 7.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-02 00:00:00', 8.01500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-03 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-04 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-05 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-06 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-07 00:00:00', 4.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-08 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-09 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-10 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-11 00:00:00', 5.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-12 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-13 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-14 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-15 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-16 00:00:00', 5.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-17 00:00:00', 6.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-18 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-19 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-20 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-21 00:00:00', 5.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-22 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-23 00:00:00', 4.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-24 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-25 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-26 00:00:00', 4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-27 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-28 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-29 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-30 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-03-31 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-01 00:00:00', 4.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-02 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-03 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-04 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-05 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-06 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-07 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-08 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-09 00:00:00', 5.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-10 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-11 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-12 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-13 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-14 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-15 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-16 00:00:00', 5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-17 00:00:00', 5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-18 00:00:00', 5.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-19 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-20 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-21 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-22 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-23 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-24 00:00:00', 4.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-25 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-26 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-27 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-28 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-29 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-04-30 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-01 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-02 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-03 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-04 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-05 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-06 00:00:00', 4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-07 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-08 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-09 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-10 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-11 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-12 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-13 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-14 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-15 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-16 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-17 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-18 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-19 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-20 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-21 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-22 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-23 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-24 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-25 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-26 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-27 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-28 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-29 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-30 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-05-31 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-01 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-02 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-03 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-04 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-05 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-06 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-07 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-08 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-09 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-10 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-11 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-12 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-13 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-14 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-15 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-16 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-17 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-18 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-19 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-20 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-21 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-22 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-23 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-24 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-25 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-26 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-27 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-28 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-29 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-06-30 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-01 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-02 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-03 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-04 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-05 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-06 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-07 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-08 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-09 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-10 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-11 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-12 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-13 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-14 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-15 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-16 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-17 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-18 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-19 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-20 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-21 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-22 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-23 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-24 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-25 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-26 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-27 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-28 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-29 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-30 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-07-31 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-01 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-02 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-03 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-04 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-05 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-06 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-07 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-08 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-09 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-10 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-11 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-12 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-13 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-14 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-15 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-16 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-17 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-18 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-19 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-20 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-21 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-22 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-23 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-24 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-25 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-26 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-27 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-28 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-29 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-30 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-08-31 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-01 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-02 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-03 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-04 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-05 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-06 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-07 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-08 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-09 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-10 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-11 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-12 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-13 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-14 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-15 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-16 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-17 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-18 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-19 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-20 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-21 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-22 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-23 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-24 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-25 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-26 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-27 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-28 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-29 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-09-30 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-01 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-02 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-03 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-04 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-05 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-06 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-07 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-08 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-09 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-10 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-11 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-12 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-13 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-14 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-15 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-16 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-17 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-18 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-19 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-20 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-21 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-22 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-23 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-24 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-25 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-26 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-27 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-28 00:00:00', 4.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-29 00:00:00', 5.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-30 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-10-31 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-01 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-02 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-03 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-04 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-05 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-06 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-07 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-08 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-09 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-10 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-11 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-12 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-13 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-14 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-15 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-16 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-17 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-18 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-19 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-20 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-21 00:00:00', 6.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-22 00:00:00', 5.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-23 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-24 00:00:00', 6.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-25 00:00:00', 0.994000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-26 00:00:00', 5.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-27 00:00:00', 6.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-28 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-29 00:00:00', 5.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-11-30 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-01 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-02 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-03 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-04 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-05 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-06 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-07 00:00:00', 6.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-08 00:00:00', 6.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-09 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-10 00:00:00', 0.957000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-11 00:00:00', 5.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-12 00:00:00', 4.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-13 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-14 00:00:00', 6.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-15 00:00:00', 7.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-16 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-17 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-18 00:00:00', 7.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-19 00:00:00', 7.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-20 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-21 00:00:00', 6.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-22 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-23 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-24 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-25 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-26 00:00:00', 4.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-27 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-28 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-29 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-30 00:00:00', 5.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2009-12-31 00:00:00', 5.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-01 00:00:00', 5.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-02 00:00:00', 5.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-03 00:00:00', 6.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-04 00:00:00', 7.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-05 00:00:00', 7.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-06 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-07 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-08 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-09 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-10 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-11 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-12 00:00:00', 5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-13 00:00:00', 5.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-14 00:00:00', 8.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-15 00:00:00', 7.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-16 00:00:00', 7.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-17 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-18 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-19 00:00:00', 5.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-20 00:00:00', 7.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-21 00:00:00', 7.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-22 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-23 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-24 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-25 00:00:00', 6.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-26 00:00:00', 7.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-27 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-28 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-29 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-30 00:00:00', 7.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-01-31 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-01 00:00:00', 5.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-02 00:00:00', 6.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-03 00:00:00', 4.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-04 00:00:00', 7.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-05 00:00:00', 7.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-06 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-07 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-08 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-09 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-10 00:00:00', 6.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-11 00:00:00', 5.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-12 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-13 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-14 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-15 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-16 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-17 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-18 00:00:00', 6.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-19 00:00:00', 6.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-20 00:00:00', 6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-21 00:00:00', 7.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-22 00:00:00', 5.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-23 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-24 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-25 00:00:00', 6.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-26 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-27 00:00:00', 6.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-02-28 00:00:00', 5.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-01 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-02 00:00:00', 5.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-03 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-04 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-05 00:00:00', 6.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-06 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-07 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-08 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-09 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-10 00:00:00', 4.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-11 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-12 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-13 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-14 00:00:00', 6.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-15 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-16 00:00:00', 6.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-17 00:00:00', 6.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-18 00:00:00', 6.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-19 00:00:00', 6.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-20 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-21 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-22 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-23 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-24 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-25 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-26 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-27 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-28 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-29 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-30 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-03-31 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-01 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-02 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-03 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-04 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-05 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-06 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-07 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-08 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-09 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-10 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-11 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-12 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-13 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-14 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-15 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-16 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-17 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-18 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-19 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-20 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-21 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-22 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-23 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-24 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-25 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-26 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-27 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-28 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-29 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-04-30 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-01 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-02 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-03 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-04 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-05 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-06 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-07 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-08 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-09 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-10 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-11 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-12 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-13 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-14 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-15 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-16 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-17 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-18 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-19 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-20 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-21 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-22 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-23 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-24 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-25 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-26 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-27 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-28 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-29 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-30 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-05-31 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-01 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-02 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-03 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-04 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-05 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-06 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-07 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-08 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-09 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-10 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-11 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-12 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-13 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-14 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-15 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-16 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-17 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-18 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-19 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-20 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-21 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-22 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-23 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-24 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-25 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-26 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-27 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-28 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-29 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-06-30 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-01 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-02 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-03 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-04 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-05 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-06 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-07 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-08 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-09 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-10 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-11 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-12 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-13 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-14 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-15 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-16 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-17 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-18 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-19 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-20 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-21 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-22 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-23 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-24 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-25 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-26 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-27 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-28 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-29 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-30 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-07-31 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-01 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-02 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-03 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-04 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-05 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-06 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-07 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-08 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-09 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-10 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-11 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-12 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-13 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-14 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-15 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-16 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-17 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-18 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-19 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-20 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-21 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-22 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-23 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-24 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-25 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-26 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-27 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-28 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-29 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-30 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-08-31 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-01 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-02 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-03 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-04 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-05 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-06 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-07 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-08 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-09 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-10 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-11 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-12 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-13 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-14 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-15 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-16 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-17 00:00:00', 1.02400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-18 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-19 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-20 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-21 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-22 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-23 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-24 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-25 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-26 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-27 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-28 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-29 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-09-30 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-01 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-02 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-03 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-04 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-05 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-06 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-07 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-08 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-09 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-10 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-11 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-12 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-13 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-14 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-15 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-16 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-17 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-18 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-19 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-20 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-21 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-22 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-23 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-24 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-25 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-26 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-27 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-28 00:00:00', 5.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-29 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-30 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-10-31 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-01 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-02 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-03 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-04 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-05 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-06 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-07 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-08 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-09 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-10 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-11 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-12 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-13 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-14 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-15 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-16 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-17 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-18 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-19 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-20 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-21 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-22 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-23 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-24 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-25 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-26 00:00:00', 4.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-27 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-28 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-29 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-11-30 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-01 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-02 00:00:00', 5.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-03 00:00:00', 3.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-04 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-05 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-06 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-07 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-08 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-09 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-10 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-11 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-12 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-13 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-14 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-15 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-16 00:00:00', 6.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-17 00:00:00', 5.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-18 00:00:00', 6.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-19 00:00:00', 6.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-20 00:00:00', 5.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-21 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-22 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-23 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-24 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-25 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-26 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-27 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-28 00:00:00', 0.873000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-29 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-30 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2010-12-31 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-01 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-02 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-03 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-04 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-05 00:00:00', 5.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-06 00:00:00', 5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-07 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-08 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-09 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-10 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-11 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-12 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-13 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-14 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-15 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-16 00:00:00', 5.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-17 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-18 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-19 00:00:00', 4.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-20 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-21 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-22 00:00:00', 4.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-23 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-24 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-25 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-26 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-27 00:00:00', 5.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-28 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-29 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-30 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-01-31 00:00:00', 6.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-01 00:00:00', 5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-02 00:00:00', 5.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-03 00:00:00', 5.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-04 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-05 00:00:00', 4.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-06 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-07 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-08 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-09 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-10 00:00:00', 4.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-11 00:00:00', 5.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-12 00:00:00', 5.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-13 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-14 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-15 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-16 00:00:00', 5.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-17 00:00:00', 5.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-18 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-19 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-20 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-21 00:00:00', 6.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-22 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-23 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-24 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-25 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-26 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-27 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-02-28 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-01 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-02 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-03 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-04 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-05 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-06 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-07 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-08 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-09 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-10 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-11 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-12 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-13 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-14 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-15 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-16 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-17 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-18 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-19 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-20 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-21 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-22 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-23 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-24 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-25 00:00:00', 5.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-26 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-27 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-28 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-29 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-30 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-03-31 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-01 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-02 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-03 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-04 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-05 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-06 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-07 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-08 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-09 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-10 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-11 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-12 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-13 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-14 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-15 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-16 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-17 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-18 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-19 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-20 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-21 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-22 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-23 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-24 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-25 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-26 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-27 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-28 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-29 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-04-30 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-01 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-02 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-03 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-04 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-05 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-06 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-07 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-08 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-09 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-10 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-11 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-12 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-13 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-14 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-15 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-16 00:00:00', 4.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-17 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-18 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-19 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-20 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-21 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-22 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-23 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-24 00:00:00', 4.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-25 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-26 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-27 00:00:00', 4.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-28 00:00:00', 4.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-29 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-30 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-05-31 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-01 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-02 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-03 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-04 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-05 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-06 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-07 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-08 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-09 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-10 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-11 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-12 00:00:00', 4.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-13 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-14 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-15 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-16 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-17 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-18 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-19 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-20 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-21 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-22 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-23 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-24 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-25 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-26 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-27 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-28 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-29 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-06-30 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-01 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-02 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-03 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-04 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-05 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-06 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-07 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-08 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-09 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-10 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-11 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-12 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-13 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-14 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-15 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-16 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-17 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-18 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-19 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-20 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-21 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-22 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-23 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-24 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-25 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-26 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-27 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-28 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-29 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-30 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-07-31 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-01 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-02 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-03 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-04 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-05 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-06 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-07 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-08 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-09 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-10 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-11 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-12 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-13 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-14 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-15 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-16 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-17 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-18 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-19 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-20 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-21 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-22 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-23 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-24 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-25 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-26 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-27 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-28 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-29 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-30 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-08-31 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-01 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-02 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-03 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-04 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-05 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-06 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-07 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-08 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-09 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-10 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-11 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-12 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-13 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-14 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-15 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-16 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-17 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-18 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-19 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-20 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-21 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-22 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-23 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-24 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-25 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-26 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-27 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-28 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-29 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-09-30 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-01 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-02 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-03 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-04 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-05 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-06 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-07 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-08 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-09 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-10 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-11 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-12 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-13 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-14 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-15 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-16 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-17 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-18 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-19 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-20 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-21 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-22 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-23 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-24 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-25 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-26 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-27 00:00:00', 5.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-28 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-29 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-30 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-10-31 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-01 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-02 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-03 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-04 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-05 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-06 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-07 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-08 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-09 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-10 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-11 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-12 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-13 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-14 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-15 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-16 00:00:00', 5.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-17 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-18 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-19 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-20 00:00:00', 5.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-21 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-22 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-23 00:00:00', 4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-24 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-25 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-26 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-27 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-28 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-29 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-11-30 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-01 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-02 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-03 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-04 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-05 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-06 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-07 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-08 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-09 00:00:00', 5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-10 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-11 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-12 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-13 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-14 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-15 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-16 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-17 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-18 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-19 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-20 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-21 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-22 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-23 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-24 00:00:00', 5.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-25 00:00:00', 6.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-26 00:00:00', 4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-27 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-28 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-29 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-30 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2011-12-31 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-01 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-02 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-03 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-04 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-05 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-06 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-07 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-08 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-09 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-10 00:00:00', 5.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-11 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-12 00:00:00', 6.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-13 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-14 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-15 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-16 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-17 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-18 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-19 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-20 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-21 00:00:00', 5.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-22 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-23 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-24 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-25 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-26 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-27 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-28 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-29 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-30 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-01-31 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-01 00:00:00', 5.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-02 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-03 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-04 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-05 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-06 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-07 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-08 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-09 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-10 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-11 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-12 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-13 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-14 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-15 00:00:00', 6.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-16 00:00:00', 6.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-17 00:00:00', 6.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-18 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-19 00:00:00', 5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-20 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-21 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-22 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-23 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-24 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-25 00:00:00', 5.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-26 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-27 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-28 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-02-29 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-01 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-02 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-03 00:00:00', 5.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-04 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-05 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-06 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-07 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-08 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-09 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-10 00:00:00', 4.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-11 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-12 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-13 00:00:00', 5.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-14 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-15 00:00:00', 6.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-16 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-17 00:00:00', 5.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-18 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-19 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-20 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-21 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-22 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-23 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-24 00:00:00', 5.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-25 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-26 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-27 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-28 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-29 00:00:00', 4.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-30 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-03-31 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-01 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-02 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-03 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-04 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-05 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-06 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-07 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-08 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-09 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-10 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-11 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-12 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-13 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-14 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-15 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-16 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-17 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-18 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-19 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-20 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-21 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-22 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-23 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-24 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-25 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-26 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-27 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-28 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-29 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-04-30 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-01 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-02 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-03 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-04 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-05 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-06 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-07 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-08 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-09 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-10 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-11 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-12 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-13 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-14 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-15 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-16 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-17 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-18 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-19 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-20 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-21 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-22 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-23 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-24 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-25 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-26 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-27 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-28 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-29 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-30 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-05-31 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-01 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-02 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-03 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-04 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-05 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-06 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-07 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-08 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-09 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-10 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-11 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-12 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-13 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-14 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-15 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-16 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-17 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-18 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-19 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-20 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-21 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-22 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-23 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-24 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-25 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-26 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-27 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-28 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-29 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-06-30 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-01 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-02 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-03 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-04 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-05 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-06 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-07 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-08 00:00:00', 4.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-09 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-10 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-11 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-12 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-13 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-14 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-15 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-16 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-17 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-18 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-19 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-20 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-21 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-22 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-23 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-24 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-25 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-26 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-27 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-28 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-29 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-30 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-07-31 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-01 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-02 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-03 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-04 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-05 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-06 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-07 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-08 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-09 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-10 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-11 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-12 00:00:00', 4.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-13 00:00:00', 4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-14 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-15 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-16 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-17 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-18 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-19 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-20 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-21 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-22 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-23 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-24 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-25 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-26 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-27 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-28 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-29 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-30 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-08-31 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-01 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-02 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-03 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-04 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-05 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-06 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-07 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-08 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-09 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-10 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-11 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-12 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-13 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-14 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-15 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-16 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-17 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-18 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-19 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-20 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-21 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-22 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-23 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-24 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-25 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-26 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-27 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-28 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-29 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-09-30 00:00:00', 4.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-01 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-02 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-03 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-04 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-05 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-06 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-07 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-08 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-09 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-10 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-11 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-12 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-13 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-14 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-15 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-16 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-17 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-18 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-19 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-20 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-21 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-22 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-23 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-24 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-25 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-26 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-27 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-28 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-29 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-30 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-10-31 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-01 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-02 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-03 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-04 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-05 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-06 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-07 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-08 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-09 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-10 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-11 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-12 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-13 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-14 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-15 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-16 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-17 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-18 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-19 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-20 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-21 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-22 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-23 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-24 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-25 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-26 00:00:00', 4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-27 00:00:00', 5.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-28 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-29 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-11-30 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-01 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-02 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-03 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-04 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-05 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-06 00:00:00', 4.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-07 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-08 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-09 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-10 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-11 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-12 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-13 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-14 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-15 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-16 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-17 00:00:00', 5.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-18 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-19 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-20 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-21 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-22 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-23 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-24 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-25 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-26 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-27 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-28 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-29 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-30 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2012-12-31 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-01 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-02 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-03 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-04 00:00:00', 5.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-05 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-06 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-07 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-08 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-09 00:00:00', 5.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-10 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-11 00:00:00', 5.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-12 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-13 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-14 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-15 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-16 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-17 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-18 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-19 00:00:00', 5.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-20 00:00:00', 6.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-21 00:00:00', 5.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-22 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-23 00:00:00', 5.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-24 00:00:00', 5.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-25 00:00:00', 6.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-26 00:00:00', 6.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-27 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-28 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-29 00:00:00', 5.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-30 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-01-31 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-01 00:00:00', 6.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-02 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-03 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-04 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-05 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-06 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-07 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-08 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-09 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-10 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-11 00:00:00', 4.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-12 00:00:00', 5.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-13 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-14 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-15 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-16 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-17 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-18 00:00:00', 4.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-19 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-20 00:00:00', 6.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-21 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-22 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-23 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-24 00:00:00', 5.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-25 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-26 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-27 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-02-28 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-01 00:00:00', 6.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-02 00:00:00', 6.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-03 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-04 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-05 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-06 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-07 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-08 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-09 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-10 00:00:00', 5.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-11 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-12 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-13 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-14 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-15 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-16 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-17 00:00:00', 6.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-18 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-19 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-20 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-21 00:00:00', 4.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-22 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-23 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-24 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-25 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-26 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-27 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-28 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-29 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-30 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-03-31 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-01 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-02 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-03 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-04 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-05 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-06 00:00:00', 5.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-07 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-08 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-09 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-10 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-11 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-12 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-13 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-14 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-15 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-16 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-17 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-18 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-19 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-20 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-21 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-22 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-23 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-24 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-25 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-26 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-27 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-28 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-29 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-04-30 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-01 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-02 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-03 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-04 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-05 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-06 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-07 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-08 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-09 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-10 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-11 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-12 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-13 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-14 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-15 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-16 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-17 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-18 00:00:00', 5.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-19 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-20 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-21 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-22 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-23 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-24 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-25 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-26 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-27 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-28 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-29 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-30 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-05-31 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-01 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-02 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-03 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-04 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-05 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-06 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-07 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-08 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-09 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-10 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-11 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-12 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-13 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-14 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-15 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-16 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-17 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-18 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-19 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-20 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-21 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-22 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-23 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-24 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-25 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-26 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-27 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-28 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-29 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-06-30 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-01 00:00:00', 4.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-02 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-03 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-04 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-05 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-06 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-07 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-08 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-09 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-10 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-11 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-12 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-13 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-14 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-15 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-16 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-17 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-18 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-19 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-20 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-21 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-22 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-23 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-24 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-25 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-26 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-27 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-28 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-29 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-30 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-07-31 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-01 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-02 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-03 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-04 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-05 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-06 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-07 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-08 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-09 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-10 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-11 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-12 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-13 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-14 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-15 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-16 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-17 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-18 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-19 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-20 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-21 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-22 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-23 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-24 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-25 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-26 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-27 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-28 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-29 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-30 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-08-31 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-01 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-02 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-03 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-04 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-05 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-06 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-07 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-08 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-09 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-10 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-11 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-12 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-13 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-14 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-15 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-16 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-17 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-18 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-19 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-20 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-21 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-22 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-23 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-24 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-25 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-26 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-27 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-28 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-29 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-09-30 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-01 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-02 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-03 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-04 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-05 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-06 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-07 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-08 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-09 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-10 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-11 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-12 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-13 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-14 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-15 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-16 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-17 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-18 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-19 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-20 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-21 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-22 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-23 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-24 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-25 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-26 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-27 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-28 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-29 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-30 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-10-31 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-01 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-02 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-03 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-04 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-05 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-06 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-07 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-08 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-09 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-10 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-11 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-12 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-13 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-14 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-15 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-16 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-17 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-18 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-19 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-20 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-21 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-22 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-23 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-24 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-25 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-26 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-27 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-28 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-29 00:00:00', 5.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-11-30 00:00:00', 5.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-01 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-02 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-03 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-04 00:00:00', 6.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-05 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-06 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-07 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-08 00:00:00', 4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-09 00:00:00', 5.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-10 00:00:00', 5.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-11 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-12 00:00:00', 6.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-13 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-14 00:00:00', 5.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-15 00:00:00', 5.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-16 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-17 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-18 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-19 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-20 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-21 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-22 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-23 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-24 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-25 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-26 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-27 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-28 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-29 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-30 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2013-12-31 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-01 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-02 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-03 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-04 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-05 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-06 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-07 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-08 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-09 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-10 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-11 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-12 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-13 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-14 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-15 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-16 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-17 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-18 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-19 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-20 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-21 00:00:00', 4.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-22 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-23 00:00:00', 5.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-24 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-25 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-26 00:00:00', 5.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-27 00:00:00', 5.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-28 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-29 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-30 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-01-31 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-01 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-02 00:00:00', 3.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-03 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-04 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-05 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-06 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-07 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-08 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-09 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-10 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-11 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-12 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-13 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-14 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-15 00:00:00', 1.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-16 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-17 00:00:00', 4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-18 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-19 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-20 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-21 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-22 00:00:00', 5.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-23 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-24 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-25 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-26 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-27 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-02-28 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-01 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-02 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-03 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-04 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-05 00:00:00', 5.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-06 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-07 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-08 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-09 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-10 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-11 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-12 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-13 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-14 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-15 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-16 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-17 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-18 00:00:00', 4.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-19 00:00:00', 5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-20 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-21 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-22 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-23 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-24 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-25 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-26 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-27 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-28 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-29 00:00:00', 5.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-30 00:00:00', 5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-03-31 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-01 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-02 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-03 00:00:00', 5.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-04 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-05 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-06 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-07 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-08 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-09 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-10 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-11 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-12 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-13 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-14 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-15 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-16 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-17 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-18 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-19 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-20 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-21 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-22 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-23 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-24 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-25 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-26 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-27 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-28 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-29 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-04-30 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-01 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-02 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-03 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-04 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-05 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-06 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-07 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-08 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-09 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-10 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-11 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-12 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-13 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-14 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-15 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-16 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-17 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-18 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-19 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-20 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-21 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-22 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-23 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-24 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-25 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-26 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-27 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-28 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-29 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-30 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-05-31 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-01 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-02 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-03 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-04 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-05 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-06 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-07 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-08 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-09 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-10 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-11 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-12 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-13 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-14 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-15 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-16 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-17 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-18 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-19 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-20 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-21 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-22 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-23 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-24 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-25 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-26 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-27 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-28 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-29 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-06-30 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-01 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-02 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-03 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-04 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-05 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-06 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-07 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-08 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-09 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-10 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-11 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-12 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-13 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-14 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-15 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-16 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-17 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-18 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-19 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-20 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-21 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-22 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-23 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-24 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-25 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-26 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-27 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-28 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-29 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-30 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (32, '2014-07-31 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-01 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-02 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-03 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-04 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-05 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-06 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-07 00:00:00', 4.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-08 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-09 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-10 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-11 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-12 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-13 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-14 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-15 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-16 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-17 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-18 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-19 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-20 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-21 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-22 00:00:00', 5.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-23 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-24 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-25 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-26 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-27 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-28 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-29 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-30 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-01-31 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-01 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-02 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-03 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-04 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-05 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-06 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-07 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-08 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-09 00:00:00', 4.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-10 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-11 00:00:00', 4.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-12 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-13 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-14 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-15 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-16 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-17 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-18 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-19 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-20 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-21 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-22 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-23 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-24 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-25 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-26 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-27 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-02-28 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-01 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-02 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-03 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-04 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-05 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-06 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-07 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-08 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-09 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-10 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-11 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-12 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-13 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-14 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-15 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-16 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-17 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-18 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-19 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-20 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-21 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-22 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-23 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-24 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-25 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-26 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-27 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-28 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-29 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-30 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-03-31 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-01 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-02 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-03 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-04 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-05 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-06 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-07 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-08 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-09 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-10 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-11 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-12 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-13 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-14 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-15 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-16 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-17 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-18 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-19 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-20 00:00:00', 5.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-21 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-22 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-23 00:00:00', 5.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-24 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-25 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-26 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-27 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-28 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-29 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-04-30 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-01 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-02 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-03 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-04 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-05 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-06 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-07 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-08 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-09 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-10 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-11 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-12 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-13 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-14 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-15 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-16 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-17 00:00:00', 4.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-18 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-19 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-20 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-21 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-22 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-23 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-24 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-25 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-26 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-27 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-28 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-29 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-30 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-05-31 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-01 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-02 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-03 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-04 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-05 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-06 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-07 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-08 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-09 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-10 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-11 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-12 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-13 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-14 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-15 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-16 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-17 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-18 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-19 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-20 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-21 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-22 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-23 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-24 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-25 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-26 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-27 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-28 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-29 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-06-30 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-01 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-02 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-03 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-04 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-05 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-06 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-07 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-08 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-09 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-10 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-11 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-12 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-13 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-14 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-15 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-16 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-17 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-18 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-19 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-20 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-21 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-22 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-23 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-24 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-25 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-26 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-27 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-28 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-29 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-30 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-07-31 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-01 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-02 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-03 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-04 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-05 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-06 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-07 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-08 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-09 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-10 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-11 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-12 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-13 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-14 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-15 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-16 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-17 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-18 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-19 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-20 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-21 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-22 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-23 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-24 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-25 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-26 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-27 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-28 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-29 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-30 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-08-31 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-01 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-02 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-03 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-04 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-05 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-06 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-07 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-08 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-09 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-10 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-11 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-12 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-13 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-14 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-15 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-16 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-17 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-18 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-19 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-20 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-21 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-22 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-23 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-24 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-25 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-26 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-27 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-28 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-29 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-09-30 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-01 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-02 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-03 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-04 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-05 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-06 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-07 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-08 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-09 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-10 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-11 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-12 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-13 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-14 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-15 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-16 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-17 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-18 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-19 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-20 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-21 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-22 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-23 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-24 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-25 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-26 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-27 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-28 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-29 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-30 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-10-31 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-01 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-02 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-03 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-04 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-05 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-06 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-07 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-08 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-09 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-10 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-11 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-12 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-13 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-14 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-15 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-16 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-17 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-18 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-19 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-20 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-21 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-22 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-23 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-24 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-25 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-26 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-27 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-28 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-29 00:00:00', 4.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-11-30 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-01 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-02 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-03 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-04 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-05 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-06 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-07 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-08 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-09 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-10 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-11 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-12 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-13 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-14 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-15 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-16 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-17 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-18 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-19 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-20 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-21 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-22 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-23 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-24 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-25 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-26 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-27 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-28 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-29 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-30 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1979-12-31 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-01 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-02 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-03 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-04 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-05 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-06 00:00:00', 5.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-07 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-08 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-09 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-10 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-11 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-12 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-13 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-14 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-15 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-16 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-17 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-18 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-19 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-20 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-21 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-22 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-23 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-24 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-25 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-26 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-27 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-28 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-29 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-30 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-01-31 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-01 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-02 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-03 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-04 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-05 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-06 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-07 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-08 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-09 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-10 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-11 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-12 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-13 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-14 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-15 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-16 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-17 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-18 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-19 00:00:00', 5.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-20 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-21 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-22 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-23 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-24 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-25 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-26 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-27 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-28 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-02-29 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-01 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-02 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-03 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-04 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-05 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-06 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-07 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-08 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-09 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-10 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-11 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-12 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-13 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-14 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-15 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-16 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-17 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-18 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-19 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-20 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-21 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-22 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-23 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-24 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-25 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-26 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-27 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-28 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-29 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-30 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-03-31 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-01 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-02 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-03 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-04 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-05 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-06 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-07 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-08 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-09 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-10 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-11 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-12 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-13 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-14 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-15 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-16 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-17 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-18 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-19 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-20 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-21 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-22 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-23 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-24 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-25 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-26 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-27 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-28 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-29 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-04-30 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-01 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-02 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-03 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-04 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-05 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-06 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-07 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-08 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-09 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-10 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-11 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-12 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-13 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-14 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-15 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-16 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-17 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-18 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-19 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-20 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-21 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-22 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-23 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-24 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-25 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-26 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-27 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-28 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-29 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-30 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-05-31 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-01 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-02 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-03 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-04 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-05 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-06 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-07 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-08 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-09 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-10 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-11 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-12 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-13 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-14 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-15 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-16 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-17 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-18 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-19 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-20 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-21 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-22 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-23 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-24 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-25 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-26 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-27 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-28 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-29 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-06-30 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-01 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-02 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-03 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-04 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-05 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-06 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-07 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-08 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-09 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-10 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-11 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-12 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-13 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-14 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-15 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-16 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-17 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-18 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-19 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-20 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-21 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-22 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-23 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-24 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-25 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-26 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-27 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-28 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-29 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-30 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-07-31 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-01 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-02 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-03 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-04 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-05 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-06 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-07 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-08 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-09 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-10 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-11 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-12 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-13 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-14 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-15 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-16 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-17 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-18 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-19 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-20 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-21 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-22 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-23 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-24 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-25 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-26 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-27 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-28 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-29 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-30 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-08-31 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-01 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-02 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-03 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-04 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-05 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-06 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-07 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-08 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-09 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-10 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-11 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-12 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-13 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-14 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-15 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-16 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-17 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-18 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-19 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-20 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-21 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-22 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-23 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-24 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-25 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-26 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-27 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-28 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-29 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-09-30 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-01 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-02 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-03 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-04 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-05 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-06 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-07 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-08 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-09 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-10 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-11 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-12 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-13 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-14 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-15 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-16 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-17 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-18 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-19 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-20 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-21 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-22 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-23 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-24 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-25 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-26 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-27 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-28 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-29 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-30 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-10-31 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-01 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-02 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-03 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-04 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-05 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-06 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-07 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-08 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-09 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-10 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-11 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-12 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-13 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-14 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-15 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-16 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-17 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-18 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-19 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-20 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-21 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-22 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-23 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-24 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-25 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-26 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-27 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-28 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-29 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-11-30 00:00:00', 1.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-01 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-02 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-03 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-04 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-05 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-06 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-07 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-08 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-09 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-10 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-11 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-12 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-13 00:00:00', 4.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-14 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-15 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-16 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-17 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-18 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-19 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-20 00:00:00', 0.848999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-21 00:00:00', 1.10300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-22 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-23 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-24 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-25 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-26 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-27 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-28 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-29 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-30 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1980-12-31 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-01 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-02 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-03 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-04 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-05 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-06 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-07 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-08 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-09 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-10 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-11 00:00:00', 4.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-12 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-13 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-14 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-15 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-16 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-17 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-18 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-19 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-20 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-21 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-22 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-23 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-24 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-25 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-26 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-27 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-28 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-29 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-30 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-01-31 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-01 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-02 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-03 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-04 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-05 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-06 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-07 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-08 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-09 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-10 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-11 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-12 00:00:00', 1.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-13 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-14 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-15 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-16 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-17 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-18 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-19 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-20 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-21 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-22 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-23 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-24 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-25 00:00:00', 3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-26 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-27 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-02-28 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-01 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-02 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-03 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-04 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-05 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-06 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-07 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-08 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-09 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-10 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-11 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-12 00:00:00', 5.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-13 00:00:00', 6.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-14 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-15 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-16 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-17 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-18 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-19 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-20 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-21 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-22 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-23 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-24 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-25 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-26 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-27 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-28 00:00:00', 5.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-29 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-30 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-03-31 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-01 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-02 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-03 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-04 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-05 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-06 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-07 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-08 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-09 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-10 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-11 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-12 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-13 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-14 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-15 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-16 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-17 00:00:00', 4.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-18 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-19 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-20 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-21 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-22 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-23 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-24 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-25 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-26 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-27 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-28 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-29 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-04-30 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-01 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-02 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-03 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-04 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-05 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-06 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-07 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-08 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-09 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-10 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-11 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-12 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-13 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-14 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-15 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-16 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-17 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-18 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-19 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-20 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-21 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-22 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-23 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-24 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-25 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-26 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-27 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-28 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-29 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-30 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-05-31 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-01 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-02 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-03 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-04 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-05 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-06 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-07 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-08 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-09 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-10 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-11 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-12 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-13 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-14 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-15 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-16 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-17 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-18 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-19 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-20 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-21 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-22 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-23 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-24 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-25 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-26 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-27 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-28 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-29 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-06-30 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-01 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-02 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-03 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-04 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-05 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-06 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-07 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-08 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-09 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-10 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-11 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-12 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-13 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-14 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-15 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-16 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-17 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-18 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-19 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-20 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-21 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-22 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-23 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-24 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-25 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-26 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-27 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-28 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-29 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-30 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-07-31 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-01 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-02 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-03 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-04 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-05 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-06 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-07 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-08 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-09 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-10 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-11 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-12 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-13 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-14 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-15 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-16 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-17 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-18 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-19 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-20 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-21 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-22 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-23 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-24 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-25 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-26 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-27 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-28 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-29 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-30 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-08-31 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-01 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-02 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-03 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-04 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-05 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-06 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-07 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-08 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-09 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-10 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-11 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-12 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-13 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-14 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-15 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-16 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-17 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-18 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-19 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-20 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-21 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-22 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-23 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-24 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-25 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-26 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-27 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-28 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-29 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-09-30 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-01 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-02 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-03 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-04 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-05 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-06 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-07 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-08 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-09 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-10 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-11 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-12 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-13 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-14 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-15 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-16 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-17 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-18 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-19 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-20 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-21 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-22 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-23 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-24 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-25 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-26 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-27 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-28 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-29 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-30 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-10-31 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-01 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-02 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-03 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-04 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-05 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-06 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-07 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-08 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-09 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-10 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-11 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-12 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-13 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-14 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-15 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-16 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-17 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-18 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-19 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-20 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-21 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-22 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-23 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-24 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-25 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-26 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-27 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-28 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-29 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-11-30 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-01 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-02 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-03 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-04 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-05 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-06 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-07 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-08 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-09 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-10 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-11 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-12 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-13 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-14 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-15 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-16 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-17 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-18 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-19 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-20 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-21 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-22 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-23 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-24 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-25 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-26 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-27 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-28 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-29 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-30 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1981-12-31 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-01 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-02 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-03 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-04 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-05 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-06 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-07 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-08 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-09 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-10 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-11 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-12 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-13 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-14 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-15 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-16 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-17 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-18 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-19 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-20 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-21 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-22 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-23 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-24 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-25 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-26 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-27 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-28 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-29 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-30 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-01-31 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-01 00:00:00', 6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-02 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-03 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-04 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-05 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-06 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-07 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-08 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-09 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-10 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-11 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-12 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-13 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-14 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-15 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-16 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-17 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-18 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-19 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-20 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-21 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-22 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-23 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-24 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-25 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-26 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-27 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-02-28 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-01 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-02 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-03 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-04 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-05 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-06 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-07 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-08 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-09 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-10 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-11 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-12 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-13 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-14 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-15 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-16 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-17 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-18 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-19 00:00:00', 5.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-20 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-21 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-22 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-23 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-24 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-25 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-26 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-27 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-28 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-29 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-30 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-03-31 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-01 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-02 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-03 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-04 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-05 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-06 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-07 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-08 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-09 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-10 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-11 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-12 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-13 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-14 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-15 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-16 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-17 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-18 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-19 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-20 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-21 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-22 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-23 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-24 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-25 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-26 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-27 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-28 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-29 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-04-30 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-01 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-02 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-03 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-04 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-05 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-06 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-07 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-08 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-09 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-10 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-11 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-12 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-13 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-14 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-15 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-16 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-17 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-18 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-19 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-20 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-21 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-22 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-23 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-24 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-25 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-26 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-27 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-28 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-29 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-30 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-05-31 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-01 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-02 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-03 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-04 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-05 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-06 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-07 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-08 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-09 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-10 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-11 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-12 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-13 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-14 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-15 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-16 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-17 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-18 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-19 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-20 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-21 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-22 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-23 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-24 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-25 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-26 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-27 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-28 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-29 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-06-30 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-01 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-02 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-03 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-04 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-05 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-06 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-07 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-08 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-09 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-10 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-11 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-12 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-13 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-14 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-15 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-16 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-17 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-18 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-19 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-20 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-21 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-22 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-23 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-24 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-25 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-26 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-27 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-28 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-29 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-30 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-07-31 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-01 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-02 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-03 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-04 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-05 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-06 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-07 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-08 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-09 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-10 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-11 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-12 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-13 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-14 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-15 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-16 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-17 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-18 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-19 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-20 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-21 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-22 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-23 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-24 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-25 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-26 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-27 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-28 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-29 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-30 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-08-31 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-01 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-02 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-03 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-04 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-05 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-06 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-07 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-08 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-09 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-10 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-11 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-12 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-13 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-14 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-15 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-16 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-17 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-18 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-19 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-20 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-21 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-22 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-23 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-24 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-25 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-26 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-27 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-28 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-29 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-09-30 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-01 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-02 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-03 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-04 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-05 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-06 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-07 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-08 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-09 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-10 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-11 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-12 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-13 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-14 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-15 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-16 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-17 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-18 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-19 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-20 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-21 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-22 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-23 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-24 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-25 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-26 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-27 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-28 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-29 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-30 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-10-31 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-01 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-02 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-03 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-04 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-05 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-06 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-07 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-08 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-09 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-10 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-11 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-12 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-13 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-14 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-15 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-16 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-17 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-18 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-19 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-20 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-21 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-22 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-23 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-24 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-25 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-26 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-27 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-28 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-29 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-11-30 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-01 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-02 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-03 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-04 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-05 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-06 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-07 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-08 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-09 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-10 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-11 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-12 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-13 00:00:00', 1.10099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-14 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-15 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-16 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-17 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-18 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-19 00:00:00', 1.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-20 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-21 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-22 00:00:00', 1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-23 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-24 00:00:00', 0.971000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-25 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-26 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-27 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-28 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-29 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-30 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1982-12-31 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-01 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-02 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-03 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-04 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-05 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-06 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-07 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-08 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-09 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-10 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-11 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-12 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-13 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-14 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-15 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-16 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-17 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-18 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-19 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-20 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-21 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-22 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-23 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-24 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-25 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-26 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-27 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-28 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-29 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-30 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-01-31 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-01 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-02 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-03 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-04 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-05 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-06 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-07 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-08 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-09 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-10 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-11 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-12 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-13 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-14 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-15 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-16 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-17 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-18 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-19 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-20 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-21 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-22 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-23 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-24 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-25 00:00:00', 4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-26 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-27 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-02-28 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-01 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-02 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-03 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-04 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-05 00:00:00', 4.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-06 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-07 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-08 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-09 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-10 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-11 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-12 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-13 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-14 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-15 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-16 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-17 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-18 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-19 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-20 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-21 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-22 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-23 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-24 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-25 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-26 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-27 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-28 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-29 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-30 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-03-31 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-01 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-02 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-03 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-04 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-05 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-06 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-07 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-08 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-09 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-10 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-11 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-12 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-13 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-14 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-15 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-16 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-17 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-18 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-19 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-20 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-21 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-22 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-23 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-24 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-25 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-26 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-27 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-28 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-29 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-04-30 00:00:00', 1.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-01 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-02 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-03 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-04 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-05 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-06 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-07 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-08 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-09 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-10 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-11 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-12 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-13 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-14 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-15 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-16 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-17 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-18 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-19 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-20 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-21 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-22 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-23 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-24 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-25 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-26 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-27 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-28 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-29 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-30 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-05-31 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-01 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-02 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-03 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-04 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-05 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-06 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-07 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-08 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-09 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-10 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-11 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-12 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-13 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-14 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-15 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-16 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-17 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-18 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-19 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-20 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-21 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-22 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-23 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-24 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-25 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-26 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-27 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-28 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-29 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-06-30 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-01 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-02 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-03 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-04 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-05 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-06 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-07 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-08 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-09 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-10 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-11 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-12 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-13 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-14 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-15 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-16 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-17 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-18 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-19 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-20 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-21 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-22 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-23 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-24 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-25 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-26 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-27 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-28 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-29 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-30 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-07-31 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-01 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-02 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-03 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-04 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-05 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-06 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-07 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-08 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-09 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-10 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-11 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-12 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-13 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-14 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-15 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-16 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-17 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-18 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-19 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-20 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-21 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-22 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-23 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-24 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-25 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-26 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-27 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-28 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-29 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-30 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-08-31 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-01 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-03 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-05 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-07 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-09 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-11 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-13 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-15 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-17 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-19 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-21 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-23 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-25 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-27 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-29 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-01 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-03 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-05 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-07 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-09 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-11 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-13 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-15 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-17 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-19 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-21 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-23 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-25 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-27 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-29 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-30 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-10-31 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-01 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-02 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-03 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-04 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-05 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-06 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-07 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-08 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-09 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-10 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-11 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-12 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-13 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-14 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-15 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-16 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-17 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-18 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-19 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-20 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-21 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-22 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-23 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-24 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-25 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-26 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-27 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-28 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-29 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-11-30 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-01 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-02 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-03 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-04 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-05 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-06 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-07 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-08 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-09 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-10 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-11 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-12 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-13 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-14 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-15 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-16 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-17 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-18 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-19 00:00:00', 1.16900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-20 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-21 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-22 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-23 00:00:00', 1.15299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-24 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-25 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-26 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-27 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-28 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-29 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-30 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1983-12-31 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-01 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-02 00:00:00', 4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-03 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-04 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-05 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-06 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-07 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-08 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-09 00:00:00', 4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-10 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-11 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-12 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-13 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-14 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-15 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-16 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-17 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-18 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-19 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-20 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-21 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-22 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-23 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-24 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-25 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-26 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-27 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-28 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-29 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-30 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-01-31 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-01 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-02 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-03 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-04 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-05 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-06 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-07 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-08 00:00:00', 5.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-09 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-10 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-11 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-12 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-13 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-14 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-15 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-16 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-17 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-18 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-19 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-20 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-21 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-22 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-23 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-24 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-25 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-26 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-27 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-28 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-02-29 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-01 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-02 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-03 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-04 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-05 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-06 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-07 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-08 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-09 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-10 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-11 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-12 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-13 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-14 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-15 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-16 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-17 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-18 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-19 00:00:00', 4.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-20 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-21 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-22 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-23 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-24 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-25 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-26 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-27 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-28 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-29 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-30 00:00:00', 1.27100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-03-31 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-01 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-02 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-03 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-04 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-05 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-06 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-07 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-08 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-09 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-10 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-11 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-12 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-13 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-14 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-15 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-16 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-17 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-18 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-19 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-20 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-21 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-22 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-23 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-24 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-25 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-26 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-27 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-28 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-29 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-04-30 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-01 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-02 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-03 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-04 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-05 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-06 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-07 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-08 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-09 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-10 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-11 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-12 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-13 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-14 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-15 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-16 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-17 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-18 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-19 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-20 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-21 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-22 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-23 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-24 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-25 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-26 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-27 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-28 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-29 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-30 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-05-31 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-01 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-02 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-03 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-04 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-05 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-06 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-07 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-08 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-09 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-10 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-11 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-12 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-13 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-14 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-15 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-16 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-17 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-18 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-19 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-20 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-21 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-22 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-23 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-24 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-25 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-26 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-27 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-28 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-29 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-06-30 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-01 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-02 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-03 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-04 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-05 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-06 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-07 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-08 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-09 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-10 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-11 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-12 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-13 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-14 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-15 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-16 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-17 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-18 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-19 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-20 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-21 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-22 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-23 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-24 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-25 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-26 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-27 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-28 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-29 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-30 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-07-31 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-01 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-02 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-03 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-04 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-05 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-06 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-07 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-08 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-09 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-10 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-11 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-12 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-13 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-14 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-15 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-16 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-17 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-18 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-19 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-20 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-21 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-22 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-23 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-24 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-25 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-26 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-27 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-28 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-29 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-30 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-08-31 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-01 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-02 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-03 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-04 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-05 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-06 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-07 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-08 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-09 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-10 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-11 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-12 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-13 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-14 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-15 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-16 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-17 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-18 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-19 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-20 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-21 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-22 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-23 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-24 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-25 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-26 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-27 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-28 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-29 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-09-30 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-01 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-02 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-03 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-04 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-05 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-06 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-07 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-08 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-09 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-10 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-11 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-12 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-13 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-14 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-15 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-16 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-17 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-18 00:00:00', 4.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-19 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-20 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-21 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-22 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-23 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-24 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-25 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-26 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-27 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-28 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-29 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-30 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-10-31 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-01 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-02 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-03 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-04 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-05 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-06 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-07 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-08 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-09 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-10 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-11 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-12 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-13 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-14 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-15 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-16 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-17 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-18 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-19 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-20 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-21 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-22 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-23 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-24 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-25 00:00:00', 3.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-26 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-27 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-28 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-29 00:00:00', 5.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-11-30 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-01 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-02 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-03 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-04 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-05 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-06 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-07 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-08 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-09 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-10 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-11 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-12 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-13 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-14 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-15 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-16 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-17 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-18 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-19 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-20 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-21 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-22 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-23 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-24 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-25 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-26 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-27 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-28 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-29 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-30 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1984-12-31 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-01 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-02 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-03 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-04 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-05 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-06 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-07 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-08 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-09 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-10 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-11 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-12 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-13 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-14 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-15 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-16 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-17 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-18 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-19 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-20 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-21 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-22 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-23 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-24 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-25 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-26 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-27 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-28 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-29 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-30 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-01-31 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-01 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-02 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-03 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-04 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-05 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-06 00:00:00', 5.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-07 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-08 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-09 00:00:00', 6.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-10 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-11 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-12 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-13 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-14 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-15 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-16 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-17 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-18 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-19 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-20 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-21 00:00:00', 4.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-22 00:00:00', 4.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-23 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-24 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-25 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-26 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-27 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-02-28 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-01 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-02 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-03 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-04 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-05 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-06 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-07 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-08 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-09 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-10 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-11 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-12 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-13 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-14 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-15 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-16 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-17 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-18 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-19 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-20 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-21 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-22 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-23 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-24 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-25 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-26 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-27 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-28 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-29 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-30 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-03-31 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-01 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-02 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-03 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-04 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-05 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-06 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-07 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-08 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-09 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-10 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-11 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-12 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-13 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-14 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-15 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-16 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-17 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-18 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-19 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-20 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-21 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-22 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-23 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-24 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-25 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-26 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-27 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-28 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-29 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-04-30 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-01 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-02 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-03 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-04 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-05 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-06 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-07 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-08 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-09 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-10 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-11 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-12 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-13 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-14 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-15 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-16 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-17 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-18 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-19 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-20 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-21 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-22 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-23 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-24 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-25 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-26 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-27 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-28 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-29 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-30 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-05-31 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-01 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-02 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-03 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-04 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-05 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-06 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-07 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-08 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-09 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-10 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-11 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-12 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-13 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-14 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-15 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-16 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-17 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-18 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-19 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-20 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-21 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-22 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-23 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-24 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-25 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-26 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-27 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-28 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-29 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-06-30 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-01 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-02 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-03 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-04 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-05 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-06 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-07 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-08 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-09 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-10 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-11 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-12 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-13 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-14 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-15 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-16 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-17 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-18 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-19 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-20 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-21 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-22 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-23 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-24 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-25 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-26 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-27 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-28 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-29 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-30 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-07-31 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-01 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-02 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-03 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-04 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-05 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-06 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-07 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-08 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-09 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-10 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-11 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-12 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-13 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-14 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-15 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-16 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-17 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-18 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-19 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-20 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-21 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-22 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-23 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-24 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-25 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-26 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-27 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-28 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-29 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-30 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-08-31 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-01 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-02 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-03 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-04 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-05 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-06 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-07 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-08 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-09 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-10 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-11 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-12 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-13 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-14 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-15 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-16 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-17 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-18 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-19 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-20 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-21 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-22 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-23 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-24 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-25 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-26 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-27 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-28 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-29 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-09-30 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-01 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-02 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-03 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-04 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-05 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-06 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-07 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-08 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-09 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-10 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-11 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-12 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-13 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-14 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-15 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-16 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-17 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-18 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-19 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-20 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-21 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-22 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-23 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-24 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-25 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-26 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-27 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-28 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-29 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-30 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-10-31 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-01 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-02 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-03 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-04 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-05 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-06 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-07 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-08 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-09 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-10 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-11 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-12 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-13 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-14 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-15 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-16 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-17 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-18 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-19 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-20 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-21 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-22 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-23 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-24 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-25 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-26 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-27 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-28 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-29 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-11-30 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-01 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-02 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-03 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-04 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-05 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-06 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-07 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-08 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-09 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-10 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-11 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-12 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-13 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-14 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-15 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-16 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-17 00:00:00', 4.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-18 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-19 00:00:00', 6.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-20 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-21 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-22 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-23 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-24 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-25 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-26 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-27 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-28 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-29 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-30 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1985-12-31 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-01 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-02 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-03 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-04 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-05 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-06 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-07 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-08 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-09 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-10 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-11 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-12 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-13 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-14 00:00:00', 4.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-15 00:00:00', 4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-16 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-17 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-18 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-19 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-20 00:00:00', 6.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-21 00:00:00', 6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-22 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-23 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-24 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-25 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-26 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-27 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-28 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-29 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-30 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-01-31 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-01 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-02 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-03 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-04 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-05 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-06 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-07 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-08 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-09 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-10 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-11 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-12 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-13 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-14 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-15 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-16 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-17 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-18 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-19 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-20 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-21 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-22 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-23 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-24 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-25 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-26 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-27 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-02-28 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-01 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-02 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-03 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-04 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-05 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-06 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-07 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-08 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-09 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-10 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-11 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-12 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-13 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-14 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-15 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-16 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-17 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-18 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-19 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-20 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-21 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-22 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-23 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-24 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-25 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-26 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-27 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-28 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-29 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-30 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-03-31 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-01 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-02 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-03 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-04 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-05 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-06 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-07 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-08 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-09 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-10 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-11 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-12 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-13 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-14 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-15 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-16 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-17 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-18 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-19 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-20 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-21 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-22 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-23 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-24 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-25 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-26 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-27 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-28 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-29 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-04-30 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-01 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-02 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-03 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-04 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-05 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-06 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-07 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-08 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-09 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-10 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-11 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-12 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-13 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-14 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-15 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-16 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-17 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-18 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-19 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-20 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-21 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-22 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-23 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-24 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-25 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-26 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-27 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-28 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-29 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-30 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-01 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-02 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-03 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-04 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-05 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-06 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-07 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-08 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-09 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-10 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-11 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-12 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-13 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-14 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-15 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-16 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-17 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-18 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-19 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-20 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-21 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-22 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-23 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-24 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-25 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-26 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-27 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-28 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-29 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-06-30 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-01 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-02 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-03 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-04 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-05 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-06 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-07 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-08 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-09 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-10 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-11 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-12 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-13 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-14 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-15 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-16 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-17 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-18 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-19 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-20 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-21 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-22 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-23 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-24 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-25 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-26 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-27 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-28 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-29 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-30 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-07-31 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-01 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-02 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-03 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-04 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-05 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-06 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-07 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-08 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-09 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-10 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-11 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-12 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-13 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-14 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-15 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-16 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-17 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-18 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-19 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-20 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-21 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-22 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-23 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-24 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-25 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-26 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-27 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-28 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-29 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-30 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-08-31 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-01 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-02 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-03 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-04 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-05 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-06 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-07 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-08 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-09 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-10 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-11 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-12 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-13 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-14 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-15 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-16 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-17 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-18 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-19 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-20 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-21 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-22 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-23 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-24 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-25 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-26 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-27 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-28 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-29 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-09-30 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-01 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-02 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-03 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-04 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-05 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-06 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-07 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-08 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-09 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-10 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-11 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-12 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-13 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-14 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-15 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-16 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-17 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-18 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-19 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-20 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-21 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-22 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-23 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-24 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-25 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-26 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-27 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-28 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-29 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-30 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-10-31 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-01 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-02 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-03 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-04 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-05 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-06 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-07 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-08 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-09 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-10 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-11 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-12 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-13 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-14 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-15 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-16 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-17 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-18 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-19 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-20 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-21 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-22 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-23 00:00:00', 1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-24 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-25 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-26 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-27 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-28 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-29 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-11-30 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-01 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-02 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-03 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-04 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-05 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-06 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-07 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-08 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-09 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-10 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-11 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-12 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-13 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-14 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-15 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-16 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-17 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-18 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-19 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-20 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-21 00:00:00', 4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-22 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-23 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-24 00:00:00', 1.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-01 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-02 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-03 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-04 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-05 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-06 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-07 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-08 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-09 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-10 00:00:00', 4.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-11 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-12 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-13 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-14 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-15 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-16 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-17 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-18 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-19 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-20 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-21 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-22 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-23 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-24 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-25 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-26 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-27 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-28 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-29 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-30 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-01-31 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-01 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-02 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-03 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-04 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-05 00:00:00', 4.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-06 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-07 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-08 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-09 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-10 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-11 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-12 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-13 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-14 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-15 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-16 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-17 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-18 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-19 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-20 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-21 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-22 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-23 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-24 00:00:00', 1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-25 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-26 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-27 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-02-28 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-01 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-02 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-03 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-04 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-05 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-06 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-07 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-08 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-09 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-10 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-11 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-12 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-13 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-14 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-15 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-16 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-17 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-18 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-19 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-20 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-21 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-22 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-23 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-24 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-25 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-26 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-27 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-28 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-29 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-30 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-03-31 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-01 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-02 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-03 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-04 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-05 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-06 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-07 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-08 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-09 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-10 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-11 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-12 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-13 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-14 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-15 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-16 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-17 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-18 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-19 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-20 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-21 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-22 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-23 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-24 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-25 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-26 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-27 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-28 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-29 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-04-30 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-01 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-02 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-03 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-04 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-05 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-06 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-07 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-08 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-09 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-10 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-11 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-12 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-13 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-14 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-15 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-16 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-17 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-18 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-19 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-20 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-21 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-22 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-23 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-24 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-25 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-26 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-27 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-28 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-29 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-30 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-05-31 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-01 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-02 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-03 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-04 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-05 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-06 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-07 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-08 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-09 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-10 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-11 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-12 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-13 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-14 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-15 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-16 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-17 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-18 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-19 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-20 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-21 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-22 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-23 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-24 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-25 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-26 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-27 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-28 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-29 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-06-30 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-01 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-02 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-03 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-04 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-05 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-06 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-07 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-08 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-09 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-10 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-11 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-12 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-13 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-14 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-15 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-16 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-17 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-18 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-19 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-20 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-21 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-22 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-23 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-24 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-25 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-26 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-27 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-28 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-29 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-30 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-07-31 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-01 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-02 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-03 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-04 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-05 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-06 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-07 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-08 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-09 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-10 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-11 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-12 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-13 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-14 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-15 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-16 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-17 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-18 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-19 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-20 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-21 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-22 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-23 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-24 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-25 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-26 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-27 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-28 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-29 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-30 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-08-31 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-01 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-02 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-03 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-04 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-05 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-06 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-07 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-08 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-09 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-10 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-11 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-12 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-13 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-14 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-15 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-16 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-17 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-18 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-19 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-20 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-21 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-22 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-23 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-24 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-25 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-26 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-27 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-28 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-29 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-09-30 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-01 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-02 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-03 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-04 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-05 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-06 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-07 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-08 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-09 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-10 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-11 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-12 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-13 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-14 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-15 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-16 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-17 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-18 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-19 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-20 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-21 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-22 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-23 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-24 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-25 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-26 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-27 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-28 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-29 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-30 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-10-31 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-01 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-02 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-03 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-04 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-05 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-06 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-07 00:00:00', 5.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-08 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-09 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-10 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-11 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-12 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-13 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-14 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-15 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-16 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-17 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-18 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-19 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-20 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-21 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-22 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-23 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-24 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-25 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-26 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-27 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-28 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-29 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-11-30 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-01 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-02 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-03 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-04 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-05 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-06 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-07 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-08 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-09 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-10 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-11 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-12 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-13 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-14 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-15 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-16 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-17 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-18 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-19 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-20 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-21 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-22 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-23 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-24 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-25 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-26 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-27 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-28 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-29 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-30 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1987-12-31 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-01 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-02 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-03 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-04 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-05 00:00:00', 0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-06 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-07 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-08 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-09 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-10 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-11 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-12 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-13 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-14 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-15 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-16 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-17 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-18 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-19 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-20 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-21 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-22 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-23 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-24 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-25 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-26 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-27 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-28 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-29 00:00:00', 5.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-30 00:00:00', 4.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-01-31 00:00:00', 5.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-01 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-02 00:00:00', 5.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-03 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-04 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-05 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-06 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-07 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-08 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-09 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-10 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-11 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-12 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-13 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-14 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-15 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-16 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-17 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-18 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-19 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-20 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-21 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-22 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-23 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-24 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-25 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-26 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-27 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-28 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-02-29 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-01 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-02 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-03 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-04 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-05 00:00:00', 5.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-06 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-07 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-08 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-09 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-10 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-11 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-12 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-13 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-14 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-15 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-16 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-17 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-18 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-19 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-20 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-21 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-22 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-23 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-24 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-25 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-26 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-27 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-28 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-29 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-30 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-03-31 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-01 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-02 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-03 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-04 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-05 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-06 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-07 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-08 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-09 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-10 00:00:00', 1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-11 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-12 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-13 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-14 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-15 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-16 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-17 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-18 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-19 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-20 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-21 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-22 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-23 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-24 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-25 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-26 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-27 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-28 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-29 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-04-30 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-01 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-02 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-03 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-04 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-05 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-06 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-07 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-08 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-09 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-10 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-11 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-12 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-13 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-14 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-15 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-16 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-17 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-18 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-19 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-20 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-21 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-22 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-23 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-24 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-25 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-26 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-27 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-28 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-29 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-30 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-05-31 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-01 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-02 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-03 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-04 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-05 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-06 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-07 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-08 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-09 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-10 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-11 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-12 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-13 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-14 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-15 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-16 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-17 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-18 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-19 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-20 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-21 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-22 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-23 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-24 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-25 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-26 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-27 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-28 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-29 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-06-30 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-01 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-02 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-03 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-04 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-05 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-06 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-07 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-08 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-09 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-10 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-11 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-12 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-13 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-14 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-15 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-16 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-17 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-18 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-19 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-20 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-21 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-22 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-23 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-24 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-25 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-26 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-27 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-28 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-29 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-30 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-07-31 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-01 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-02 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-03 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-04 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-05 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-06 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-07 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-08 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-09 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-10 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-11 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-12 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-13 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-14 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-15 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-16 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-17 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-18 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-19 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-20 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-21 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-22 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-23 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-24 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-25 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-26 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-27 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-28 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-29 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-30 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-08-31 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-01 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-02 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-03 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-04 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-05 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-06 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-07 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-08 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-09 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-10 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-11 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-12 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-13 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-14 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-15 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-16 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-17 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-18 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-19 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-20 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-21 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-22 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-23 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-24 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-25 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-26 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-27 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-28 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-29 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-09-30 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-01 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-02 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-03 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-04 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-05 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-06 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-07 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-08 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-09 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-10 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-11 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-12 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-13 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-14 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-15 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-16 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-17 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-18 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-19 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-20 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-21 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-22 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-23 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-24 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-25 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-26 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-27 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-28 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-29 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-30 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-10-31 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-01 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-02 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-03 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-04 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-05 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-06 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-07 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-08 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-09 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-10 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-11 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-12 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-13 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-14 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-15 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-16 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-17 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-18 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-19 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-20 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-21 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-22 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-23 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-24 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-25 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-26 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-27 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-28 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-29 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-11-30 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-01 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-02 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-03 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-04 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-05 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-06 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-07 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-08 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-09 00:00:00', 1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-10 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-11 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-12 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-13 00:00:00', 3.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-14 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-15 00:00:00', 4.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-16 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-17 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-18 00:00:00', 4.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-19 00:00:00', 4.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-20 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-21 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-22 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-23 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-24 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-25 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-26 00:00:00', 5.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-27 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-28 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-29 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-30 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1988-12-31 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-01 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-02 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-03 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-04 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-05 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-06 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-07 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-08 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-09 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-10 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-11 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-12 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-13 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-14 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-15 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-16 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-17 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-18 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-19 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-20 00:00:00', 4.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-21 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-22 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-23 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-24 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-25 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-26 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-27 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-28 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-29 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-30 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-01-31 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-01 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-02 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-03 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-04 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-05 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-06 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-07 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-08 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-09 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-10 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-11 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-12 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-13 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-14 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-15 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-16 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-17 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-18 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-19 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-20 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-21 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-22 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-23 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-24 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-25 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-26 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-27 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-02-28 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-01 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-02 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-03 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-04 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-05 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-06 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-07 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-08 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-09 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-10 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-11 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-12 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-13 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-14 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-15 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-16 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-17 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-18 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-19 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-20 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-21 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-22 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-23 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-24 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-25 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-26 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-27 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-28 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-29 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-30 00:00:00', 4.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-03-31 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-01 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-02 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-03 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-04 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-05 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-06 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-07 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-08 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-09 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-10 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-11 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-12 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-13 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-14 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-15 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-16 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-17 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-18 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-19 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-20 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-21 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-22 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-23 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-24 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-25 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-26 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-27 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-28 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-29 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-04-30 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-01 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-02 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-03 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-04 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-05 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-06 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-07 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-08 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-09 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-10 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-11 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-12 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-13 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-14 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-15 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-16 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-17 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-18 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-19 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-20 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-21 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-22 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-23 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-24 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-25 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-26 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-27 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-28 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-29 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-30 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-05-31 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-01 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-02 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-03 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-04 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-05 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-06 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-07 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-08 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-09 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-10 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-11 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-12 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-13 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-14 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-15 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-16 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-17 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-18 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-19 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-20 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-21 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-22 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-23 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-24 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-25 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-26 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-27 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-28 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-29 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-06-30 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-01 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-02 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-03 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-04 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-05 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-06 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-07 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-08 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-09 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-10 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-11 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-12 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-13 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-14 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-15 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-16 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-17 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-18 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-19 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-20 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-21 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-22 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-23 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-24 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-25 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-26 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-27 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-28 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-29 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-30 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-07-31 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-01 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-02 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-03 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-04 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-05 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-06 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-07 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-08 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-09 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-10 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-11 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-12 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-13 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-14 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-15 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-16 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-17 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-18 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-19 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-20 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-21 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-22 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-23 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-24 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-25 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-26 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-27 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-28 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-29 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-30 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-08-31 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-01 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-02 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-03 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-04 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-05 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-06 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-07 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-08 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-09 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-10 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-11 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-12 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-13 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-14 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-15 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-16 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-17 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-18 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-19 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-20 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-21 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-22 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-23 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-24 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-25 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-26 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-27 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-28 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-29 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-09-30 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-01 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-02 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-03 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-04 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-05 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-06 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-07 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-08 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-09 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-10 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-11 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-12 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-13 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-14 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-15 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-16 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-17 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-18 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-19 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-20 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-21 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-22 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-23 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-24 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-25 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-26 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-27 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-28 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-29 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-30 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-10-31 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-01 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-02 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-03 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-04 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-05 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-06 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-07 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-08 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-09 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-10 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-11 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-12 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-13 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-14 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-15 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-16 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-17 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-18 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-19 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-20 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-21 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-22 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-23 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-24 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-25 00:00:00', 5.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-26 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-27 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-28 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-29 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-11-30 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-01 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-02 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-03 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-04 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-05 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-06 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-07 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-08 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-09 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-10 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-11 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-12 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-13 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-14 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-15 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-16 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-17 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-18 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-19 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-20 00:00:00', 0.939999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-21 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-22 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-23 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-24 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-25 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-26 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-27 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-28 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-29 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-30 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1989-12-31 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-01 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-02 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-03 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-04 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-05 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-06 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-07 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-08 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-09 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-10 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-11 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-12 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-13 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-14 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-15 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-16 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-17 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-18 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-19 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-20 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-21 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-22 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-23 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-24 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-25 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-26 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-27 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-28 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-29 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-30 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-01-31 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-01 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-02 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-03 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-04 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-05 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-06 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-07 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-08 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-09 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-10 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-11 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-12 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-13 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-14 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-15 00:00:00', 4.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-16 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-17 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-18 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-19 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-20 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-21 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-22 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-23 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-24 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-25 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-26 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-27 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-02-28 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-01 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-02 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-03 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-04 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-05 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-06 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-07 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-08 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-09 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-10 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-11 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-12 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-13 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-14 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-15 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-16 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-17 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-18 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-19 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-20 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-21 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-22 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-23 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-24 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-25 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-26 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-27 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-28 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-29 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-30 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-03-31 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-01 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-02 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-03 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-04 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-05 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-06 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-07 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-08 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-09 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-10 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-11 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-12 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-13 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-14 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-15 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-16 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-17 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-18 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-19 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-20 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-21 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-22 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-23 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-24 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-25 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-26 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-27 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-28 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-29 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-04-30 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-01 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-02 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-03 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-04 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-05 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-06 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-07 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-08 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-09 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-10 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-11 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-12 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-13 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-14 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-15 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-16 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-17 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-18 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-19 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-20 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-21 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-22 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-23 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-24 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-25 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-26 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-27 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-28 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-29 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-30 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-05-31 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-01 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-02 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-03 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-04 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-05 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-06 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-07 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-08 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-09 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-10 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-11 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-12 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-13 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-14 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-15 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-16 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-17 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-18 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-19 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-20 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-21 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-22 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-23 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-24 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-25 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-26 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-27 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-28 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-29 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-06-30 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-01 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-02 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-03 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-04 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-05 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-06 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-07 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-08 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-09 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-10 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-11 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-12 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-13 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-14 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-15 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-16 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-17 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-18 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-19 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-20 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-21 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-22 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-23 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-24 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-25 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-26 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-27 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-28 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-29 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-30 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-07-31 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-01 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-02 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-03 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-04 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-05 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-06 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-07 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-08 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-09 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-10 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-11 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-12 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-13 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-14 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-15 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-16 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-17 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-18 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-19 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-20 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-21 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-22 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-23 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-24 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-25 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-26 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-27 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-28 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-29 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-30 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-08-31 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-01 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-02 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-03 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-04 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-05 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-06 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-07 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-08 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-09 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-10 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-11 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-12 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-13 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-14 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-15 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-16 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-17 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-18 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-19 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-20 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-21 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-22 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-23 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-24 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-25 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-26 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-27 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-28 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-29 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-09-30 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-01 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-02 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-03 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-04 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-05 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-06 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-07 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-08 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-09 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-10 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-11 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-12 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-13 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-14 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-15 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-16 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-17 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-18 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-19 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-20 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-21 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-22 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-23 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-24 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-25 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-26 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-27 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-28 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-29 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-30 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-10-31 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-01 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-02 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-03 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-04 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-05 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-06 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-07 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-08 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-09 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-10 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-11 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-12 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-13 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-14 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-15 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-16 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-17 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-18 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-19 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-20 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-21 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-22 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-23 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-24 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-25 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-26 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-27 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-28 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-29 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-11-30 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-01 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-02 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-03 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-04 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-05 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-06 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-07 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-08 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-09 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-10 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-11 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-12 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-13 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-14 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-15 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-16 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-17 00:00:00', 5.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-18 00:00:00', 5.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-19 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-20 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-21 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-22 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-23 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-24 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-25 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-26 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-27 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-28 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-29 00:00:00', 1.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-30 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1990-12-31 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-01 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-02 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-03 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-04 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-05 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-06 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-07 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-08 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-09 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-10 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-11 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-12 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-13 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-14 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-15 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-16 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-17 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-18 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-19 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-20 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-21 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-22 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-23 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-24 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-25 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-26 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-27 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-28 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-29 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-30 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-01-31 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-01 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-02 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-03 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-04 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-05 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-06 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-07 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-08 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-09 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-10 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-11 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-12 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-13 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-14 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-15 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-16 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-17 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-18 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-19 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-20 00:00:00', 3.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-21 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-22 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-23 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-24 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-25 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-26 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-27 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-02-28 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-01 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-02 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-03 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-04 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-05 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-06 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-07 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-08 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-09 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-10 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-11 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-12 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-13 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-14 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-15 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-16 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-17 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-18 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-19 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-20 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-21 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-22 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-23 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-24 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-25 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-26 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-27 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-28 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-29 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-30 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-03-31 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-01 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-02 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-03 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-04 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-05 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-06 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-07 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-08 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-09 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-10 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-11 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-12 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-13 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-14 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-15 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-16 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-17 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-18 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-19 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-20 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-21 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-22 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-23 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-24 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-25 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-26 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-27 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-28 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-29 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-04-30 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-01 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-02 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-03 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-04 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-05 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-06 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-07 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-08 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-09 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-10 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-11 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-12 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-13 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-14 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-15 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-16 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-17 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-18 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-19 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-20 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-21 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-22 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-23 00:00:00', 5.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-24 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-25 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-26 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-27 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-28 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-29 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-30 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-05-31 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-01 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-02 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-03 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-04 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-05 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-06 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-07 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-08 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-09 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-10 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-11 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-12 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-13 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-14 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-15 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-16 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-17 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-18 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-19 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-20 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-21 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-22 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-23 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-24 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-25 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-26 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-27 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-28 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-29 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-06-30 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-01 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-02 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-03 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-04 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-05 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-06 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-07 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-08 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-09 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-10 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-11 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-12 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-13 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-14 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-15 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-16 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-17 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-18 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-19 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-20 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-21 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-22 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-23 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-24 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-25 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-26 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-27 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-28 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-29 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-30 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-07-31 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-01 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-02 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-03 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-04 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-05 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-06 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-07 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-08 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-09 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-10 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-11 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-12 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-13 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-14 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-15 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-16 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-17 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-18 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-19 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-20 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-21 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-22 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-23 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-24 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-25 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-26 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-27 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-28 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-29 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-30 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-08-31 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-01 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-02 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-03 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-04 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-05 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-06 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-07 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-08 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-09 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-10 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-11 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-12 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-13 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-14 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-15 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-16 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-17 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-18 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-19 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-20 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-21 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-22 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-23 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-24 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-25 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-26 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-27 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-28 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-29 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-09-30 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-01 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-02 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-03 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-04 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-05 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-06 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-07 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-08 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-09 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-10 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-11 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-12 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-13 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-14 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-15 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-16 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-17 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-18 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-19 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-20 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-21 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-22 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-23 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-24 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-25 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-26 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-27 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-28 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-29 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-30 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-10-31 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-01 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-02 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-03 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-04 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-05 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-06 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-07 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-08 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-09 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-10 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-11 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-12 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-13 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-14 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-15 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-16 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-17 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-18 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-19 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-20 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-21 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-22 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-23 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-24 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-25 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-26 00:00:00', 0.981000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-27 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-28 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-29 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-11-30 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-01 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-02 00:00:00', 4.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-03 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-04 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-05 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-06 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-07 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-08 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-09 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-10 00:00:00', 5.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-11 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-12 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-13 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-14 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-15 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-16 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-17 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-18 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-19 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-20 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-21 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-22 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-23 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-24 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-25 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-26 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-27 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-28 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-29 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-30 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1991-12-31 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-01 00:00:00', 5.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-02 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-03 00:00:00', 5.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-04 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-05 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-06 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-07 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-08 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-09 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-10 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-11 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-12 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-13 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-14 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-15 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-16 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-17 00:00:00', 5.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-18 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-19 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-20 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-21 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-22 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-23 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-24 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-25 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-26 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-27 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-28 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-29 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-30 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-01-31 00:00:00', 5.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-01 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-02 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-03 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-04 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-05 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-06 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-07 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-08 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-09 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-10 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-11 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-12 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-13 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-14 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-15 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-16 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-17 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-18 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-19 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-20 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-21 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-22 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-23 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-24 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-25 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-26 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-27 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-28 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-02-29 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-01 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-02 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-03 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-04 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-05 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-06 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-07 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-08 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-09 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-10 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-11 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-12 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-13 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-14 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-15 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-16 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-17 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-18 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-19 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-20 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-21 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-22 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-23 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-24 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-25 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-26 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-27 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-28 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-29 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-30 00:00:00', 4.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-03-31 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-01 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-02 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-03 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-04 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-05 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-06 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-07 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-08 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-09 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-10 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-11 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-12 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-13 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-14 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-15 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-16 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-17 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-18 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-19 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-20 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-21 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-22 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-23 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-24 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-25 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-26 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-27 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-28 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-29 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-04-30 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-01 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-02 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-03 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-04 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-05 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-06 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-07 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-08 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-09 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-10 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-11 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-12 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-13 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-14 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-15 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-16 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-17 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-18 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-19 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-20 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-21 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-22 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-23 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-24 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-25 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-26 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-27 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-28 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-29 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-30 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-05-31 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-01 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-02 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-03 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-04 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-05 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-06 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-07 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-08 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-09 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-10 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-11 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-12 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-13 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-14 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-15 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-16 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-17 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-18 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-19 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-20 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-21 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-22 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-23 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-24 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-25 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-26 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-27 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-28 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-29 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-06-30 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-01 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-02 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-03 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-04 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-05 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-06 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-07 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-08 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-09 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-10 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-11 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-12 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-13 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-14 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-15 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-16 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-17 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-18 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-19 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-20 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-21 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-22 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-23 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-24 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-25 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-26 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-27 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-28 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-29 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-30 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-07-31 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-01 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-02 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-03 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-04 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-05 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-06 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-07 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-08 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-09 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-10 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-11 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-12 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-13 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-14 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-15 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-16 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-17 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-18 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-19 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-20 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-21 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-22 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-23 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-24 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-25 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-26 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-27 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-28 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-29 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-30 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-08-31 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-01 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-02 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-03 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-04 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-05 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-06 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-07 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-08 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-09 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-10 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-11 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-12 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-13 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-14 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-15 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-16 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-17 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-18 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-19 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-20 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-21 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-22 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-23 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-24 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-25 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-26 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-27 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-28 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-29 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-09-30 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-01 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-02 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-03 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-04 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-05 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-06 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-07 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-08 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-09 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-10 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-11 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-12 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-13 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-14 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-15 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-16 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-17 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-18 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-19 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-20 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-21 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-22 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-23 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-24 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-25 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-26 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-27 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-28 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-29 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-30 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-10-31 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-01 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-02 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-03 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-04 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-05 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-06 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-07 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-08 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-09 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-10 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-11 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-12 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-13 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-14 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-15 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-16 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-17 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-18 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-19 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-20 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-21 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-22 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-23 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-24 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-25 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-26 00:00:00', 4.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-27 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-28 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-29 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-11-30 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-01 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-02 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-03 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-04 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-05 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-06 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-07 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-08 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-09 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-10 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-11 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-12 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-13 00:00:00', 5.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-14 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-15 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-16 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-17 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-18 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-19 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-20 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-21 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-22 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-23 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-24 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-25 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-26 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-27 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-28 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-29 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-30 00:00:00', 4.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1992-12-31 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-01 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-02 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-03 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-04 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-05 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-06 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-07 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-08 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-09 00:00:00', 6.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-10 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-11 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-12 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-13 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-14 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-15 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-16 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-17 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-18 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-19 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-20 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-21 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-22 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-23 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-24 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-25 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-26 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-27 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-28 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-29 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-30 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-01-31 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-01 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-02 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-03 00:00:00', 5.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-04 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-05 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-06 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-07 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-08 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-09 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-10 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-11 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-12 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-13 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-14 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-15 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-16 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-17 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-18 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-19 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-20 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-21 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-22 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-23 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-24 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-25 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-26 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-27 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-02-28 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-01 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-02 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-03 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-04 00:00:00', 5.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-05 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-06 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-07 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-08 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-09 00:00:00', 4.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-10 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-11 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-12 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-13 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-14 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-15 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-16 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-17 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-18 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-19 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-20 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-21 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-22 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-23 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-24 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-25 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-26 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-27 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-28 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-29 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-30 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-03-31 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-01 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-02 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-03 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-04 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-05 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-06 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-07 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-08 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-09 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-10 00:00:00', 1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-11 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-12 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-13 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-14 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-15 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-16 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-17 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-18 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-19 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-20 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-21 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-22 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-23 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-24 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-25 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-26 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-27 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-28 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-29 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-04-30 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-01 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-02 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-03 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-04 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-05 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-06 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-07 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-08 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-09 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-10 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-11 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-12 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-13 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-14 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-15 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-16 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-17 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-18 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-19 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-20 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-21 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-22 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-23 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-24 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-25 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-26 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-27 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-28 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-29 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-30 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-05-31 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-01 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-02 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-03 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-04 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-05 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-06 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-07 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-08 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-09 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-10 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-11 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-12 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-13 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-14 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-15 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-16 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-17 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-18 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-19 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-20 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-21 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-22 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-23 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-24 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-25 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-26 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-27 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-28 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-29 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-06-30 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-01 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-02 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-03 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-04 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-05 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-06 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-07 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-08 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-09 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-10 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-11 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-12 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-13 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-14 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-15 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-16 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-17 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-18 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-19 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-20 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-21 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-22 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-23 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-24 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-25 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-26 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-27 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-28 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-29 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-30 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-07-31 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-01 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-02 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-03 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-04 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-05 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-06 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-07 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-08 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-09 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-10 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-11 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-12 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-13 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-14 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-15 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-16 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-17 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-18 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-19 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-20 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-21 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-22 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-23 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-24 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-25 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-26 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-27 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-28 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-29 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-30 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-08-31 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-01 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-02 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-03 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-04 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-05 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-06 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-07 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-08 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-09 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-10 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-11 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-12 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-13 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-14 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-15 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-16 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-17 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-18 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-19 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-20 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-21 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-22 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-23 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-24 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-25 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-26 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-27 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-28 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-29 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-09-30 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-01 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-02 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-03 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-04 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-05 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-06 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-07 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-08 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-09 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-10 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-11 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-12 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-13 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-14 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-15 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-16 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-17 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-18 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-19 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-20 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-21 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-22 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-23 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-24 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-25 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-26 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-27 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-28 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-29 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-30 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-10-31 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-01 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-02 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-03 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-04 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-05 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-06 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-07 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-08 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-09 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-10 00:00:00', 4.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-11 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-12 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-13 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-14 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-15 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-16 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-17 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-18 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-19 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-20 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-21 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-22 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-23 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-24 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-25 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-26 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-27 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-28 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-29 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-11-30 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-01 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-02 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-03 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-04 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-05 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-06 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-07 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-08 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-09 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-10 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-11 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-12 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-13 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-14 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-15 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-16 00:00:00', 0.949000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-17 00:00:00', 0.703000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-18 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-19 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-20 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-21 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-22 00:00:00', 4.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-23 00:00:00', 4.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-24 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-25 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-26 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-27 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-28 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-29 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-30 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1993-12-31 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-01 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-02 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-03 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-04 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-05 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-06 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-07 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-08 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-09 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-10 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-11 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-12 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-13 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-14 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-15 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-16 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-17 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-18 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-19 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-20 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-21 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-22 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-23 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-24 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-25 00:00:00', 5.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-26 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-27 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-28 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-29 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-30 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-01-31 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-01 00:00:00', 5.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-02 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-03 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-04 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-05 00:00:00', 5.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-06 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-07 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-08 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-09 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-10 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-11 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-12 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-13 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-14 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-15 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-16 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-17 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-18 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-19 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-20 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-21 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-22 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-23 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-24 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-25 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-26 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-27 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-02-28 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-01 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-02 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-03 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-04 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-05 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-06 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-07 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-08 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-09 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-10 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-11 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-12 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-13 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-14 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-15 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-16 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-17 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-18 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-19 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-20 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-21 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-22 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-23 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-24 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-25 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-26 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-27 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-28 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-29 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-30 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-03-31 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-01 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-02 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-03 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-04 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-05 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-06 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-07 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-08 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-09 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-10 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-11 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-12 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-13 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-14 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-15 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-16 00:00:00', 1.32799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-17 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-18 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-19 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-20 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-21 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-22 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-23 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-24 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-25 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-26 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-27 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-28 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-29 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-04-30 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-01 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-02 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-03 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-04 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-05 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-06 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-07 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-08 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-09 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-10 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-11 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-12 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-13 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-14 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-15 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-16 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-17 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-18 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-19 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-20 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-21 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-22 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-23 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-24 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-25 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-26 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-27 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-28 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-29 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-30 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-05-31 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-01 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-02 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-03 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-04 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-05 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-06 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-07 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-08 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-09 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-10 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-11 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-12 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-13 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-14 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-15 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-16 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-17 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-18 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-19 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-20 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-21 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-22 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-23 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-24 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-25 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-26 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-27 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-28 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-29 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-06-30 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-01 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-02 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-03 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-04 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-05 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-06 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-07 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-08 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-09 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-10 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-11 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-12 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-13 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-14 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-15 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-16 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-17 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-18 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-19 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-20 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-21 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-22 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-23 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-24 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-25 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-26 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-27 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-28 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-29 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-30 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-07-31 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-01 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-02 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-03 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-04 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-05 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-06 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-07 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-08 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-09 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-10 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-11 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-12 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-13 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-14 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-15 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-16 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-17 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-18 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-19 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-20 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-21 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-22 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-23 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-24 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-25 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-26 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-27 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-28 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-29 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-30 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-08-31 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-01 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-02 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-03 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-04 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-05 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-06 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-07 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-08 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-09 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-10 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-11 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-12 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-13 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-14 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-15 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-16 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-17 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-18 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-19 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-20 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-21 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-22 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-23 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-24 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-25 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-26 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-27 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-28 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-29 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-09-30 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-01 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-02 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-03 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-04 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-05 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-06 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-07 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-08 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-09 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-10 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-11 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-12 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-13 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-14 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-15 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-16 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-17 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-18 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-19 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-20 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-21 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-22 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-23 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-24 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-25 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-26 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-27 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-28 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-29 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-30 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-10-31 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-01 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-02 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-03 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-04 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-05 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-06 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-07 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-08 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-09 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-10 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-11 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-12 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-13 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-14 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-15 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-16 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-17 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-18 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-19 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-20 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-21 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-22 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-23 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-24 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-25 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-26 00:00:00', 4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-27 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-28 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-29 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-11-30 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-01 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-02 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-03 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-04 00:00:00', 6.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-05 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-06 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-07 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-08 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-09 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-10 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-11 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-12 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-13 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-14 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-15 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-16 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-17 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-18 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-19 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-20 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-21 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-22 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-23 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-24 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-25 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-26 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-27 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-28 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-29 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-30 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1994-12-31 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-01 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-02 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-03 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-04 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-05 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-06 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-07 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-08 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-09 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-10 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-11 00:00:00', 5.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-12 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-13 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-14 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-15 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-16 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-17 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-18 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-19 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-20 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-21 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-22 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-23 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-24 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-25 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-26 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-27 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-28 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-29 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-30 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-01-31 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-01 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-02 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-03 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-04 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-05 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-06 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-07 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-08 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-09 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-10 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-11 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-12 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-13 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-14 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-15 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-16 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-17 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-18 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-19 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-20 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-21 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-22 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-23 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-24 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-25 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-26 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-27 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-02-28 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-01 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-02 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-03 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-04 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-05 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-06 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-07 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-08 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-09 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-10 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-11 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-12 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-13 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-14 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-15 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-16 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-17 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-18 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-19 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-20 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-21 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-22 00:00:00', 0.990999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-23 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-24 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-25 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-26 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-27 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-28 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-29 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-30 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-03-31 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-01 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-02 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-03 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-04 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-05 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-06 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-07 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-08 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-09 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-10 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-11 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-12 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-13 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-14 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-15 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-16 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-17 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-18 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-19 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-20 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-21 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-22 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-23 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-24 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-25 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-26 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-27 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-28 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-29 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-04-30 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-01 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-02 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-03 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-04 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-05 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-06 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-07 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-08 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-09 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-10 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-11 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-12 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-13 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-14 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-15 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-16 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-17 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-18 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-19 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-20 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-21 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-22 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-23 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-24 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-25 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-26 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-27 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-28 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-29 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-30 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-05-31 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-01 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-02 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-03 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-04 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-05 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-06 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-07 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-08 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-09 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-10 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-11 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-12 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-13 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-14 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-15 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-16 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-17 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-18 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-19 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-20 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-21 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-22 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-23 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-24 00:00:00', 5.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-25 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-26 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-27 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-28 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-29 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-06-30 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-01 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-02 00:00:00', 6.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-03 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-04 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-05 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-06 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-07 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-08 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-09 00:00:00', 5.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-10 00:00:00', 4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-11 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-12 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-13 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-14 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-15 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-16 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-17 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-18 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-19 00:00:00', 5.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-20 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-21 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-22 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-23 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-24 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-25 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-26 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-27 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-28 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-29 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-30 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-07-31 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-01 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-02 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-03 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-04 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-05 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-06 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-07 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-08 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-09 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-10 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-11 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-12 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-13 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-14 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-15 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-16 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-17 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-18 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-19 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-20 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-21 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-22 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-23 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-24 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-25 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-26 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-27 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-28 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-29 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-30 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-08-31 00:00:00', 6.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-01 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-02 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-03 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-04 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-05 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-06 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-07 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-08 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-09 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-10 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-11 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-12 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-13 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-14 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-15 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-16 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-17 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-18 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-19 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-20 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-21 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-22 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-23 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-24 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-25 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-26 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-27 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-28 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-29 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-09-30 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-01 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-02 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-03 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-04 00:00:00', 5.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-05 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-06 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-07 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-08 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-09 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-10 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-11 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-12 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-13 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-14 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-15 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-16 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-17 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-18 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-19 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-20 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-21 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-22 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-23 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-24 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-25 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-26 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-27 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-28 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-29 00:00:00', 1.02400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-30 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-10-31 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-01 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-02 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-03 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-04 00:00:00', 1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-05 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-06 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-07 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-08 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-09 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-10 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-11 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-12 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-13 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-14 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-15 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-16 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-17 00:00:00', 0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-18 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-19 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-20 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-21 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-22 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-23 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-24 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-25 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-26 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-27 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-28 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-29 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-11-30 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-01 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-02 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-03 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-04 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-05 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-06 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-07 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-08 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-09 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-10 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-11 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-12 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-13 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-14 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-15 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-16 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-17 00:00:00', 4.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-18 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-19 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-20 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-21 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-22 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-23 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-24 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-25 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-26 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-27 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-28 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-29 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-30 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1995-12-31 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-01 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-02 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-03 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-04 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-05 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-06 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-07 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-08 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-09 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-10 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-11 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-12 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-13 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-14 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-15 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-16 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-17 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-18 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-19 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-20 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-21 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-22 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-23 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-24 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-25 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-26 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-27 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-28 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-29 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-30 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-01-31 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-01 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-02 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-03 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-04 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-05 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-06 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-07 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-08 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-09 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-10 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-11 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-12 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-13 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-14 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-15 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-16 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-17 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-18 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-19 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-20 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-21 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-22 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-23 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-24 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-25 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-26 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-27 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-28 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-02-29 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-01 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-02 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-03 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-04 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-05 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-06 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-07 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-08 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-09 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-10 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-11 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-12 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-13 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-14 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-15 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-16 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-17 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-18 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-19 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-20 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-21 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-22 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-23 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-24 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-25 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-26 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-27 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-28 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-29 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-30 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-03-31 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-01 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-02 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-03 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-04 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-05 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-06 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-07 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-08 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-09 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-10 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-11 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-12 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-13 00:00:00', 5.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-14 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-15 00:00:00', 4.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-16 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-17 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-18 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-19 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-20 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-21 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-22 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-23 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-24 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-25 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-26 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-27 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-28 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-29 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-04-30 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-01 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-02 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-03 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-04 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-05 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-06 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-07 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-08 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-09 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-10 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-11 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-12 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-13 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-14 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-15 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-16 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-17 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-18 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-19 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-20 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-21 00:00:00', 1.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-22 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-23 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-24 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-25 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-26 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-27 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-28 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-29 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-30 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-05-31 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-01 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-02 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-03 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-04 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-05 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-06 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-07 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-08 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-09 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-10 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-11 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-12 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-13 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-14 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-15 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-16 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-17 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-18 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-19 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-20 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-21 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-22 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-23 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-24 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-25 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-26 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-27 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-28 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-29 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-06-30 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-01 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-02 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-03 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-04 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-05 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-06 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-07 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-08 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-09 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-10 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-11 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-12 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-13 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-14 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-15 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-16 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-17 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-18 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-19 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-20 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-21 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-22 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-23 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-24 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-25 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-26 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-27 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-28 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-29 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-30 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-07-31 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-01 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-02 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-03 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-04 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-05 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-06 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-07 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-08 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-09 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-10 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-11 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-12 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-13 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-14 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-15 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-16 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-17 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-18 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-19 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-20 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-21 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-22 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-23 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-24 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-25 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-26 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-27 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-28 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-29 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-30 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-08-31 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-01 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-02 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-03 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-04 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-05 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-06 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-07 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-08 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-09 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-10 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-11 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-12 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-13 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-14 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-15 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-16 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-17 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-18 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-19 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-20 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-21 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-22 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-23 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-24 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-25 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-26 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-27 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-28 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-29 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-09-30 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-01 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-02 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-03 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-04 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-05 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-06 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-07 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-08 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-09 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-10 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-11 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-12 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-13 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-14 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-15 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-16 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-17 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-18 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-19 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-20 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-21 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-22 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-23 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-24 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-25 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-26 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-27 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-28 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-29 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-30 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-10-31 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-01 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-02 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-03 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-04 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-05 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-06 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-07 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-08 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-09 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-10 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-11 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-12 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-13 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-14 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-15 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-16 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-17 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-18 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-19 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-20 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-21 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-22 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-23 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-24 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-25 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-26 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-27 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-28 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-29 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-11-30 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-01 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-02 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-03 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-04 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-05 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-06 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-07 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-08 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-09 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-10 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-11 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-12 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-13 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-14 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-15 00:00:00', 4.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-16 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-17 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-18 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-19 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-20 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-21 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-22 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-23 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-24 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-25 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-26 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-27 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-28 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-29 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-30 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1996-12-31 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-01 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-02 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-03 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-04 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-05 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-06 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-07 00:00:00', 4.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-08 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-09 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-10 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-11 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-12 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-13 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-14 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-15 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-16 00:00:00', 5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-17 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-18 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-19 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-20 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-21 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-22 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-23 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-24 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-25 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-26 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-27 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-28 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-29 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-30 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-01-31 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-01 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-02 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-03 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-04 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-05 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-06 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-07 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-08 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-09 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-10 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-11 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-12 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-13 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-14 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-15 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-16 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-17 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-18 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-19 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-20 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-21 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-22 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-23 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-24 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-25 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-26 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-27 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-02-28 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-01 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-02 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-03 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-04 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-05 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-06 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-07 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-08 00:00:00', 6.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-09 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-10 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-11 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-12 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-13 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-14 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-15 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-16 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-17 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-18 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-19 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-20 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-21 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-22 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-23 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-24 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-25 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-26 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-27 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-28 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-29 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-30 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-03-31 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-01 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-02 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-03 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-04 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-05 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-06 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-07 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-08 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-09 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-10 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-11 00:00:00', 4.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-12 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-13 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-14 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-15 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-16 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-17 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-18 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-19 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-20 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-21 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-22 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-23 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-24 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-25 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-26 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-27 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-28 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-29 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-04-30 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-01 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-02 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-03 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-04 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-05 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-06 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-07 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-08 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-09 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-10 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-11 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-12 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-13 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-14 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-15 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-16 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-17 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-18 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-19 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-20 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-21 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-22 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-23 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-24 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-25 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-26 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-27 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-28 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-29 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-30 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-05-31 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-01 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-02 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-03 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-04 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-05 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-06 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-07 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-08 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-09 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-10 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-11 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-12 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-13 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-14 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-15 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-16 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-17 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-18 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-19 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-20 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-21 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-22 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-23 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-24 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-25 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-26 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-27 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-28 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-29 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-06-30 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-01 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-02 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-03 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-04 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-05 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-06 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-07 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-08 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-09 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-10 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-11 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-12 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-13 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-14 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-15 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-16 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-17 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-18 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-19 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-20 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-21 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-22 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-23 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-24 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-25 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-26 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-27 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-28 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-29 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-30 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-07-31 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-01 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-02 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-03 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-04 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-05 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-06 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-07 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-08 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-09 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-10 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-11 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-12 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-13 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-14 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-15 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-16 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-17 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-18 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-19 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-20 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-21 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-22 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-23 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-24 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-25 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-26 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-27 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-28 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-29 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-30 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-08-31 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-01 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-02 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-03 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-04 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-05 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-06 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-07 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-08 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-09 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-10 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-11 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-12 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-13 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-14 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-15 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-16 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-17 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-18 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-19 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-20 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-21 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-22 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-23 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-24 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-25 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-26 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-27 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-28 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-29 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-09-30 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-01 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-02 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-03 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-04 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-05 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-06 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-07 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-08 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-09 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-10 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-11 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-12 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-13 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-14 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-15 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-16 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-17 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-18 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-19 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-20 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-21 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-22 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-23 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-24 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-25 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-26 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-27 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-28 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-29 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-30 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-10-31 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-01 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-02 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-03 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-04 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-05 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-06 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-07 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-08 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-09 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-10 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-11 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-12 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-13 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-14 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-15 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-16 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-17 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-18 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-19 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-20 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-21 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-22 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-23 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-24 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-25 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-26 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-27 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-28 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-29 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-11-30 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-01 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-02 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-03 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-04 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-05 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-06 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-07 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-08 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-09 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-10 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-11 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-12 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-13 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-14 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-15 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-16 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-17 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-18 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-19 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-20 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-21 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-22 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-23 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-24 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-25 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-26 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-27 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-28 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-29 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-30 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1997-12-31 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-01 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-02 00:00:00', 4.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-03 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-04 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-05 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-06 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-07 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-08 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-09 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-10 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-11 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-12 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-13 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-14 00:00:00', 5.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-15 00:00:00', 4.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-16 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-17 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-18 00:00:00', 4.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-19 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-20 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-21 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-22 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-23 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-24 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-25 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-26 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-27 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-28 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-29 00:00:00', 4.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-30 00:00:00', 5.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-01-31 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-01 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-02 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-03 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-04 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-05 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-06 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-07 00:00:00', 4.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-08 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-09 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-10 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-11 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-12 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-13 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-14 00:00:00', 5.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-15 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-16 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-17 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-18 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-19 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-20 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-21 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-22 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-23 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-24 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-25 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-26 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-27 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-02-28 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-01 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-02 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-03 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-04 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-05 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-06 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-07 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-08 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-09 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-10 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-11 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-12 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-13 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-14 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-15 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-16 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-17 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-18 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-19 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-20 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-21 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-22 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-23 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-24 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-25 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-26 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-27 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-28 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-29 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-30 00:00:00', 5.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-03-31 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-01 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-02 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-03 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-04 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-05 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-06 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-07 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-08 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-09 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-10 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-11 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-12 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-13 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-14 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-15 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-16 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-17 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-18 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-19 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-20 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-21 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-22 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-23 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-24 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-25 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-26 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-27 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-28 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-29 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-04-30 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-01 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-02 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-03 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-04 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-05 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-06 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-07 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-08 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-09 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-10 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-11 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-12 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-13 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-14 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-15 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-16 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-17 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-18 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-19 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-20 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-21 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-22 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-23 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-24 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-25 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-26 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-27 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-28 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-29 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-30 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-05-31 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-01 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-02 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-03 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-04 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-05 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-06 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-07 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-08 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-09 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-10 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-11 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-12 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-13 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-14 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-15 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-16 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-17 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-18 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-19 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-20 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-21 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-22 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-23 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-24 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-25 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-26 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-27 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-28 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-29 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-06-30 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-01 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-02 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-03 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-04 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-05 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-06 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-07 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-08 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-09 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-10 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-11 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-12 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-13 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-14 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-15 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-16 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-17 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-18 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-19 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-20 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-21 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-22 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-23 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-24 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-25 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-26 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-27 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-28 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-29 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-30 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-07-31 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-01 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-02 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-03 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-04 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-05 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-06 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-07 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-08 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-09 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-10 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-11 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-12 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-13 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-14 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-15 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-16 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-17 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-18 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-19 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-20 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-21 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-22 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-23 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-24 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-25 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-26 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-27 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-28 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-29 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-30 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-08-31 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-01 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-02 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-03 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-04 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-05 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-06 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-07 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-08 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-09 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-10 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-11 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-12 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-13 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-14 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-15 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-16 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-17 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-18 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-19 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-20 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-21 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-22 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-23 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-24 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-25 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-26 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-27 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-28 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-29 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-09-30 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-01 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-02 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-03 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-04 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-05 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-06 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-07 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-08 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-09 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-10 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-11 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-12 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-13 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-14 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-15 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-16 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-17 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-18 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-19 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-20 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-21 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-22 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-23 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-24 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-25 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-26 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-27 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-28 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-29 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-30 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-10-31 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-01 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-02 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-03 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-04 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-05 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-06 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-07 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-08 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-09 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-10 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-11 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-12 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-13 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-14 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-15 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-16 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-17 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-18 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-19 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-20 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-21 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-22 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-23 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-24 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-25 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-26 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-27 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-28 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-29 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-11-30 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-01 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-02 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-03 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-04 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-05 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-06 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-07 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-08 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-09 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-10 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-11 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-12 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-13 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-14 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-15 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-16 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-17 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-18 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-19 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-20 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-21 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-22 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-23 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-24 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-25 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-26 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-27 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-28 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-29 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-30 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1998-12-31 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-02 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-04 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-06 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-08 00:00:00', 5.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-10 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-12 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-14 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-16 00:00:00', 4.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-18 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-20 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-22 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-24 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-26 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-28 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-30 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-01 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-03 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-05 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-07 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-09 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-11 00:00:00', 6.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-13 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-15 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-17 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-19 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-21 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-23 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-25 00:00:00', 4.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-27 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-01 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-03 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-04 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-05 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-06 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-07 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-08 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-09 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-10 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-11 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-12 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-13 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-14 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-15 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-16 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-17 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-18 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-19 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-20 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-21 00:00:00', 4.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-22 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-23 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-24 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-25 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-26 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-27 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-28 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-29 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-30 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-03-31 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-01 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-02 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-03 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-04 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-05 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-06 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-07 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-08 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-09 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-10 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-11 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-12 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-13 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-14 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-15 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-16 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-17 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-18 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-19 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-20 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-21 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-22 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-23 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-24 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-25 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-26 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-27 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-28 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-29 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-04-30 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-01 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-02 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-03 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-04 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-05 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-06 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-07 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-08 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-09 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-10 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-11 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-12 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-13 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-14 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-15 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-16 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-17 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-18 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-19 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-20 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-21 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-22 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-23 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-24 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-25 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-26 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-27 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-28 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-29 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-30 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-05-31 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-01 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-02 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-03 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-04 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-05 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-06 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-07 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-08 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-09 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-10 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-11 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-12 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-13 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-14 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-15 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-16 00:00:00', 4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-17 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-18 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-19 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-20 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-21 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-22 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-23 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-24 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-25 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-26 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-27 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-28 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-29 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-06-30 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-01 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-02 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-03 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-04 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-05 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-06 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-07 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-08 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-09 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-10 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-11 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-12 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-13 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-14 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-15 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-16 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-17 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-18 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-19 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-20 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-21 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-22 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-23 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-24 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-25 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-26 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-27 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-28 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-29 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-30 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-07-31 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-01 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-02 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-03 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-04 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-05 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-06 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-07 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-08 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-09 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-10 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-11 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-12 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-13 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-14 00:00:00', 3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-15 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-16 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-17 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-18 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-19 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-20 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-21 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-22 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-23 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-24 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-25 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-26 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-27 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-28 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-29 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-30 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-08-31 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-01 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-02 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-03 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-04 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-05 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-06 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-07 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-08 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-09 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-10 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-11 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-12 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-13 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-14 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-15 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-16 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-17 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-18 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-19 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-20 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-21 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-22 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-23 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-24 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-25 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-26 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-27 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-28 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-29 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-09-30 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-01 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-02 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-03 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-04 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-05 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-06 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-07 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-08 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-09 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-10 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-11 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-12 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-13 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-14 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-15 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-16 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-17 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-18 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-19 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-20 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-21 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-22 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-23 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-24 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-25 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-26 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-27 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-28 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-29 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-30 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-10-31 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-01 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-02 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-03 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-04 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-05 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-06 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-07 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-08 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-09 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-10 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-11 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-12 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-13 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-14 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-15 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-16 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-17 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-18 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-19 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-20 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-21 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-22 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-23 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-24 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-25 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-26 00:00:00', 5.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-27 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-28 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-29 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-11-30 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-01 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-02 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-03 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-04 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-05 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-06 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-07 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-08 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-09 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-10 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-11 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-12 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-13 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-14 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-15 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-16 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-17 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-18 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-19 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-20 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-21 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-22 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-23 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-24 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-25 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-26 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-27 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-28 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-29 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-30 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '1999-12-31 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-01 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-02 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-03 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-04 00:00:00', 0.880999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-05 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-06 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-07 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-08 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-09 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-10 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-11 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-12 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-13 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-14 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-15 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-16 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-17 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-18 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-19 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-20 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-21 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-22 00:00:00', 4.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-23 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-24 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-25 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-26 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-27 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-28 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-29 00:00:00', 4.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-30 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-01-31 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-01 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-02 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-03 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-04 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-05 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-06 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-07 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-08 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-09 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-10 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-11 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-12 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-13 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-14 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-15 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-16 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-17 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-18 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-19 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-20 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-21 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-22 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-23 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-24 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-25 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-26 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-27 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-28 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-02-29 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-01 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-02 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-03 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-04 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-05 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-06 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-07 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-08 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-09 00:00:00', 4.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-10 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-11 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-12 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-13 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-14 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-15 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-16 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-17 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-18 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-19 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-20 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-21 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-22 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-23 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-24 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-25 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-26 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-27 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-28 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-29 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-30 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-03-31 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-01 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-02 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-03 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-04 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-05 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-06 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-07 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-08 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-09 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-10 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-11 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-12 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-13 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-14 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-15 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-16 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-17 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-18 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-19 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-20 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-21 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-22 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-23 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-24 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-25 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-26 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-27 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-28 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-29 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-04-30 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-01 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-02 00:00:00', 4.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-03 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-04 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-05 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-06 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-07 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-08 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-09 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-10 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-11 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-12 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-13 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-14 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-15 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-16 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-17 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-18 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-19 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-20 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-21 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-22 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-23 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-24 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-25 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-26 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-27 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-28 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-29 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-30 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-05-31 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-01 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-02 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-03 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-04 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-05 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-06 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-07 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-08 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-09 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-10 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-11 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-12 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-13 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-14 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-15 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-16 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-17 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-18 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-19 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-20 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-21 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-22 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-23 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-24 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-25 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-26 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-27 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-28 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-29 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-06-30 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-01 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-02 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-03 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-04 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-05 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-06 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-07 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-08 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-09 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-10 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-11 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-12 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-13 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-14 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-15 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-16 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-17 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-18 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-19 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-20 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-21 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-22 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-23 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-24 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-25 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-26 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-27 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-28 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-29 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-30 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-07-31 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-01 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-02 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-03 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-04 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-05 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-06 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-07 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-08 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-09 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-10 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-11 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-12 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-13 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-14 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-15 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-16 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-17 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-18 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-19 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-20 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-21 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-22 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-23 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-24 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-25 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-26 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-27 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-28 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-29 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-30 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-08-31 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-01 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-02 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-03 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-04 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-05 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-06 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-07 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-08 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-09 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-10 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-11 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-12 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-13 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-14 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-15 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-16 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-17 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-18 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-19 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-20 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-21 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-22 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-23 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-24 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-25 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-26 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-27 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-28 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-29 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-09-30 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-01 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-02 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-03 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-04 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-05 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-06 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-07 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-08 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-09 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-10 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-11 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-12 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-13 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-14 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-15 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-16 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-17 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-18 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-19 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-20 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-21 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-22 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-23 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-24 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-25 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-26 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-27 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-28 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-29 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-30 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-10-31 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-01 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-02 00:00:00', 1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-03 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-04 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-05 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-06 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-07 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-08 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-09 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-10 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-11 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-12 00:00:00', 4.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-13 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-14 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-15 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-16 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-17 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-18 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-19 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-20 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-21 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-22 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-23 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-24 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-25 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-26 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-27 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-28 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-29 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-11-30 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-01 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-02 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-03 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-04 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-05 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-06 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-07 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-08 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-09 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-10 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-11 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-12 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-13 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-14 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-15 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-16 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-17 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-18 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-19 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-20 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-21 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-22 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-23 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-24 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-25 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-26 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-27 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-28 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-29 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-30 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2000-12-31 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-01 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-02 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-03 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-04 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-05 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-06 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-07 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-08 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-09 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-10 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-11 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-12 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-13 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-14 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-15 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-16 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-17 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-18 00:00:00', 4.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-19 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-20 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-21 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-22 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-23 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-24 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-25 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-26 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-27 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-28 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-29 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-30 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-01-31 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-01 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-02 00:00:00', 4.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-03 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-04 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-05 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-06 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-07 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-08 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-09 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-10 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-11 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-12 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-13 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-14 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-15 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-16 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-17 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-18 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-19 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-20 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-21 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-22 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-23 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-24 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-25 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-26 00:00:00', 4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-27 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-02-28 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-01 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-02 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-03 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-04 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-05 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-06 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-07 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-08 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-09 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-10 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-11 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-12 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-13 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-14 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-15 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-16 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-17 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-18 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-19 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-20 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-21 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-22 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-23 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-24 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-25 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-26 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-27 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-28 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-29 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-30 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-03-31 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-01 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-02 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-03 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-04 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-05 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-06 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-07 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-08 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-09 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-10 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-11 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-12 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-13 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-14 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-15 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-16 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-17 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-18 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-19 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-20 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-21 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-22 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-23 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-24 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-25 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-26 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-27 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-28 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-29 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-04-30 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-01 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-02 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-03 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-04 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-05 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-06 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-07 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-08 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-09 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-10 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-11 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-12 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-13 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-14 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-15 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-16 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-17 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-18 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-19 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-20 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-21 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-22 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-23 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-24 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-25 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-26 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-27 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-28 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-29 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-30 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-05-31 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-01 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-02 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-03 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-04 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-05 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-06 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-07 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-08 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-09 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-10 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-11 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-12 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-13 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-14 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-15 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-16 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-17 00:00:00', 3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-18 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-19 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-20 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-21 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-22 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-23 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-24 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-25 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-26 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-27 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-28 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-29 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-06-30 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-01 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-02 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-03 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-04 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-05 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-06 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-07 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-08 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-09 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-10 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-11 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-12 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-13 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-14 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-15 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-16 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-17 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-18 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-19 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-20 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-21 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-22 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-23 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-24 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-25 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-26 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-27 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-28 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-29 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-30 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-07-31 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-01 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-02 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-03 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-04 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-05 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-06 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-07 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-08 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-09 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-10 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-11 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-12 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-13 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-14 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-15 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-16 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-17 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-18 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-19 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-20 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-21 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-22 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-23 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-24 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-25 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-26 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-27 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-28 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-29 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-30 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-08-31 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-01 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-02 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-03 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-04 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-05 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-06 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-07 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-08 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-09 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-10 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-11 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-12 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-13 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-14 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-15 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-16 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-17 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-18 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-19 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-20 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-21 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-22 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-23 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-24 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-25 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-26 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-27 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-28 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-29 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-09-30 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-01 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-02 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-03 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-04 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-05 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-06 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-07 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-08 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-09 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-10 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-11 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-12 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-13 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-14 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-15 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-16 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-17 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-18 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-19 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-20 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-21 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-22 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-23 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-24 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-25 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-26 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-27 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-28 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-29 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-30 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-10-31 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-01 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-02 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-03 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-04 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-05 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-06 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-07 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-08 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-09 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-10 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-11 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-12 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-13 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-14 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-15 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-16 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-17 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-18 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-19 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-20 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-21 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-22 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-23 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-24 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-25 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-26 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-27 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-28 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-29 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-11-30 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-01 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-02 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-03 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-04 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-05 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-06 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-07 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-08 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-09 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-10 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-11 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-12 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-13 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-14 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-15 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-16 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-17 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-18 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-19 00:00:00', 5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-20 00:00:00', 6.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-21 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-22 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-23 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-24 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-25 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-26 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-27 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-28 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-29 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-30 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2001-12-31 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-01 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-02 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-03 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-04 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-05 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-06 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-07 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-08 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-09 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-10 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-11 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-12 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-13 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-14 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-15 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-16 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-17 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-18 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-19 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-20 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-21 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-22 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-23 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-24 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-25 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-26 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-27 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-28 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-29 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-30 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-01-31 00:00:00', 4.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-01 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-02 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-03 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-04 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-05 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-06 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-07 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-08 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-09 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-10 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-11 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-12 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-13 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-14 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-15 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-16 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-17 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-18 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-19 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-20 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-21 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-22 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-23 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-24 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-25 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-26 00:00:00', 5.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-27 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-02-28 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-01 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-02 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-03 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-04 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-05 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-06 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-07 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-08 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-09 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-10 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-11 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-12 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-13 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-14 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-15 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-16 00:00:00', 5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-17 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-18 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-19 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-20 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-21 00:00:00', 5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-22 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-23 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-24 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-25 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-26 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-27 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-28 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-29 00:00:00', 6.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-30 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-03-31 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-01 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-02 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-03 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-04 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-05 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-06 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-07 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-08 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-09 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-10 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-11 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-12 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-13 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-14 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-15 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-16 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-17 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-18 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-19 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-20 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-21 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-22 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-23 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-24 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-25 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-26 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-27 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-28 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-29 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-04-30 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-01 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-02 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-03 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-04 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-05 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-06 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-07 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-08 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-09 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-10 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-11 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-12 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-13 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-14 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-15 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-16 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-17 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-18 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-19 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-20 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-21 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-22 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-23 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-24 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-25 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-26 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-27 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-28 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-29 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-30 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-05-31 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-01 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-02 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-03 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-04 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-05 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-06 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-07 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-08 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-09 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-10 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-11 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-12 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-13 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-14 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-15 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-16 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-17 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-18 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-19 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-20 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-21 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-22 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-23 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-24 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-25 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-26 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-27 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-28 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-29 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-06-30 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-01 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-02 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-03 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-04 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-05 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-06 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-07 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-08 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-09 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-10 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-11 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-12 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-13 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-14 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-15 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-16 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-17 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-18 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-19 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-20 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-21 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-22 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-23 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-24 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-25 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-26 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-27 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-28 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-29 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-30 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-07-31 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-01 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-02 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-03 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-04 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-05 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-06 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-07 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-08 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-09 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-10 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-11 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-12 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-13 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-14 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-15 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-16 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-17 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-18 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-19 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-20 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-21 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-22 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-23 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-24 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-25 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-26 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-27 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-28 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-29 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-30 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-08-31 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-01 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-02 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-03 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-04 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-05 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-06 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-07 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-08 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-09 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-10 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-11 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-12 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-13 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-14 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-15 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-16 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-17 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-18 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-19 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-20 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-21 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-22 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-23 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-24 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-25 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-26 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-27 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-28 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-29 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-09-30 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-01 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-02 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-03 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-04 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-05 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-06 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-07 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-08 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-09 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-10 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-11 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-12 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-13 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-14 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-15 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-16 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-17 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-18 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-19 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-20 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-21 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-22 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-23 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-24 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-25 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-26 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-27 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-28 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-29 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-30 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-10-31 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-01 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-02 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-03 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-04 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-05 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-06 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-07 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-08 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-09 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-10 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-11 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-12 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-13 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-14 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-15 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-16 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-17 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-18 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-19 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-20 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-21 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-22 00:00:00', 1.13399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-23 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-24 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-25 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-26 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-27 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-28 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-29 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-11-30 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-01 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-02 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-03 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-04 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-05 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-06 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-07 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-08 00:00:00', 4.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-09 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-10 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-11 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-12 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-13 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-14 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-15 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-16 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-17 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-18 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-19 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-20 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-21 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-22 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-23 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-24 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-25 00:00:00', 4.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-26 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-27 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-28 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-29 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-30 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2002-12-31 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-01 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-02 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-03 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-04 00:00:00', 4.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-05 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-06 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-07 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-08 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-09 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-10 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-11 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-12 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-13 00:00:00', 5.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-14 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-15 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-16 00:00:00', 4.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-17 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-18 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-19 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-20 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-21 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-22 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-23 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-24 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-25 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-26 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-27 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-28 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-29 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-30 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-01-31 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-01 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-02 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-03 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-04 00:00:00', 5.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-05 00:00:00', 4.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-06 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-07 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-08 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-09 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-10 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-11 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-12 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-13 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-14 00:00:00', 4.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-15 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-16 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-17 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-18 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-19 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-20 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-21 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-22 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-23 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-24 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-25 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-26 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-27 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-02-28 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-01 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-02 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-03 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-04 00:00:00', 4.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-05 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-06 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-07 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-08 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-09 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-10 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-11 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-12 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-13 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-14 00:00:00', 5.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-15 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-16 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-17 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-18 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-19 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-20 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-21 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-22 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-23 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-24 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-25 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-26 00:00:00', 5.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-27 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-28 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-29 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-30 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-03-31 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-01 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-02 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-03 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-04 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-05 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-06 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-07 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-08 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-09 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-10 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-11 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-12 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-13 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-14 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-15 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-16 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-17 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-18 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-19 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-20 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-21 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-22 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-23 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-24 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-25 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-26 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-27 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-28 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-29 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-04-30 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-01 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-02 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-03 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-04 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-05 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-06 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-07 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-08 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-09 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-10 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-11 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-12 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-13 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-14 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-15 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-16 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-17 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-18 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-19 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-20 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-21 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-22 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-23 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-24 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-25 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-26 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-27 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-28 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-29 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-30 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-05-31 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-01 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-02 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-03 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-04 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-05 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-06 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-07 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-08 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-09 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-10 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-11 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-12 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-13 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-14 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-15 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-16 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-17 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-18 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-19 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-20 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-21 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-22 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-23 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-24 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-25 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-26 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-27 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-28 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-29 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-06-30 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-01 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-02 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-03 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-04 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-05 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-06 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-07 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-08 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-09 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-10 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-11 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-12 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-13 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-14 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-15 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-16 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-17 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-18 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-19 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-20 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-21 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-22 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-23 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-24 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-25 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-26 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-27 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-28 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-29 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-30 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-07-31 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-01 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-02 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-03 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-04 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-05 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-06 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-07 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-08 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-09 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-10 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-11 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-12 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-13 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-14 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-15 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-16 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-17 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-18 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-19 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-20 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-21 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-22 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-23 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-24 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-25 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-26 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-27 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-28 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-29 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-30 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-08-31 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-01 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-02 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-03 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-04 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-05 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-06 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-07 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-08 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-09 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-10 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-11 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-12 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-13 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-14 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-15 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-16 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-17 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-18 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-19 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-20 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-21 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-22 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-23 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-24 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-25 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-26 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-27 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-28 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-29 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-09-30 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-01 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-02 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-03 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-04 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-05 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-06 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-07 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-08 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-09 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-10 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-11 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-12 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-13 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-14 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-15 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-16 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-17 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-18 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-19 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-20 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-21 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-22 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-23 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-24 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-25 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-26 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-27 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-28 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-29 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-30 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-10-31 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-01 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-02 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-03 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-04 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-05 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-06 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-07 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-08 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-09 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-10 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-11 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-12 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-13 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-14 00:00:00', 4.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-15 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-16 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-17 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-18 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-19 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-20 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-21 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-22 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-23 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-24 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-25 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-26 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-27 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-28 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-29 00:00:00', 0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-11-30 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-01 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-02 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-03 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-04 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-05 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-06 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-07 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-08 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-09 00:00:00', 4.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-10 00:00:00', 4.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-11 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-12 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-13 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-14 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-15 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-16 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-17 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-18 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-19 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-20 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-21 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-22 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-23 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-24 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-25 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-26 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-27 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-28 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-29 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-30 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2003-12-31 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-01 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-02 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-03 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-04 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-05 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-06 00:00:00', 5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-07 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-08 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-09 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-10 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-11 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-12 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-13 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-14 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-15 00:00:00', 4.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-16 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-17 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-18 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-19 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-20 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-21 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-22 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-23 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-24 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-25 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-26 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-27 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-28 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-29 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-30 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-01-31 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-01 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-02 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-03 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-04 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-05 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-06 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-07 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-08 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-09 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-10 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-11 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-12 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-13 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-14 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-15 00:00:00', 6.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-16 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-17 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-18 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-19 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-20 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-21 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-22 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-23 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-24 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-25 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-26 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-27 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-28 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-02-29 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-01 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-02 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-03 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-04 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-05 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-06 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-07 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-08 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-09 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-10 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-11 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-12 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-13 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-14 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-15 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-16 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-17 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-18 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-19 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-20 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-21 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-22 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-23 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-24 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-25 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-26 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-27 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-28 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-29 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-30 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-03-31 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-01 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-02 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-03 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-04 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-05 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-06 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-07 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-08 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-09 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-10 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-11 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-12 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-13 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-14 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-15 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-16 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-17 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-18 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-19 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-20 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-21 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-22 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-23 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-24 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-25 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-26 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-27 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-28 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-29 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-04-30 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-01 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-02 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-03 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-04 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-05 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-06 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-07 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-08 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-09 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-10 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-11 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-12 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-13 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-14 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-15 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-16 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-17 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-18 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-19 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-20 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-21 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-22 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-23 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-24 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-25 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-26 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-27 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-28 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-29 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-30 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-05-31 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-01 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-02 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-03 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-04 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-05 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-06 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-07 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-08 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-09 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-10 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-11 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-12 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-13 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-14 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-15 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-16 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-17 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-18 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-19 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-20 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-21 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-22 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-23 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-24 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-25 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-26 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-27 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-28 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-29 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-06-30 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-01 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-02 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-03 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-04 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-05 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-06 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-07 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-08 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-09 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-10 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-11 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-12 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-13 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-14 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-15 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-16 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-17 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-18 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-19 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-20 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-21 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-22 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-23 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-24 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-25 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-26 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-27 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-28 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-29 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-30 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-07-31 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-01 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-02 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-03 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-04 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-05 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-06 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-07 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-08 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-09 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-10 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-11 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-12 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-13 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-14 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-15 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-16 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-17 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-18 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-19 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-20 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-21 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-22 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-23 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-24 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-25 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-26 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-27 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-28 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-29 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-30 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-08-31 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-01 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-02 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-03 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-04 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-05 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-06 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-07 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-08 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-09 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-10 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-11 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-12 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-13 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-14 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-15 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-16 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-17 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-18 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-19 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-20 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-21 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-22 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-23 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-24 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-25 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-26 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-27 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-28 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-29 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-09-30 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-01 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-02 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-03 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-04 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-05 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-06 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-07 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-08 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-09 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-10 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-11 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-12 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-13 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-14 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-15 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-16 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-17 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-18 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-19 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-20 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-21 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-22 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-23 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-24 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-25 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-26 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-27 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-28 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-29 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-30 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-10-31 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-01 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-02 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-03 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-04 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-05 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-06 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-07 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-08 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-09 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-10 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-11 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-12 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-13 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-14 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-15 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-16 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-17 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-18 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-19 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-20 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-21 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-22 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-23 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-24 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-25 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-26 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-27 00:00:00', 5.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-28 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-29 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-11-30 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-01 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-02 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-03 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-04 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-05 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-06 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-07 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-08 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-09 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-10 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-11 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-12 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-13 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-14 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-15 00:00:00', 4.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-16 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-17 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-18 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-19 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-20 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-21 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-22 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-23 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-24 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-25 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-26 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-27 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-28 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-29 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-30 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2004-12-31 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-01 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-02 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-03 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-04 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-05 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-06 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-07 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-08 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-09 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-10 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-11 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-12 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-13 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-14 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-15 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-16 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-17 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-18 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-19 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-20 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-21 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-22 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-23 00:00:00', 4.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-24 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-25 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-26 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-27 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-28 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-29 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-30 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-01-31 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-01 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-02 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-03 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-04 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-05 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-06 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-07 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-08 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-09 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-10 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-11 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-12 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-13 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-14 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-15 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-16 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-17 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-18 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-19 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-20 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-21 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-22 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-23 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-24 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-25 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-26 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-27 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-02-28 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-01 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-02 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-03 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-04 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-05 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-06 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-07 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-08 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-09 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-10 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-11 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-12 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-13 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-14 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-15 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-16 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-17 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-18 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-19 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-20 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-21 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-22 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-23 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-24 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-25 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-26 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-27 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-28 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-29 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-30 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-03-31 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-01 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-02 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-03 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-04 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-05 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-06 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-07 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-08 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-09 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-10 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-11 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-12 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-13 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-14 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-15 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-16 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-17 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-18 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-19 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-20 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-21 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-22 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-23 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-24 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-25 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-26 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-27 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-28 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-29 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-04-30 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-01 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-02 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-03 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-04 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-05 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-06 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-07 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-08 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-09 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-10 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-11 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-12 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-13 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-14 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-15 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-16 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-17 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-18 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-19 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-20 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-21 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-22 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-23 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-24 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-25 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-26 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-27 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-28 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-29 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-30 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-05-31 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-01 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-02 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-03 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-04 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-05 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-06 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-07 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-08 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-09 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-10 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-11 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-12 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-13 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-14 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-15 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-16 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-17 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-18 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-19 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-20 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-21 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-22 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-23 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-24 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-25 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-26 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-27 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-28 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-29 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-06-30 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-01 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-02 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-03 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-04 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-05 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-06 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-07 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-08 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-09 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-10 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-11 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-12 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-13 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-14 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-15 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-16 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-17 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-18 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-19 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-20 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-21 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-22 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-23 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-24 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-25 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-26 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-27 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-28 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-29 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-30 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-07-31 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-01 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-02 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-03 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-04 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-05 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-06 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-07 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-08 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-09 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-10 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-11 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-12 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-13 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-14 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-15 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-16 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-17 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-18 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-19 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-20 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-21 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-22 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-23 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-24 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-25 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-26 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-27 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-28 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-29 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-30 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-08-31 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-01 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-02 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-03 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-04 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-05 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-06 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-07 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-08 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-09 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-10 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-11 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-12 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-13 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-14 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-15 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-16 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-17 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-18 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-19 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-20 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-21 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-22 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-23 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-24 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-25 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-26 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-27 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-28 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-29 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-09-30 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-01 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-02 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-03 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-04 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-05 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-06 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-07 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-08 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-09 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-10 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-11 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-12 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-13 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-14 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-15 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-16 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-17 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-18 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-19 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-20 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-21 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-22 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-23 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-24 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-25 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-26 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-27 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-28 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-29 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-30 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-10-31 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-01 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-02 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-03 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-04 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-05 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-06 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-07 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-08 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-09 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-10 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-11 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-12 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-13 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-14 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-15 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-16 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-17 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-18 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-19 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-20 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-21 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-22 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-23 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-24 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-25 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-26 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-27 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-28 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-29 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-11-30 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-01 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-02 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-03 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-04 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-05 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-06 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-07 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-08 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-09 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-10 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-11 00:00:00', 1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-12 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-13 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-14 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-15 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-16 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-17 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-18 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-19 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-20 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-21 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-22 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-23 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-24 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-25 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-26 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-27 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-28 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-29 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-30 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2005-12-31 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-01 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-02 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-03 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-04 00:00:00', 3.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-05 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-06 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-07 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-08 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-09 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-10 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-11 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-12 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-13 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-14 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-15 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-16 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-17 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-18 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-19 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-20 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-21 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-22 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-23 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-24 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-25 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-26 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-27 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-28 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-29 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-30 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-01-31 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-01 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-02 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-03 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-04 00:00:00', 5.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-05 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-06 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-07 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-08 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-09 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-10 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-11 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-12 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-13 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-14 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-15 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-16 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-17 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-18 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-19 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-20 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-21 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-22 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-23 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-24 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-25 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-26 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-27 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-02-28 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-01 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-02 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-03 00:00:00', 5.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-04 00:00:00', 5.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-05 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-06 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-07 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-08 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-09 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-10 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-11 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-12 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-13 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-14 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-15 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-16 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-17 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-18 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-19 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-20 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-21 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-22 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-23 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-24 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-25 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-26 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-27 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-28 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-29 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-30 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-03-31 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-01 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-02 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-03 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-04 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-05 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-06 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-07 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-08 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-09 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-10 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-11 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-12 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-13 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-14 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-15 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-16 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-17 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-18 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-19 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-20 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-21 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-22 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-23 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-24 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-25 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-26 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-27 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-28 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-29 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-04-30 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-01 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-02 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-03 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-04 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-05 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-06 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-07 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-08 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-09 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-10 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-11 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-12 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-13 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-14 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-15 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-16 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-17 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-18 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-19 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-20 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-21 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-22 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-23 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-24 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-25 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-26 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-27 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-28 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-29 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-30 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-05-31 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-01 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-02 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-03 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-04 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-05 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-06 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-07 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-08 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-09 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-10 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-11 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-12 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-13 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-14 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-15 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-16 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-17 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-18 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-19 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-20 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-21 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-22 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-23 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-24 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-25 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-26 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-27 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-28 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-29 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-06-30 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-01 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-02 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-03 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-04 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-05 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-06 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-07 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-08 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-09 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-10 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-11 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-12 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-13 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-14 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-15 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-16 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-17 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-18 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-19 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-20 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-21 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-22 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-23 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-24 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-25 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-26 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-27 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-28 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-29 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-30 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-07-31 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-01 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-02 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-03 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-04 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-05 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-06 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-07 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-08 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-09 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-10 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-11 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-12 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-13 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-14 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-15 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-16 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-17 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-18 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-19 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-20 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-21 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-22 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-23 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-24 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-25 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-26 00:00:00', 3.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-27 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-28 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-29 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-30 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-08-31 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-01 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-02 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-03 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-04 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-05 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-06 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-07 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-08 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-09 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-10 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-11 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-12 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-13 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-14 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-15 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-16 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-17 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-18 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-19 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-20 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-21 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-22 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-23 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-24 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-25 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-26 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-27 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-28 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-29 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-09-30 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-01 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-02 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-03 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-04 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-05 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-06 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-07 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-08 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-09 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-10 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-11 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-12 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-13 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-14 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-15 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-16 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-17 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-18 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-19 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-20 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-21 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-22 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-23 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-24 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-25 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-26 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-27 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-28 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-29 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-30 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-10-31 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-01 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-02 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-03 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-04 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-05 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-06 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-07 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-08 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-09 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-10 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-11 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-12 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-13 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-14 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-15 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-16 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-17 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-18 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-19 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-20 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-21 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-22 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-23 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-24 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-25 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-26 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-27 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-28 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-29 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-11-30 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-01 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-02 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-03 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-04 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-05 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-06 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-07 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-08 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-09 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-10 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-11 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-12 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-13 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-14 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-15 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-16 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-17 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-18 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-19 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-20 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-21 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-22 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-23 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-24 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-25 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-26 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-27 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-28 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-29 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-30 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2006-12-31 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-01 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-02 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-03 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-04 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-05 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-06 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-07 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-08 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-09 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-10 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-11 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-12 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-13 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-14 00:00:00', 4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-15 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-16 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-17 00:00:00', 5.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-18 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-19 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-20 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-21 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-22 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-23 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-24 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-25 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-26 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-27 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-28 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-29 00:00:00', 5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-30 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-01-31 00:00:00', 5.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-01 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-02 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-03 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-04 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-05 00:00:00', 5.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-06 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-07 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-08 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-09 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-10 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-11 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-12 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-13 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-14 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-15 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-16 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-17 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-18 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-19 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-20 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-21 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-22 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-23 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-24 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-25 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-26 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-27 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-02-28 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-01 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-02 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-03 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-04 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-05 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-06 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-07 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-08 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-09 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-10 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-11 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-12 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-13 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-14 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-15 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-16 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-17 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-18 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-19 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-20 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-21 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-22 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-23 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-24 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-25 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-26 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-27 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-28 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-29 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-30 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-03-31 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-01 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-02 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-03 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-04 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-05 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-06 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-07 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-08 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-09 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-10 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-11 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-12 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-13 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-14 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-15 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-16 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-17 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-18 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-19 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-20 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-21 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-22 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-23 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-24 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-25 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-26 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-27 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-28 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-29 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-04-30 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-01 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-02 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-03 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-04 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-05 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-06 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-07 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-08 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-09 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-10 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-11 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-12 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-13 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-14 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-15 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-16 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-17 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-18 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-19 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-20 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-21 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-22 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-23 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-24 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-25 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-26 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-27 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-28 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-29 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-30 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-05-31 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-01 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-02 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-03 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-04 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-05 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-06 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-07 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-08 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-09 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-10 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-11 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-12 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-13 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-14 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-15 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-16 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-17 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-18 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-19 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-20 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-21 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-22 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-23 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-24 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-25 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-26 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-27 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-28 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-29 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-06-30 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-01 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-02 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-03 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-04 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-05 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-06 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-07 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-08 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-09 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-10 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-11 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-12 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-13 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-14 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-15 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-16 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-17 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-18 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-19 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-20 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-21 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-22 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-23 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-24 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-25 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-26 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-27 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-28 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-29 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-30 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-07-31 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-01 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-02 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-03 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-04 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-05 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-06 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-07 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-08 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-09 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-10 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-11 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-12 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-13 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-14 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-15 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-16 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-17 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-18 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-19 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-20 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-21 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-22 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-23 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-24 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-25 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-26 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-27 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-28 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-29 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-30 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-08-31 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-01 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-02 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-03 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-04 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-05 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-06 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-07 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-08 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-09 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-10 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-11 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-12 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-13 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-14 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-15 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-16 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-17 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-18 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-19 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-20 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-21 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-22 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-23 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-24 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-25 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-26 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-27 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-28 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-29 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-09-30 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-01 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-02 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-03 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-04 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-05 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-06 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-07 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-08 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-09 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-10 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-11 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-12 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-13 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-14 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-15 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-16 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-17 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-18 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-19 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-20 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-21 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-22 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-23 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-24 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-25 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-26 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-27 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-28 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-29 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-30 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-10-31 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-01 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-02 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-03 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-04 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-05 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-06 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-07 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-08 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-09 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-10 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-11 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-12 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-13 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-14 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-15 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-16 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-17 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-18 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-19 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-20 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-21 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-22 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-23 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-24 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-25 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-26 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-27 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-28 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-29 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-11-30 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-01 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-02 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-03 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-04 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-05 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-06 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-07 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-08 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-09 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-10 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-11 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-12 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-13 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-14 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-15 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-16 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-17 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-18 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-19 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-20 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-21 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-22 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-23 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-24 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-25 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-26 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-27 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-28 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-29 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-30 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2007-12-31 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-01 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-02 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-03 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-04 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-05 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-06 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-07 00:00:00', 4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-08 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-09 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-10 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-11 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-12 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-13 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-14 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-15 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-16 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-17 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-18 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-19 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-20 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-21 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-22 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-23 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-24 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-25 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-26 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-27 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-28 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-29 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-30 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-01-31 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-01 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-02 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-03 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-04 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-05 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-06 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-07 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-08 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-09 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-10 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-11 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-12 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-13 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-14 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-15 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-16 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-17 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-18 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-19 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-20 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-21 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-22 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-23 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-24 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-25 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-26 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-27 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-28 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-02-29 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-01 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-02 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-03 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-04 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-05 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-06 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-07 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-08 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-09 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-10 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-11 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-12 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-13 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-14 00:00:00', 5.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-15 00:00:00', 5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-16 00:00:00', 5.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-17 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-18 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-19 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-20 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-21 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-22 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-23 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-24 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-25 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-26 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-27 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-28 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-29 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-30 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-03-31 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-01 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-02 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-03 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-04 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-05 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-06 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-07 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-08 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-09 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-10 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-11 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-12 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-13 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-14 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-15 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-16 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-17 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-18 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-19 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-20 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-21 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-22 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-23 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-24 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-25 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-26 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-27 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-28 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-29 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-04-30 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-01 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-02 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-03 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-04 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-05 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-06 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-07 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-08 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-09 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-10 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-11 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-12 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-13 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-14 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-15 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-16 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-17 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-18 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-19 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-20 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-21 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-22 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-23 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-24 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-25 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-26 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-27 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-28 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-29 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-30 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-05-31 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-01 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-02 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-03 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-04 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-05 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-06 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-07 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-08 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-09 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-10 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-11 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-12 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-13 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-14 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-15 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-16 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-17 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-18 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-19 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-20 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-21 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-22 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-23 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-24 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-25 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-26 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-27 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-28 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-29 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-06-30 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-01 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-02 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-03 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-04 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-05 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-06 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-07 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-08 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-09 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-10 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-11 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-12 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-13 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-14 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-15 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-16 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-17 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-18 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-19 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-20 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-21 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-22 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-23 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-24 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-25 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-26 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-27 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-28 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-29 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-30 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-07-31 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-01 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-02 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-03 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-04 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-05 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-06 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-07 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-08 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-09 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-10 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-11 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-12 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-13 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-14 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-15 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-16 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-17 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-18 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-19 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-20 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-21 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-22 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-23 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-24 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-25 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-26 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-27 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-28 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-29 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-30 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-08-31 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-01 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-02 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-03 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-04 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-05 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-06 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-07 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-08 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-09 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-10 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-11 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-12 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-13 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-14 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-15 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-16 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-17 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-18 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-19 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-20 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-21 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-22 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-23 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-24 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-25 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-26 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-27 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-28 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-29 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-09-30 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-01 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-02 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-03 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-04 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-05 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-06 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-07 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-08 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-09 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-10 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-11 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-12 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-13 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-14 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-15 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-16 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-17 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-18 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-19 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-20 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-21 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-22 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-23 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-24 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-25 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-26 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-27 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-28 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-29 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-30 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-10-31 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-01 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-02 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-03 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-04 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-05 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-06 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-07 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-08 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-09 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-10 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-11 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-12 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-13 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-14 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-15 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-16 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-17 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-18 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-19 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-20 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-21 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-22 00:00:00', 4.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-23 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-24 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-25 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-26 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-27 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-28 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-29 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-11-30 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-01 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-02 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-03 00:00:00', 1.07700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-04 00:00:00', 0.878000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-05 00:00:00', 1.21599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-06 00:00:00', 0.677999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-07 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-08 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-09 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-10 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-11 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-12 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-13 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-14 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-15 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-16 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-17 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-18 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-19 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-20 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-21 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-22 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-23 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-24 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-25 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-26 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-27 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-28 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-29 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-30 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2008-12-31 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-01 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-02 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-03 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-04 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-05 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-06 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-07 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-08 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-09 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-10 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-11 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-12 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-13 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-14 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-15 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-16 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-17 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-18 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-19 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-20 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-21 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-22 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-23 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-24 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-25 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-26 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-27 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-28 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-29 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-30 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-01-31 00:00:00', 4.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-01 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-02 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-03 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-04 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-05 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-06 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-07 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-08 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-09 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-10 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-11 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-12 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-13 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-14 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-15 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-16 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-17 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-18 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-19 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-20 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-21 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-22 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-23 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-24 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-25 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-26 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-27 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-02-28 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-01 00:00:00', 4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-02 00:00:00', 5.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-03 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-04 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-05 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-06 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-07 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-08 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-09 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-10 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-11 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-12 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-13 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-14 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-15 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-16 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-17 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-18 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-19 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-20 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-21 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-22 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-23 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-24 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-25 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-26 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-27 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-28 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-29 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-30 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-03-31 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-01 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-02 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-03 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-04 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-05 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-06 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-07 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-08 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-09 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-10 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-11 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-12 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-13 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-14 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-15 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-16 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-17 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-18 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-19 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-20 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-21 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-22 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-23 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-24 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-25 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-26 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-27 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-28 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-29 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-04-30 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-01 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-02 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-03 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-04 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-05 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-06 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-07 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-08 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-09 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-10 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-11 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-12 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-13 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-14 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-15 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-16 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-17 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-18 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-19 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-20 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-21 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-22 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-23 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-24 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-25 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-26 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-27 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-28 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-29 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-30 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-05-31 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-01 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-02 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-03 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-04 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-05 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-06 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-07 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-08 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-09 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-10 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-11 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-12 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-13 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-14 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-15 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-16 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-17 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-18 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-19 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-20 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-21 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-22 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-23 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-24 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-25 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-26 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-27 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-28 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-29 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-06-30 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-01 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-02 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-03 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-04 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-05 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-06 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-07 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-08 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-09 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-10 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-11 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-12 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-13 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-14 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-15 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-16 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-17 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-18 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-19 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-20 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-21 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-22 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-23 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-24 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-25 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-26 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-27 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-28 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-29 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-30 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-07-31 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-01 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-02 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-03 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-04 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-05 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-06 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-07 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-08 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-09 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-10 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-11 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-12 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-13 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-14 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-15 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-16 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-17 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-18 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-19 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-20 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-21 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-22 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-23 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-24 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-25 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-26 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-27 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-28 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-29 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-30 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-08-31 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-01 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-02 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-03 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-04 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-05 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-06 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-07 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-08 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-09 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-10 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-11 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-12 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-13 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-14 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-15 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-16 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-17 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-18 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-19 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-20 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-21 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-22 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-23 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-24 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-25 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-26 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-27 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-28 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-29 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-09-30 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-01 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-02 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-03 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-04 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-05 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-06 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-07 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-08 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-09 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-10 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-11 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-12 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-13 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-14 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-15 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-16 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-17 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-18 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-19 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-20 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-21 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-22 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-23 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-24 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-25 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-26 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-27 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-28 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-29 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-30 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-10-31 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-01 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-02 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-03 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-04 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-05 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-06 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-07 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-08 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-09 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-10 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-11 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-12 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-13 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-14 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-15 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-16 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-17 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-18 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-19 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-20 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-21 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-22 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-23 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-24 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-25 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-26 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-27 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-28 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-29 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-11-30 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-01 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-02 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-03 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-04 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-05 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-06 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-07 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-08 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-09 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-10 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-11 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-12 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-13 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-14 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-15 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-16 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-17 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-18 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-19 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-20 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-21 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-22 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-23 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-24 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-25 00:00:00', 1.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-26 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-27 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-28 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-29 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-30 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2009-12-31 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-01 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-02 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-03 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-04 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-05 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-06 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-07 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-08 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-09 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-10 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-11 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-12 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-13 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-14 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-15 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-16 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-17 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-18 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-19 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-20 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-21 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-22 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-23 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-24 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-25 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-26 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-27 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-28 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-29 00:00:00', 4.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-30 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-01-31 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-01 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-02 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-03 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-04 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-05 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-06 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-07 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-08 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-09 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-10 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-11 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-12 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-13 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-14 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-15 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-16 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-17 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-18 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-19 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-20 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-21 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-22 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-23 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-24 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-25 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-26 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-27 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-02-28 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-01 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-02 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-03 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-04 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-05 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-06 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-07 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-08 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-09 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-10 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-11 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-12 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-13 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-14 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-15 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-16 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-17 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-18 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-19 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-20 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-21 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-22 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-23 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-24 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-25 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-26 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-27 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-28 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-29 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-30 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-03-31 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-01 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-02 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-03 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-04 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-05 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-06 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-07 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-08 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-09 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-10 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-11 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-12 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-13 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-14 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-15 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-16 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-17 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-18 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-19 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-20 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-21 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-22 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-23 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-24 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-25 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-26 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-27 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-28 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-29 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-04-30 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-01 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-02 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-03 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-04 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-05 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-06 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-07 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-08 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-09 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-10 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-11 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-12 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-13 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-14 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-15 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-16 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-17 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-18 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-19 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-20 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-21 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-22 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-23 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-24 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-25 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-26 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-27 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-28 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-29 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-30 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-05-31 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-01 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-02 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-03 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-04 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-05 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-06 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-07 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-08 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-09 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-10 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-11 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-12 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-13 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-14 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-15 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-16 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-17 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-18 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-19 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-20 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-21 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-22 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-23 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-24 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-25 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-26 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-27 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-28 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-29 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-06-30 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-01 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-02 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-03 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-04 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-05 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-06 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-07 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-08 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-09 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-10 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-11 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-12 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-13 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-14 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-15 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-16 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-17 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-18 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-19 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-20 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-21 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-22 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-23 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-24 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-25 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-26 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-27 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-28 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-29 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-30 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-07-31 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-01 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-02 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-03 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-04 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-05 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-06 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-07 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-08 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-09 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-10 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-11 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-12 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-13 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-14 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-15 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-16 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-17 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-18 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-19 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-20 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-21 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-22 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-23 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-24 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-25 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-26 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-27 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-28 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-29 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-30 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-08-31 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-01 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-02 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-03 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-04 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-05 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-06 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-07 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-08 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-09 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-10 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-11 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-12 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-13 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-14 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-15 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-16 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-17 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-18 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-19 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-20 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-21 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-22 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-23 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-24 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-25 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-26 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-27 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-28 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-29 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-09-30 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-01 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-02 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-03 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-04 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-05 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-06 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-07 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-08 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-09 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-10 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-11 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-12 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-13 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-14 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-15 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-16 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-17 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-18 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-19 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-20 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-21 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-22 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-23 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-24 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-25 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-26 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-27 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-28 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-29 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-30 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-10-31 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-01 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-02 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-03 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-04 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-05 00:00:00', 1.20599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-06 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-07 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-08 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-09 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-10 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-11 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-12 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-13 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-14 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-15 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-16 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-17 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-18 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-19 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-20 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-21 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-22 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-23 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-24 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-25 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-26 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-27 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-28 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-29 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-11-30 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-01 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-02 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-03 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-04 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-05 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-06 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-07 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-08 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-09 00:00:00', 1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-10 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-11 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-12 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-13 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-14 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-15 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-16 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-17 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-18 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-19 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-20 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-21 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-22 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-23 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-24 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-25 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-26 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-27 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-28 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-29 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-30 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2010-12-31 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-01 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-02 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-03 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-04 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-05 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-06 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-07 00:00:00', 1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-08 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-09 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-10 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-11 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-12 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-13 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-14 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-15 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-16 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-17 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-18 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-19 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-20 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-21 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-22 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-23 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-24 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-25 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-26 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-27 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-28 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-29 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-30 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-01-31 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-01 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-02 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-03 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-04 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-05 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-06 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-07 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-08 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-09 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-10 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-11 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-12 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-13 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-14 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-15 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-16 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-17 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-18 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-19 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-20 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-21 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-22 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-23 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-24 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-25 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-26 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-27 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-02-28 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-01 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-02 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-03 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-04 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-05 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-06 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-07 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-08 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-09 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-10 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-11 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-12 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-13 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-14 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-15 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-16 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-17 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-18 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-19 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-20 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-21 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-22 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-23 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-24 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-25 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-26 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-27 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-28 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-29 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-30 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-03-31 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-01 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-02 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-03 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-04 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-05 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-06 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-07 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-08 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-09 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-10 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-11 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-12 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-13 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-14 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-15 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-16 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-17 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-18 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-19 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-20 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-21 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-22 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-23 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-24 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-25 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-26 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-27 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-28 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-29 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-04-30 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-01 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-02 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-03 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-04 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-05 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-06 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-07 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-08 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-09 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-10 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-11 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-12 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-13 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-14 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-15 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-16 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-17 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-18 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-19 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-20 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-21 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-22 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-23 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-24 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-25 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-26 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-27 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-28 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-29 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-30 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-05-31 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-01 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-02 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-03 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-04 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-05 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-06 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-07 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-08 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-09 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-10 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-11 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-12 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-13 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-14 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-15 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-16 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-17 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-18 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-19 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-20 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-21 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-22 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-23 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-24 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-25 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-26 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-27 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-28 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-29 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-06-30 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-01 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-02 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-03 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-04 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-05 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-06 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-07 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-08 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-09 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-10 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-11 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-12 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-13 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-14 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-15 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-16 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-17 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-18 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-19 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-20 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-21 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-22 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-23 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-24 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-25 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-26 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-27 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-28 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-29 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-30 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-07-31 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-01 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-02 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-03 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-04 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-05 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-06 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-07 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-08 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-09 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-10 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-11 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-12 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-13 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-14 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-15 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-16 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-17 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-18 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-19 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-20 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-21 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-22 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-23 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-24 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-25 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-26 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-27 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-28 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-29 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-30 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-08-31 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-01 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-02 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-03 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-04 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-05 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-06 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-07 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-08 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-09 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-10 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-11 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-12 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-13 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-14 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-15 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-16 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-17 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-18 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-19 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-20 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-21 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-22 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-23 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-24 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-25 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-26 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-27 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-28 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-29 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-09-30 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-01 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-02 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-03 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-04 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-05 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-06 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-07 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-08 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-09 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-10 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-11 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-12 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-13 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-14 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-15 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-16 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-17 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-18 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-19 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-20 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-21 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-22 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-23 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-24 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-25 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-26 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-27 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-28 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-29 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-30 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-10-31 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-01 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-02 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-03 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-04 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-05 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-06 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-07 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-08 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-09 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-10 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-11 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-12 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-13 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-14 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-15 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-16 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-17 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-18 00:00:00', 1.02400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-19 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-20 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-21 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-22 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-23 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-24 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-25 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-26 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-27 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-28 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-29 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-11-30 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-01 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-02 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-03 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-04 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-05 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-06 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-07 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-08 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-09 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-10 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-11 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-12 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-13 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-14 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-15 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-16 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-17 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-18 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-19 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-20 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-21 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-22 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-23 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-24 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-25 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-26 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-27 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-28 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-29 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-30 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2011-12-31 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-01 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-02 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-03 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-04 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-05 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-06 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-07 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-08 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-09 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-10 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-11 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-12 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-13 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-14 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-15 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-16 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-17 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-18 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-19 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-20 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-21 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-22 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-23 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-24 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-25 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-26 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-27 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-28 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-29 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-30 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-01-31 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-01 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-02 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-03 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-04 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-05 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-06 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-07 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-08 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-09 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-10 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-11 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-12 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-13 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-14 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-15 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-16 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-17 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-18 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-19 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-20 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-21 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-22 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-23 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-24 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-25 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-26 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-27 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-28 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-02-29 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-01 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-02 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-03 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-04 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-05 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-06 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-07 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-08 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-09 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-10 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-11 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-12 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-13 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-14 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-15 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-16 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-17 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-18 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-19 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-20 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-21 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-22 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-23 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-24 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-25 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-26 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-27 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-28 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-29 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-30 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-03-31 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-01 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-02 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-03 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-04 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-05 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-06 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-07 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-08 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-09 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-10 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-11 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-12 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-13 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-14 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-15 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-16 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-17 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-18 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-19 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-20 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-21 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-22 00:00:00', 1.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-23 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-24 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-25 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-26 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-27 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-28 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-29 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-04-30 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-01 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-02 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-03 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-04 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-05 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-06 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-07 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-08 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-09 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-10 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-11 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-12 00:00:00', 1.08399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-13 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-14 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-15 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-16 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-17 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-18 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-19 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-20 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-21 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-22 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-23 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-24 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-25 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-26 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-27 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-28 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-29 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-30 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-05-31 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-01 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-02 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-03 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-04 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-05 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-06 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-07 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-08 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-09 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-10 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-11 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-12 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-13 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-14 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-15 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-16 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-17 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-18 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-19 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-20 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-21 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-22 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-23 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-24 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-25 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-26 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-27 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-28 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-29 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-06-30 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-01 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-02 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-03 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-04 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-05 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-06 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-07 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-08 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-09 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-10 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-11 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-12 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-13 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-14 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-15 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-16 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-17 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-18 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-19 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-20 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-21 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-22 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-23 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-24 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-25 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-26 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-27 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-28 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-29 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-30 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-07-31 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-01 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-02 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-03 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-04 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-05 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-06 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-07 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-08 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-09 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-10 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-11 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-12 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-13 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-14 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-15 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-16 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-17 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-18 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-19 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-20 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-21 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-22 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-23 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-24 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-25 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-26 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-27 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-28 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-29 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-30 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-08-31 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-01 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-02 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-03 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-04 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-05 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-06 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-07 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-08 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-09 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-10 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-11 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-12 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-13 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-14 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-15 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-16 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-17 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-18 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-19 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-20 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-21 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-22 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-23 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-24 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-25 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-26 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-27 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-28 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-29 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-09-30 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-01 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-02 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-03 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-04 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-05 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-06 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-07 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-08 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-09 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-10 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-11 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-12 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-13 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-14 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-15 00:00:00', 1.10399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-16 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-17 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-18 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-19 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-20 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-21 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-22 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-23 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-24 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-25 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-26 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-27 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-28 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-29 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-30 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-10-31 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-01 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-02 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-03 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-04 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-05 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-06 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-07 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-08 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-09 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-10 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-11 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-12 00:00:00', 1.09399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-13 00:00:00', 0.938000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-14 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-15 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-16 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-17 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-18 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-19 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-20 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-21 00:00:00', 1.25899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-22 00:00:00', 0.690999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-23 00:00:00', 1.16299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-24 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-25 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-26 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-27 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-28 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-29 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-11-30 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-01 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-02 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-03 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-04 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-05 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-06 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-07 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-08 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-09 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-10 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-11 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-12 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-13 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-14 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-15 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-16 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-17 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-18 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-19 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-20 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-21 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-22 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-23 00:00:00', 0.933000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-24 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-25 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-26 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-27 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-28 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-29 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-30 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2012-12-31 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-01 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-02 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-03 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-04 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-05 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-06 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-07 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-08 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-09 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-10 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-11 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-12 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-13 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-14 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-15 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-16 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-17 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-18 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-19 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-20 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-21 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-22 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-23 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-24 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-25 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-26 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-27 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-28 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-29 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-30 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-01-31 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-01 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-02 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-03 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-04 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-05 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-06 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-07 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-08 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-09 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-10 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-11 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-12 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-13 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-14 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-15 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-16 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-17 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-18 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-19 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-20 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-21 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-22 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-23 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-24 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-25 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-26 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-27 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-02-28 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-01 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-02 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-03 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-04 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-05 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-06 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-07 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-08 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-09 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-10 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-11 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-12 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-13 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-14 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-15 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-16 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-17 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-18 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-19 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-20 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-21 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-22 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-23 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-24 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-25 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-26 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-27 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-28 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-29 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-30 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-03-31 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-01 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-02 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-03 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-04 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-05 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-06 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-07 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-08 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-09 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-10 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-11 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-12 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-13 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-14 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-15 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-16 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-17 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-18 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-19 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-20 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-21 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-22 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-23 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-24 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-25 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-26 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-27 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-28 00:00:00', 1.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-29 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-04-30 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-01 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-02 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-03 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-04 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-05 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-06 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-07 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-08 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-09 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-10 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-11 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-12 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-13 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-14 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-15 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-16 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-17 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-18 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-19 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-20 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-21 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-22 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-23 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-24 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-25 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-26 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-27 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-28 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-29 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-30 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-05-31 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-01 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-02 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-03 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-04 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-05 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-06 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-07 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-08 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-09 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-10 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-11 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-12 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-13 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-14 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-15 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-16 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-17 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-18 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-19 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-20 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-21 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-22 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-23 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-24 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-25 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-26 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-27 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-28 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-29 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-06-30 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-01 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-02 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-03 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-04 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-05 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-06 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-07 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-08 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-09 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-10 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-11 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-12 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-13 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-14 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-15 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-16 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-17 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-18 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-19 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-20 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-21 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-22 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-23 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-24 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-25 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-26 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-27 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-28 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-29 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-30 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-07-31 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-01 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-02 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-03 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-04 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-05 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-06 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-07 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-08 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-09 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-10 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-11 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-12 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-13 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-14 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-15 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-16 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-17 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-18 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-19 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-20 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-21 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-22 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-23 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-24 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-25 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-26 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-27 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-28 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-29 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-30 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-08-31 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-01 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-02 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-03 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-04 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-05 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-06 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-07 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-08 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-09 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-10 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-11 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-12 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-13 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-14 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-15 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-16 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-17 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-18 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-19 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-20 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-21 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-22 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-23 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-24 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-25 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-26 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-27 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-28 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-29 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-09-30 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-01 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-02 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-03 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-04 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-05 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-06 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-07 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-08 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-09 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-10 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-11 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-12 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-13 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-14 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-15 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-16 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-17 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-18 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-19 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-20 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-21 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-22 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-23 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-24 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-25 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-26 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-27 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-28 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-29 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-30 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-10-31 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-01 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-02 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-03 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-04 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-05 00:00:00', 1.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-06 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-07 00:00:00', 1.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-08 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-09 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-10 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-11 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-12 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-13 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-14 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-15 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-16 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-17 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-18 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-19 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-20 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-21 00:00:00', 1.27799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-22 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-23 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-24 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-25 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-26 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-27 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-28 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-29 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-11-30 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-01 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-02 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-03 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-04 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-05 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-06 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-07 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-08 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-09 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-10 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-11 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-12 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-13 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-14 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-15 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-16 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-17 00:00:00', 1.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-18 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-19 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-20 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-21 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-22 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-23 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-24 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-25 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-26 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-27 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-28 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-29 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-30 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2013-12-31 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-01 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-02 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-03 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-04 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-05 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-06 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-07 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-08 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-09 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-10 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-11 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-12 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-13 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-14 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-15 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-16 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-17 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-18 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-19 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-20 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-21 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-22 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-23 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-24 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-25 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-26 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-27 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-28 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-29 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-30 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-01-31 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-01 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-02 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-03 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-04 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-05 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-06 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-07 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-08 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-09 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-10 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-11 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-12 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-13 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-14 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-15 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-16 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-17 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-18 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-19 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-20 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-21 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-22 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-23 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-24 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-25 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-26 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-27 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-02-28 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-01 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-02 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-03 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-04 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-05 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-06 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-07 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-08 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-09 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-10 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-11 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-12 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-13 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-14 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-15 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-16 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-17 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-18 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-19 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-20 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-21 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-22 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-23 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-24 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-25 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-26 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-27 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-28 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-29 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-30 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-03-31 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-01 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-02 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-03 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-04 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-05 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-06 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-07 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-08 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-09 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-10 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-11 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-12 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-13 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-14 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-15 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-16 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-17 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-18 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-19 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-20 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-21 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-22 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-23 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-24 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-25 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-26 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-27 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-28 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-29 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-04-30 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-01 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-02 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-03 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-04 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-05 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-06 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-07 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-08 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-09 00:00:00', 1.02799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-10 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-11 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-12 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-13 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-14 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-15 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-16 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-17 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-18 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-19 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-20 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-21 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-22 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-23 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-24 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-25 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-26 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-27 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-28 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-29 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-30 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-05-31 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-01 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-02 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-03 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-04 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-05 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-06 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-07 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-08 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-09 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-10 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-11 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-12 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-13 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-14 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-15 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-16 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-17 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-18 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-19 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-20 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-21 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-22 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-23 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-24 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-25 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-26 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-27 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-28 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-29 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-06-30 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-01 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-02 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-03 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-04 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-05 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-06 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-07 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-08 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-09 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-10 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-11 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-12 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-13 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-14 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-15 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-16 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-17 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-18 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-19 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-20 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-21 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-22 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-23 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-24 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-25 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-26 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-27 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-28 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-29 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-30 00:00:00', 1.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (33, '2014-07-31 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-01 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-02 00:00:00', 4.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-03 00:00:00', 5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-04 00:00:00', 6.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-05 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-06 00:00:00', 5.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-07 00:00:00', 7.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-08 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-09 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-10 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-11 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-12 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-13 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-14 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-15 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-16 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-17 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-18 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-19 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-20 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-21 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-22 00:00:00', 7.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-23 00:00:00', 5.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-24 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-25 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-26 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-27 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-28 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-29 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-30 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-01-31 00:00:00', 4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-01 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-02 00:00:00', 5.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-03 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-04 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-05 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-06 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-07 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-08 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-09 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-10 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-11 00:00:00', 6.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-12 00:00:00', 5.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-13 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-14 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-15 00:00:00', 4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-16 00:00:00', 5.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-17 00:00:00', 5.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-18 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-19 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-20 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-21 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-22 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-23 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-24 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-25 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-26 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-27 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-02-28 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-01 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-02 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-03 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-04 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-05 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-06 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-07 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-08 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-09 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-10 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-11 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-12 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-13 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-14 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-15 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-16 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-17 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-18 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-19 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-20 00:00:00', 4.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-21 00:00:00', 4.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-22 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-23 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-24 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-25 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-26 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-27 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-28 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-29 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-30 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-03-31 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-01 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-02 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-03 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-04 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-05 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-06 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-07 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-08 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-09 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-10 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-11 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-12 00:00:00', 5.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-13 00:00:00', 6.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-14 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-15 00:00:00', 6.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-16 00:00:00', 7.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-17 00:00:00', 6.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-18 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-19 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-20 00:00:00', 6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-21 00:00:00', 6.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-22 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-23 00:00:00', 8.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-24 00:00:00', 7.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-25 00:00:00', 6.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-26 00:00:00', 7.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-27 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-28 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-29 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-04-30 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-01 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-02 00:00:00', 5.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-03 00:00:00', 6.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-04 00:00:00', 5.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-05 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-06 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-07 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-08 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-09 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-10 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-11 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-12 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-13 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-14 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-15 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-16 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-17 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-18 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-19 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-20 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-21 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-22 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-23 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-24 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-25 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-26 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-27 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-28 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-29 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-30 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-05-31 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-01 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-02 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-03 00:00:00', 6.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-04 00:00:00', 6.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-05 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-06 00:00:00', 5.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-07 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-08 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-09 00:00:00', 6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-10 00:00:00', 5.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-11 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-12 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-13 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-14 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-15 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-16 00:00:00', 5.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-17 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-18 00:00:00', 4.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-19 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-20 00:00:00', 5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-21 00:00:00', 5.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-22 00:00:00', 5.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-23 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-24 00:00:00', 5.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-25 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-26 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-27 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-28 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-29 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-06-30 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-01 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-02 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-03 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-04 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-05 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-06 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-07 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-08 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-09 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-10 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-11 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-12 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-13 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-14 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-15 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-16 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-17 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-18 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-19 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-20 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-21 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-22 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-23 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-24 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-25 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-26 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-27 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-28 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-29 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-30 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-07-31 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-01 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-02 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-03 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-04 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-05 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-06 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-07 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-08 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-09 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-10 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-11 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-12 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-13 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-14 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-15 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-16 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-17 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-18 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-19 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-20 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-21 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-22 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-23 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-24 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-25 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-26 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-27 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-28 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-29 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-30 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-08-31 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-01 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-02 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-03 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-04 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-05 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-06 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-07 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-08 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-09 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-10 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-11 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-12 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-13 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-14 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-15 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-16 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-17 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-18 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-19 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-20 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-21 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-22 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-23 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-24 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-25 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-26 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-27 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-28 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-29 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-09-30 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-01 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-02 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-03 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-04 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-05 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-06 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-07 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-08 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-09 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-10 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-11 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-12 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-13 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-14 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-15 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-16 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-17 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-18 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-19 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-20 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-21 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-22 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-23 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-24 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-25 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-26 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-27 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-28 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-29 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-30 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-10-31 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-01 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-02 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-03 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-04 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-05 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-06 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-07 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-08 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-09 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-10 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-11 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-12 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-13 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-14 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-15 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-16 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-17 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-18 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-19 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-20 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-21 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-22 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-23 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-24 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-25 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-26 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-27 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-28 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-29 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-11-30 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-01 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-02 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-03 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-04 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-05 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-06 00:00:00', 4.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-07 00:00:00', 5.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-08 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-09 00:00:00', 4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-10 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-11 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-12 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-13 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-14 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-15 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-16 00:00:00', 5.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-17 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-18 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-19 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-20 00:00:00', 4.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-21 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-22 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-23 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-24 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-25 00:00:00', 4.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-26 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-27 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-28 00:00:00', 5.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-29 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-30 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1979-12-31 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-01 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-02 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-03 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-04 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-05 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-06 00:00:00', 6.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-07 00:00:00', 7.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-08 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-09 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-10 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-11 00:00:00', 5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-12 00:00:00', 5.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-13 00:00:00', 5.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-14 00:00:00', 6.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-15 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-16 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-17 00:00:00', 5.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-18 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-19 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-20 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-21 00:00:00', 5.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-22 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-23 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-24 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-25 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-26 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-27 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-28 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-29 00:00:00', 6.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-30 00:00:00', 5.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-01-31 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-01 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-02 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-03 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-04 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-05 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-06 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-07 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-08 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-09 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-10 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-11 00:00:00', 5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-12 00:00:00', 6.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-13 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-14 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-15 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-16 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-17 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-18 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-19 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-20 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-21 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-22 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-23 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-24 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-25 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-26 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-27 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-28 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-02-29 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-01 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-02 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-03 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-04 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-05 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-06 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-07 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-08 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-09 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-10 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-11 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-12 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-13 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-14 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-15 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-16 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-17 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-18 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-19 00:00:00', 6.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-20 00:00:00', 5.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-21 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-22 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-23 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-24 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-25 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-26 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-27 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-28 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-29 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-30 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-03-31 00:00:00', 5.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-01 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-02 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-03 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-04 00:00:00', 6.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-05 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-06 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-07 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-08 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-09 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-10 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-11 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-12 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-13 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-14 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-15 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-16 00:00:00', 7.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-17 00:00:00', 6.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-18 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-19 00:00:00', 5.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-20 00:00:00', 5.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-21 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-22 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-23 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-24 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-25 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-26 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-27 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-28 00:00:00', 5.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-29 00:00:00', 6.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-04-30 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-01 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-02 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-03 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-04 00:00:00', 4.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-05 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-06 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-07 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-08 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-09 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-10 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-11 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-12 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-13 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-14 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-15 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-16 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-17 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-18 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-19 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-20 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-21 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-22 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-23 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-24 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-25 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-26 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-27 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-28 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-29 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-30 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-05-31 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-01 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-02 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-03 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-04 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-05 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-06 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-07 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-08 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-09 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-10 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-11 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-12 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-13 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-14 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-15 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-16 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-17 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-18 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-19 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-20 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-21 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-22 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-23 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-24 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-25 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-26 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-27 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-28 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-29 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-06-30 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-01 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-02 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-03 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-04 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-05 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-06 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-07 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-08 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-09 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-10 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-11 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-12 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-13 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-14 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-15 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-16 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-17 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-18 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-19 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-20 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-21 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-22 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-23 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-24 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-25 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-26 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-27 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-28 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-29 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-30 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-07-31 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-01 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-02 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-03 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-04 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-05 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-06 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-07 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-08 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-09 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-10 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-11 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-12 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-13 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-14 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-15 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-16 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-17 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-18 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-19 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-20 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-21 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-22 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-23 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-24 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-25 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-26 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-27 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-28 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-29 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-30 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-08-31 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-01 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-02 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-03 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-04 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-05 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-06 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-07 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-08 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-09 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-10 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-11 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-12 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-13 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-14 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-15 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-16 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-17 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-18 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-19 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-20 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-21 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-22 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-23 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-24 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-25 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-26 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-27 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-28 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-29 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-09-30 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-01 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-02 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-03 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-04 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-05 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-06 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-07 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-08 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-09 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-10 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-11 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-12 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-13 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-14 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-15 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-16 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-17 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-18 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-19 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-20 00:00:00', 5.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-21 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-22 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-23 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-24 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-25 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-26 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-27 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-28 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-29 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-30 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-10-31 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-01 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-02 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-03 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-04 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-05 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-06 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-07 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-08 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-09 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-10 00:00:00', 4.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-11 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-12 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-13 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-14 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-15 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-16 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-17 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-18 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-19 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-20 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-21 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-22 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-23 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-24 00:00:00', 4.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-25 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-26 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-27 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-28 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-29 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-11-30 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-01 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-02 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-03 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-04 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-05 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-06 00:00:00', 5.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-07 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-08 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-09 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-10 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-11 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-12 00:00:00', 6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-13 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-14 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-15 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-16 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-17 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-18 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-19 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-20 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-21 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-22 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-23 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-24 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-25 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-26 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-27 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-28 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-29 00:00:00', 5.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-30 00:00:00', 5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1980-12-31 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-01 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-02 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-03 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-04 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-05 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-06 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-07 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-08 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-09 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-10 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-11 00:00:00', 6.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-12 00:00:00', 6.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-13 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-14 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-15 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-16 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-17 00:00:00', 6.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-18 00:00:00', 5.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-19 00:00:00', 5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-20 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-21 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-22 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-23 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-24 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-25 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-26 00:00:00', 6.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-27 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-28 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-29 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-30 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-01-31 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-01 00:00:00', 6.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-02 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-03 00:00:00', 5.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-04 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-05 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-06 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-07 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-08 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-09 00:00:00', 5.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-10 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-11 00:00:00', 4.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-12 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-13 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-14 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-15 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-16 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-17 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-18 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-19 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-20 00:00:00', 4.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-21 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-22 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-23 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-24 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-25 00:00:00', 4.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-26 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-27 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-02-28 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-01 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-02 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-03 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-04 00:00:00', 5.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-05 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-06 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-07 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-08 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-09 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-10 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-11 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-12 00:00:00', 6.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-13 00:00:00', 7.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-14 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-15 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-16 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-17 00:00:00', 4.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-18 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-19 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-20 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-21 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-22 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-23 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-24 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-25 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-26 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-27 00:00:00', 6.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-28 00:00:00', 6.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-29 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-30 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-03-31 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-01 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-02 00:00:00', 5.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-03 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-04 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-05 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-06 00:00:00', 6.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-07 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-08 00:00:00', 4.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-09 00:00:00', 7.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-10 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-11 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-12 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-13 00:00:00', 6.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-14 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-15 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-16 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-17 00:00:00', 6.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-18 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-19 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-20 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-21 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-22 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-23 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-24 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-25 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-26 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-27 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-28 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-29 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-04-30 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-01 00:00:00', 4.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-02 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-03 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-04 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-05 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-06 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-07 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-08 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-09 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-10 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-11 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-12 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-13 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-14 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-15 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-16 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-17 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-18 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-19 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-20 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-21 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-22 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-23 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-24 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-25 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-26 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-27 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-28 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-29 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-30 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-05-31 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-01 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-02 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-03 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-04 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-05 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-06 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-07 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-08 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-09 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-10 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-11 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-12 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-13 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-14 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-15 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-16 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-17 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-18 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-19 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-20 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-21 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-22 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-23 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-24 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-25 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-26 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-27 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-28 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-29 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-06-30 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-01 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-02 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-03 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-04 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-05 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-06 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-07 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-08 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-09 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-10 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-11 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-12 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-13 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-14 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-15 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-16 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-17 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-18 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-19 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-20 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-21 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-22 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-23 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-24 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-25 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-26 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-27 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-28 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-29 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-30 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-07-31 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-01 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-02 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-03 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-04 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-05 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-06 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-07 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-08 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-09 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-10 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-11 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-12 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-13 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-14 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-15 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-16 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-17 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-18 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-19 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-20 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-21 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-22 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-23 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-24 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-25 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-26 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-27 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-28 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-29 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-30 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-08-31 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-01 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-02 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-03 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-04 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-05 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-06 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-07 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-08 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-09 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-10 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-11 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-12 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-13 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-14 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-15 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-16 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-17 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-18 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-19 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-20 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-21 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-22 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-23 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-24 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-25 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-26 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-27 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-28 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-29 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-09-30 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-01 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-02 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-03 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-04 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-05 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-06 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-07 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-08 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-09 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-10 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-11 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-12 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-13 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-14 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-15 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-16 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-17 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-18 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-19 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-20 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-21 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-22 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-23 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-24 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-25 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-26 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-27 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-28 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-29 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-30 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-10-31 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-01 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-02 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-03 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-04 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-05 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-06 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-07 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-08 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-09 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-10 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-11 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-12 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-13 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-14 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-15 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-16 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-17 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-18 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-19 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-20 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-21 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-22 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-23 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-24 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-25 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-26 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-27 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-28 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-29 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-11-30 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-01 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-02 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-03 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-04 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-05 00:00:00', 5.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-06 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-07 00:00:00', 5.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-08 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-09 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-10 00:00:00', 4.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-11 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-12 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-13 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-14 00:00:00', 4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-15 00:00:00', 6.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-16 00:00:00', 6.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-17 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-18 00:00:00', 5.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-19 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-20 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-21 00:00:00', 5.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-22 00:00:00', 5.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-23 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-24 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-25 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-26 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-27 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-28 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-29 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-30 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1981-12-31 00:00:00', 5.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-01 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-02 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-03 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-04 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-05 00:00:00', 5.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-06 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-07 00:00:00', 6.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-08 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-09 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-10 00:00:00', 5.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-11 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-12 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-13 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-14 00:00:00', 6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-15 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-16 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-17 00:00:00', 6.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-18 00:00:00', 5.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-19 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-20 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-21 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-22 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-23 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-24 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-25 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-26 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-27 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-28 00:00:00', 5.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-29 00:00:00', 7.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-30 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-01-31 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-01 00:00:00', 7.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-02 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-03 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-04 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-05 00:00:00', 6.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-06 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-07 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-08 00:00:00', 4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-09 00:00:00', 5.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-10 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-11 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-12 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-13 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-14 00:00:00', 6.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-15 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-16 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-17 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-18 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-19 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-20 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-21 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-22 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-23 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-24 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-25 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-26 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-27 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-02-28 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-01 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-02 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-03 00:00:00', 4.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-04 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-05 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-06 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-07 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-08 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-09 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-10 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-11 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-12 00:00:00', 5.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-13 00:00:00', 4.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-14 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-15 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-16 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-17 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-18 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-19 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-20 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-21 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-22 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-23 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-24 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-25 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-26 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-27 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-28 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-29 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-30 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-03-31 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-01 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-02 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-03 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-04 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-05 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-06 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-07 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-08 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-09 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-10 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-11 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-12 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-13 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-14 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-15 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-16 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-17 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-18 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-19 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-20 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-21 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-22 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-23 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-24 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-25 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-26 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-27 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-28 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-29 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-04-30 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-01 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-02 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-03 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-04 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-05 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-06 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-07 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-08 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-09 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-10 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-11 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-12 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-13 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-14 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-15 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-16 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-17 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-18 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-19 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-20 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-21 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-22 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-23 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-24 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-25 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-26 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-27 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-28 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-29 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-30 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-05-31 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-01 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-02 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-03 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-04 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-05 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-06 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-07 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-08 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-09 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-10 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-11 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-12 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-13 00:00:00', 4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-14 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-15 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-16 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-17 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-18 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-19 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-20 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-21 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-22 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-23 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-24 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-25 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-26 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-27 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-28 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-29 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-06-30 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-01 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-02 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-03 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-04 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-05 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-06 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-07 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-08 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-09 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-10 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-11 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-12 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-13 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-14 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-15 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-16 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-17 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-18 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-19 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-20 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-21 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-22 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-23 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-24 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-25 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-26 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-27 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-28 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-29 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-30 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-07-31 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-01 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-02 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-03 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-04 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-05 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-06 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-07 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-08 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-09 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-10 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-11 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-12 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-13 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-14 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-15 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-16 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-17 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-18 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-19 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-20 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-21 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-22 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-23 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-24 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-25 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-26 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-27 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-28 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-29 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-30 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-08-31 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-01 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-02 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-03 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-04 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-05 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-06 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-07 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-08 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-09 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-10 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-11 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-12 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-13 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-14 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-15 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-16 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-17 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-18 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-19 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-20 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-21 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-22 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-23 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-24 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-25 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-26 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-27 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-28 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-29 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-09-30 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-01 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-02 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-03 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-04 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-05 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-06 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-07 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-08 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-09 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-10 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-11 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-12 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-13 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-14 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-15 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-16 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-17 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-18 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-19 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-20 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-21 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-22 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-23 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-24 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-25 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-26 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-27 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-28 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-29 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-30 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-10-31 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-01 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-02 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-03 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-04 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-05 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-06 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-07 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-08 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-09 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-10 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-11 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-12 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-13 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-14 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-15 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-16 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-17 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-18 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-19 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-20 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-21 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-22 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-23 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-24 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-25 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-26 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-27 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-28 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-29 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-11-30 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-01 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-02 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-03 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-04 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-05 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-06 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-07 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-08 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-09 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-10 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-11 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-12 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-13 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-14 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-15 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-16 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-17 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-18 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-19 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-20 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-21 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-22 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-23 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-24 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-25 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-26 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-27 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-28 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-29 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-30 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1982-12-31 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-01 00:00:00', 4.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-02 00:00:00', 5.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-03 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-04 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-05 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-06 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-07 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-08 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-09 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-10 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-11 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-12 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-13 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-14 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-15 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-16 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-17 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-18 00:00:00', 6.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-19 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-20 00:00:00', 5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-21 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-22 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-23 00:00:00', 5.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-24 00:00:00', 6.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-25 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-26 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-27 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-28 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-29 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-30 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-01-31 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-01 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-02 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-03 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-04 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-05 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-06 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-07 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-08 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-09 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-10 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-11 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-12 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-13 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-14 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-15 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-16 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-17 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-18 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-19 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-20 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-21 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-22 00:00:00', 4.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-23 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-24 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-25 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-26 00:00:00', 4.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-27 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-02-28 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-01 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-02 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-03 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-04 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-05 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-06 00:00:00', 6.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-07 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-08 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-09 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-10 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-11 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-12 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-13 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-14 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-15 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-16 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-17 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-18 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-19 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-20 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-21 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-22 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-23 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-24 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-25 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-26 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-27 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-28 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-29 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-30 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-03-31 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-01 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-02 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-03 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-04 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-05 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-06 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-07 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-08 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-09 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-10 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-11 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-12 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-13 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-14 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-15 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-16 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-17 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-18 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-19 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-20 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-21 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-22 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-23 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-24 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-25 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-26 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-27 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-28 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-29 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-04-30 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-01 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-02 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-03 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-04 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-05 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-06 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-07 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-08 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-09 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-10 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-11 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-12 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-13 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-14 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-15 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-16 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-17 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-18 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-19 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-20 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-21 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-22 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-23 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-24 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-25 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-26 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-27 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-28 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-29 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-30 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-05-31 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-01 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-02 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-03 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-04 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-05 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-06 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-07 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-08 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-09 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-10 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-11 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-12 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-13 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-14 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-15 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-16 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-17 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-18 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-19 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-20 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-21 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-22 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-23 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-24 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-25 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-26 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-27 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-28 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-29 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-06-30 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-01 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-02 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-03 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-04 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-05 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-06 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-07 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-08 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-09 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-10 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-11 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-12 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-13 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-14 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-15 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-16 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-17 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-18 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-19 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-20 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-21 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-22 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-23 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-24 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-25 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-26 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-27 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-28 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-29 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-30 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-07-31 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-01 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-02 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-03 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-04 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-05 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-06 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-07 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-08 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-09 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-10 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-11 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-12 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-13 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-14 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-15 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-16 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-17 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-18 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-19 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-20 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-21 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-22 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-23 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-24 00:00:00', 3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-25 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-26 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-27 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-28 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-29 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-30 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-08-31 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-01 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-03 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-05 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-07 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-09 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-11 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-13 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-15 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-17 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-19 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-21 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-23 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-25 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-27 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-29 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-01 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-03 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-05 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-07 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-09 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-11 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-13 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-15 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-17 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-19 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-21 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-23 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-25 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-27 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-29 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-30 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-10-31 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-01 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-02 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-03 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-04 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-05 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-06 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-07 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-08 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-09 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-10 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-11 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-12 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-13 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-14 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-15 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-16 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-17 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-18 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-19 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-20 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-21 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-22 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-23 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-24 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-25 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-26 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-27 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-28 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-29 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-11-30 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-01 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-02 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-03 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-04 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-05 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-06 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-07 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-08 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-09 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-10 00:00:00', 4.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-11 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-12 00:00:00', 5.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-13 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-14 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-15 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-16 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-17 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-18 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-19 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-20 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-21 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-22 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-23 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-24 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-25 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-26 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-27 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-28 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-29 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-30 00:00:00', 5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1983-12-31 00:00:00', 4.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-01 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-02 00:00:00', 6.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-03 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-04 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-05 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-06 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-07 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-08 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-09 00:00:00', 6.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-10 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-11 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-12 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-13 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-14 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-15 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-16 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-17 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-18 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-19 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-20 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-21 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-22 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-23 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-24 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-25 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-26 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-27 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-28 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-29 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-30 00:00:00', 4.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-01-31 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-01 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-02 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-03 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-04 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-05 00:00:00', 5.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-06 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-07 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-08 00:00:00', 7.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-09 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-10 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-11 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-12 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-13 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-14 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-15 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-16 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-17 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-18 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-19 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-20 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-21 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-22 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-23 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-24 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-25 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-26 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-27 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-28 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-02-29 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-01 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-02 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-03 00:00:00', 4.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-04 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-05 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-06 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-07 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-08 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-09 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-10 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-11 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-12 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-13 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-14 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-15 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-16 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-17 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-18 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-19 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-20 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-21 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-22 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-23 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-24 00:00:00', 4.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-25 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-26 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-27 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-28 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-29 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-30 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-03-31 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-01 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-02 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-03 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-04 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-05 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-06 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-07 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-08 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-09 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-10 00:00:00', 5.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-11 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-12 00:00:00', 4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-13 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-14 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-15 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-16 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-17 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-18 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-19 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-20 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-21 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-22 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-23 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-24 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-25 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-26 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-27 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-28 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-29 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-04-30 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-01 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-02 00:00:00', 6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-03 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-04 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-05 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-06 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-07 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-08 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-09 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-10 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-11 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-12 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-13 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-14 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-15 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-16 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-17 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-18 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-19 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-20 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-21 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-22 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-23 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-24 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-25 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-26 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-27 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-28 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-29 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-30 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-05-31 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-01 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-02 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-03 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-04 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-05 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-06 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-07 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-08 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-09 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-10 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-11 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-12 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-13 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-14 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-15 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-16 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-17 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-18 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-19 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-20 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-21 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-22 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-23 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-24 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-25 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-26 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-27 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-28 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-29 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-06-30 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-01 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-02 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-03 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-04 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-05 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-06 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-07 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-08 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-09 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-10 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-11 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-12 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-13 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-14 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-15 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-16 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-17 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-18 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-19 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-20 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-21 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-22 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-23 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-24 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-25 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-26 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-27 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-28 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-29 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-30 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-07-31 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-01 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-02 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-03 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-04 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-05 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-06 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-07 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-08 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-09 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-10 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-11 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-12 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-13 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-14 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-15 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-16 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-17 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-18 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-19 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-20 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-21 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-22 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-23 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-24 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-25 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-26 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-27 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-28 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-29 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-30 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-08-31 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-01 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-02 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-03 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-04 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-05 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-06 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-07 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-08 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-09 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-10 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-11 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-12 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-13 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-14 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-15 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-16 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-17 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-18 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-19 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-20 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-21 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-22 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-23 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-24 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-25 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-26 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-27 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-28 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-29 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-09-30 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-01 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-02 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-03 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-04 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-05 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-06 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-07 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-08 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-09 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-10 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-11 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-12 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-13 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-14 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-15 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-16 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-17 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-18 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-19 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-20 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-21 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-22 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-23 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-24 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-25 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-26 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-27 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-28 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-29 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-30 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-10-31 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-01 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-02 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-03 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-04 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-05 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-06 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-07 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-08 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-09 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-10 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-11 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-12 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-13 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-14 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-15 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-16 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-17 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-18 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-19 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-20 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-21 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-22 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-23 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-24 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-25 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-26 00:00:00', 5.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-27 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-28 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-29 00:00:00', 6.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-11-30 00:00:00', 5.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-01 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-02 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-03 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-04 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-05 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-06 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-07 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-08 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-09 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-10 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-11 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-12 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-13 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-14 00:00:00', 4.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-15 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-16 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-17 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-18 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-19 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-20 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-21 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-22 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-23 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-24 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-25 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-26 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-27 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-28 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-29 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-30 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1984-12-31 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-01 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-02 00:00:00', 6.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-03 00:00:00', 6.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-04 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-05 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-06 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-07 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-08 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-09 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-10 00:00:00', 4.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-11 00:00:00', 5.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-12 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-13 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-14 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-15 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-16 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-17 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-18 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-19 00:00:00', 5.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-20 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-21 00:00:00', 5.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-22 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-23 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-24 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-25 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-26 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-27 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-28 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-29 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-30 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-01-31 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-01 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-02 00:00:00', 6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-03 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-04 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-05 00:00:00', 5.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-06 00:00:00', 6.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-07 00:00:00', 5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-08 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-09 00:00:00', 6.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-10 00:00:00', 5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-11 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-12 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-13 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-14 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-15 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-16 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-17 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-18 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-19 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-20 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-21 00:00:00', 5.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-22 00:00:00', 6.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-23 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-24 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-25 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-26 00:00:00', 6.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-27 00:00:00', 5.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-02-28 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-01 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-02 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-03 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-04 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-05 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-06 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-07 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-08 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-09 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-10 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-11 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-12 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-13 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-14 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-15 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-16 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-17 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-18 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-19 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-20 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-21 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-22 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-23 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-24 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-25 00:00:00', 5.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-26 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-27 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-28 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-29 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-30 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-03-31 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-01 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-02 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-03 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-04 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-05 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-06 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-07 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-08 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-09 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-10 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-11 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-12 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-13 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-14 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-15 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-16 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-17 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-18 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-19 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-20 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-21 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-22 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-23 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-24 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-25 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-26 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-27 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-28 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-29 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-04-30 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-01 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-02 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-03 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-04 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-05 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-06 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-07 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-08 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-09 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-10 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-11 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-12 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-13 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-14 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-15 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-16 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-17 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-18 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-19 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-20 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-21 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-22 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-23 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-24 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-25 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-26 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-27 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-28 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-29 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-30 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-05-31 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-01 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-02 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-03 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-04 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-05 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-06 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-07 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-08 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-09 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-10 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-11 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-12 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-13 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-14 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-15 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-16 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-17 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-18 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-19 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-20 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-21 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-22 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-23 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-24 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-25 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-26 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-27 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-28 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-29 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-06-30 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-01 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-02 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-03 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-04 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-05 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-06 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-07 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-08 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-09 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-10 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-11 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-12 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-13 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-14 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-15 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-16 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-17 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-18 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-19 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-20 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-21 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-22 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-23 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-24 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-25 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-26 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-27 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-28 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-29 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-30 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-07-31 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-01 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-02 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-03 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-04 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-05 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-06 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-07 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-08 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-09 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-10 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-11 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-12 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-13 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-14 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-15 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-16 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-17 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-18 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-19 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-20 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-21 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-22 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-23 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-24 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-25 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-26 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-27 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-28 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-29 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-30 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-08-31 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-01 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-02 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-03 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-04 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-05 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-06 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-07 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-08 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-09 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-10 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-11 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-12 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-13 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-14 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-15 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-16 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-17 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-18 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-19 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-20 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-21 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-22 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-23 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-24 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-25 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-26 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-27 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-28 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-29 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-09-30 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-01 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-02 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-03 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-04 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-05 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-06 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-07 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-08 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-09 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-10 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-11 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-12 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-13 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-14 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-15 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-16 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-17 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-18 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-19 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-20 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-21 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-22 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-23 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-24 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-25 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-26 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-27 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-28 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-29 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-30 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-10-31 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-01 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-02 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-03 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-04 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-05 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-06 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-07 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-08 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-09 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-10 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-11 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-12 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-13 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-14 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-15 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-16 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-17 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-18 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-19 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-20 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-21 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-22 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-23 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-24 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-25 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-26 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-27 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-28 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-29 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-11-30 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-01 00:00:00', 4.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-02 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-03 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-04 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-05 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-06 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-07 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-08 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-09 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-10 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-11 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-12 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-13 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-14 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-15 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-16 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-17 00:00:00', 6.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-18 00:00:00', 6.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-19 00:00:00', 7.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-20 00:00:00', 5.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-21 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-22 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-23 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-24 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-25 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-26 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-27 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-28 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-29 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-30 00:00:00', 4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1985-12-31 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-01 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-02 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-03 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-04 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-05 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-06 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-07 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-08 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-09 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-10 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-11 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-12 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-13 00:00:00', 6.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-14 00:00:00', 5.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-15 00:00:00', 5.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-16 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-17 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-18 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-19 00:00:00', 3.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-20 00:00:00', 6.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-21 00:00:00', 6.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-22 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-23 00:00:00', 4.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-24 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-25 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-26 00:00:00', 4.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-27 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-28 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-29 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-30 00:00:00', 5.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-01-31 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-01 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-02 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-03 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-04 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-05 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-06 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-07 00:00:00', 4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-08 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-09 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-10 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-11 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-12 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-13 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-14 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-15 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-16 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-17 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-18 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-19 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-20 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-21 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-22 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-23 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-24 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-25 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-26 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-27 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-02-28 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-01 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-02 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-03 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-04 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-05 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-06 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-07 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-08 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-09 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-10 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-11 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-12 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-13 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-14 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-15 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-16 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-17 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-18 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-19 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-20 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-21 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-22 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-23 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-24 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-25 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-26 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-27 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-28 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-29 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-30 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-03-31 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-01 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-02 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-03 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-04 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-05 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-06 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-07 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-08 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-09 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-10 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-11 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-12 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-13 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-14 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-15 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-16 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-17 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-18 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-19 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-20 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-21 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-22 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-23 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-24 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-25 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-26 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-27 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-28 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-29 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-04-30 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-01 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-02 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-03 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-04 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-05 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-06 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-07 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-08 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-09 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-10 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-11 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-12 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-13 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-14 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-15 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-16 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-17 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-18 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-19 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-20 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-21 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-22 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-23 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-24 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-25 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-26 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-27 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-28 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-29 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-30 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-01 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-02 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-03 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-04 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-05 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-06 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-07 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-08 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-09 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-10 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-11 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-12 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-13 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-14 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-15 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-16 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-17 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-18 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-19 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-20 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-21 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-22 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-23 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-24 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-25 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-26 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-27 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-28 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-29 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-06-30 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-01 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-02 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-03 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-04 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-05 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-06 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-07 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-08 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-09 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-10 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-11 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-12 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-13 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-14 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-15 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-16 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-17 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-18 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-19 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-20 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-21 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-22 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-23 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-24 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-25 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-26 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-27 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-28 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-29 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-30 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-07-31 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-01 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-02 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-03 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-04 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-05 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-06 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-07 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-08 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-09 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-10 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-11 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-12 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-13 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-14 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-15 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-16 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-17 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-18 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-19 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-20 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-21 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-22 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-23 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-24 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-25 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-26 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-27 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-28 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-29 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-30 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-08-31 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-01 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-02 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-03 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-04 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-05 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-06 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-07 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-08 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-09 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-10 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-11 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-12 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-13 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-14 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-15 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-16 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-17 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-18 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-19 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-20 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-21 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-22 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-23 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-24 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-25 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-26 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-27 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-28 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-29 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-09-30 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-01 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-02 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-03 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-04 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-05 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-06 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-07 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-08 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-09 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-10 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-11 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-12 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-13 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-14 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-15 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-16 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-17 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-18 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-19 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-20 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-21 00:00:00', 3.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-22 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-23 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-24 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-25 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-26 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-27 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-28 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-29 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-30 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-10-31 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-01 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-02 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-03 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-04 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-05 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-06 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-07 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-08 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-09 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-10 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-11 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-12 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-13 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-14 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-15 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-16 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-17 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-18 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-19 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-20 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-21 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-22 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-23 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-24 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-25 00:00:00', 1.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-26 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-27 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-28 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-29 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-11-30 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-01 00:00:00', 5.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-02 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-03 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-04 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-05 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-06 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-07 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-08 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-09 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-10 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-11 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-12 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-13 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-14 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-15 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-16 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-17 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-18 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-19 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-20 00:00:00', 6.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-21 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-22 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-23 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-24 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-01 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-02 00:00:00', 5.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-03 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-04 00:00:00', 4.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-05 00:00:00', 4.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-06 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-07 00:00:00', 5.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-08 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-09 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-10 00:00:00', 5.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-11 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-12 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-13 00:00:00', 1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-14 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-15 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-16 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-17 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-18 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-19 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-20 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-21 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-22 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-23 00:00:00', 4.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-24 00:00:00', 5.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-25 00:00:00', 5.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-26 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-27 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-28 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-29 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-30 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-01-31 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-01 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-02 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-03 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-04 00:00:00', 4.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-05 00:00:00', 5.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-06 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-07 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-08 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-09 00:00:00', 6.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-10 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-11 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-12 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-13 00:00:00', 5.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-14 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-15 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-16 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-17 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-18 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-19 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-20 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-21 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-22 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-23 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-24 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-25 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-26 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-27 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-02-28 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-01 00:00:00', 5.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-02 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-03 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-04 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-05 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-06 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-07 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-08 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-09 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-10 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-11 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-12 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-13 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-14 00:00:00', 6.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-15 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-16 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-17 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-18 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-19 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-20 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-21 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-22 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-23 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-24 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-25 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-26 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-27 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-28 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-29 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-30 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-03-31 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-01 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-02 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-03 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-04 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-05 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-06 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-07 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-08 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-09 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-10 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-11 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-12 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-13 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-14 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-15 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-16 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-17 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-18 00:00:00', 5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-19 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-20 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-21 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-22 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-23 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-24 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-25 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-26 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-27 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-28 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-29 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-04-30 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-01 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-02 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-03 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-04 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-05 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-06 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-07 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-08 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-09 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-10 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-11 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-12 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-13 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-14 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-15 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-16 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-17 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-18 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-19 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-20 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-21 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-22 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-23 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-24 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-25 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-26 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-27 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-28 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-29 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-30 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-05-31 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-01 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-02 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-03 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-04 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-05 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-06 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-07 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-08 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-09 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-10 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-11 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-12 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-13 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-14 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-15 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-16 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-17 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-18 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-19 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-20 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-21 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-22 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-23 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-24 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-25 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-26 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-27 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-28 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-29 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-06-30 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-01 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-02 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-03 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-04 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-05 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-06 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-07 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-08 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-09 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-10 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-11 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-12 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-13 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-14 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-15 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-16 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-17 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-18 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-19 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-20 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-21 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-22 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-23 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-24 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-25 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-26 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-27 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-28 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-29 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-30 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-07-31 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-01 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-02 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-03 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-04 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-05 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-06 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-07 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-08 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-09 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-10 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-11 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-12 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-13 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-14 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-15 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-16 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-17 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-18 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-19 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-20 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-21 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-22 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-23 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-24 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-25 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-26 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-27 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-28 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-29 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-30 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-08-31 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-01 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-02 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-03 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-04 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-05 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-06 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-07 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-08 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-09 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-10 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-11 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-12 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-13 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-14 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-15 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-16 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-17 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-18 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-19 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-20 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-21 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-22 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-23 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-24 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-25 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-26 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-27 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-28 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-29 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-09-30 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-01 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-02 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-03 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-04 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-05 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-06 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-07 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-08 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-09 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-10 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-11 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-12 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-13 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-14 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-15 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-16 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-17 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-18 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-19 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-20 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-21 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-22 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-23 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-24 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-25 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-26 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-27 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-28 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-29 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-30 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-10-31 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-01 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-02 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-03 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-04 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-05 00:00:00', 5.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-06 00:00:00', 6.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-07 00:00:00', 7.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-08 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-09 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-10 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-11 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-12 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-13 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-14 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-15 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-16 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-17 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-18 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-19 00:00:00', 6.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-20 00:00:00', 6.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-21 00:00:00', 6.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-22 00:00:00', 6.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-23 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-24 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-25 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-26 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-27 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-28 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-29 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-11-30 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-01 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-02 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-03 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-04 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-05 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-06 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-07 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-08 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-09 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-10 00:00:00', 5.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-11 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-12 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-13 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-14 00:00:00', 4.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-15 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-16 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-17 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-18 00:00:00', 5.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-19 00:00:00', 5.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-20 00:00:00', 5.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-21 00:00:00', 7.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-22 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-23 00:00:00', 6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-24 00:00:00', 7.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-25 00:00:00', 6.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-26 00:00:00', 6.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-27 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-28 00:00:00', 5.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-29 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-30 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1987-12-31 00:00:00', 6.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-01 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-02 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-03 00:00:00', 4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-04 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-05 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-06 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-07 00:00:00', 5.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-08 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-09 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-10 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-11 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-12 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-13 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-14 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-15 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-16 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-17 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-18 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-19 00:00:00', 5.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-20 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-21 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-22 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-23 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-24 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-25 00:00:00', 4.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-26 00:00:00', 5.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-27 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-28 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-29 00:00:00', 6.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-30 00:00:00', 5.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-01-31 00:00:00', 6.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-01 00:00:00', 6.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-02 00:00:00', 7.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-03 00:00:00', 5.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-04 00:00:00', 4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-05 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-06 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-07 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-08 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-09 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-10 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-11 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-12 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-13 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-14 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-15 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-16 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-17 00:00:00', 5.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-18 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-19 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-20 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-21 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-22 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-23 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-24 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-25 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-26 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-27 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-28 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-02-29 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-01 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-02 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-03 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-04 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-05 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-06 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-07 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-08 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-09 00:00:00', 5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-10 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-11 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-12 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-13 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-14 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-15 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-16 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-17 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-18 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-19 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-20 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-21 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-22 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-23 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-24 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-25 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-26 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-27 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-28 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-29 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-30 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-03-31 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-01 00:00:00', 6.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-02 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-03 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-04 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-05 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-06 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-07 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-08 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-09 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-10 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-11 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-12 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-13 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-14 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-15 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-16 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-17 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-18 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-19 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-20 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-21 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-22 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-23 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-24 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-25 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-26 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-27 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-28 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-29 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-04-30 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-01 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-02 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-03 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-04 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-05 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-06 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-07 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-08 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-09 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-10 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-11 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-12 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-13 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-14 00:00:00', 5.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-15 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-16 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-17 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-18 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-19 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-20 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-21 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-22 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-23 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-24 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-25 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-26 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-27 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-28 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-29 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-30 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-05-31 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-01 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-02 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-03 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-04 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-05 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-06 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-07 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-08 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-09 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-10 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-11 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-12 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-13 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-14 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-15 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-16 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-17 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-18 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-19 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-20 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-21 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-22 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-23 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-24 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-25 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-26 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-27 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-28 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-29 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-06-30 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-01 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-02 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-03 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-04 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-05 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-06 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-07 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-08 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-09 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-10 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-11 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-12 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-13 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-14 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-15 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-16 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-17 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-18 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-19 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-20 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-21 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-22 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-23 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-24 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-25 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-26 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-27 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-28 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-29 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-30 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-07-31 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-01 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-02 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-03 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-04 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-05 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-06 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-07 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-08 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-09 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-10 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-11 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-12 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-13 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-14 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-15 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-16 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-17 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-18 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-19 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-20 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-21 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-22 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-23 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-24 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-25 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-26 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-27 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-28 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-29 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-30 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-08-31 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-01 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-02 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-03 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-04 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-05 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-06 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-07 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-08 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-09 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-10 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-11 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-12 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-13 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-14 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-15 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-16 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-17 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-18 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-19 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-20 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-21 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-22 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-23 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-24 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-25 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-26 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-27 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-28 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-29 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-09-30 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-01 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-02 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-03 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-04 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-05 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-06 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-07 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-08 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-09 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-10 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-11 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-12 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-13 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-14 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-15 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-16 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-17 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-18 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-19 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-20 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-21 00:00:00', 5.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-22 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-23 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-24 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-25 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-26 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-27 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-28 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-29 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-30 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-10-31 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-01 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-02 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-03 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-04 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-05 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-06 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-07 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-08 00:00:00', 3.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-09 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-10 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-11 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-12 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-13 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-14 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-15 00:00:00', 4.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-16 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-17 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-18 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-19 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-20 00:00:00', 5.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-21 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-22 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-23 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-24 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-25 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-26 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-27 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-28 00:00:00', 4.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-29 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-11-30 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-01 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-02 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-03 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-04 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-05 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-06 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-07 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-08 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-09 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-10 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-11 00:00:00', 5.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-12 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-13 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-14 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-15 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-16 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-17 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-18 00:00:00', 5.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-19 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-20 00:00:00', 6.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-21 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-22 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-23 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-24 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-25 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-26 00:00:00', 6.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-27 00:00:00', 6.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-28 00:00:00', 5.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-29 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-30 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1988-12-31 00:00:00', 5.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-01 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-02 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-03 00:00:00', 5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-04 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-05 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-06 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-07 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-08 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-09 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-10 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-11 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-12 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-13 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-14 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-15 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-16 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-17 00:00:00', 6.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-18 00:00:00', 5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-19 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-20 00:00:00', 6.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-21 00:00:00', 4.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-22 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-23 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-24 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-25 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-26 00:00:00', 4.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-27 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-28 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-29 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-30 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-01-31 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-01 00:00:00', 6.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-02 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-03 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-04 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-05 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-06 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-07 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-08 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-09 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-10 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-11 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-12 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-13 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-14 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-15 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-16 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-17 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-18 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-19 00:00:00', 4.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-20 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-21 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-22 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-23 00:00:00', 6.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-24 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-25 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-26 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-27 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-02-28 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-01 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-02 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-03 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-04 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-05 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-06 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-07 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-08 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-09 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-10 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-11 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-12 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-13 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-14 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-15 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-16 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-17 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-18 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-19 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-20 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-21 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-22 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-23 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-24 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-25 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-26 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-27 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-28 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-29 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-30 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-03-31 00:00:00', 4.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-01 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-02 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-03 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-04 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-05 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-06 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-07 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-08 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-09 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-10 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-11 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-12 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-13 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-14 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-15 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-16 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-17 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-18 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-19 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-20 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-21 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-22 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-23 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-24 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-25 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-26 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-27 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-28 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-29 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-04-30 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-01 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-02 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-03 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-04 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-05 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-06 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-07 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-08 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-09 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-10 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-11 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-12 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-13 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-14 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-15 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-16 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-17 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-18 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-19 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-20 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-21 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-22 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-23 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-24 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-25 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-26 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-27 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-28 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-29 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-30 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-05-31 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-01 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-02 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-03 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-04 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-05 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-06 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-07 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-08 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-09 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-10 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-11 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-12 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-13 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-14 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-15 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-16 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-17 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-18 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-19 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-20 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-21 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-22 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-23 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-24 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-25 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-26 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-27 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-28 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-29 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-06-30 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-01 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-02 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-03 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-04 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-05 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-06 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-07 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-08 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-09 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-10 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-11 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-12 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-13 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-14 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-15 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-16 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-17 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-18 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-19 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-20 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-21 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-22 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-23 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-24 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-25 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-26 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-27 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-28 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-29 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-30 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-07-31 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-01 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-02 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-03 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-04 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-05 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-06 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-07 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-08 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-09 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-10 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-11 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-12 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-13 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-14 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-15 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-16 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-17 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-18 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-19 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-20 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-21 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-22 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-23 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-24 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-25 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-26 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-27 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-28 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-29 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-30 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-08-31 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-01 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-02 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-03 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-04 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-05 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-06 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-07 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-08 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-09 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-10 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-11 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-12 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-13 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-14 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-15 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-16 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-17 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-18 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-19 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-20 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-21 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-22 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-23 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-24 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-25 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-26 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-27 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-28 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-29 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-09-30 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-01 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-02 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-03 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-04 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-05 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-06 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-07 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-08 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-09 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-10 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-11 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-12 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-13 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-14 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-15 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-16 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-17 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-18 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-19 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-20 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-21 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-22 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-23 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-24 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-25 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-26 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-27 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-28 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-29 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-30 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-10-31 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-01 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-02 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-03 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-04 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-05 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-06 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-07 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-08 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-09 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-10 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-11 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-12 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-13 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-14 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-15 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-16 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-17 00:00:00', 4.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-18 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-19 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-20 00:00:00', 5.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-21 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-22 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-23 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-24 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-25 00:00:00', 6.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-26 00:00:00', 4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-27 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-28 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-29 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-11-30 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-01 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-02 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-03 00:00:00', 3.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-04 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-05 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-06 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-07 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-08 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-09 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-10 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-11 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-12 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-13 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-14 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-15 00:00:00', 4.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-16 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-17 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-18 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-19 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-20 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-21 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-22 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-23 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-24 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-25 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-26 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-27 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-28 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-29 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-30 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1989-12-31 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-01 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-02 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-03 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-04 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-05 00:00:00', 6.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-06 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-07 00:00:00', 4.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-08 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-09 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-10 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-11 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-12 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-13 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-14 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-15 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-16 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-17 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-18 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-19 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-20 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-21 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-22 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-23 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-24 00:00:00', 6.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-25 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-26 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-27 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-28 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-29 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-30 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-01-31 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-01 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-02 00:00:00', 5.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-03 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-04 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-05 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-06 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-07 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-08 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-09 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-10 00:00:00', 5.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-11 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-12 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-13 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-14 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-15 00:00:00', 5.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-16 00:00:00', 6.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-17 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-18 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-19 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-20 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-21 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-22 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-23 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-24 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-25 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-26 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-27 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-02-28 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-01 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-02 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-03 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-04 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-05 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-06 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-07 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-08 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-09 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-10 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-11 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-12 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-13 00:00:00', 4.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-14 00:00:00', 5.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-15 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-16 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-17 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-18 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-19 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-20 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-21 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-22 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-23 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-24 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-25 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-26 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-27 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-28 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-29 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-30 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-03-31 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-01 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-02 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-03 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-04 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-05 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-06 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-07 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-08 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-09 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-10 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-11 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-12 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-13 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-14 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-15 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-16 00:00:00', 5.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-17 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-18 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-19 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-20 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-21 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-22 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-23 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-24 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-25 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-26 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-27 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-28 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-29 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-04-30 00:00:00', 5.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-01 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-02 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-03 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-04 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-05 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-06 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-07 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-08 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-09 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-10 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-11 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-12 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-13 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-14 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-15 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-16 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-17 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-18 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-19 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-20 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-21 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-22 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-23 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-24 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-25 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-26 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-27 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-28 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-29 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-30 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-05-31 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-01 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-02 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-03 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-04 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-05 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-06 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-07 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-08 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-09 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-10 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-11 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-12 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-13 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-14 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-15 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-16 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-17 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-18 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-19 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-20 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-21 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-22 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-23 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-24 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-25 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-26 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-27 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-28 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-29 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-06-30 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-01 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-02 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-03 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-04 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-05 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-06 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-07 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-08 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-09 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-10 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-11 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-12 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-13 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-14 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-15 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-16 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-17 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-18 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-19 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-20 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-21 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-22 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-23 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-24 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-25 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-26 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-27 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-28 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-29 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-30 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-07-31 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-01 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-02 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-03 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-04 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-05 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-06 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-07 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-08 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-09 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-10 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-11 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-12 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-13 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-14 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-15 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-16 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-17 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-18 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-19 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-20 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-21 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-22 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-23 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-24 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-25 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-26 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-27 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-28 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-29 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-30 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-08-31 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-01 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-02 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-03 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-04 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-05 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-06 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-07 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-08 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-09 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-10 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-11 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-12 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-13 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-14 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-15 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-16 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-17 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-18 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-19 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-20 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-21 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-22 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-23 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-24 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-25 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-26 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-27 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-28 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-29 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-09-30 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-01 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-02 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-03 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-04 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-05 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-06 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-07 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-08 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-09 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-10 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-11 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-12 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-13 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-14 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-15 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-16 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-17 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-18 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-19 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-20 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-21 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-22 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-23 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-24 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-25 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-26 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-27 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-28 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-29 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-30 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-10-31 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-01 00:00:00', 3.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-02 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-03 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-04 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-05 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-06 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-07 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-08 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-09 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-10 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-11 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-12 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-13 00:00:00', 5.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-14 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-15 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-16 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-17 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-18 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-19 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-20 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-21 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-22 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-23 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-24 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-25 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-26 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-27 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-28 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-29 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-11-30 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-01 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-02 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-03 00:00:00', 4.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-04 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-05 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-06 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-07 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-08 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-09 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-10 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-11 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-12 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-13 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-14 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-15 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-16 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-17 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-18 00:00:00', 6.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-19 00:00:00', 6.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-20 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-21 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-22 00:00:00', 4.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-23 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-24 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-25 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-26 00:00:00', 5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-27 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-28 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-29 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-30 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1990-12-31 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-01 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-02 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-03 00:00:00', 4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-04 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-05 00:00:00', 6.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-06 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-07 00:00:00', 5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-08 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-09 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-10 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-11 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-12 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-13 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-14 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-15 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-16 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-17 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-18 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-19 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-20 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-21 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-22 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-23 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-24 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-25 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-26 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-27 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-28 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-29 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-30 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-01-31 00:00:00', 5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-01 00:00:00', 5.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-02 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-03 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-04 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-05 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-06 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-07 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-08 00:00:00', 5.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-09 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-10 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-11 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-12 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-13 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-14 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-15 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-16 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-17 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-18 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-19 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-20 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-21 00:00:00', 5.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-22 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-23 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-24 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-25 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-26 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-27 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-02-28 00:00:00', 4.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-01 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-02 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-03 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-04 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-05 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-06 00:00:00', 5.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-07 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-08 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-09 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-10 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-11 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-12 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-13 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-14 00:00:00', 5.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-15 00:00:00', 5.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-16 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-17 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-18 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-19 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-20 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-21 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-22 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-23 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-24 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-25 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-26 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-27 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-28 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-29 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-30 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-03-31 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-01 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-02 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-03 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-04 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-05 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-06 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-07 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-08 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-09 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-10 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-11 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-12 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-13 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-14 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-15 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-16 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-17 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-18 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-19 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-20 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-21 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-22 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-23 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-24 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-25 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-26 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-27 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-28 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-29 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-04-30 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-01 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-02 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-03 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-04 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-05 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-06 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-07 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-08 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-09 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-10 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-11 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-12 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-13 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-14 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-15 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-16 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-17 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-18 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-19 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-20 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-21 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-22 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-23 00:00:00', 5.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-24 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-25 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-26 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-27 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-28 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-29 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-30 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-05-31 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-01 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-02 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-03 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-04 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-05 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-06 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-07 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-08 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-09 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-10 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-11 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-12 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-13 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-14 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-15 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-16 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-17 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-18 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-19 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-20 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-21 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-22 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-23 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-24 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-25 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-26 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-27 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-28 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-29 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-06-30 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-01 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-02 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-03 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-04 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-05 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-06 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-07 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-08 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-09 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-10 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-11 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-12 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-13 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-14 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-15 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-16 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-17 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-18 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-19 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-20 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-21 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-22 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-23 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-24 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-25 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-26 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-27 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-28 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-29 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-30 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-07-31 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-01 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-02 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-03 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-04 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-05 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-06 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-07 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-08 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-09 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-10 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-11 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-12 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-13 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-14 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-15 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-16 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-17 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-18 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-19 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-20 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-21 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-22 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-23 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-24 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-25 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-26 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-27 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-28 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-29 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-30 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-08-31 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-01 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-02 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-03 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-04 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-05 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-06 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-07 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-08 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-09 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-10 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-11 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-12 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-13 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-14 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-15 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-16 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-17 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-18 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-19 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-20 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-21 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-22 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-23 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-24 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-25 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-26 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-27 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-28 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-29 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-09-30 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-01 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-02 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-03 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-04 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-05 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-06 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-07 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-08 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-09 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-10 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-11 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-12 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-13 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-14 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-15 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-16 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-17 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-18 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-19 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-20 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-21 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-22 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-23 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-24 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-25 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-26 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-27 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-28 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-29 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-30 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-10-31 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-01 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-02 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-03 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-04 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-05 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-06 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-07 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-08 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-09 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-10 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-11 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-12 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-13 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-14 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-15 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-16 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-17 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-18 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-19 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-20 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-21 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-22 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-23 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-24 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-25 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-26 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-27 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-28 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-29 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-11-30 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-01 00:00:00', 5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-02 00:00:00', 6.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-03 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-04 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-05 00:00:00', 6.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-06 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-07 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-08 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-09 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-10 00:00:00', 6.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-11 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-12 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-13 00:00:00', 4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-14 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-15 00:00:00', 4.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-16 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-17 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-18 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-19 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-20 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-21 00:00:00', 1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-22 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-23 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-24 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-25 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-26 00:00:00', 5.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-27 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-28 00:00:00', 5.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-29 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-30 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1991-12-31 00:00:00', 5.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-01 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-02 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-03 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-04 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-05 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-06 00:00:00', 4.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-07 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-08 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-09 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-10 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-11 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-12 00:00:00', 5.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-13 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-14 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-15 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-16 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-17 00:00:00', 7.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-18 00:00:00', 5.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-19 00:00:00', 5.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-20 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-21 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-22 00:00:00', 5.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-23 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-24 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-25 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-26 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-27 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-28 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-29 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-30 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-01-31 00:00:00', 6.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-01 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-02 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-03 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-04 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-05 00:00:00', 4.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-06 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-07 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-08 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-09 00:00:00', 5.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-10 00:00:00', 5.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-11 00:00:00', 6.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-12 00:00:00', 5.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-13 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-14 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-15 00:00:00', 5.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-16 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-17 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-18 00:00:00', 5.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-19 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-20 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-21 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-22 00:00:00', 4.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-23 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-24 00:00:00', 6.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-25 00:00:00', 6.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-26 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-27 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-28 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-02-29 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-01 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-02 00:00:00', 3.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-03 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-04 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-05 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-06 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-07 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-08 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-09 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-10 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-11 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-12 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-13 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-14 00:00:00', 5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-15 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-16 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-17 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-18 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-19 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-20 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-21 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-22 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-23 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-24 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-25 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-26 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-27 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-28 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-29 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-30 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-03-31 00:00:00', 6.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-01 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-02 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-03 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-04 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-05 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-06 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-07 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-08 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-09 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-10 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-11 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-12 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-13 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-14 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-15 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-16 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-17 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-18 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-19 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-20 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-21 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-22 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-23 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-24 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-25 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-26 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-27 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-28 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-29 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-04-30 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-01 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-02 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-03 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-04 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-05 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-06 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-07 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-08 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-09 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-10 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-11 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-12 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-13 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-14 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-15 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-16 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-17 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-18 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-19 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-20 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-21 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-22 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-23 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-24 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-25 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-26 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-27 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-28 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-29 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-30 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-05-31 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-01 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-02 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-03 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-04 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-05 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-06 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-07 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-08 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-09 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-10 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-11 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-12 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-13 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-14 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-15 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-16 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-17 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-18 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-19 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-20 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-21 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-22 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-23 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-24 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-25 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-26 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-27 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-28 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-29 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-06-30 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-01 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-02 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-03 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-04 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-05 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-06 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-07 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-08 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-09 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-10 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-11 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-12 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-13 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-14 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-15 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-16 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-17 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-18 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-19 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-20 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-21 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-22 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-23 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-24 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-25 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-26 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-27 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-28 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-29 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-30 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-07-31 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-01 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-02 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-03 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-04 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-05 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-06 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-07 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-08 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-09 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-10 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-11 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-12 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-13 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-14 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-15 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-16 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-17 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-18 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-19 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-20 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-21 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-22 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-23 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-24 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-25 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-26 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-27 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-28 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-29 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-30 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-08-31 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-01 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-02 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-03 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-04 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-05 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-06 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-07 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-08 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-09 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-10 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-11 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-12 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-13 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-14 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-15 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-16 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-17 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-18 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-19 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-20 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-21 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-22 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-23 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-24 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-25 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-26 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-27 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-28 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-29 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-09-30 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-01 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-02 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-03 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-04 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-05 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-06 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-07 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-08 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-09 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-10 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-11 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-12 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-13 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-14 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-15 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-16 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-17 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-18 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-19 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-20 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-21 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-22 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-23 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-24 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-25 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-26 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-27 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-28 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-29 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-30 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-10-31 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-01 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-02 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-03 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-04 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-05 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-06 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-07 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-08 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-09 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-10 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-11 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-12 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-13 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-14 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-15 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-16 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-17 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-18 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-19 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-20 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-21 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-22 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-23 00:00:00', 5.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-24 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-25 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-26 00:00:00', 6.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-27 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-28 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-29 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-11-30 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-01 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-02 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-03 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-04 00:00:00', 4.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-05 00:00:00', 4.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-06 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-07 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-08 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-09 00:00:00', 5.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-10 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-11 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-12 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-13 00:00:00', 6.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-14 00:00:00', 6.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-15 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-16 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-17 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-18 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-19 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-20 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-21 00:00:00', 4.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-22 00:00:00', 6.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-23 00:00:00', 4.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-24 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-25 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-26 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-27 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-28 00:00:00', 7.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-29 00:00:00', 4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-30 00:00:00', 6.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1992-12-31 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-01 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-02 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-03 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-04 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-05 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-06 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-07 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-08 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-09 00:00:00', 7.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-10 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-11 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-12 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-13 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-14 00:00:00', 4.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-15 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-16 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-17 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-18 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-19 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-20 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-21 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-22 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-23 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-24 00:00:00', 5.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-25 00:00:00', 6.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-26 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-27 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-28 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-29 00:00:00', 5.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-30 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-01-31 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-01 00:00:00', 5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-02 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-03 00:00:00', 6.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-04 00:00:00', 6.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-05 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-06 00:00:00', 5.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-07 00:00:00', 5.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-08 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-09 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-10 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-11 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-12 00:00:00', 5.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-13 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-14 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-15 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-16 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-17 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-18 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-19 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-20 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-21 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-22 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-23 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-24 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-25 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-26 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-27 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-02-28 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-01 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-02 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-03 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-04 00:00:00', 6.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-05 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-06 00:00:00', 5.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-07 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-08 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-09 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-10 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-11 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-12 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-13 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-14 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-15 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-16 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-17 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-18 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-19 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-20 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-21 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-22 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-23 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-24 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-25 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-26 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-27 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-28 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-29 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-30 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-03-31 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-01 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-02 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-03 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-04 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-05 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-06 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-07 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-08 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-09 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-10 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-11 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-12 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-13 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-14 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-15 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-16 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-17 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-18 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-19 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-20 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-21 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-22 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-23 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-24 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-25 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-26 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-27 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-28 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-29 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-04-30 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-01 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-02 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-03 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-04 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-05 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-06 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-07 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-08 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-09 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-10 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-11 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-12 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-13 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-14 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-15 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-16 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-17 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-18 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-19 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-20 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-21 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-22 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-23 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-24 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-25 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-26 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-27 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-28 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-29 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-30 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-05-31 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-01 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-02 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-03 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-04 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-05 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-06 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-07 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-08 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-09 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-10 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-11 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-12 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-13 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-14 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-15 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-16 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-17 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-18 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-19 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-20 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-21 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-22 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-23 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-24 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-25 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-26 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-27 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-28 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-29 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-06-30 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-01 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-02 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-03 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-04 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-05 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-06 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-07 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-08 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-09 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-10 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-11 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-12 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-13 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-14 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-15 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-16 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-17 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-18 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-19 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-20 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-21 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-22 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-23 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-24 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-25 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-26 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-27 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-28 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-29 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-30 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-07-31 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-01 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-02 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-03 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-04 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-05 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-06 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-07 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-08 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-09 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-10 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-11 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-12 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-13 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-14 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-15 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-16 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-17 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-18 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-19 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-20 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-21 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-22 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-23 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-24 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-25 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-26 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-27 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-28 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-29 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-30 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-08-31 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-01 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-02 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-03 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-04 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-05 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-06 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-07 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-08 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-09 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-10 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-11 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-12 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-13 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-14 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-15 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-16 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-17 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-18 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-19 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-20 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-21 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-22 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-23 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-24 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-25 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-26 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-27 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-28 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-29 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-09-30 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-01 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-02 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-03 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-04 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-05 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-06 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-07 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-08 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-09 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-10 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-11 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-12 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-13 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-14 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-15 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-16 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-17 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-18 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-19 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-20 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-21 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-22 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-23 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-24 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-25 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-26 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-27 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-28 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-29 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-30 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-10-31 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-01 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-02 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-03 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-04 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-05 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-06 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-07 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-08 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-09 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-10 00:00:00', 6.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-11 00:00:00', 6.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-12 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-13 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-14 00:00:00', 4.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-15 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-16 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-17 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-18 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-19 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-20 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-21 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-22 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-23 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-24 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-25 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-26 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-27 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-28 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-29 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-11-30 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-01 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-02 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-03 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-04 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-05 00:00:00', 6.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-06 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-07 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-08 00:00:00', 4.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-09 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-10 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-11 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-12 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-13 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-14 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-15 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-16 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-17 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-18 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-19 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-20 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-21 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-22 00:00:00', 6.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-23 00:00:00', 6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-24 00:00:00', 5.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-25 00:00:00', 5.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-26 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-27 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-28 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-29 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-30 00:00:00', 4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1993-12-31 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-01 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-02 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-03 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-04 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-05 00:00:00', 5.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-06 00:00:00', 6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-07 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-08 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-09 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-10 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-11 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-12 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-13 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-14 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-15 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-16 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-17 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-18 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-19 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-20 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-21 00:00:00', 7.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-22 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-23 00:00:00', 6.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-24 00:00:00', 4.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-25 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-26 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-27 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-28 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-29 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-30 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-01-31 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-01 00:00:00', 5.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-02 00:00:00', 5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-03 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-04 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-05 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-06 00:00:00', 6.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-07 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-08 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-09 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-10 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-11 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-12 00:00:00', 6.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-13 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-14 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-15 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-16 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-17 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-18 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-19 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-20 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-21 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-22 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-23 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-24 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-25 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-26 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-27 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-02-28 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-01 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-02 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-03 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-04 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-05 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-06 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-07 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-08 00:00:00', 5.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-09 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-10 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-11 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-12 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-13 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-14 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-15 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-16 00:00:00', 4.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-17 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-18 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-19 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-20 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-21 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-22 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-23 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-24 00:00:00', 4.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-25 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-26 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-27 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-28 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-29 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-30 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-03-31 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-01 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-02 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-03 00:00:00', 4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-04 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-05 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-06 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-07 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-08 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-09 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-10 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-11 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-12 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-13 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-14 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-15 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-16 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-17 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-18 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-19 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-20 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-21 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-22 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-23 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-24 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-25 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-26 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-27 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-28 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-29 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-04-30 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-01 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-02 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-03 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-04 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-05 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-06 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-07 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-08 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-09 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-10 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-11 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-12 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-13 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-14 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-15 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-16 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-17 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-18 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-19 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-20 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-21 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-22 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-23 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-24 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-25 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-26 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-27 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-28 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-29 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-30 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-05-31 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-01 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-02 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-03 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-04 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-05 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-06 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-07 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-08 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-09 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-10 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-11 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-12 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-13 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-14 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-15 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-16 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-17 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-18 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-19 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-20 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-21 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-22 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-23 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-24 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-25 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-26 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-27 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-28 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-29 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-06-30 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-01 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-02 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-03 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-04 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-05 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-06 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-07 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-08 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-09 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-10 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-11 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-12 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-13 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-14 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-15 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-16 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-17 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-18 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-19 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-20 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-21 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-22 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-23 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-24 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-25 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-26 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-27 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-28 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-29 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-30 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-07-31 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-01 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-02 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-03 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-04 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-05 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-06 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-07 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-08 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-09 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-10 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-11 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-12 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-13 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-14 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-15 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-16 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-17 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-18 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-19 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-20 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-21 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-22 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-23 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-24 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-25 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-26 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-27 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-28 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-29 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-30 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-08-31 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-01 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-02 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-03 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-04 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-05 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-06 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-07 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-08 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-09 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-10 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-11 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-12 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-13 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-14 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-15 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-16 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-17 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-18 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-19 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-20 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-21 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-22 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-23 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-24 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-25 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-26 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-27 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-28 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-29 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-09-30 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-01 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-02 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-03 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-04 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-05 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-06 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-07 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-08 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-09 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-10 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-11 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-12 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-13 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-14 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-15 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-16 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-17 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-18 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-19 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-20 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-21 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-22 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-23 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-24 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-25 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-26 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-27 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-28 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-29 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-30 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-10-31 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-01 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-02 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-03 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-04 00:00:00', 4.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-05 00:00:00', 5.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-06 00:00:00', 5.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-07 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-08 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-09 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-10 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-11 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-12 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-13 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-14 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-15 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-16 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-17 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-18 00:00:00', 5.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-19 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-20 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-21 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-22 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-23 00:00:00', 5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-24 00:00:00', 5.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-25 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-26 00:00:00', 6.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-27 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-28 00:00:00', 4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-29 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-11-30 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-01 00:00:00', 6.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-02 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-03 00:00:00', 6.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-04 00:00:00', 7.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-05 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-06 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-07 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-08 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-09 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-10 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-11 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-12 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-13 00:00:00', 6.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-14 00:00:00', 6.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-15 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-16 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-17 00:00:00', 4.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-18 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-19 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-20 00:00:00', 6.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-21 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-22 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-23 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-24 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-25 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-26 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-27 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-28 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-29 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-30 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1994-12-31 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-01 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-02 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-03 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-04 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-05 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-06 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-07 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-08 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-09 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-10 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-11 00:00:00', 6.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-12 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-13 00:00:00', 4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-14 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-15 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-16 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-17 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-18 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-19 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-20 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-21 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-22 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-23 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-24 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-25 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-26 00:00:00', 6.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-27 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-28 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-29 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-30 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-01-31 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-01 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-02 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-03 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-04 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-05 00:00:00', 6.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-06 00:00:00', 6.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-07 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-08 00:00:00', 5.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-09 00:00:00', 5.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-10 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-11 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-12 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-13 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-14 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-15 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-16 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-17 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-18 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-19 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-20 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-21 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-22 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-23 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-24 00:00:00', 4.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-25 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-26 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-27 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-02-28 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-01 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-02 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-03 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-04 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-05 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-06 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-07 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-08 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-09 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-10 00:00:00', 4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-11 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-12 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-13 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-14 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-15 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-16 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-17 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-18 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-19 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-20 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-21 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-22 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-23 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-24 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-25 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-26 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-27 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-28 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-29 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-30 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-03-31 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-01 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-02 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-03 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-04 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-05 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-06 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-07 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-08 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-09 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-10 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-11 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-12 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-13 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-14 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-15 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-16 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-17 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-18 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-19 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-20 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-21 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-22 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-23 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-24 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-25 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-26 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-27 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-28 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-29 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-04-30 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-01 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-02 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-03 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-04 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-05 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-06 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-07 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-08 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-09 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-10 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-11 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-12 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-13 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-14 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-15 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-16 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-17 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-18 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-19 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-20 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-21 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-22 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-23 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-24 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-25 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-26 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-27 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-28 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-29 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-30 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-05-31 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-01 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-02 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-03 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-04 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-05 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-06 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-07 00:00:00', 5.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-08 00:00:00', 5.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-09 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-10 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-11 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-12 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-13 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-14 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-15 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-16 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-17 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-18 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-19 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-20 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-21 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-22 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-23 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-24 00:00:00', 6.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-25 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-26 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-27 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-28 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-29 00:00:00', 4.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-06-30 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-01 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-02 00:00:00', 5.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-03 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-04 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-05 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-06 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-07 00:00:00', 5.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-08 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-09 00:00:00', 5.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-10 00:00:00', 4.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-11 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-12 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-13 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-14 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-15 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-16 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-17 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-18 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-19 00:00:00', 5.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-20 00:00:00', 4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-21 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-22 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-23 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-24 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-25 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-26 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-27 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-28 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-29 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-30 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-07-31 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-01 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-02 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-03 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-04 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-05 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-06 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-07 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-08 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-09 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-10 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-11 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-12 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-13 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-14 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-15 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-16 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-17 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-18 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-19 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-20 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-21 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-22 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-23 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-24 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-25 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-26 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-27 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-28 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-29 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-30 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-08-31 00:00:00', 6.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-01 00:00:00', 6.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-02 00:00:00', 5.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-03 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-04 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-05 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-06 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-07 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-08 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-09 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-10 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-11 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-12 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-13 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-14 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-15 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-16 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-17 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-18 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-19 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-20 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-21 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-22 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-23 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-24 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-25 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-26 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-27 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-28 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-29 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-09-30 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-01 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-02 00:00:00', 5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-03 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-04 00:00:00', 6.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-05 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-06 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-07 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-08 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-09 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-10 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-11 00:00:00', 5.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-12 00:00:00', 5.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-13 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-14 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-15 00:00:00', 5.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-16 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-17 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-18 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-19 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-20 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-21 00:00:00', 4.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-22 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-23 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-24 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-25 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-26 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-27 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-28 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-29 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-30 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-10-31 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-01 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-02 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-03 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-04 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-05 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-06 00:00:00', 4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-07 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-08 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-09 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-10 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-11 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-12 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-13 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-14 00:00:00', 5.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-15 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-16 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-17 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-18 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-19 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-20 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-21 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-22 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-23 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-24 00:00:00', 5.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-25 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-26 00:00:00', 6.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-27 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-28 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-29 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-11-30 00:00:00', 5.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-01 00:00:00', 5.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-02 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-03 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-04 00:00:00', 5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-05 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-06 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-07 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-08 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-09 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-10 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-11 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-12 00:00:00', 4.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-13 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-14 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-15 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-16 00:00:00', 6.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-17 00:00:00', 6.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-18 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-19 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-20 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-21 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-22 00:00:00', 5.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-23 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-24 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-25 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-26 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-27 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-28 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-29 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-30 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1995-12-31 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-01 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-02 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-03 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-04 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-05 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-06 00:00:00', 5.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-07 00:00:00', 6.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-08 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-09 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-10 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-11 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-12 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-13 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-14 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-15 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-16 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-17 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-18 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-19 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-20 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-21 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-22 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-23 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-24 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-25 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-26 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-27 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-28 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-29 00:00:00', 5.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-30 00:00:00', 5.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-01-31 00:00:00', 3.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-01 00:00:00', 5.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-02 00:00:00', 7.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-03 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-04 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-05 00:00:00', 6.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-06 00:00:00', 7.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-07 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-08 00:00:00', 4.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-09 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-10 00:00:00', 7.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-11 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-12 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-13 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-14 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-15 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-16 00:00:00', 5.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-17 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-18 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-19 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-20 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-21 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-22 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-23 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-24 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-25 00:00:00', 5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-26 00:00:00', 4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-27 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-28 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-02-29 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-01 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-02 00:00:00', 5.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-03 00:00:00', 5.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-04 00:00:00', 5.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-05 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-06 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-07 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-08 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-09 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-10 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-11 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-12 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-13 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-14 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-15 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-16 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-17 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-18 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-19 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-20 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-21 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-22 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-23 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-24 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-25 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-26 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-27 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-28 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-29 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-30 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-03-31 00:00:00', 3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-01 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-02 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-03 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-04 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-05 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-06 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-07 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-08 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-09 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-10 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-11 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-12 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-13 00:00:00', 6.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-14 00:00:00', 6.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-15 00:00:00', 5.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-16 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-17 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-18 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-19 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-20 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-21 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-22 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-23 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-24 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-25 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-26 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-27 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-28 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-29 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-04-30 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-01 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-02 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-03 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-04 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-05 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-06 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-07 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-08 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-09 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-10 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-11 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-12 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-13 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-14 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-15 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-16 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-17 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-18 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-19 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-20 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-21 00:00:00', 1.27799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-22 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-23 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-24 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-25 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-26 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-27 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-28 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-29 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-30 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-05-31 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-01 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-02 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-03 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-04 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-05 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-06 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-07 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-08 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-09 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-10 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-11 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-12 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-13 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-14 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-15 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-16 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-17 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-18 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-19 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-20 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-21 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-22 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-23 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-24 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-25 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-26 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-27 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-28 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-29 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-06-30 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-01 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-02 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-03 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-04 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-05 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-06 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-07 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-08 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-09 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-10 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-11 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-12 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-13 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-14 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-15 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-16 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-17 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-18 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-19 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-20 00:00:00', 4.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-21 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-22 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-23 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-24 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-25 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-26 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-27 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-28 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-29 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-30 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-07-31 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-01 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-02 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-03 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-04 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-05 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-06 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-07 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-08 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-09 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-10 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-11 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-12 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-13 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-14 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-15 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-16 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-17 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-18 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-19 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-20 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-21 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-22 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-23 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-24 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-25 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-26 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-27 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-28 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-29 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-30 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-08-31 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-01 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-02 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-03 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-04 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-05 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-06 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-07 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-08 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-09 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-10 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-11 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-12 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-13 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-14 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-15 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-16 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-17 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-18 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-19 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-20 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-21 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-22 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-23 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-24 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-25 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-26 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-27 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-28 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-29 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-09-30 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-01 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-02 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-03 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-04 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-05 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-06 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-07 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-08 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-09 00:00:00', 4.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-10 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-11 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-12 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-13 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-14 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-15 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-16 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-17 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-18 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-19 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-20 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-21 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-22 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-23 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-24 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-25 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-26 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-27 00:00:00', 5.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-28 00:00:00', 5.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-29 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-30 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-10-31 00:00:00', 5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-01 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-02 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-03 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-04 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-05 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-06 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-07 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-08 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-09 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-10 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-11 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-12 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-13 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-14 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-15 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-16 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-17 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-18 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-19 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-20 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-21 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-22 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-23 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-24 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-25 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-26 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-27 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-28 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-29 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-11-30 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-01 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-02 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-03 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-04 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-05 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-06 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-07 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-08 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-09 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-10 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-11 00:00:00', 4.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-12 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-13 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-14 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-15 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-16 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-17 00:00:00', 6.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-18 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-19 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-20 00:00:00', 5.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-21 00:00:00', 5.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-22 00:00:00', 5.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-23 00:00:00', 6.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-24 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-25 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-26 00:00:00', 5.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-27 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-28 00:00:00', 5.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-29 00:00:00', 5.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-30 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1996-12-31 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-01 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-02 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-03 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-04 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-05 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-06 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-07 00:00:00', 5.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-08 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-09 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-10 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-11 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-12 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-13 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-14 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-15 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-16 00:00:00', 7.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-17 00:00:00', 6.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-18 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-19 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-20 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-21 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-22 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-23 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-24 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-25 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-26 00:00:00', 6.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-27 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-28 00:00:00', 5.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-29 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-30 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-01-31 00:00:00', 5.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-01 00:00:00', 5.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-02 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-03 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-04 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-05 00:00:00', 4.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-06 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-07 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-08 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-09 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-10 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-11 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-12 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-13 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-14 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-15 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-16 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-17 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-18 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-19 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-20 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-21 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-22 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-23 00:00:00', 5.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-24 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-25 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-26 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-27 00:00:00', 5.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-02-28 00:00:00', 6.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-01 00:00:00', 4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-02 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-03 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-04 00:00:00', 5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-05 00:00:00', 5.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-06 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-07 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-08 00:00:00', 6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-09 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-10 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-11 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-12 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-13 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-14 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-15 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-16 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-17 00:00:00', 5.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-18 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-19 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-20 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-21 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-22 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-23 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-24 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-25 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-26 00:00:00', 4.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-27 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-28 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-29 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-30 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-03-31 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-01 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-02 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-03 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-04 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-05 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-06 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-07 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-08 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-09 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-10 00:00:00', 5.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-11 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-12 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-13 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-14 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-15 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-16 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-17 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-18 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-19 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-20 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-21 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-22 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-23 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-24 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-25 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-26 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-27 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-28 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-29 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-04-30 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-01 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-02 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-03 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-04 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-05 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-06 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-07 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-08 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-09 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-10 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-11 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-12 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-13 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-14 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-15 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-16 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-17 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-18 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-19 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-20 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-21 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-22 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-23 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-24 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-25 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-26 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-27 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-28 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-29 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-30 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-05-31 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-01 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-02 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-03 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-04 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-05 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-06 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-07 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-08 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-09 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-10 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-11 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-12 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-13 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-14 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-15 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-16 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-17 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-18 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-19 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-20 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-21 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-22 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-23 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-24 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-25 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-26 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-27 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-28 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-29 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-06-30 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-01 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-02 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-03 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-04 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-05 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-06 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-07 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-08 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-09 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-10 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-11 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-12 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-13 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-14 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-15 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-16 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-17 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-18 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-19 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-20 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-21 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-22 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-23 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-24 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-25 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-26 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-27 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-28 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-29 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-30 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-07-31 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-01 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-02 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-03 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-04 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-05 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-06 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-07 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-08 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-09 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-10 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-11 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-12 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-13 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-14 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-15 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-16 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-17 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-18 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-19 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-20 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-21 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-22 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-23 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-24 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-25 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-26 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-27 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-28 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-29 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-30 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-08-31 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-01 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-02 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-03 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-04 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-05 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-06 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-07 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-08 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-09 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-10 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-11 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-12 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-13 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-14 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-15 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-16 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-17 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-18 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-19 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-20 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-21 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-22 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-23 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-24 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-25 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-26 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-27 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-28 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-29 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-09-30 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-01 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-02 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-03 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-04 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-05 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-06 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-07 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-08 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-09 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-10 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-11 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-12 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-13 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-14 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-15 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-16 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-17 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-18 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-19 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-20 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-21 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-22 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-23 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-24 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-25 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-26 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-27 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-28 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-29 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-30 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-10-31 00:00:00', 3.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-01 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-02 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-03 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-04 00:00:00', 4.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-05 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-06 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-07 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-08 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-09 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-10 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-11 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-12 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-13 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-14 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-15 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-16 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-17 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-18 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-19 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-20 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-21 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-22 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-23 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-24 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-25 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-26 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-27 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-28 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-29 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-11-30 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-01 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-02 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-03 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-04 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-05 00:00:00', 4.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-06 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-07 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-08 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-09 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-10 00:00:00', 5.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-11 00:00:00', 5.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-12 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-13 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-14 00:00:00', 5.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-15 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-16 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-17 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-18 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-19 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-20 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-21 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-22 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-23 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-24 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-25 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-26 00:00:00', 5.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-27 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-28 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-29 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-30 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1997-12-31 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-01 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-02 00:00:00', 6.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-03 00:00:00', 5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-04 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-05 00:00:00', 5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-06 00:00:00', 6.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-07 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-08 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-09 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-10 00:00:00', 5.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-11 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-12 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-13 00:00:00', 6.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-14 00:00:00', 5.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-15 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-16 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-17 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-18 00:00:00', 6.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-19 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-20 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-21 00:00:00', 5.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-22 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-23 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-24 00:00:00', 6.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-25 00:00:00', 6.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-26 00:00:00', 5.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-27 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-28 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-29 00:00:00', 6.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-30 00:00:00', 5.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-01-31 00:00:00', 5.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-01 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-02 00:00:00', 5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-03 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-04 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-05 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-06 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-07 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-08 00:00:00', 6.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-09 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-10 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-11 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-12 00:00:00', 6.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-13 00:00:00', 5.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-14 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-15 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-16 00:00:00', 4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-17 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-18 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-19 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-20 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-21 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-22 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-23 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-24 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-25 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-26 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-27 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-02-28 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-01 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-02 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-03 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-04 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-05 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-06 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-07 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-08 00:00:00', 4.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-09 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-10 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-11 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-12 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-13 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-14 00:00:00', 5.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-15 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-16 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-17 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-18 00:00:00', 5.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-19 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-20 00:00:00', 4.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-21 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-22 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-23 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-24 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-25 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-26 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-27 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-28 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-29 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-30 00:00:00', 6.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-03-31 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-01 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-02 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-03 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-04 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-05 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-06 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-07 00:00:00', 4.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-08 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-09 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-10 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-11 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-12 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-13 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-14 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-15 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-16 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-17 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-18 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-19 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-20 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-21 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-22 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-23 00:00:00', 5.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-24 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-25 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-26 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-27 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-28 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-29 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-04-30 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-01 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-02 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-03 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-04 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-05 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-06 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-07 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-08 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-09 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-10 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-11 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-12 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-13 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-14 00:00:00', 5.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-15 00:00:00', 5.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-16 00:00:00', 5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-17 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-18 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-19 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-20 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-21 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-22 00:00:00', 5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-23 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-24 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-25 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-26 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-27 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-28 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-29 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-30 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-05-31 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-01 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-02 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-03 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-04 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-05 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-06 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-07 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-08 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-09 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-10 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-11 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-12 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-13 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-14 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-15 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-16 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-17 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-18 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-19 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-20 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-21 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-22 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-23 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-24 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-25 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-26 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-27 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-28 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-29 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-06-30 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-01 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-02 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-03 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-04 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-05 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-06 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-07 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-08 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-09 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-10 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-11 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-12 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-13 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-14 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-15 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-16 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-17 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-18 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-19 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-20 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-21 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-22 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-23 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-24 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-25 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-26 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-27 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-28 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-29 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-30 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-07-31 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-01 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-02 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-03 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-04 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-05 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-06 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-07 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-08 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-09 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-10 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-11 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-12 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-13 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-14 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-15 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-16 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-17 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-18 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-19 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-20 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-21 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-22 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-23 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-24 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-25 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-26 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-27 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-28 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-29 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-30 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-08-31 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-01 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-02 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-03 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-04 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-05 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-06 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-07 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-08 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-09 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-10 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-11 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-12 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-13 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-14 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-15 00:00:00', 6.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-16 00:00:00', 6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-17 00:00:00', 6.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-18 00:00:00', 5.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-19 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-20 00:00:00', 5.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-21 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-22 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-23 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-24 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-25 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-26 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-27 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-28 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-29 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-09-30 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-01 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-02 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-03 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-04 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-05 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-06 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-07 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-08 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-09 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-10 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-11 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-12 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-13 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-14 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-15 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-16 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-17 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-18 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-19 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-20 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-21 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-22 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-23 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-24 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-25 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-26 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-27 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-28 00:00:00', 4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-29 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-30 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-10-31 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-01 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-02 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-03 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-04 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-05 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-06 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-07 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-08 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-09 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-10 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-11 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-12 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-13 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-14 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-15 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-16 00:00:00', 4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-17 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-18 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-19 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-20 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-21 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-22 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-23 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-24 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-25 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-26 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-27 00:00:00', 4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-28 00:00:00', 6.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-29 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-11-30 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-01 00:00:00', 5.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-02 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-03 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-04 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-05 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-06 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-07 00:00:00', 5.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-08 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-09 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-10 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-11 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-12 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-13 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-14 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-15 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-16 00:00:00', 5.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-17 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-18 00:00:00', 7.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-19 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-20 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-21 00:00:00', 5.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-22 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-23 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-24 00:00:00', 6.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-25 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-26 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-27 00:00:00', 4.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-28 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-29 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-30 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1998-12-31 00:00:00', 6.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-02 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-04 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-06 00:00:00', 6.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-08 00:00:00', 7.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-10 00:00:00', 5.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-12 00:00:00', 6.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-14 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-16 00:00:00', 5.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-18 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-20 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-22 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-24 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-26 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-28 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-30 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-01 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-03 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-05 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-07 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-09 00:00:00', 6.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-11 00:00:00', 7.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-13 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-15 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-17 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-19 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-21 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-23 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-25 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-27 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-01 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-03 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-04 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-05 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-06 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-07 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-08 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-09 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-10 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-11 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-12 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-13 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-14 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-15 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-16 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-17 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-18 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-19 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-20 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-21 00:00:00', 5.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-22 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-23 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-24 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-25 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-26 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-27 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-28 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-29 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-30 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-03-31 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-01 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-02 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-03 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-04 00:00:00', 6.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-05 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-06 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-07 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-08 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-09 00:00:00', 6.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-10 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-11 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-12 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-13 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-14 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-15 00:00:00', 5.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-16 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-17 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-18 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-19 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-20 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-21 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-22 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-23 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-24 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-25 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-26 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-27 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-28 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-29 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-04-30 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-01 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-02 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-03 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-04 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-05 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-06 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-07 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-08 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-09 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-10 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-11 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-12 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-13 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-14 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-15 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-16 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-17 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-18 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-19 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-20 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-21 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-22 00:00:00', 3.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-23 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-24 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-25 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-26 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-27 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-28 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-29 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-30 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-05-31 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-01 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-02 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-03 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-04 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-05 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-06 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-07 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-08 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-09 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-10 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-11 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-12 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-13 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-14 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-15 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-16 00:00:00', 4.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-17 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-18 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-19 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-20 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-21 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-22 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-23 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-24 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-25 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-26 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-27 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-28 00:00:00', 4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-29 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-06-30 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-01 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-02 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-03 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-04 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-05 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-06 00:00:00', 3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-07 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-08 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-09 00:00:00', 3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-10 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-11 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-12 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-13 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-14 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-15 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-16 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-17 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-18 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-19 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-20 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-21 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-22 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-23 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-24 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-25 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-26 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-27 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-28 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-29 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-30 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-07-31 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-01 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-02 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-03 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-04 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-05 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-06 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-07 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-08 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-09 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-10 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-11 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-12 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-13 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-14 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-15 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-16 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-17 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-18 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-19 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-20 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-21 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-22 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-23 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-24 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-25 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-26 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-27 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-28 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-29 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-30 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-08-31 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-01 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-02 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-03 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-04 00:00:00', 3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-05 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-06 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-07 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-08 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-09 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-10 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-11 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-12 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-13 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-14 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-15 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-16 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-17 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-18 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-19 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-20 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-21 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-22 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-23 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-24 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-25 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-26 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-27 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-28 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-29 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-09-30 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-01 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-02 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-03 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-04 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-05 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-06 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-07 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-08 00:00:00', 3.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-09 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-10 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-11 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-12 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-13 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-14 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-15 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-16 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-17 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-18 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-19 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-20 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-21 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-22 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-23 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-24 00:00:00', 4.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-25 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-26 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-27 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-28 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-29 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-30 00:00:00', 3.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-10-31 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-01 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-02 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-03 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-04 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-05 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-06 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-07 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-08 00:00:00', 5.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-09 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-10 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-11 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-12 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-13 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-14 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-15 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-16 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-17 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-18 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-19 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-20 00:00:00', 5.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-21 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-22 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-23 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-24 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-25 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-26 00:00:00', 6.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-27 00:00:00', 5.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-28 00:00:00', 6.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-29 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-11-30 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-01 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-02 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-03 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-04 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-05 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-06 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-07 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-08 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-09 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-10 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-11 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-12 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-13 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-14 00:00:00', 4.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-15 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-16 00:00:00', 5.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-17 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-18 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-19 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-20 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-21 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-22 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-23 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-24 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-25 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-26 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-27 00:00:00', 6.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-28 00:00:00', 6.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-29 00:00:00', 5.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-30 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '1999-12-31 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-01 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-02 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-03 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-04 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-05 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-06 00:00:00', 5.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-07 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-08 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-09 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-10 00:00:00', 5.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-11 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-12 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-13 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-14 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-15 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-16 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-17 00:00:00', 6.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-18 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-19 00:00:00', 5.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-20 00:00:00', 5.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-21 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-22 00:00:00', 6.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-23 00:00:00', 5.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-24 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-25 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-26 00:00:00', 4.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-27 00:00:00', 6.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-28 00:00:00', 6.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-29 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-30 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-01-31 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-01 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-02 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-03 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-04 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-05 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-06 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-07 00:00:00', 5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-08 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-09 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-10 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-11 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-12 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-13 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-14 00:00:00', 6.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-15 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-16 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-17 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-18 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-19 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-20 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-21 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-22 00:00:00', 4.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-23 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-24 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-25 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-26 00:00:00', 4.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-27 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-28 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-02-29 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-01 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-02 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-03 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-04 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-05 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-06 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-07 00:00:00', 4.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-08 00:00:00', 4.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-09 00:00:00', 5.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-10 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-11 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-12 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-13 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-14 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-15 00:00:00', 5.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-16 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-17 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-18 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-19 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-20 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-21 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-22 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-23 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-24 00:00:00', 5.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-25 00:00:00', 5.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-26 00:00:00', 4.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-27 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-28 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-29 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-30 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-03-31 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-01 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-02 00:00:00', 3.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-03 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-04 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-05 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-06 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-07 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-08 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-09 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-10 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-11 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-12 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-13 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-14 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-15 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-16 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-17 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-18 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-19 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-20 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-21 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-22 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-23 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-24 00:00:00', 4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-25 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-26 00:00:00', 3.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-27 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-28 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-29 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-04-30 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-01 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-02 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-03 00:00:00', 4.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-04 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-05 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-06 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-07 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-08 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-09 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-10 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-11 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-12 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-13 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-14 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-15 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-16 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-17 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-18 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-19 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-20 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-21 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-22 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-23 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-24 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-25 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-26 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-27 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-28 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-29 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-30 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-05-31 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-01 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-02 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-03 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-04 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-05 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-06 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-07 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-08 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-09 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-10 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-11 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-12 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-13 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-14 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-15 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-16 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-17 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-18 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-19 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-20 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-21 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-22 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-23 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-24 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-25 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-26 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-27 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-28 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-29 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-06-30 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-01 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-02 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-03 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-04 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-05 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-06 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-07 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-08 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-09 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-10 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-11 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-12 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-13 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-14 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-15 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-16 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-17 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-18 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-19 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-20 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-21 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-22 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-23 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-24 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-25 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-26 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-27 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-28 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-29 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-30 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-07-31 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-01 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-02 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-03 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-04 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-05 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-06 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-07 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-08 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-09 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-10 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-11 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-12 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-13 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-14 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-15 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-16 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-17 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-18 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-19 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-20 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-21 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-22 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-23 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-24 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-25 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-26 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-27 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-28 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-29 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-30 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-08-31 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-01 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-02 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-03 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-04 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-05 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-06 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-07 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-08 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-09 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-10 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-11 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-12 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-13 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-14 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-15 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-16 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-17 00:00:00', 3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-18 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-19 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-20 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-21 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-22 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-23 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-24 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-25 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-26 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-27 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-28 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-29 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-09-30 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-01 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-02 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-03 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-04 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-05 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-06 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-07 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-08 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-09 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-10 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-11 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-12 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-13 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-14 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-15 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-16 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-17 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-18 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-19 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-20 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-21 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-22 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-23 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-24 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-25 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-26 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-27 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-28 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-29 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-30 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-10-31 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-01 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-02 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-03 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-04 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-05 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-06 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-07 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-08 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-09 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-10 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-11 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-12 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-13 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-14 00:00:00', 5.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-15 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-16 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-17 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-18 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-19 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-20 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-21 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-22 00:00:00', 5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-23 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-24 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-25 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-26 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-27 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-28 00:00:00', 6.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-29 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-11-30 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-01 00:00:00', 6.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-02 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-03 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-04 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-05 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-06 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-07 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-08 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-09 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-10 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-11 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-12 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-13 00:00:00', 5.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-14 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-15 00:00:00', 6.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-16 00:00:00', 5.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-17 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-18 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-19 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-20 00:00:00', 6.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-21 00:00:00', 6.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-22 00:00:00', 7.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-23 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-24 00:00:00', 5.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-25 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-26 00:00:00', 5.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-27 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-28 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-29 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-30 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2000-12-31 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-01 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-02 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-03 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-04 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-05 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-06 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-07 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-08 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-09 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-10 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-11 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-12 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-13 00:00:00', 4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-14 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-15 00:00:00', 6.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-16 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-17 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-18 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-19 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-20 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-21 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-22 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-23 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-24 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-25 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-26 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-27 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-28 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-29 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-30 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-01-31 00:00:00', 1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-01 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-02 00:00:00', 5.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-03 00:00:00', 5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-04 00:00:00', 5.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-05 00:00:00', 6.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-06 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-07 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-08 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-09 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-10 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-11 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-12 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-13 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-14 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-15 00:00:00', 7.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-16 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-17 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-18 00:00:00', 5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-19 00:00:00', 6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-20 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-21 00:00:00', 7.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-22 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-23 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-24 00:00:00', 5.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-25 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-26 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-27 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-02-28 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-01 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-02 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-03 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-04 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-05 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-06 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-07 00:00:00', 5.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-08 00:00:00', 4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-09 00:00:00', 5.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-10 00:00:00', 5.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-11 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-12 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-13 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-14 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-15 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-16 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-17 00:00:00', 4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-18 00:00:00', 5.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-19 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-20 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-21 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-22 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-23 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-24 00:00:00', 5.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-25 00:00:00', 5.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-26 00:00:00', 6.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-27 00:00:00', 5.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-28 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-29 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-30 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-03-31 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-01 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-02 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-03 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-04 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-05 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-06 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-07 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-08 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-09 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-10 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-11 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-12 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-13 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-14 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-15 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-16 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-17 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-18 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-19 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-20 00:00:00', 2.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-21 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-22 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-23 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-24 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-25 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-26 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-27 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-28 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-29 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-04-30 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-01 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-02 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-03 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-04 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-05 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-06 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-07 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-08 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-09 00:00:00', 5.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-10 00:00:00', 4.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-11 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-12 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-13 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-14 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-15 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-16 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-17 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-18 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-19 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-20 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-21 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-22 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-23 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-24 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-25 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-26 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-27 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-28 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-29 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-30 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-05-31 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-01 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-02 00:00:00', 4.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-03 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-04 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-05 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-06 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-07 00:00:00', 3.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-08 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-09 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-10 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-11 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-12 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-13 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-14 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-15 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-16 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-17 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-18 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-19 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-20 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-21 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-22 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-23 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-24 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-25 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-26 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-27 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-28 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-29 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-06-30 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-01 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-02 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-03 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-04 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-05 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-06 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-07 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-08 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-09 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-10 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-11 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-12 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-13 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-14 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-15 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-16 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-17 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-18 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-19 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-20 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-21 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-22 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-23 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-24 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-25 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-26 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-27 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-28 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-29 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-30 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-07-31 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-01 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-02 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-03 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-04 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-05 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-06 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-07 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-08 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-09 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-10 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-11 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-12 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-13 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-14 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-15 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-16 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-17 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-18 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-19 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-20 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-21 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-22 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-23 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-24 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-25 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-26 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-27 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-28 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-29 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-30 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-08-31 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-01 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-02 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-03 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-04 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-05 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-06 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-07 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-08 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-09 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-10 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-11 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-12 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-13 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-14 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-15 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-16 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-17 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-18 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-19 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-20 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-21 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-22 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-23 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-24 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-25 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-26 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-27 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-28 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-29 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-09-30 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-01 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-02 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-03 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-04 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-05 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-06 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-07 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-08 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-09 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-10 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-11 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-12 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-13 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-14 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-15 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-16 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-17 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-18 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-19 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-20 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-21 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-22 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-23 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-24 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-25 00:00:00', 5.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-26 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-27 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-28 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-29 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-30 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-10-31 00:00:00', 4.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-01 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-02 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-03 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-04 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-05 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-06 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-07 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-08 00:00:00', 6.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-09 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-10 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-11 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-12 00:00:00', 5.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-13 00:00:00', 5.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-14 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-15 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-16 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-17 00:00:00', 6.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-18 00:00:00', 6.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-19 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-20 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-21 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-22 00:00:00', 5.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-23 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-24 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-25 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-26 00:00:00', 3.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-27 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-28 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-29 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-11-30 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-01 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-02 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-03 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-04 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-05 00:00:00', 5.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-06 00:00:00', 5.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-07 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-08 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-09 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-10 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-11 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-12 00:00:00', 6.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-13 00:00:00', 4.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-14 00:00:00', 4.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-15 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-16 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-17 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-18 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-19 00:00:00', 6.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-20 00:00:00', 7.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-21 00:00:00', 6.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-22 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-23 00:00:00', 5.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-24 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-25 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-26 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-27 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-28 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-29 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-30 00:00:00', 5.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2001-12-31 00:00:00', 5.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-01 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-02 00:00:00', 5.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-03 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-04 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-05 00:00:00', 4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-06 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-07 00:00:00', 6.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-08 00:00:00', 7.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-09 00:00:00', 5.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-10 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-11 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-12 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-13 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-14 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-15 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-16 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-17 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-18 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-19 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-20 00:00:00', 5.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-21 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-22 00:00:00', 6.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-23 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-24 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-25 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-26 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-27 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-28 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-29 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-30 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-01-31 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-01 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-02 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-03 00:00:00', 5.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-04 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-05 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-06 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-07 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-08 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-09 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-10 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-11 00:00:00', 5.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-12 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-13 00:00:00', 7.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-14 00:00:00', 7.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-15 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-16 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-17 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-18 00:00:00', 4.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-19 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-20 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-21 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-22 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-23 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-24 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-25 00:00:00', 5.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-26 00:00:00', 5.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-27 00:00:00', 5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-02-28 00:00:00', 5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-01 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-02 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-03 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-04 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-05 00:00:00', 5.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-06 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-07 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-08 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-09 00:00:00', 5.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-10 00:00:00', 5.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-11 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-12 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-13 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-14 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-15 00:00:00', 5.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-16 00:00:00', 6.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-17 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-18 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-19 00:00:00', 5.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-20 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-21 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-22 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-23 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-24 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-25 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-26 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-27 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-28 00:00:00', 4.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-29 00:00:00', 6.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-30 00:00:00', 4.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-03-31 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-01 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-02 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-03 00:00:00', 5.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-04 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-05 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-06 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-07 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-08 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-09 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-10 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-11 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-12 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-13 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-14 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-15 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-16 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-17 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-18 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-19 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-20 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-21 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-22 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-23 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-24 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-25 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-26 00:00:00', 5.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-27 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-28 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-29 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-04-30 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-01 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-02 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-03 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-04 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-05 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-06 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-07 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-08 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-09 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-10 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-11 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-12 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-13 00:00:00', 4.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-14 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-15 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-16 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-17 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-18 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-19 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-20 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-21 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-22 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-23 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-24 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-25 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-26 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-27 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-28 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-29 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-30 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-05-31 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-01 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-02 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-03 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-04 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-05 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-06 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-07 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-08 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-09 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-10 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-11 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-12 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-13 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-14 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-15 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-16 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-17 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-18 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-19 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-20 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-21 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-22 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-23 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-24 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-25 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-26 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-27 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-28 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-29 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-06-30 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-01 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-02 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-03 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-04 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-05 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-06 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-07 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-08 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-09 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-10 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-11 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-12 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-13 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-14 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-15 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-16 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-17 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-18 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-19 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-20 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-21 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-22 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-23 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-24 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-25 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-26 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-27 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-28 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-29 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-30 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-07-31 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-01 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-02 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-03 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-04 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-05 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-06 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-07 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-08 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-09 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-10 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-11 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-12 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-13 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-14 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-15 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-16 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-17 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-18 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-19 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-20 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-21 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-22 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-23 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-24 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-25 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-26 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-27 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-28 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-29 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-30 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-08-31 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-01 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-02 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-03 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-04 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-05 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-06 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-07 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-08 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-09 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-10 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-11 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-12 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-13 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-14 00:00:00', 3.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-15 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-16 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-17 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-18 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-19 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-20 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-21 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-22 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-23 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-24 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-25 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-26 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-27 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-28 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-29 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-09-30 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-01 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-02 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-03 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-04 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-05 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-06 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-07 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-08 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-09 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-10 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-11 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-12 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-13 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-14 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-15 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-16 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-17 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-18 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-19 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-20 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-21 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-22 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-23 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-24 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-25 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-26 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-27 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-28 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-29 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-30 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-10-31 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-01 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-02 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-03 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-04 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-05 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-06 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-07 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-08 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-09 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-10 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-11 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-12 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-13 00:00:00', 4.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-14 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-15 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-16 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-17 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-18 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-19 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-20 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-21 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-22 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-23 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-24 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-25 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-26 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-27 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-28 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-29 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-11-30 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-01 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-02 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-03 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-04 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-05 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-06 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-07 00:00:00', 5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-08 00:00:00', 6.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-09 00:00:00', 7.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-10 00:00:00', 5.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-11 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-12 00:00:00', 3.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-13 00:00:00', 5.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-14 00:00:00', 4.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-15 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-16 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-17 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-18 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-19 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-20 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-21 00:00:00', 6.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-22 00:00:00', 7.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-23 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-24 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-25 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-26 00:00:00', 5.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-27 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-28 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-29 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-30 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2002-12-31 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-01 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-02 00:00:00', 4.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-03 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-04 00:00:00', 6.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-05 00:00:00', 5.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-06 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-07 00:00:00', 5.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-08 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-09 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-10 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-11 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-12 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-13 00:00:00', 7.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-14 00:00:00', 6.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-15 00:00:00', 6.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-16 00:00:00', 6.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-17 00:00:00', 5.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-18 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-19 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-20 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-21 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-22 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-23 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-24 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-25 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-26 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-27 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-28 00:00:00', 5.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-29 00:00:00', 6.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-30 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-01-31 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-01 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-02 00:00:00', 5.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-03 00:00:00', 5.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-04 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-05 00:00:00', 6.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-06 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-07 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-08 00:00:00', 4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-09 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-10 00:00:00', 5.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-11 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-12 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-13 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-14 00:00:00', 6.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-15 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-16 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-17 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-18 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-19 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-20 00:00:00', 5.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-21 00:00:00', 5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-22 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-23 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-24 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-25 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-26 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-27 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-02-28 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-01 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-02 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-03 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-04 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-05 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-06 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-07 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-08 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-09 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-10 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-11 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-12 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-13 00:00:00', 6.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-14 00:00:00', 5.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-15 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-16 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-17 00:00:00', 5.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-18 00:00:00', 5.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-19 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-20 00:00:00', 7.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-21 00:00:00', 7.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-22 00:00:00', 5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-23 00:00:00', 5.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-24 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-25 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-26 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-27 00:00:00', 6.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-28 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-29 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-30 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-03-31 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-01 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-02 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-03 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-04 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-05 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-06 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-07 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-08 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-09 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-10 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-11 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-12 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-13 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-14 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-15 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-16 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-17 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-18 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-19 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-20 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-21 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-22 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-23 00:00:00', 4.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-24 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-25 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-26 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-27 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-28 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-29 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-04-30 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-01 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-02 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-03 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-04 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-05 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-06 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-07 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-08 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-09 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-10 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-11 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-12 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-13 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-14 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-15 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-16 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-17 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-18 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-19 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-20 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-21 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-22 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-23 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-24 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-25 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-26 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-27 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-28 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-29 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-30 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-05-31 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-01 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-02 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-03 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-04 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-05 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-06 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-07 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-08 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-09 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-10 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-11 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-12 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-13 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-14 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-15 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-16 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-17 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-18 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-19 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-20 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-21 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-22 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-23 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-24 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-25 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-26 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-27 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-28 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-29 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-06-30 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-01 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-02 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-03 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-04 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-05 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-06 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-07 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-08 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-09 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-10 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-11 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-12 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-13 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-14 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-15 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-16 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-17 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-18 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-19 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-20 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-21 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-22 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-23 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-24 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-25 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-26 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-27 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-28 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-29 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-30 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-07-31 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-01 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-02 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-03 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-04 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-05 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-06 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-07 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-08 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-09 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-10 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-11 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-12 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-13 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-14 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-15 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-16 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-17 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-18 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-19 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-20 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-21 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-22 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-23 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-24 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-25 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-26 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-27 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-28 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-29 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-30 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-08-31 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-01 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-02 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-03 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-04 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-05 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-06 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-07 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-08 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-09 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-10 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-11 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-12 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-13 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-14 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-15 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-16 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-17 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-18 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-19 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-20 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-21 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-22 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-23 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-24 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-25 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-26 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-27 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-28 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-29 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-09-30 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-01 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-02 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-03 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-04 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-05 00:00:00', 3.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-06 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-07 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-08 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-09 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-10 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-11 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-12 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-13 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-14 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-15 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-16 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-17 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-18 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-19 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-20 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-21 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-22 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-23 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-24 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-25 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-26 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-27 00:00:00', 4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-28 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-29 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-30 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-10-31 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-01 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-02 00:00:00', 4.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-03 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-04 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-05 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-06 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-07 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-08 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-09 00:00:00', 4.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-10 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-11 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-12 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-13 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-14 00:00:00', 5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-15 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-16 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-17 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-18 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-19 00:00:00', 5.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-20 00:00:00', 6.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-21 00:00:00', 6.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-22 00:00:00', 6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-23 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-24 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-25 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-26 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-27 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-28 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-29 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-11-30 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-01 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-02 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-03 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-04 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-05 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-06 00:00:00', 5.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-07 00:00:00', 6.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-08 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-09 00:00:00', 5.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-10 00:00:00', 6.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-11 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-12 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-13 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-14 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-15 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-16 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-17 00:00:00', 6.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-18 00:00:00', 5.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-19 00:00:00', 5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-20 00:00:00', 6.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-21 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-22 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-23 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-24 00:00:00', 6.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-25 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-26 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-27 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-28 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-29 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-30 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2003-12-31 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-01 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-02 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-03 00:00:00', 5.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-04 00:00:00', 6.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-05 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-06 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-07 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-08 00:00:00', 6.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-09 00:00:00', 6.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-10 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-11 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-12 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-13 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-14 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-15 00:00:00', 5.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-16 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-17 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-18 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-19 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-20 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-21 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-22 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-23 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-24 00:00:00', 6.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-25 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-26 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-27 00:00:00', 5.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-28 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-29 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-30 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-01-31 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-01 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-02 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-03 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-04 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-05 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-06 00:00:00', 6.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-07 00:00:00', 7.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-08 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-09 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-10 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-11 00:00:00', 5.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-12 00:00:00', 6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-13 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-14 00:00:00', 5.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-15 00:00:00', 7.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-16 00:00:00', 6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-17 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-18 00:00:00', 4.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-19 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-20 00:00:00', 5.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-21 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-22 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-23 00:00:00', 5.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-24 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-25 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-26 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-27 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-28 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-02-29 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-01 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-02 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-03 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-04 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-05 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-06 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-07 00:00:00', 5.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-08 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-09 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-10 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-11 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-12 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-13 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-14 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-15 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-16 00:00:00', 5.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-17 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-18 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-19 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-20 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-21 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-22 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-23 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-24 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-25 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-26 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-27 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-28 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-29 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-30 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-03-31 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-01 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-02 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-03 00:00:00', 4.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-04 00:00:00', 4.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-05 00:00:00', 4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-06 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-07 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-08 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-09 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-10 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-11 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-12 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-13 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-14 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-15 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-16 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-17 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-18 00:00:00', 5.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-19 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-20 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-21 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-22 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-23 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-24 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-25 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-26 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-27 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-28 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-29 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-04-30 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-01 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-02 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-03 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-04 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-05 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-06 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-07 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-08 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-09 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-10 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-11 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-12 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-13 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-14 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-15 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-16 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-17 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-18 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-19 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-20 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-21 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-22 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-23 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-24 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-25 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-26 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-27 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-28 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-29 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-30 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-05-31 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-01 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-02 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-03 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-04 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-05 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-06 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-07 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-08 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-09 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-10 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-11 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-12 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-13 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-14 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-15 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-16 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-17 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-18 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-19 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-20 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-21 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-22 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-23 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-24 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-25 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-26 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-27 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-28 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-29 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-06-30 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-01 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-02 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-03 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-04 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-05 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-06 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-07 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-08 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-09 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-10 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-11 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-12 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-13 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-14 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-15 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-16 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-17 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-18 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-19 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-20 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-21 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-22 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-23 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-24 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-25 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-26 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-27 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-28 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-29 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-30 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-07-31 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-01 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-02 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-03 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-04 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-05 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-06 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-07 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-08 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-09 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-10 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-11 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-12 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-13 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-14 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-15 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-16 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-17 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-18 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-19 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-20 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-21 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-22 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-23 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-24 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-25 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-26 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-27 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-28 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-29 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-30 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-08-31 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-01 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-02 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-03 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-04 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-05 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-06 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-07 00:00:00', 3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-08 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-09 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-10 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-11 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-12 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-13 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-14 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-15 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-16 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-17 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-18 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-19 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-20 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-21 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-22 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-23 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-24 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-25 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-26 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-27 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-28 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-29 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-09-30 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-01 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-02 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-03 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-04 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-05 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-06 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-07 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-08 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-09 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-10 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-11 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-12 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-13 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-14 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-15 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-16 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-17 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-18 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-19 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-20 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-21 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-22 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-23 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-24 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-25 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-26 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-27 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-28 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-29 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-30 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-10-31 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-01 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-02 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-03 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-04 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-05 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-06 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-07 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-08 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-09 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-10 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-11 00:00:00', 3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-12 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-13 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-14 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-15 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-16 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-17 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-18 00:00:00', 4.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-19 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-20 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-21 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-22 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-23 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-24 00:00:00', 5.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-25 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-26 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-27 00:00:00', 7.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-28 00:00:00', 6.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-29 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-11-30 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-01 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-02 00:00:00', 6.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-03 00:00:00', 4.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-04 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-05 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-06 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-07 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-08 00:00:00', 5.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-09 00:00:00', 5.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-10 00:00:00', 6.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-11 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-12 00:00:00', 5.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-13 00:00:00', 6.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-14 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-15 00:00:00', 6.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-16 00:00:00', 6.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-17 00:00:00', 5.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-18 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-19 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-20 00:00:00', 4.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-21 00:00:00', 4.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-22 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-23 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-24 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-25 00:00:00', 4.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-26 00:00:00', 5.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-27 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-28 00:00:00', 0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-29 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-30 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2004-12-31 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-01 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-02 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-03 00:00:00', 6.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-04 00:00:00', 6.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-05 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-06 00:00:00', 5.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-07 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-08 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-09 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-10 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-11 00:00:00', 5.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-12 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-13 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-14 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-15 00:00:00', 4.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-16 00:00:00', 4.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-17 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-18 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-19 00:00:00', 5.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-20 00:00:00', 6.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-21 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-22 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-23 00:00:00', 5.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-24 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-25 00:00:00', 5.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-26 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-27 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-28 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-29 00:00:00', 5.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-30 00:00:00', 4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-01-31 00:00:00', 5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-01 00:00:00', 5.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-02 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-03 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-04 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-05 00:00:00', 5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-06 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-07 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-08 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-09 00:00:00', 5.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-10 00:00:00', 5.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-11 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-12 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-13 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-14 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-15 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-16 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-17 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-18 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-19 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-20 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-21 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-22 00:00:00', 5.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-23 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-24 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-25 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-26 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-27 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-02-28 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-01 00:00:00', 4.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-02 00:00:00', 4.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-03 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-04 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-05 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-06 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-07 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-08 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-09 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-10 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-11 00:00:00', 5.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-12 00:00:00', 4.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-13 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-14 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-15 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-16 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-17 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-18 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-19 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-20 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-21 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-22 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-23 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-24 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-25 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-26 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-27 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-28 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-29 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-30 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-03-31 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-01 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-02 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-03 00:00:00', 4.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-04 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-05 00:00:00', 4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-06 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-07 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-08 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-09 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-10 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-11 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-12 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-13 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-14 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-15 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-16 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-17 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-18 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-19 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-20 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-21 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-22 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-23 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-24 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-25 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-26 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-27 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-28 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-29 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-04-30 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-01 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-02 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-03 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-04 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-05 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-06 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-07 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-08 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-09 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-10 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-11 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-12 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-13 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-14 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-15 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-16 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-17 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-18 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-19 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-20 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-21 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-22 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-23 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-24 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-25 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-26 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-27 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-28 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-29 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-30 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-05-31 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-01 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-02 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-03 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-04 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-05 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-06 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-07 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-08 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-09 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-10 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-11 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-12 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-13 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-14 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-15 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-16 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-17 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-18 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-19 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-20 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-21 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-22 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-23 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-24 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-25 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-26 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-27 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-28 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-29 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-06-30 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-01 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-02 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-03 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-04 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-05 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-06 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-07 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-08 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-09 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-10 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-11 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-12 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-13 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-14 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-15 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-16 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-17 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-18 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-19 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-20 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-21 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-22 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-23 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-24 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-25 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-26 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-27 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-28 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-29 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-30 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-07-31 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-01 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-02 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-03 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-04 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-05 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-06 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-07 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-08 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-09 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-10 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-11 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-12 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-13 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-14 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-15 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-16 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-17 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-18 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-19 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-20 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-21 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-22 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-23 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-24 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-25 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-26 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-27 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-28 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-29 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-30 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-08-31 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-01 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-02 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-03 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-04 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-05 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-06 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-07 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-08 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-09 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-10 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-11 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-12 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-13 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-14 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-15 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-16 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-17 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-18 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-19 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-20 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-21 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-22 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-23 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-24 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-25 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-26 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-27 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-28 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-29 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-09-30 00:00:00', 3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-01 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-02 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-03 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-04 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-05 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-06 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-07 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-08 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-09 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-10 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-11 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-12 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-13 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-14 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-15 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-16 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-17 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-18 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-19 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-20 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-21 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-22 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-23 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-24 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-25 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-26 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-27 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-28 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-29 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-30 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-10-31 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-01 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-02 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-03 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-04 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-05 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-06 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-07 00:00:00', 3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-08 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-09 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-10 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-11 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-12 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-13 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-14 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-15 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-16 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-17 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-18 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-19 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-20 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-21 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-22 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-23 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-24 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-25 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-26 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-27 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-28 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-29 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-11-30 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-01 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-02 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-03 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-04 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-05 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-06 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-07 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-08 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-09 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-10 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-11 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-12 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-13 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-14 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-15 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-16 00:00:00', 4.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-17 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-18 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-19 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-20 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-21 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-22 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-23 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-24 00:00:00', 5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-25 00:00:00', 5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-26 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-27 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-28 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-29 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-30 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2005-12-31 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-01 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-02 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-03 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-04 00:00:00', 5.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-05 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-06 00:00:00', 5.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-07 00:00:00', 6.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-08 00:00:00', 6.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-09 00:00:00', 5.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-10 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-11 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-12 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-13 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-14 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-15 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-16 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-17 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-18 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-19 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-20 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-21 00:00:00', 5.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-22 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-23 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-24 00:00:00', 6.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-25 00:00:00', 4.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-26 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-27 00:00:00', 4.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-28 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-29 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-30 00:00:00', 4.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-01-31 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-01 00:00:00', 6.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-02 00:00:00', 6.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-03 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-04 00:00:00', 7.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-05 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-06 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-07 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-08 00:00:00', 5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-09 00:00:00', 6.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-10 00:00:00', 6.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-11 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-12 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-13 00:00:00', 4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-14 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-15 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-16 00:00:00', 4.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-17 00:00:00', 5.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-18 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-19 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-20 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-21 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-22 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-23 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-24 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-25 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-26 00:00:00', 4.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-27 00:00:00', 4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-02-28 00:00:00', 4.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-01 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-02 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-03 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-04 00:00:00', 5.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-05 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-06 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-07 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-08 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-09 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-10 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-11 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-12 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-13 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-14 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-15 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-16 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-17 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-18 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-19 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-20 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-21 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-22 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-23 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-24 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-25 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-26 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-27 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-28 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-29 00:00:00', 4.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-30 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-03-31 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-01 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-02 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-03 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-04 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-05 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-06 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-07 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-08 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-09 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-10 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-11 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-12 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-13 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-14 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-15 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-16 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-17 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-18 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-19 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-20 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-21 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-22 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-23 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-24 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-25 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-26 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-27 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-28 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-29 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-04-30 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-01 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-02 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-03 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-04 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-05 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-06 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-07 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-08 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-09 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-10 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-11 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-12 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-13 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-14 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-15 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-16 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-17 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-18 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-19 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-20 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-21 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-22 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-23 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-24 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-25 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-26 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-27 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-28 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-29 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-30 00:00:00', 3.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-05-31 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-01 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-02 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-03 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-04 00:00:00', 3.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-05 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-06 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-07 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-08 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-09 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-10 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-11 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-12 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-13 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-14 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-15 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-16 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-17 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-18 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-19 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-20 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-21 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-22 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-23 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-24 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-25 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-26 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-27 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-28 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-29 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-06-30 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-01 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-02 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-03 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-04 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-05 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-06 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-07 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-08 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-09 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-10 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-11 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-12 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-13 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-14 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-15 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-16 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-17 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-18 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-19 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-20 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-21 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-22 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-23 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-24 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-25 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-26 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-27 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-28 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-29 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-30 00:00:00', 3.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-07-31 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-01 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-02 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-03 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-04 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-05 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-06 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-07 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-08 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-09 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-10 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-11 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-12 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-13 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-14 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-15 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-16 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-17 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-18 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-19 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-20 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-21 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-22 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-23 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-24 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-25 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-26 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-27 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-28 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-29 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-30 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-08-31 00:00:00', 3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-01 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-02 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-03 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-04 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-05 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-06 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-07 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-08 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-09 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-10 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-11 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-12 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-13 00:00:00', 3.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-14 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-15 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-16 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-17 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-18 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-19 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-20 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-21 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-22 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-23 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-24 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-25 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-26 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-27 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-28 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-29 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-09-30 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-01 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-02 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-03 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-04 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-05 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-06 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-07 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-08 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-09 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-10 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-11 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-12 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-13 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-14 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-15 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-16 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-17 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-18 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-19 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-20 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-21 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-22 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-23 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-24 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-25 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-26 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-27 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-28 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-29 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-30 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-10-31 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-01 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-02 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-03 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-04 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-05 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-06 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-07 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-08 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-09 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-10 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-11 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-12 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-13 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-14 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-15 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-16 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-17 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-18 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-19 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-20 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-21 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-22 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-23 00:00:00', 4.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-24 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-25 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-26 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-27 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-28 00:00:00', 5.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-29 00:00:00', 5.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-11-30 00:00:00', 3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-01 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-02 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-03 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-04 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-05 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-06 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-07 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-08 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-09 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-10 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-11 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-12 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-13 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-14 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-15 00:00:00', 4.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-16 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-17 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-18 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-19 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-20 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-21 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-22 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-23 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-24 00:00:00', 3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-25 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-26 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-27 00:00:00', 7.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-28 00:00:00', 6.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-29 00:00:00', 5.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-30 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2006-12-31 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-01 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-02 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-03 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-04 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-05 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-06 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-07 00:00:00', 4.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-08 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-09 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-10 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-11 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-12 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-13 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-14 00:00:00', 5.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-15 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-16 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-17 00:00:00', 6.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-18 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-19 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-20 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-21 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-22 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-23 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-24 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-25 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-26 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-27 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-28 00:00:00', 5.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-29 00:00:00', 6.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-30 00:00:00', 5.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-01-31 00:00:00', 6.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-01 00:00:00', 6.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-02 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-03 00:00:00', 5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-04 00:00:00', 4.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-05 00:00:00', 6.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-06 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-07 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-08 00:00:00', 5.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-09 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-10 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-11 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-12 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-13 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-14 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-15 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-16 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-17 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-18 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-19 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-20 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-21 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-22 00:00:00', 5.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-23 00:00:00', 5.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-24 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-25 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-26 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-27 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-02-28 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-01 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-02 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-03 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-04 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-05 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-06 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-07 00:00:00', 3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-08 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-09 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-10 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-11 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-12 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-13 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-14 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-15 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-16 00:00:00', 4.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-17 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-18 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-19 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-20 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-21 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-22 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-23 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-24 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-25 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-26 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-27 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-28 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-29 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-30 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-03-31 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-01 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-02 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-03 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-04 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-05 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-06 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-07 00:00:00', 4.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-08 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-09 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-10 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-11 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-12 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-13 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-14 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-15 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-16 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-17 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-18 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-19 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-20 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-21 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-22 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-23 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-24 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-25 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-26 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-27 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-28 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-29 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-04-30 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-01 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-02 00:00:00', 4.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-03 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-04 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-05 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-06 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-07 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-08 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-09 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-10 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-11 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-12 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-13 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-14 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-15 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-16 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-17 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-18 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-19 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-20 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-21 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-22 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-23 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-24 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-25 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-26 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-27 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-28 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-29 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-30 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-05-31 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-01 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-02 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-03 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-04 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-05 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-06 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-07 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-08 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-09 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-10 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-11 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-12 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-13 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-14 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-15 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-16 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-17 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-18 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-19 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-20 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-21 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-22 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-23 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-24 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-25 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-26 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-27 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-28 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-29 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-06-30 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-01 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-02 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-03 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-04 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-05 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-06 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-07 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-08 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-09 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-10 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-11 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-12 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-13 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-14 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-15 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-16 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-17 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-18 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-19 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-20 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-21 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-22 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-23 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-24 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-25 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-26 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-27 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-28 00:00:00', 3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-29 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-30 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-07-31 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-01 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-02 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-03 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-04 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-05 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-06 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-07 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-08 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-09 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-10 00:00:00', 3.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-11 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-12 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-13 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-14 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-15 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-16 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-17 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-18 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-19 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-20 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-21 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-22 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-23 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-24 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-25 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-26 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-27 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-28 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-29 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-30 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-08-31 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-01 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-02 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-03 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-04 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-05 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-06 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-07 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-08 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-09 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-10 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-11 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-12 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-13 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-14 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-15 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-16 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-17 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-18 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-19 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-20 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-21 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-22 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-23 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-24 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-25 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-26 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-27 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-28 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-29 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-09-30 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-01 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-02 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-03 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-04 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-05 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-06 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-07 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-08 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-09 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-10 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-11 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-12 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-13 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-14 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-15 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-16 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-17 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-18 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-19 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-20 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-21 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-22 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-23 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-24 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-25 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-26 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-27 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-28 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-29 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-30 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-10-31 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-01 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-02 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-03 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-04 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-05 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-06 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-07 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-08 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-09 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-10 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-11 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-12 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-13 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-14 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-15 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-16 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-17 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-18 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-19 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-20 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-21 00:00:00', 5.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-22 00:00:00', 6.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-23 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-24 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-25 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-26 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-27 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-28 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-29 00:00:00', 4.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-11-30 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-01 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-02 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-03 00:00:00', 6.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-04 00:00:00', 5.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-05 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-06 00:00:00', 4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-07 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-08 00:00:00', 5.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-09 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-10 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-11 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-12 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-13 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-14 00:00:00', 5.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-15 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-16 00:00:00', 5.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-17 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-18 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-19 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-20 00:00:00', 6.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-21 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-22 00:00:00', 6.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-23 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-24 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-25 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-26 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-27 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-28 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-29 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-30 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2007-12-31 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-01 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-02 00:00:00', 5.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-03 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-04 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-05 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-06 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-07 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-08 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-09 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-10 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-11 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-12 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-13 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-14 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-15 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-16 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-17 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-18 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-19 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-20 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-21 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-22 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-23 00:00:00', 4.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-24 00:00:00', 5.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-25 00:00:00', 3.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-26 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-27 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-28 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-29 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-30 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-01-31 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-01 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-02 00:00:00', 4.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-03 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-04 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-05 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-06 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-07 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-08 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-09 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-10 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-11 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-12 00:00:00', 6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-13 00:00:00', 5.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-14 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-15 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-16 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-17 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-18 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-19 00:00:00', 6.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-20 00:00:00', 7.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-21 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-22 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-23 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-24 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-25 00:00:00', 5.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-26 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-27 00:00:00', 7.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-28 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-02-29 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-01 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-02 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-03 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-04 00:00:00', 5.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-05 00:00:00', 4.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-06 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-07 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-08 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-09 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-10 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-11 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-12 00:00:00', 4.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-13 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-14 00:00:00', 4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-15 00:00:00', 5.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-16 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-17 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-18 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-19 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-20 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-21 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-22 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-23 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-24 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-25 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-26 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-27 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-28 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-29 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-30 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-03-31 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-01 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-02 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-03 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-04 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-05 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-06 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-07 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-08 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-09 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-10 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-11 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-12 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-13 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-14 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-15 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-16 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-17 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-18 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-19 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-20 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-21 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-22 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-23 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-24 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-25 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-26 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-27 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-28 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-29 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-04-30 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-01 00:00:00', 3.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-02 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-03 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-04 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-05 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-06 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-07 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-08 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-09 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-10 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-11 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-12 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-13 00:00:00', 3.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-14 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-15 00:00:00', 4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-16 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-17 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-18 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-19 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-20 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-21 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-22 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-23 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-24 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-25 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-26 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-27 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-28 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-29 00:00:00', 3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-30 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-05-31 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-01 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-02 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-03 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-04 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-05 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-06 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-07 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-08 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-09 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-10 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-11 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-12 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-13 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-14 00:00:00', 3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-15 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-16 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-17 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-18 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-19 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-20 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-21 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-22 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-23 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-24 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-25 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-26 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-27 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-28 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-29 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-06-30 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-01 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-02 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-03 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-04 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-05 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-06 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-07 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-08 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-09 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-10 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-11 00:00:00', 3.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-12 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-13 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-14 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-15 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-16 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-17 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-18 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-19 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-20 00:00:00', 3.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-21 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-22 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-23 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-24 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-25 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-26 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-27 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-28 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-29 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-30 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-07-31 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-01 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-02 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-03 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-04 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-05 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-06 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-07 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-08 00:00:00', 3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-09 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-10 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-11 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-12 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-13 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-14 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-15 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-16 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-17 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-18 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-19 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-20 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-21 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-22 00:00:00', 3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-23 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-24 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-25 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-26 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-27 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-28 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-29 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-30 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-08-31 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-01 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-02 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-03 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-04 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-05 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-06 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-07 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-08 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-09 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-10 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-11 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-12 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-13 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-14 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-15 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-16 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-17 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-18 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-19 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-20 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-21 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-22 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-23 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-24 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-25 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-26 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-27 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-28 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-29 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-09-30 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-01 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-02 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-03 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-04 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-05 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-06 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-07 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-08 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-09 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-10 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-11 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-12 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-13 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-14 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-15 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-16 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-17 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-18 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-19 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-20 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-21 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-22 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-23 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-24 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-25 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-26 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-27 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-28 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-29 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-30 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-10-31 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-01 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-02 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-03 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-04 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-05 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-06 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-07 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-08 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-09 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-10 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-11 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-12 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-13 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-14 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-15 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-16 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-17 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-18 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-19 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-20 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-21 00:00:00', 6.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-22 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-23 00:00:00', 5.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-24 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-25 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-26 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-27 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-28 00:00:00', 6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-29 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-11-30 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-01 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-02 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-03 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-04 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-05 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-06 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-07 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-08 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-09 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-10 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-11 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-12 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-13 00:00:00', 4.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-14 00:00:00', 4.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-15 00:00:00', 5.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-16 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-17 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-18 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-19 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-20 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-21 00:00:00', 6.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-22 00:00:00', 6.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-23 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-24 00:00:00', 5.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-25 00:00:00', 5.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-26 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-27 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-28 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-29 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-30 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2008-12-31 00:00:00', 4.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-01 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-02 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-03 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-04 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-05 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-06 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-07 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-08 00:00:00', 4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-09 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-10 00:00:00', 4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-11 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-12 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-13 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-14 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-15 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-16 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-17 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-18 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-19 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-20 00:00:00', 3.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-21 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-22 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-23 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-24 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-25 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-26 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-27 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-28 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-29 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-30 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-01-31 00:00:00', 5.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-01 00:00:00', 5.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-02 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-03 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-04 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-05 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-06 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-07 00:00:00', 5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-08 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-09 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-10 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-11 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-12 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-13 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-14 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-15 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-16 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-17 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-18 00:00:00', 4.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-19 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-20 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-21 00:00:00', 4.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-22 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-23 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-24 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-25 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-26 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-27 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-02-28 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-01 00:00:00', 5.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-02 00:00:00', 6.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-03 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-04 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-05 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-06 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-07 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-08 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-09 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-10 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-11 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-12 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-13 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-14 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-15 00:00:00', 5.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-16 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-17 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-18 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-19 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-20 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-21 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-22 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-23 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-24 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-25 00:00:00', 3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-26 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-27 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-28 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-29 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-30 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-03-31 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-01 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-02 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-03 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-04 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-05 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-06 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-07 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-08 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-09 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-10 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-11 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-12 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-13 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-14 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-15 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-16 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-17 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-18 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-19 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-20 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-21 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-22 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-23 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-24 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-25 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-26 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-27 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-28 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-29 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-04-30 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-01 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-02 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-03 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-04 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-05 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-06 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-07 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-08 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-09 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-10 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-11 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-12 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-13 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-14 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-15 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-16 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-17 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-18 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-19 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-20 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-21 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-22 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-23 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-24 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-25 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-26 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-27 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-28 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-29 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-30 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-05-31 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-01 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-02 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-03 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-04 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-05 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-06 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-07 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-08 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-09 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-10 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-11 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-12 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-13 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-14 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-15 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-16 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-17 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-18 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-19 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-20 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-21 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-22 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-23 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-24 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-25 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-26 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-27 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-28 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-29 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-06-30 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-01 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-02 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-03 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-04 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-05 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-06 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-07 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-08 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-09 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-10 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-11 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-12 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-13 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-14 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-15 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-16 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-17 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-18 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-19 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-20 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-21 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-22 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-23 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-24 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-25 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-26 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-27 00:00:00', 3.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-28 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-29 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-30 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-07-31 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-01 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-02 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-03 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-04 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-05 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-06 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-07 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-08 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-09 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-10 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-11 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-12 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-13 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-14 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-15 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-16 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-17 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-18 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-19 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-20 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-21 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-22 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-23 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-24 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-25 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-26 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-27 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-28 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-29 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-30 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-08-31 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-01 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-02 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-03 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-04 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-05 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-06 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-07 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-08 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-09 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-10 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-11 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-12 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-13 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-14 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-15 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-16 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-17 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-18 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-19 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-20 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-21 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-22 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-23 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-24 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-25 00:00:00', 3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-26 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-27 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-28 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-29 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-09-30 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-01 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-02 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-03 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-04 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-05 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-06 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-07 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-08 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-09 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-10 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-11 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-12 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-13 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-14 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-15 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-16 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-17 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-18 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-19 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-20 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-21 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-22 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-23 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-24 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-25 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-26 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-27 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-28 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-29 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-30 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-10-31 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-01 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-02 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-03 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-04 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-05 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-06 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-07 00:00:00', 3.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-08 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-09 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-10 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-11 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-12 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-13 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-14 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-15 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-16 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-17 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-18 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-19 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-20 00:00:00', 3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-21 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-22 00:00:00', 5.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-23 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-24 00:00:00', 5.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-25 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-26 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-27 00:00:00', 5.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-28 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-29 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-11-30 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-01 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-02 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-03 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-04 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-05 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-06 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-07 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-08 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-09 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-10 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-11 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-12 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-13 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-14 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-15 00:00:00', 5.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-16 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-17 00:00:00', 4.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-18 00:00:00', 5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-19 00:00:00', 6.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-20 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-21 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-22 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-23 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-24 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-25 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-26 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-27 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-28 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-29 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-30 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2009-12-31 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-01 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-02 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-03 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-04 00:00:00', 6.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-05 00:00:00', 5.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-06 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-07 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-08 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-09 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-10 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-11 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-12 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-13 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-14 00:00:00', 6.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-15 00:00:00', 5.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-16 00:00:00', 5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-17 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-18 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-19 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-20 00:00:00', 5.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-21 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-22 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-23 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-24 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-25 00:00:00', 5.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-26 00:00:00', 5.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-27 00:00:00', 3.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-28 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-29 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-30 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-01-31 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-01 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-02 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-03 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-04 00:00:00', 4.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-05 00:00:00', 5.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-06 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-07 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-08 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-09 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-10 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-11 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-12 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-13 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-14 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-15 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-16 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-17 00:00:00', 6.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-18 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-19 00:00:00', 5.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-20 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-21 00:00:00', 5.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-22 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-23 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-24 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-25 00:00:00', 4.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-26 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-27 00:00:00', 4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-02-28 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-01 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-02 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-03 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-04 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-05 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-06 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-07 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-08 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-09 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-10 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-11 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-12 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-13 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-14 00:00:00', 4.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-15 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-16 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-17 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-18 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-19 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-20 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-21 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-22 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-23 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-24 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-25 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-26 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-27 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-28 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-29 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-30 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-03-31 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-01 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-02 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-03 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-04 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-05 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-06 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-07 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-08 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-09 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-10 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-11 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-12 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-13 00:00:00', 3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-14 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-15 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-16 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-17 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-18 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-19 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-20 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-21 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-22 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-23 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-24 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-25 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-26 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-27 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-28 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-29 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-04-30 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-01 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-02 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-03 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-04 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-05 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-06 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-07 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-08 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-09 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-10 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-11 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-12 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-13 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-14 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-15 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-16 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-17 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-18 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-19 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-20 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-21 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-22 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-23 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-24 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-25 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-26 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-27 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-28 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-29 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-30 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-05-31 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-01 00:00:00', 3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-02 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-03 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-04 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-05 00:00:00', 2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-06 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-07 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-08 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-09 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-10 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-11 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-12 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-13 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-14 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-15 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-16 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-17 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-18 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-19 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-20 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-21 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-22 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-23 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-24 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-25 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-26 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-27 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-28 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-29 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-06-30 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-01 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-02 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-03 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-04 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-05 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-06 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-07 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-08 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-09 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-10 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-11 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-12 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-13 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-14 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-15 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-16 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-17 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-18 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-19 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-20 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-21 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-22 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-23 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-24 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-25 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-26 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-27 00:00:00', 3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-28 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-29 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-30 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-07-31 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-01 00:00:00', 3.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-02 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-03 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-04 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-05 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-06 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-07 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-08 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-09 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-10 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-11 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-12 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-13 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-14 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-15 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-16 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-17 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-18 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-19 00:00:00', 3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-20 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-21 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-22 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-23 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-24 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-25 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-26 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-27 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-28 00:00:00', 3.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-29 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-30 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-08-31 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-01 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-02 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-03 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-04 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-05 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-06 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-07 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-08 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-09 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-10 00:00:00', 3.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-11 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-12 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-13 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-14 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-15 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-16 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-17 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-18 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-19 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-20 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-21 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-22 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-23 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-24 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-25 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-26 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-27 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-28 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-29 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-09-30 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-01 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-02 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-03 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-04 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-05 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-06 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-07 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-08 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-09 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-10 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-11 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-12 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-13 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-14 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-15 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-16 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-17 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-18 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-19 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-20 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-21 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-22 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-23 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-24 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-25 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-26 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-27 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-28 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-29 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-30 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-10-31 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-01 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-02 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-03 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-04 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-05 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-06 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-07 00:00:00', 3.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-08 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-09 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-10 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-11 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-12 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-13 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-14 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-15 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-16 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-17 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-18 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-19 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-20 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-21 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-22 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-23 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-24 00:00:00', 3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-25 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-26 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-27 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-28 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-29 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-11-30 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-01 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-02 00:00:00', 4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-03 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-04 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-05 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-06 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-07 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-08 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-09 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-10 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-11 00:00:00', 4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-12 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-13 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-14 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-15 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-16 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-17 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-18 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-19 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-20 00:00:00', 4.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-21 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-22 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-23 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-24 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-25 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-26 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-27 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-28 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-29 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-30 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2010-12-31 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-01 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-02 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-03 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-04 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-05 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-06 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-07 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-08 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-09 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-10 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-11 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-12 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-13 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-14 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-15 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-16 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-17 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-18 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-19 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-20 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-21 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-22 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-23 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-24 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-25 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-26 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-27 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-28 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-29 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-30 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-01-31 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-01 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-02 00:00:00', 4.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-03 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-04 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-05 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-06 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-07 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-08 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-09 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-10 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-11 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-12 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-13 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-14 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-15 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-16 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-17 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-18 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-19 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-20 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-21 00:00:00', 5.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-22 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-23 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-24 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-25 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-26 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-27 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-02-28 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-01 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-02 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-03 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-04 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-05 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-06 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-07 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-08 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-09 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-10 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-11 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-12 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-13 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-14 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-15 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-16 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-17 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-18 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-19 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-20 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-21 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-22 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-23 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-24 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-25 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-26 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-27 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-28 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-29 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-30 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-03-31 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-01 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-02 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-03 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-04 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-05 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-06 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-07 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-08 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-09 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-10 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-11 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-12 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-13 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-14 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-15 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-16 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-17 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-18 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-19 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-20 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-21 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-22 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-23 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-24 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-25 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-26 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-27 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-28 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-29 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-04-30 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-01 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-02 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-03 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-04 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-05 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-06 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-07 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-08 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-09 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-10 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-11 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-12 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-13 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-14 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-15 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-16 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-17 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-18 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-19 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-20 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-21 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-22 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-23 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-24 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-25 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-26 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-27 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-28 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-29 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-30 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-05-31 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-01 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-02 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-03 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-04 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-05 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-06 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-07 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-08 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-09 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-10 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-11 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-12 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-13 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-14 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-15 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-16 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-17 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-18 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-19 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-20 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-21 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-22 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-23 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-24 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-25 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-26 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-27 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-28 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-29 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-06-30 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-01 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-02 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-03 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-04 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-05 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-06 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-07 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-08 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-09 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-10 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-11 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-12 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-13 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-14 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-15 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-16 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-17 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-18 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-19 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-20 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-21 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-22 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-23 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-24 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-25 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-26 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-27 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-28 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-29 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-30 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-07-31 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-01 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-02 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-03 00:00:00', 3.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-04 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-05 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-06 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-07 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-08 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-09 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-10 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-11 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-12 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-13 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-14 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-15 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-16 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-17 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-18 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-19 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-20 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-21 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-22 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-23 00:00:00', 3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-24 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-25 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-26 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-27 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-28 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-29 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-30 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-08-31 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-01 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-02 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-03 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-04 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-05 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-06 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-07 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-08 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-09 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-10 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-11 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-12 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-13 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-14 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-15 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-16 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-17 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-18 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-19 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-20 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-21 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-22 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-23 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-24 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-25 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-26 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-27 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-28 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-29 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-09-30 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-01 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-02 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-03 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-04 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-05 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-06 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-07 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-08 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-09 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-10 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-11 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-12 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-13 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-14 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-15 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-16 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-17 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-18 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-19 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-20 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-21 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-22 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-23 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-24 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-25 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-26 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-27 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-28 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-29 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-30 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-10-31 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-01 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-02 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-03 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-04 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-05 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-06 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-07 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-08 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-09 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-10 00:00:00', 4.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-11 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-12 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-13 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-14 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-15 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-16 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-17 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-18 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-19 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-20 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-21 00:00:00', 5.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-22 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-23 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-24 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-25 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-26 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-27 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-28 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-29 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-11-30 00:00:00', 4.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-01 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-02 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-03 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-04 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-05 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-06 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-07 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-08 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-09 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-10 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-11 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-12 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-13 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-14 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-15 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-16 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-17 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-18 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-19 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-20 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-21 00:00:00', 3.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-22 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-23 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-24 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-25 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-26 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-27 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-28 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-29 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-30 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2011-12-31 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-01 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-02 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-03 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-04 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-05 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-06 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-07 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-08 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-09 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-10 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-11 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-12 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-13 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-14 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-15 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-16 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-17 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-18 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-19 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-20 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-21 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-22 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-23 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-24 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-25 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-26 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-27 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-28 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-29 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-30 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-01-31 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-01 00:00:00', 4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-02 00:00:00', 4.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-03 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-04 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-05 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-06 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-07 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-08 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-09 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-10 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-11 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-12 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-13 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-14 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-15 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-16 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-17 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-18 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-19 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-20 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-21 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-22 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-23 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-24 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-25 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-26 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-27 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-28 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-02-29 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-01 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-02 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-03 00:00:00', 4.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-04 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-05 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-06 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-07 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-08 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-09 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-10 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-11 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-12 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-13 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-14 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-15 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-16 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-17 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-18 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-19 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-20 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-21 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-22 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-23 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-24 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-25 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-26 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-27 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-28 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-29 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-30 00:00:00', 3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-03-31 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-01 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-02 00:00:00', 3.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-03 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-04 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-05 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-06 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-07 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-08 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-09 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-10 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-11 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-12 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-13 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-14 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-15 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-16 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-17 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-18 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-19 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-20 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-21 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-22 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-23 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-24 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-25 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-26 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-27 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-28 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-29 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-04-30 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-01 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-02 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-03 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-04 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-05 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-06 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-07 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-08 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-09 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-10 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-11 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-12 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-13 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-14 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-15 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-16 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-17 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-18 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-19 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-20 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-21 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-22 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-23 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-24 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-25 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-26 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-27 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-28 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-29 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-30 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-05-31 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-01 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-02 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-03 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-04 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-05 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-06 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-07 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-08 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-09 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-10 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-11 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-12 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-13 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-14 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-15 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-16 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-17 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-18 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-19 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-20 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-21 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-22 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-23 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-24 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-25 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-26 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-27 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-28 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-29 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-06-30 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-01 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-02 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-03 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-04 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-05 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-06 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-07 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-08 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-09 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-10 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-11 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-12 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-13 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-14 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-15 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-16 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-17 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-18 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-19 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-20 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-21 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-22 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-23 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-24 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-25 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-26 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-27 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-28 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-29 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-30 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-07-31 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-01 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-02 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-03 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-04 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-05 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-06 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-07 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-08 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-09 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-10 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-11 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-12 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-13 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-14 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-15 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-16 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-17 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-18 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-19 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-20 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-21 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-22 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-23 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-24 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-25 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-26 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-27 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-28 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-29 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-30 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-08-31 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-01 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-02 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-03 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-04 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-05 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-06 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-07 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-08 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-09 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-10 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-11 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-12 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-13 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-14 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-15 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-16 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-17 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-18 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-19 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-20 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-21 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-22 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-23 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-24 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-25 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-26 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-27 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-28 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-29 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-09-30 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-01 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-02 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-03 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-04 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-05 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-06 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-07 00:00:00', 2.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-08 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-09 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-10 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-11 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-12 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-13 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-14 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-15 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-16 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-17 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-18 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-19 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-20 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-21 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-22 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-23 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-24 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-25 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-26 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-27 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-28 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-29 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-30 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-10-31 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-01 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-02 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-03 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-04 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-05 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-06 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-07 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-08 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-09 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-10 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-11 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-12 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-13 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-14 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-15 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-16 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-17 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-18 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-19 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-20 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-21 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-22 00:00:00', 1.11000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-23 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-24 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-25 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-26 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-27 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-28 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-29 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-11-30 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-01 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-02 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-03 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-04 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-05 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-06 00:00:00', 3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-07 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-08 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-09 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-10 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-11 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-12 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-13 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-14 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-15 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-16 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-17 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-18 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-19 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-20 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-21 00:00:00', 4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-22 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-23 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-24 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-25 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-26 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-27 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-28 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-29 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-30 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2012-12-31 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-01 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-02 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-03 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-04 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-05 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-06 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-07 00:00:00', 4.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-08 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-09 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-10 00:00:00', 5.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-11 00:00:00', 5.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-12 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-13 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-14 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-15 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-16 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-17 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-18 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-19 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-20 00:00:00', 4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-21 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-22 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-23 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-24 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-25 00:00:00', 4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-26 00:00:00', 4.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-27 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-28 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-29 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-30 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-01-31 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-01 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-02 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-03 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-04 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-05 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-06 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-07 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-08 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-09 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-10 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-11 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-12 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-13 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-14 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-15 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-16 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-17 00:00:00', 3.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-18 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-19 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-20 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-21 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-22 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-23 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-24 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-25 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-26 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-27 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-02-28 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-01 00:00:00', 4.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-02 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-03 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-04 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-05 00:00:00', 4.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-06 00:00:00', 4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-07 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-08 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-09 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-10 00:00:00', 4.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-11 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-12 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-13 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-14 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-15 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-16 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-17 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-18 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-19 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-20 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-21 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-22 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-23 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-24 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-25 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-26 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-27 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-28 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-29 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-30 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-03-31 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-01 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-02 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-03 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-04 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-05 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-06 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-07 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-08 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-09 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-10 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-11 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-12 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-13 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-14 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-15 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-16 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-17 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-18 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-19 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-20 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-21 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-22 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-23 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-24 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-25 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-26 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-27 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-28 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-29 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-04-30 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-01 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-02 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-03 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-04 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-05 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-06 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-07 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-08 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-09 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-10 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-11 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-12 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-13 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-14 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-15 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-16 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-17 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-18 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-19 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-20 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-21 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-22 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-23 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-24 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-25 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-26 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-27 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-28 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-29 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-30 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-05-31 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-01 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-02 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-03 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-04 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-05 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-06 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-07 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-08 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-09 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-10 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-11 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-12 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-13 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-14 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-15 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-16 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-17 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-18 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-19 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-20 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-21 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-22 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-23 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-24 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-25 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-26 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-27 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-28 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-29 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-06-30 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-01 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-02 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-03 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-04 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-05 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-06 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-07 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-08 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-09 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-10 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-11 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-12 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-13 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-14 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-15 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-16 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-17 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-18 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-19 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-20 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-21 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-22 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-23 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-24 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-25 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-26 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-27 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-28 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-29 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-30 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-07-31 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-01 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-02 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-03 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-04 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-05 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-06 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-07 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-08 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-09 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-10 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-11 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-12 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-13 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-14 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-15 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-16 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-17 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-18 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-19 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-20 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-21 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-22 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-23 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-24 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-25 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-26 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-27 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-28 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-29 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-30 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-08-31 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-01 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-02 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-03 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-04 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-05 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-06 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-07 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-08 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-09 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-10 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-11 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-12 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-13 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-14 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-15 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-16 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-17 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-18 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-19 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-20 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-21 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-22 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-23 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-24 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-25 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-26 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-27 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-28 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-29 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-09-30 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-01 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-02 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-03 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-04 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-05 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-06 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-07 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-08 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-09 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-10 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-11 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-12 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-13 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-14 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-15 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-16 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-17 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-18 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-19 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-20 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-21 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-22 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-23 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-24 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-25 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-26 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-27 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-28 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-29 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-30 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-10-31 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-01 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-02 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-03 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-04 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-05 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-06 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-07 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-08 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-09 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-10 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-11 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-12 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-13 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-14 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-15 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-16 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-17 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-18 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-19 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-20 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-21 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-22 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-23 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-24 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-25 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-26 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-27 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-28 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-29 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-11-30 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-01 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-02 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-03 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-04 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-05 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-06 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-07 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-08 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-09 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-10 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-11 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-12 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-13 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-14 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-15 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-16 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-17 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-18 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-19 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-20 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-21 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-22 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-23 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-24 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-25 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-26 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-27 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-28 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-29 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-30 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2013-12-31 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-01 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-02 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-03 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-04 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-05 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-06 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-07 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-08 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-09 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-10 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-11 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-12 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-13 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-14 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-15 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-16 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-17 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-18 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-19 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-20 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-21 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-22 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-23 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-24 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-25 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-26 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-27 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-28 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-29 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-30 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-01-31 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-01 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-02 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-03 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-04 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-05 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-06 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-07 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-08 00:00:00', 3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-09 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-10 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-11 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-12 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-13 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-14 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-15 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-16 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-17 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-18 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-19 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-20 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-21 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-22 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-23 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-24 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-25 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-26 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-27 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-02-28 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-01 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-02 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-03 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-04 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-05 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-06 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-07 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-08 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-09 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-10 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-11 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-12 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-13 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-14 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-15 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-16 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-17 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-18 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-19 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-20 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-21 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-22 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-23 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-24 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-25 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-26 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-27 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-28 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-29 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-30 00:00:00', 3.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-03-31 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-01 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-02 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-03 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-04 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-05 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-06 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-07 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-08 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-09 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-10 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-11 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-12 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-13 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-14 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-15 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-16 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-17 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-18 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-19 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-20 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-21 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-22 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-23 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-24 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-25 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-26 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-27 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-28 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-29 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-04-30 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-01 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-02 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-03 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-04 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-05 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-06 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-07 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-08 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-09 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-10 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-11 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-12 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-13 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-14 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-15 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-16 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-17 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-18 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-19 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-20 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-21 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-22 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-23 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-24 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-25 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-26 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-27 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-28 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-29 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-30 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-05-31 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-01 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-02 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-03 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-04 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-05 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-06 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-07 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-08 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-09 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-10 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-11 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-12 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-13 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-14 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-15 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-16 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-17 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-18 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-19 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-20 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-21 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-22 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-23 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-24 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-25 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-26 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-27 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-28 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-29 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-06-30 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-01 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-02 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-03 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-04 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-05 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-06 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-07 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-08 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-09 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-10 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-11 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-12 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-13 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-14 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-15 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-16 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-17 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-18 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-19 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-20 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-21 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-22 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-23 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-24 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-25 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-26 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-27 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-28 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-29 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-30 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (34, '2014-07-31 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-01 00:00:00', 1.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-02 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-03 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-04 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-05 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-06 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-07 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-08 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-09 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-10 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-11 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-12 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-13 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-14 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-15 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-16 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-17 00:00:00', 4.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-18 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-19 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-20 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-21 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-22 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-23 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-24 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-25 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-26 00:00:00', 2.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-27 00:00:00', 0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-28 00:00:00', 1.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-29 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-30 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-01-31 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-01 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-02 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-03 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-04 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-05 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-06 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-07 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-08 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-09 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-10 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-11 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-12 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-13 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-14 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-15 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-16 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-17 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-18 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-19 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-20 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-21 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-22 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-23 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-24 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-25 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-26 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-27 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-02-28 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-01 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-02 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-03 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-04 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-05 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-06 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-07 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-08 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-09 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-10 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-11 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-12 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-13 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-14 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-15 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-16 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-17 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-18 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-19 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-20 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-21 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-22 00:00:00', 0.949999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-23 00:00:00', 1.10300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-24 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-25 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-26 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-27 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-28 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-29 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-30 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-03-31 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-01 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-02 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-03 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-04 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-05 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-06 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-07 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-08 00:00:00', 1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-09 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-10 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-11 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-12 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-13 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-14 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-15 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-16 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-17 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-18 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-19 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-20 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-21 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-22 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-23 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-24 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-25 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-26 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-27 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-28 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-29 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-04-30 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-01 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-02 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-03 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-04 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-05 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-06 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-07 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-08 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-09 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-10 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-11 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-12 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-13 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-14 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-15 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-16 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-17 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-18 00:00:00', 1.27100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-19 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-20 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-21 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-22 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-23 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-24 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-25 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-26 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-27 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-28 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-29 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-30 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-05-31 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-01 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-02 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-03 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-04 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-05 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-06 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-07 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-08 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-09 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-10 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-11 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-12 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-13 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-14 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-15 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-16 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-17 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-18 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-19 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-20 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-21 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-22 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-23 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-24 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-25 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-26 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-27 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-28 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-29 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-06-30 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-01 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-02 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-03 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-04 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-05 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-06 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-07 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-08 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-09 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-10 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-11 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-12 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-13 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-14 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-15 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-16 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-17 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-18 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-19 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-20 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-21 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-22 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-23 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-24 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-25 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-26 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-27 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-28 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-29 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-30 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-07-31 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-01 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-02 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-03 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-04 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-05 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-06 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-07 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-08 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-09 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-10 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-11 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-12 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-13 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-14 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-15 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-16 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-17 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-18 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-19 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-20 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-21 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-22 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-23 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-24 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-25 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-26 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-27 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-28 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-29 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-30 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-08-31 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-01 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-02 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-03 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-04 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-05 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-06 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-07 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-08 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-09 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-10 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-11 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-12 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-13 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-14 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-15 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-16 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-17 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-18 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-19 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-20 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-21 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-22 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-23 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-24 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-25 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-26 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-27 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-28 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-29 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-09-30 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-01 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-02 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-03 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-04 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-05 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-06 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-07 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-08 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-09 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-10 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-11 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-12 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-13 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-14 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-15 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-16 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-17 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-18 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-19 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-20 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-21 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-22 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-23 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-24 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-25 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-26 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-27 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-28 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-29 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-30 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-10-31 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-01 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-02 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-03 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-04 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-05 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-06 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-07 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-08 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-09 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-10 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-11 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-12 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-13 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-14 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-15 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-16 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-17 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-18 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-19 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-20 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-21 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-22 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-23 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-24 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-25 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-26 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-27 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-28 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-29 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-11-30 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-01 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-02 00:00:00', 5.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-03 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-04 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-05 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-06 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-07 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-08 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-09 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-10 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-11 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-12 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-13 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-14 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-15 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-16 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-17 00:00:00', 3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-18 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-19 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-20 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-21 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-22 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-23 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-24 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-25 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-26 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-27 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-28 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-29 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-30 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1979-12-31 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-01 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-02 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-03 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-04 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-05 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-06 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-07 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-08 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-09 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-10 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-11 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-12 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-13 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-14 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-15 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-16 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-17 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-18 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-19 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-20 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-21 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-22 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-23 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-24 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-25 00:00:00', 5.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-26 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-27 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-28 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-29 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-30 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-01-31 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-01 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-02 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-03 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-04 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-05 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-06 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-07 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-08 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-09 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-10 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-11 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-12 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-13 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-14 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-15 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-16 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-17 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-18 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-19 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-20 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-21 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-22 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-23 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-24 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-25 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-26 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-27 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-28 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-02-29 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-01 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-02 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-03 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-04 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-05 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-06 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-07 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-08 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-09 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-10 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-11 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-12 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-13 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-14 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-15 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-16 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-17 00:00:00', 4.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-18 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-19 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-20 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-21 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-22 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-23 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-24 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-25 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-26 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-27 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-28 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-29 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-30 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-03-31 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-01 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-02 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-03 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-04 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-05 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-06 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-07 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-08 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-09 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-10 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-11 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-12 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-13 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-14 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-15 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-16 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-17 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-18 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-19 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-20 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-21 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-22 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-23 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-24 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-25 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-26 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-27 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-28 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-29 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-04-30 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-01 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-02 00:00:00', 1.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-03 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-04 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-05 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-06 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-07 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-08 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-09 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-10 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-11 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-12 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-13 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-14 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-15 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-16 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-17 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-18 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-19 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-20 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-21 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-22 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-23 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-24 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-25 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-26 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-27 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-28 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-29 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-30 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-05-31 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-01 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-02 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-03 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-04 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-05 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-06 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-07 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-08 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-09 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-10 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-11 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-12 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-13 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-14 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-15 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-16 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-17 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-18 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-19 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-20 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-21 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-22 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-23 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-24 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-25 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-26 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-27 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-28 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-29 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-06-30 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-01 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-02 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-03 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-04 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-05 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-06 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-07 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-08 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-09 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-10 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-11 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-12 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-13 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-14 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-15 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-16 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-17 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-18 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-19 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-20 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-21 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-22 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-23 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-24 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-25 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-26 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-27 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-28 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-29 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-30 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-07-31 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-01 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-02 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-03 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-04 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-05 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-06 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-07 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-08 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-09 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-10 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-11 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-12 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-13 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-14 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-15 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-16 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-17 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-18 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-19 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-20 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-21 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-22 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-23 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-24 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-25 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-26 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-27 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-28 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-29 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-30 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-08-31 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-01 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-02 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-03 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-04 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-05 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-06 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-07 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-08 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-09 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-10 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-11 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-12 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-13 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-14 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-15 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-16 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-17 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-18 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-19 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-20 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-21 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-22 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-23 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-24 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-25 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-26 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-27 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-28 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-29 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-09-30 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-01 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-02 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-03 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-04 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-05 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-06 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-07 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-08 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-09 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-10 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-11 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-12 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-13 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-14 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-15 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-16 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-17 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-18 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-19 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-20 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-21 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-22 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-23 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-24 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-25 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-26 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-27 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-28 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-29 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-30 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-10-31 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-01 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-02 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-03 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-04 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-05 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-06 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-07 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-08 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-09 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-10 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-11 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-12 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-13 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-14 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-15 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-16 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-17 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-18 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-19 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-20 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-21 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-22 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-23 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-24 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-25 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-26 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-27 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-28 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-29 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-11-30 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-01 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-02 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-03 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-04 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-05 00:00:00', 1.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-06 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-07 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-08 00:00:00', 0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-09 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-10 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-11 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-12 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-13 00:00:00', 5.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-14 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-15 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-16 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-17 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-18 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-19 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-20 00:00:00', 1.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-21 00:00:00', 1.20599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-22 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-23 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-24 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-25 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-26 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-27 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-28 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-29 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-30 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1980-12-31 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-01 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-02 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-03 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-04 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-05 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-06 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-07 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-08 00:00:00', 1.32400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-09 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-10 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-11 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-12 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-13 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-14 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-15 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-16 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-17 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-18 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-19 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-20 00:00:00', 3.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-21 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-22 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-23 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-24 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-25 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-26 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-27 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-28 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-29 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-30 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-01-31 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-01 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-02 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-03 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-04 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-05 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-06 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-07 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-08 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-09 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-10 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-11 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-12 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-13 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-14 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-15 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-16 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-17 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-18 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-19 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-20 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-21 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-22 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-23 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-24 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-25 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-26 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-27 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-02-28 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-01 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-02 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-03 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-04 00:00:00', 4.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-05 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-06 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-07 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-08 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-09 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-10 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-11 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-12 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-13 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-14 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-15 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-16 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-17 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-18 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-19 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-20 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-21 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-22 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-23 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-24 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-25 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-26 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-27 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-28 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-29 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-30 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-03-31 00:00:00', 1.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-01 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-02 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-03 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-04 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-05 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-06 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-07 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-08 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-09 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-10 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-11 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-12 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-13 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-14 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-15 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-16 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-17 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-18 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-19 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-20 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-21 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-22 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-23 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-24 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-25 00:00:00', 1.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-26 00:00:00', 1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-27 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-28 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-29 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-04-30 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-01 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-02 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-03 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-04 00:00:00', 3.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-05 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-06 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-07 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-08 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-09 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-10 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-11 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-12 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-13 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-14 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-15 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-16 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-17 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-18 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-19 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-20 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-21 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-22 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-23 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-24 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-25 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-26 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-27 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-28 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-29 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-30 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-05-31 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-01 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-02 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-03 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-04 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-05 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-06 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-07 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-08 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-09 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-10 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-11 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-12 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-13 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-14 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-15 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-16 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-17 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-18 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-19 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-20 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-21 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-22 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-23 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-24 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-25 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-26 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-27 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-28 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-29 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-06-30 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-01 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-02 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-03 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-04 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-05 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-06 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-07 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-08 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-09 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-10 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-11 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-12 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-13 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-14 00:00:00', 3.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-15 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-16 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-17 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-18 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-19 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-20 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-21 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-22 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-23 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-24 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-25 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-26 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-27 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-28 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-29 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-30 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-07-31 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-01 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-02 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-03 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-04 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-05 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-06 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-07 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-08 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-09 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-10 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-11 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-12 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-13 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-14 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-15 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-16 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-17 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-18 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-19 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-20 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-21 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-22 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-23 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-24 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-25 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-26 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-27 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-28 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-29 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-30 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-08-31 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-01 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-02 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-03 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-04 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-05 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-06 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-07 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-08 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-09 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-10 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-11 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-12 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-13 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-14 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-15 00:00:00', 1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-16 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-17 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-18 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-19 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-20 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-21 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-22 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-23 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-24 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-25 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-26 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-27 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-28 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-29 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-09-30 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-01 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-02 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-03 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-04 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-05 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-06 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-07 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-08 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-09 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-10 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-11 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-12 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-13 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-14 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-15 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-16 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-17 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-18 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-19 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-20 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-21 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-22 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-23 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-24 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-25 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-26 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-27 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-28 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-29 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-30 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-10-31 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-01 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-02 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-03 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-04 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-05 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-06 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-07 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-08 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-09 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-10 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-11 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-12 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-13 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-14 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-15 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-16 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-17 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-18 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-19 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-20 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-21 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-22 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-23 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-24 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-25 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-26 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-27 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-28 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-29 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-11-30 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-01 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-02 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-03 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-04 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-05 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-06 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-07 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-08 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-09 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-10 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-11 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-12 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-13 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-14 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-15 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-16 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-17 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-18 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-19 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-20 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-21 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-22 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-23 00:00:00', 0.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-24 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-25 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-26 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-27 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-28 00:00:00', 3.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-29 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-30 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1981-12-31 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-01 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-02 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-03 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-04 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-05 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-06 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-07 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-08 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-09 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-10 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-11 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-12 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-13 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-14 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-15 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-16 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-17 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-18 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-19 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-20 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-21 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-22 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-23 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-24 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-25 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-26 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-27 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-28 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-29 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-30 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-01-31 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-01 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-02 00:00:00', 4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-03 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-04 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-05 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-06 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-07 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-08 00:00:00', 2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-09 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-10 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-11 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-12 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-13 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-14 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-15 00:00:00', 4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-16 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-17 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-18 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-19 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-20 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-21 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-22 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-23 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-24 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-25 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-26 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-27 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-02-28 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-01 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-02 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-03 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-04 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-05 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-06 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-07 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-08 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-09 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-10 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-11 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-12 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-13 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-14 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-15 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-16 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-17 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-18 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-19 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-20 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-21 00:00:00', 3.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-22 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-23 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-24 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-25 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-26 00:00:00', 4.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-27 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-28 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-29 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-30 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-03-31 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-01 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-02 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-03 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-04 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-05 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-06 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-07 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-08 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-09 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-10 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-11 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-12 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-13 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-14 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-15 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-16 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-17 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-18 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-19 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-20 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-21 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-22 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-23 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-24 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-25 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-26 00:00:00', 1.11000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-27 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-28 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-29 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-04-30 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-01 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-02 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-03 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-04 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-05 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-06 00:00:00', 1.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-07 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-08 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-09 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-10 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-11 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-12 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-13 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-14 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-15 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-16 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-17 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-18 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-19 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-20 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-21 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-22 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-23 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-24 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-25 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-26 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-27 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-28 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-29 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-30 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-05-31 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-01 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-02 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-03 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-04 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-05 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-06 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-07 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-08 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-09 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-10 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-11 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-12 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-13 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-14 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-15 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-16 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-17 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-18 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-19 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-20 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-21 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-22 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-23 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-24 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-25 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-26 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-27 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-28 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-29 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-06-30 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-01 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-02 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-03 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-04 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-05 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-06 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-07 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-08 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-09 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-10 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-11 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-12 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-13 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-14 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-15 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-16 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-17 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-18 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-19 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-20 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-21 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-22 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-23 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-24 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-25 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-26 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-27 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-28 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-29 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-30 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-07-31 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-01 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-02 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-03 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-04 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-05 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-06 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-07 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-08 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-09 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-10 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-11 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-12 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-13 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-14 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-15 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-16 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-17 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-18 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-19 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-20 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-21 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-22 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-23 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-24 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-25 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-26 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-27 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-28 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-29 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-30 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-08-31 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-01 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-02 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-03 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-04 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-05 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-06 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-07 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-08 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-09 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-10 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-11 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-12 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-13 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-14 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-15 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-16 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-17 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-18 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-19 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-20 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-21 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-22 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-23 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-24 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-25 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-26 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-27 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-28 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-29 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-09-30 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-01 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-02 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-03 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-04 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-05 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-06 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-07 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-08 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-09 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-10 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-11 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-12 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-13 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-14 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-15 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-16 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-17 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-18 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-19 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-20 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-21 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-22 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-23 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-24 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-25 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-26 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-27 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-28 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-29 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-30 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-10-31 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-01 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-02 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-03 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-04 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-05 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-06 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-07 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-08 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-09 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-10 00:00:00', 3.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-11 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-12 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-13 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-14 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-15 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-16 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-17 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-18 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-19 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-20 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-21 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-22 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-23 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-24 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-25 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-26 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-27 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-28 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-29 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-11-30 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-01 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-02 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-03 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-04 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-05 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-06 00:00:00', 3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-07 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-08 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-09 00:00:00', 4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-10 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-11 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-12 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-13 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-14 00:00:00', 1.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-15 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-16 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-17 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-18 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-19 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-20 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-21 00:00:00', 0.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-22 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-23 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-24 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-25 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-26 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-27 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-28 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-29 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-30 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1982-12-31 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-01 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-02 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-03 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-04 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-05 00:00:00', 3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-06 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-07 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-08 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-09 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-10 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-11 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-12 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-13 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-14 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-15 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-16 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-17 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-18 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-19 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-20 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-21 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-22 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-23 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-24 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-25 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-26 00:00:00', 4.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-27 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-28 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-29 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-30 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-01-31 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-01 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-02 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-03 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-04 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-05 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-06 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-07 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-08 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-09 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-10 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-11 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-12 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-13 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-14 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-15 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-16 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-17 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-18 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-19 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-20 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-21 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-22 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-23 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-24 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-25 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-26 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-27 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-02-28 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-01 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-02 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-03 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-04 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-05 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-06 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-07 00:00:00', 4.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-08 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-09 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-10 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-11 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-12 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-13 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-14 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-15 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-16 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-17 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-18 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-19 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-20 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-21 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-22 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-23 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-24 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-25 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-26 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-27 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-28 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-29 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-30 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-03-31 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-01 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-02 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-03 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-04 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-05 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-06 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-07 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-08 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-09 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-10 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-11 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-12 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-13 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-14 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-15 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-16 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-17 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-18 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-19 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-20 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-21 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-22 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-23 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-24 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-25 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-26 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-27 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-28 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-29 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-04-30 00:00:00', 0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-01 00:00:00', 1.03199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-02 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-03 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-04 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-05 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-06 00:00:00', 1.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-07 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-08 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-09 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-10 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-11 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-12 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-13 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-14 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-15 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-16 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-17 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-18 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-19 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-20 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-21 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-22 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-23 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-24 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-25 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-26 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-27 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-28 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-29 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-30 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-05-31 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-01 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-02 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-03 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-04 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-05 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-06 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-07 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-08 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-09 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-10 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-11 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-12 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-13 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-14 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-15 00:00:00', 1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-16 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-17 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-18 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-19 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-20 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-21 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-22 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-23 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-24 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-25 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-26 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-27 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-28 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-29 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-06-30 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-01 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-02 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-03 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-04 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-05 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-06 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-07 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-08 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-09 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-10 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-11 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-12 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-13 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-14 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-15 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-16 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-17 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-18 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-19 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-20 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-21 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-22 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-23 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-24 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-25 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-26 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-27 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-28 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-29 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-30 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-07-31 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-01 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-02 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-03 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-04 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-05 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-06 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-07 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-08 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-09 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-10 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-11 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-12 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-13 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-14 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-15 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-16 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-17 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-18 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-19 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-20 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-21 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-22 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-23 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-24 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-25 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-26 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-27 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-28 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-29 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-30 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-08-31 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-01 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-03 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-05 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-07 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-09 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-11 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-13 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-15 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-17 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-19 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-21 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-23 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-25 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-27 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-29 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-01 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-03 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-05 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-07 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-09 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-11 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-13 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-15 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-17 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-19 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-21 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-23 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-25 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-27 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-29 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-30 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-10-31 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-01 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-02 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-03 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-04 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-05 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-06 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-07 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-08 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-09 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-10 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-11 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-12 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-13 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-14 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-15 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-16 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-17 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-18 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-19 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-20 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-21 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-22 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-23 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-24 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-25 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-26 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-27 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-28 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-29 00:00:00', 1.14900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-11-30 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-01 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-02 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-03 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-04 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-05 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-06 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-07 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-08 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-09 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-10 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-11 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-12 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-13 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-14 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-15 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-16 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-17 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-18 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-19 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-20 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-21 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-22 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-23 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-24 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-25 00:00:00', 0.976999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-26 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-27 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-28 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-29 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-30 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1983-12-31 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-01 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-02 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-03 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-04 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-05 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-06 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-07 00:00:00', 1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-08 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-09 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-10 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-11 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-12 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-13 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-14 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-15 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-16 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-17 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-18 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-19 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-20 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-21 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-22 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-23 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-24 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-25 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-26 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-27 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-28 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-29 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-30 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-01-31 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-01 00:00:00', 4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-02 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-03 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-04 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-05 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-06 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-07 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-08 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-09 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-10 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-11 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-12 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-13 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-14 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-15 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-16 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-17 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-18 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-19 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-20 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-21 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-22 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-23 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-24 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-25 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-26 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-27 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-28 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-02-29 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-01 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-02 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-03 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-04 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-05 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-06 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-07 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-08 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-09 00:00:00', 5.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-10 00:00:00', 4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-11 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-12 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-13 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-14 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-15 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-16 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-17 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-18 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-19 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-20 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-21 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-22 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-23 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-24 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-25 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-26 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-27 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-28 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-29 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-30 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-03-31 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-01 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-02 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-03 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-04 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-05 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-06 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-07 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-08 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-09 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-10 00:00:00', 2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-11 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-12 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-13 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-14 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-15 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-16 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-17 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-18 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-19 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-20 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-21 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-22 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-23 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-24 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-25 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-26 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-27 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-28 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-29 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-04-30 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-01 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-02 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-03 00:00:00', 5.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-04 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-05 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-06 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-07 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-08 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-09 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-10 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-11 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-12 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-13 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-14 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-15 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-16 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-17 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-18 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-19 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-20 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-21 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-22 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-23 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-24 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-25 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-26 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-27 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-28 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-29 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-30 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-05-31 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-01 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-02 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-03 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-04 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-05 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-06 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-07 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-08 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-09 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-10 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-11 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-12 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-13 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-14 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-15 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-16 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-17 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-18 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-19 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-20 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-21 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-22 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-23 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-24 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-25 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-26 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-27 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-28 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-29 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-06-30 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-01 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-02 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-03 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-04 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-05 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-06 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-07 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-08 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-09 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-10 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-11 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-12 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-13 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-14 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-15 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-16 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-17 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-18 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-19 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-20 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-21 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-22 00:00:00', 3.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-23 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-24 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-25 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-26 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-27 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-28 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-29 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-30 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-07-31 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-01 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-02 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-03 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-04 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-05 00:00:00', 3.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-06 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-07 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-08 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-09 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-10 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-11 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-12 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-13 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-14 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-15 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-16 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-17 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-18 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-19 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-20 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-21 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-22 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-23 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-24 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-25 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-26 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-27 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-28 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-29 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-30 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-08-31 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-01 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-02 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-03 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-04 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-05 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-06 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-07 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-08 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-09 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-10 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-11 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-12 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-13 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-14 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-15 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-16 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-17 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-18 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-19 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-20 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-21 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-22 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-23 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-24 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-25 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-26 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-27 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-28 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-29 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-09-30 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-01 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-02 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-03 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-04 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-05 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-06 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-07 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-08 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-09 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-10 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-11 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-12 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-13 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-14 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-15 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-16 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-17 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-18 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-19 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-20 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-21 00:00:00', 3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-22 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-23 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-24 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-25 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-26 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-27 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-28 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-29 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-30 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-10-31 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-01 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-02 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-03 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-04 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-05 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-06 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-07 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-08 00:00:00', 1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-09 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-10 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-11 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-12 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-13 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-14 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-15 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-16 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-17 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-18 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-19 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-20 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-21 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-22 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-23 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-24 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-25 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-26 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-27 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-28 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-29 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-11-30 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-01 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-02 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-03 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-04 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-05 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-06 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-07 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-08 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-09 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-10 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-11 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-12 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-13 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-14 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-15 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-16 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-17 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-18 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-19 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-20 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-21 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-22 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-23 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-24 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-25 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-26 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-27 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-28 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-29 00:00:00', 4.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-30 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1984-12-31 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-01 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-02 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-03 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-04 00:00:00', 2.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-05 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-06 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-07 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-08 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-09 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-10 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-11 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-12 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-13 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-14 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-15 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-16 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-17 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-18 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-19 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-20 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-21 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-22 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-23 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-24 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-25 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-26 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-27 00:00:00', 1.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-28 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-29 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-30 00:00:00', 0.976000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-01-31 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-01 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-02 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-03 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-04 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-05 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-06 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-07 00:00:00', 5.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-08 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-09 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-10 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-11 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-12 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-13 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-14 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-15 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-16 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-17 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-18 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-19 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-20 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-21 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-22 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-23 00:00:00', 3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-24 00:00:00', 4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-25 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-26 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-27 00:00:00', 4.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-02-28 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-01 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-02 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-03 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-04 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-05 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-06 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-07 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-08 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-09 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-10 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-11 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-12 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-13 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-14 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-15 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-16 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-17 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-18 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-19 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-20 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-21 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-22 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-23 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-24 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-25 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-26 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-27 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-28 00:00:00', 2.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-29 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-30 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-03-31 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-01 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-02 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-03 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-04 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-05 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-06 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-07 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-08 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-09 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-10 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-11 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-12 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-13 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-14 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-15 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-16 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-17 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-18 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-19 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-20 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-21 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-22 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-23 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-24 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-25 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-26 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-27 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-28 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-29 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-04-30 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-01 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-02 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-03 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-04 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-05 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-06 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-07 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-08 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-09 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-10 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-11 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-12 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-13 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-14 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-15 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-16 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-17 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-18 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-19 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-20 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-21 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-22 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-23 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-24 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-25 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-26 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-27 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-28 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-29 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-30 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-05-31 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-01 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-02 00:00:00', 3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-03 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-04 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-05 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-06 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-07 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-08 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-09 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-10 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-11 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-12 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-13 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-14 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-15 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-16 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-17 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-18 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-19 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-20 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-21 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-22 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-23 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-24 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-25 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-26 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-27 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-28 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-29 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-06-30 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-01 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-02 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-03 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-04 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-05 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-06 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-07 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-08 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-09 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-10 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-11 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-12 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-13 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-14 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-15 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-16 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-17 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-18 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-19 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-20 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-21 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-22 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-23 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-24 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-25 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-26 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-27 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-28 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-29 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-30 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-07-31 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-01 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-02 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-03 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-04 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-05 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-06 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-07 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-08 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-09 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-10 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-11 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-12 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-13 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-14 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-15 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-16 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-17 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-18 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-19 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-20 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-21 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-22 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-23 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-24 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-25 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-26 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-27 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-28 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-29 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-30 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-08-31 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-01 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-02 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-03 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-04 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-05 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-06 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-07 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-08 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-09 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-10 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-11 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-12 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-13 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-14 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-15 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-16 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-17 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-18 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-19 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-20 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-21 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-22 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-23 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-24 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-25 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-26 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-27 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-28 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-29 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-09-30 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-01 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-02 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-03 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-04 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-05 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-06 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-07 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-08 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-09 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-10 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-11 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-12 00:00:00', 4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-13 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-14 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-15 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-16 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-17 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-18 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-19 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-20 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-21 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-22 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-23 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-24 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-25 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-26 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-27 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-28 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-29 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-30 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-10-31 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-01 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-02 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-03 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-04 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-05 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-06 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-07 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-08 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-09 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-10 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-11 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-12 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-13 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-14 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-15 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-16 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-17 00:00:00', 1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-18 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-19 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-20 00:00:00', 4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-21 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-22 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-23 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-24 00:00:00', 3.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-25 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-26 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-27 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-28 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-29 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-11-30 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-01 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-02 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-03 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-04 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-05 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-06 00:00:00', 5.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-07 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-08 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-09 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-10 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-11 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-12 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-13 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-14 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-15 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-16 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-17 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-18 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-19 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-20 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-21 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-22 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-23 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-24 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-25 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-26 00:00:00', 1.02199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-27 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-28 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-29 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-30 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1985-12-31 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-01 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-02 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-03 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-04 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-05 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-06 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-07 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-08 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-09 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-10 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-11 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-12 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-13 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-14 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-15 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-16 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-17 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-18 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-19 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-20 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-21 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-22 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-23 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-24 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-25 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-26 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-27 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-28 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-29 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-30 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-01-31 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-01 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-02 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-03 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-04 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-05 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-06 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-07 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-08 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-09 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-10 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-11 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-12 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-13 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-14 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-15 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-16 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-17 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-18 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-19 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-20 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-21 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-22 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-23 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-24 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-25 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-26 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-27 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-02-28 00:00:00', 0.839999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-01 00:00:00', 1.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-02 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-03 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-04 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-05 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-06 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-07 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-08 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-09 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-10 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-11 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-12 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-13 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-14 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-15 00:00:00', 5.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-16 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-17 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-18 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-19 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-20 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-21 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-22 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-23 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-24 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-25 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-26 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-27 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-28 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-29 00:00:00', 3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-30 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-03-31 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-01 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-02 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-03 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-04 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-05 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-06 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-07 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-08 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-09 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-10 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-11 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-12 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-13 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-14 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-15 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-16 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-17 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-18 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-19 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-20 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-21 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-22 00:00:00', 5.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-23 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-24 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-25 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-26 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-27 00:00:00', 1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-28 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-29 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-04-30 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-01 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-02 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-03 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-04 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-05 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-06 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-07 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-08 00:00:00', 2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-09 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-10 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-11 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-12 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-13 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-14 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-15 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-16 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-17 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-18 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-19 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-20 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-21 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-22 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-23 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-24 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-25 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-26 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-27 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-28 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-29 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-30 00:00:00', 0.753000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-01 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-02 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-03 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-04 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-05 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-06 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-07 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-08 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-09 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-10 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-11 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-12 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-13 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-14 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-15 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-16 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-17 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-18 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-19 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-20 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-21 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-22 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-23 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-24 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-25 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-26 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-27 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-28 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-29 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-06-30 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-01 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-02 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-03 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-04 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-05 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-06 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-07 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-08 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-09 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-10 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-11 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-12 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-13 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-14 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-15 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-16 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-17 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-18 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-19 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-20 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-21 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-22 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-23 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-24 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-25 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-26 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-27 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-28 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-29 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-30 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-07-31 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-01 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-02 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-03 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-04 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-05 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-06 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-07 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-08 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-09 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-10 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-11 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-12 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-13 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-14 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-15 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-16 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-17 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-18 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-19 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-20 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-21 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-22 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-23 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-24 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-25 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-26 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-27 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-28 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-29 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-30 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-08-31 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-01 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-02 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-03 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-04 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-05 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-06 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-07 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-08 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-09 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-10 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-11 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-12 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-13 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-14 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-15 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-16 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-17 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-18 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-19 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-20 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-21 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-22 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-23 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-24 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-25 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-26 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-27 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-28 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-29 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-09-30 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-01 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-02 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-03 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-04 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-05 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-06 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-07 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-08 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-09 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-10 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-11 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-12 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-13 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-14 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-15 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-16 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-17 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-18 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-19 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-20 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-21 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-22 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-23 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-24 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-25 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-26 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-27 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-28 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-29 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-30 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-10-31 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-01 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-02 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-03 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-04 00:00:00', 1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-05 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-06 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-07 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-08 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-09 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-10 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-11 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-12 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-13 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-14 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-15 00:00:00', 4.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-16 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-17 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-18 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-19 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-20 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-21 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-22 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-23 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-24 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-25 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-26 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-27 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-28 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-29 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-11-30 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-01 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-02 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-03 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-04 00:00:00', 5.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-05 00:00:00', 5.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-06 00:00:00', 5.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-07 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-08 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-09 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-10 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-11 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-12 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-13 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-14 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-15 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-16 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-17 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-18 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-19 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-20 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-21 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-22 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-23 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-24 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-01 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-02 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-03 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-04 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-05 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-06 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-07 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-08 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-09 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-10 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-11 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-12 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-13 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-14 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-15 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-16 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-17 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-18 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-19 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-20 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-21 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-22 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-23 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-24 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-25 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-26 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-27 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-28 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-29 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-30 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-01-31 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-01 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-02 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-03 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-04 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-05 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-06 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-07 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-08 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-09 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-10 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-11 00:00:00', 4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-12 00:00:00', 5.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-13 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-14 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-15 00:00:00', 3.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-16 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-17 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-18 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-19 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-20 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-21 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-22 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-23 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-24 00:00:00', 0.990000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-25 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-26 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-27 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-02-28 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-01 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-02 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-03 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-04 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-05 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-06 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-07 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-08 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-09 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-10 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-11 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-12 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-13 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-14 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-15 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-16 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-17 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-18 00:00:00', 3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-19 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-20 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-21 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-22 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-23 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-24 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-25 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-26 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-27 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-28 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-29 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-30 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-03-31 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-01 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-02 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-03 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-04 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-05 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-06 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-07 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-08 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-09 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-10 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-11 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-12 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-13 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-14 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-15 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-16 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-17 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-18 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-19 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-20 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-21 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-22 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-23 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-24 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-25 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-26 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-27 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-28 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-29 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-04-30 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-01 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-02 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-03 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-04 00:00:00', 2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-05 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-06 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-07 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-08 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-09 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-10 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-11 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-12 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-13 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-14 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-15 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-16 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-17 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-18 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-19 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-20 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-21 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-22 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-23 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-24 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-25 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-26 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-27 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-28 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-29 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-30 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-05-31 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-01 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-02 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-03 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-04 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-05 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-06 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-07 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-08 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-09 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-10 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-11 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-12 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-13 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-14 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-15 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-16 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-17 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-18 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-19 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-20 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-21 00:00:00', 2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-22 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-23 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-24 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-25 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-26 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-27 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-28 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-29 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-06-30 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-01 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-02 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-03 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-04 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-05 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-06 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-07 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-08 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-09 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-10 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-11 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-12 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-13 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-14 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-15 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-16 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-17 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-18 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-19 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-20 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-21 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-22 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-23 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-24 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-25 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-26 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-27 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-28 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-29 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-30 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-07-31 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-01 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-02 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-03 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-04 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-05 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-06 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-07 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-08 00:00:00', 2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-09 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-10 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-11 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-12 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-13 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-14 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-15 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-16 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-17 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-18 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-19 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-20 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-21 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-22 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-23 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-24 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-25 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-26 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-27 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-28 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-29 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-30 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-08-31 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-01 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-02 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-03 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-04 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-05 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-06 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-07 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-08 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-09 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-10 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-11 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-12 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-13 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-14 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-15 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-16 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-17 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-18 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-19 00:00:00', 1.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-20 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-21 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-22 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-23 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-24 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-25 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-26 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-27 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-28 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-29 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-09-30 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-01 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-02 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-03 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-04 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-05 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-06 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-07 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-08 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-09 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-10 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-11 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-12 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-13 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-14 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-15 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-16 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-17 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-18 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-19 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-20 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-21 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-22 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-23 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-24 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-25 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-26 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-27 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-28 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-29 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-30 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-10-31 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-01 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-02 00:00:00', 1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-03 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-04 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-05 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-06 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-07 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-08 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-09 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-10 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-11 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-12 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-13 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-14 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-15 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-16 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-17 00:00:00', 1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-18 00:00:00', 0.927999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-19 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-20 00:00:00', 0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-21 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-22 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-23 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-24 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-25 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-26 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-27 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-28 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-29 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-11-30 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-01 00:00:00', 1.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-02 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-03 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-04 00:00:00', 1.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-05 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-06 00:00:00', 1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-07 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-08 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-09 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-10 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-11 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-12 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-13 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-14 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-15 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-16 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-17 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-18 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-19 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-20 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-21 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-22 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-23 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-24 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-25 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-26 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-27 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-28 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-29 00:00:00', 5.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-30 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1987-12-31 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-01 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-02 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-03 00:00:00', 4.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-04 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-05 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-06 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-07 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-08 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-09 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-10 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-11 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-12 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-13 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-14 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-15 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-16 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-17 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-18 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-19 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-20 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-21 00:00:00', 3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-22 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-23 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-24 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-25 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-26 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-27 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-28 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-29 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-30 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-01-31 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-01 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-02 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-03 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-04 00:00:00', 5.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-05 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-06 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-07 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-08 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-09 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-10 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-11 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-12 00:00:00', 1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-13 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-14 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-15 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-16 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-17 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-18 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-19 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-20 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-21 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-22 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-23 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-24 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-25 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-26 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-27 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-28 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-02-29 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-01 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-02 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-03 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-04 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-05 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-06 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-07 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-08 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-09 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-10 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-11 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-12 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-13 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-14 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-15 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-16 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-17 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-18 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-19 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-20 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-21 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-22 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-23 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-24 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-25 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-26 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-27 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-28 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-29 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-30 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-03-31 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-01 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-02 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-03 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-04 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-05 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-06 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-07 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-08 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-09 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-10 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-11 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-12 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-13 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-14 00:00:00', 1.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-15 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-16 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-17 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-18 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-19 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-20 00:00:00', 1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-21 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-22 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-23 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-24 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-25 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-26 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-27 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-28 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-29 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-04-30 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-01 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-02 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-03 00:00:00', 4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-04 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-05 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-06 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-07 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-08 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-09 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-10 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-11 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-12 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-13 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-14 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-15 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-16 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-17 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-18 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-19 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-20 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-21 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-22 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-23 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-24 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-25 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-26 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-27 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-28 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-29 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-30 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-05-31 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-01 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-02 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-03 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-04 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-05 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-06 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-07 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-08 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-09 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-10 00:00:00', 1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-11 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-12 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-13 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-14 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-15 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-16 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-17 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-18 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-19 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-20 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-21 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-22 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-23 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-24 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-25 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-26 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-27 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-28 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-29 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-06-30 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-01 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-02 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-03 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-04 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-05 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-06 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-07 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-08 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-09 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-10 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-11 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-12 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-13 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-14 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-15 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-16 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-17 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-18 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-19 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-20 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-21 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-22 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-23 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-24 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-25 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-26 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-27 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-28 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-29 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-30 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-07-31 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-01 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-02 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-03 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-04 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-05 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-06 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-07 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-08 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-09 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-10 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-11 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-12 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-13 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-14 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-15 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-16 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-17 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-18 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-19 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-20 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-21 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-22 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-23 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-24 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-25 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-26 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-27 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-28 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-29 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-30 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-08-31 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-01 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-02 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-03 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-04 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-05 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-06 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-07 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-08 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-09 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-10 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-11 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-12 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-13 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-14 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-15 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-16 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-17 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-18 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-19 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-20 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-21 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-22 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-23 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-24 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-25 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-26 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-27 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-28 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-29 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-09-30 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-01 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-02 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-03 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-04 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-05 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-06 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-07 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-08 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-09 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-10 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-11 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-12 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-13 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-14 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-15 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-16 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-17 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-18 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-19 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-20 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-21 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-22 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-23 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-24 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-25 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-26 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-27 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-28 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-29 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-30 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-10-31 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-01 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-02 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-03 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-04 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-05 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-06 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-07 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-08 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-09 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-10 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-11 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-12 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-13 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-14 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-15 00:00:00', 4.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-16 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-17 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-18 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-19 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-20 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-21 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-22 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-23 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-24 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-25 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-26 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-27 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-28 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-29 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-11-30 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-01 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-02 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-03 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-04 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-05 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-06 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-07 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-08 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-09 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-10 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-11 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-12 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-13 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-14 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-15 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-16 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-17 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-18 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-19 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-20 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-21 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-22 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-23 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-24 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-25 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-26 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-27 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-28 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-29 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-30 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1988-12-31 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-01 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-02 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-03 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-04 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-05 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-06 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-07 00:00:00', 4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-08 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-09 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-10 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-11 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-12 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-13 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-14 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-15 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-16 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-17 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-18 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-19 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-20 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-21 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-22 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-23 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-24 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-25 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-26 00:00:00', 4.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-27 00:00:00', 4.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-28 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-29 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-30 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-01-31 00:00:00', 4.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-01 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-02 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-03 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-04 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-05 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-06 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-07 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-08 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-09 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-10 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-11 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-12 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-13 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-14 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-15 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-16 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-17 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-18 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-19 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-20 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-21 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-22 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-23 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-24 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-25 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-26 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-27 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-02-28 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-01 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-02 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-03 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-04 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-05 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-06 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-07 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-08 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-09 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-10 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-11 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-12 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-13 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-14 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-15 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-16 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-17 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-18 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-19 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-20 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-21 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-22 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-23 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-24 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-25 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-26 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-27 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-28 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-29 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-30 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-03-31 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-01 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-02 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-03 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-04 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-05 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-06 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-07 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-08 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-09 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-10 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-11 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-12 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-13 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-14 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-15 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-16 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-17 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-18 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-19 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-20 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-21 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-22 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-23 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-24 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-25 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-26 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-27 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-28 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-29 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-04-30 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-01 00:00:00', 4.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-02 00:00:00', 4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-03 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-04 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-05 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-06 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-07 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-08 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-09 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-10 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-11 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-12 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-13 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-14 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-15 00:00:00', 1.05799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-16 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-17 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-18 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-19 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-20 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-21 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-22 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-23 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-24 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-25 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-26 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-27 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-28 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-29 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-30 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-05-31 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-01 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-02 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-03 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-04 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-05 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-06 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-07 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-08 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-09 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-10 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-11 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-12 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-13 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-14 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-15 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-16 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-17 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-18 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-19 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-20 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-21 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-22 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-23 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-24 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-25 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-26 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-27 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-28 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-29 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-06-30 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-01 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-02 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-03 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-04 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-05 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-06 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-07 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-08 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-09 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-10 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-11 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-12 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-13 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-14 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-15 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-16 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-17 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-18 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-19 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-20 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-21 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-22 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-23 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-24 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-25 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-26 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-27 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-28 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-29 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-30 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-07-31 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-01 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-02 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-03 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-04 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-05 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-06 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-07 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-08 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-09 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-10 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-11 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-12 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-13 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-14 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-15 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-16 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-17 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-18 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-19 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-20 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-21 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-22 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-23 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-24 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-25 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-26 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-27 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-28 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-29 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-30 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-08-31 00:00:00', 1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-01 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-02 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-03 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-04 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-05 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-06 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-07 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-08 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-09 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-10 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-11 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-12 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-13 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-14 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-15 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-16 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-17 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-18 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-19 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-20 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-21 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-22 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-23 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-24 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-25 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-26 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-27 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-28 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-29 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-09-30 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-01 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-02 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-03 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-04 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-05 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-06 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-07 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-08 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-09 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-10 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-11 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-12 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-13 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-14 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-15 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-16 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-17 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-18 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-19 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-20 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-21 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-22 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-23 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-24 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-25 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-26 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-27 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-28 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-29 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-30 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-10-31 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-01 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-02 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-03 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-04 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-05 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-06 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-07 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-08 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-09 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-10 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-11 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-12 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-13 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-14 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-15 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-16 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-17 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-18 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-19 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-20 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-21 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-22 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-23 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-24 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-25 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-26 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-27 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-28 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-29 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-11-30 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-01 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-02 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-03 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-04 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-05 00:00:00', 3.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-06 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-07 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-08 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-09 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-10 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-11 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-12 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-13 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-14 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-15 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-16 00:00:00', 3.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-17 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-18 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-19 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-20 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-21 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-22 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-23 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-24 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-25 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-26 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-27 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-28 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-29 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-30 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1989-12-31 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-01 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-02 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-03 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-04 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-05 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-06 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-07 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-08 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-09 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-10 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-11 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-12 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-13 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-14 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-15 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-16 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-17 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-18 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-19 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-20 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-21 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-22 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-23 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-24 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-25 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-26 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-27 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-28 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-29 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-30 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-01-31 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-01 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-02 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-03 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-04 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-05 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-06 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-07 00:00:00', 3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-08 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-09 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-10 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-11 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-12 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-13 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-14 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-15 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-16 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-17 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-18 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-19 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-20 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-21 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-22 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-23 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-24 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-25 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-26 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-27 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-02-28 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-01 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-02 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-03 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-04 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-05 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-06 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-07 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-08 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-09 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-10 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-11 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-12 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-13 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-14 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-15 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-16 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-17 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-18 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-19 00:00:00', 3.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-20 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-21 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-22 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-23 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-24 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-25 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-26 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-27 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-28 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-29 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-30 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-03-31 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-01 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-02 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-03 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-04 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-05 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-06 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-07 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-08 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-09 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-10 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-11 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-12 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-13 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-14 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-15 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-16 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-17 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-18 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-19 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-20 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-21 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-22 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-23 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-24 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-25 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-26 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-27 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-28 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-29 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-04-30 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-01 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-02 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-03 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-04 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-05 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-06 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-07 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-08 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-09 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-10 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-11 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-12 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-13 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-14 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-15 00:00:00', 1.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-16 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-17 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-18 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-19 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-20 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-21 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-22 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-23 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-24 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-25 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-26 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-27 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-28 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-29 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-30 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-05-31 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-01 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-02 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-03 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-04 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-05 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-06 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-07 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-08 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-09 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-10 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-11 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-12 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-13 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-14 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-15 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-16 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-17 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-18 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-19 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-20 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-21 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-22 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-23 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-24 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-25 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-26 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-27 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-28 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-29 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-06-30 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-01 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-02 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-03 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-04 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-05 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-06 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-07 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-08 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-09 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-10 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-11 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-12 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-13 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-14 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-15 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-16 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-17 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-18 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-19 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-20 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-21 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-22 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-23 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-24 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-25 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-26 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-27 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-28 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-29 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-30 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-07-31 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-01 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-02 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-03 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-04 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-05 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-06 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-07 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-08 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-09 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-10 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-11 00:00:00', 3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-12 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-13 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-14 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-15 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-16 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-17 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-18 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-19 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-20 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-21 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-22 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-23 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-24 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-25 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-26 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-27 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-28 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-29 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-30 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-08-31 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-01 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-02 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-03 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-04 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-05 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-06 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-07 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-08 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-09 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-10 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-11 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-12 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-13 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-14 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-15 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-16 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-17 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-18 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-19 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-20 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-21 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-22 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-23 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-24 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-25 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-26 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-27 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-28 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-29 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-09-30 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-01 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-02 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-03 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-04 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-05 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-06 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-07 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-08 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-09 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-10 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-11 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-12 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-13 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-14 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-15 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-16 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-17 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-18 00:00:00', 3.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-19 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-20 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-21 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-22 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-23 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-24 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-25 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-26 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-27 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-28 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-29 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-30 00:00:00', 3.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-10-31 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-01 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-02 00:00:00', 5.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-03 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-04 00:00:00', 1.07400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-05 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-06 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-07 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-08 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-09 00:00:00', 1.12699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-10 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-11 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-12 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-13 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-14 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-15 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-16 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-17 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-18 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-19 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-20 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-21 00:00:00', 1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-22 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-23 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-24 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-25 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-26 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-27 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-28 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-29 00:00:00', 1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-11-30 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-01 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-02 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-03 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-04 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-05 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-06 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-07 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-08 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-09 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-10 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-11 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-12 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-13 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-14 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-15 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-16 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-17 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-18 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-19 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-20 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-21 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-22 00:00:00', 4.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-23 00:00:00', 4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-24 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-25 00:00:00', 4.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-26 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-27 00:00:00', 4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-28 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-29 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-30 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1990-12-31 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-01 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-02 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-03 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-04 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-05 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-06 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-07 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-08 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-09 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-10 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-11 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-12 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-13 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-14 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-15 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-16 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-17 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-18 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-19 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-20 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-21 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-22 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-23 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-24 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-25 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-26 00:00:00', 4.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-27 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-28 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-29 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-30 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-01-31 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-01 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-02 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-03 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-04 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-05 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-06 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-07 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-08 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-09 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-10 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-11 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-12 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-13 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-14 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-15 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-16 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-17 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-18 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-19 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-20 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-21 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-22 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-23 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-24 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-25 00:00:00', 3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-26 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-27 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-02-28 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-01 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-02 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-03 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-04 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-05 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-06 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-07 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-08 00:00:00', 5.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-09 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-10 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-11 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-12 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-13 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-14 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-15 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-16 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-17 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-18 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-19 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-20 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-21 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-22 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-23 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-24 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-25 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-26 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-27 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-28 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-29 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-30 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-03-31 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-01 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-02 00:00:00', 1.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-03 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-04 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-05 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-06 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-07 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-08 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-09 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-10 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-11 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-12 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-13 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-14 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-15 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-16 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-17 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-18 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-19 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-20 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-21 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-22 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-23 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-24 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-25 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-26 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-27 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-28 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-29 00:00:00', 0.981000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-04-30 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-01 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-02 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-03 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-04 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-05 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-06 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-07 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-08 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-09 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-10 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-11 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-12 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-13 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-14 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-15 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-16 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-17 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-18 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-19 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-20 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-21 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-22 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-23 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-24 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-25 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-26 00:00:00', 2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-27 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-28 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-29 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-30 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-05-31 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-01 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-02 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-03 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-04 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-05 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-06 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-07 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-08 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-09 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-10 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-11 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-12 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-13 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-14 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-15 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-16 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-17 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-18 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-19 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-20 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-21 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-22 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-23 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-24 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-25 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-26 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-27 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-28 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-29 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-06-30 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-01 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-02 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-03 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-04 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-05 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-06 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-07 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-08 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-09 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-10 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-11 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-12 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-13 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-14 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-15 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-16 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-17 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-18 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-19 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-20 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-21 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-22 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-23 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-24 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-25 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-26 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-27 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-28 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-29 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-30 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-07-31 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-01 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-02 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-03 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-04 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-05 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-06 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-07 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-08 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-09 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-10 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-11 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-12 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-13 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-14 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-15 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-16 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-17 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-18 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-19 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-20 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-21 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-22 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-23 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-24 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-25 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-26 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-27 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-28 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-29 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-30 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-08-31 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-01 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-02 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-03 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-04 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-05 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-06 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-07 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-08 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-09 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-10 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-11 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-12 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-13 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-14 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-15 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-16 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-17 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-18 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-19 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-20 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-21 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-22 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-23 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-24 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-25 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-26 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-27 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-28 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-29 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-09-30 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-01 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-02 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-03 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-04 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-05 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-06 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-07 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-08 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-09 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-10 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-11 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-12 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-13 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-14 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-15 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-16 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-17 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-18 00:00:00', 0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-19 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-20 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-21 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-22 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-23 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-24 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-25 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-26 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-27 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-28 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-29 00:00:00', 0.908999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-30 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-10-31 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-01 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-02 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-03 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-04 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-05 00:00:00', 1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-06 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-07 00:00:00', 0.873000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-08 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-09 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-10 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-11 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-12 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-13 00:00:00', 1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-14 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-15 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-16 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-17 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-18 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-19 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-20 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-21 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-22 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-23 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-24 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-25 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-26 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-27 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-28 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-29 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-11-30 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-01 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-02 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-03 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-04 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-05 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-06 00:00:00', 3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-07 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-08 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-09 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-10 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-11 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-12 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-13 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-14 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-15 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-16 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-17 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-18 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-19 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-20 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-21 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-22 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-23 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-24 00:00:00', 1.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-25 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-26 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-27 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-28 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-29 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-30 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1991-12-31 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-01 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-02 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-03 00:00:00', 3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-04 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-05 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-06 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-07 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-08 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-09 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-10 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-11 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-12 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-13 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-14 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-15 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-16 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-17 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-18 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-19 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-20 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-21 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-22 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-23 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-24 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-25 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-26 00:00:00', 4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-27 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-28 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-29 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-30 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-01-31 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-01 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-02 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-03 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-04 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-05 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-06 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-07 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-08 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-09 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-10 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-11 00:00:00', 3.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-12 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-13 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-14 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-15 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-16 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-17 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-18 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-19 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-20 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-21 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-22 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-23 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-24 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-25 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-26 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-27 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-28 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-02-29 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-01 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-02 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-03 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-04 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-05 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-06 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-07 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-08 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-09 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-10 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-11 00:00:00', 4.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-12 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-13 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-14 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-15 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-16 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-17 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-18 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-19 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-20 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-21 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-22 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-23 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-24 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-25 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-26 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-27 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-28 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-29 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-30 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-03-31 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-01 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-02 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-03 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-04 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-05 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-06 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-07 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-08 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-09 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-10 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-11 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-12 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-13 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-14 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-15 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-16 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-17 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-18 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-19 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-20 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-21 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-22 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-23 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-24 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-25 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-26 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-27 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-28 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-29 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-04-30 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-01 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-02 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-03 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-04 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-05 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-06 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-07 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-08 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-09 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-10 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-11 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-12 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-13 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-14 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-15 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-16 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-17 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-18 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-19 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-20 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-21 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-22 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-23 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-24 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-25 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-26 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-27 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-28 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-29 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-30 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-05-31 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-01 00:00:00', 1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-02 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-03 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-04 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-05 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-06 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-07 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-08 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-09 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-10 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-11 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-12 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-13 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-14 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-15 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-16 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-17 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-18 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-19 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-20 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-21 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-22 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-23 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-24 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-25 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-26 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-27 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-28 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-29 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-06-30 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-01 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-02 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-03 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-04 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-05 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-06 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-07 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-08 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-09 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-10 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-11 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-12 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-13 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-14 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-15 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-16 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-17 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-18 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-19 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-20 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-21 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-22 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-23 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-24 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-25 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-26 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-27 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-28 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-29 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-30 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-07-31 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-01 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-02 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-03 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-04 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-05 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-06 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-07 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-08 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-09 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-10 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-11 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-12 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-13 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-14 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-15 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-16 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-17 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-18 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-19 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-20 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-21 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-22 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-23 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-24 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-25 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-26 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-27 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-28 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-29 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-30 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-08-31 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-01 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-02 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-03 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-04 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-05 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-06 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-07 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-08 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-09 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-10 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-11 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-12 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-13 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-14 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-15 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-16 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-17 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-18 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-19 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-20 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-21 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-22 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-23 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-24 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-25 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-26 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-27 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-28 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-29 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-09-30 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-01 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-02 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-03 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-04 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-05 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-06 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-07 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-08 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-09 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-10 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-11 00:00:00', 1.17200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-12 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-13 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-14 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-15 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-16 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-17 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-18 00:00:00', 1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-19 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-20 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-21 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-22 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-23 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-24 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-25 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-26 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-27 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-28 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-29 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-30 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-10-31 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-01 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-02 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-03 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-04 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-05 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-06 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-07 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-08 00:00:00', 1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-09 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-10 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-11 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-12 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-13 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-14 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-15 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-16 00:00:00', 0.953000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-17 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-18 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-19 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-20 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-21 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-22 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-23 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-24 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-25 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-26 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-27 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-28 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-29 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-11-30 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-01 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-02 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-03 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-04 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-05 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-06 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-07 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-08 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-09 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-10 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-11 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-12 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-13 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-14 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-15 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-16 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-17 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-18 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-19 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-20 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-21 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-22 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-23 00:00:00', 3.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-24 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-25 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-26 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-27 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-28 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-29 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-30 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1992-12-31 00:00:00', 4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-01 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-02 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-03 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-04 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-05 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-06 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-07 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-08 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-09 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-10 00:00:00', 5.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-11 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-12 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-13 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-14 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-15 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-16 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-17 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-18 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-19 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-20 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-21 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-22 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-23 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-24 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-25 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-26 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-27 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-28 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-29 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-30 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-01-31 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-01 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-02 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-03 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-04 00:00:00', 3.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-05 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-06 00:00:00', 4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-07 00:00:00', 4.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-08 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-09 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-10 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-11 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-12 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-13 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-14 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-15 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-16 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-17 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-18 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-19 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-20 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-21 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-22 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-23 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-24 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-25 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-26 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-27 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-02-28 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-01 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-02 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-03 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-04 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-05 00:00:00', 3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-06 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-07 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-08 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-09 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-10 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-11 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-12 00:00:00', 4.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-13 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-14 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-15 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-16 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-17 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-18 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-19 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-20 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-21 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-22 00:00:00', 3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-23 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-24 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-25 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-26 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-27 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-28 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-29 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-30 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-03-31 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-01 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-02 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-03 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-04 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-05 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-06 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-07 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-08 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-09 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-10 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-11 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-12 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-13 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-14 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-15 00:00:00', 5.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-16 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-17 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-18 00:00:00', 1.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-19 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-20 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-21 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-22 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-23 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-24 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-25 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-26 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-27 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-28 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-29 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-04-30 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-01 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-02 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-03 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-04 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-05 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-06 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-07 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-08 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-09 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-10 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-11 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-12 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-13 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-14 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-15 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-16 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-17 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-18 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-19 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-20 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-21 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-22 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-23 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-24 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-25 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-26 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-27 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-28 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-29 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-30 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-05-31 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-01 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-02 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-03 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-04 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-05 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-06 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-07 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-08 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-09 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-10 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-11 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-12 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-13 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-14 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-15 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-16 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-17 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-18 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-19 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-20 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-21 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-22 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-23 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-24 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-25 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-26 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-27 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-28 00:00:00', 1.04100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-29 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-06-30 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-01 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-02 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-03 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-04 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-05 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-06 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-07 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-08 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-09 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-10 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-11 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-12 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-13 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-14 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-15 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-16 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-17 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-18 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-19 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-20 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-21 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-22 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-23 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-24 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-25 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-26 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-27 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-28 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-29 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-30 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-07-31 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-01 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-02 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-03 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-04 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-05 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-06 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-07 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-08 00:00:00', 1.74500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-09 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-10 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-11 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-12 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-13 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-14 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-15 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-16 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-17 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-18 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-19 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-20 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-21 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-22 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-23 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-24 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-25 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-26 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-27 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-28 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-29 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-30 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-08-31 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-01 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-02 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-03 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-04 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-05 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-06 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-07 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-08 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-09 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-10 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-11 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-12 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-13 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-14 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-15 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-16 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-17 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-18 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-19 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-20 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-21 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-22 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-23 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-24 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-25 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-26 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-27 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-28 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-29 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-09-30 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-01 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-02 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-03 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-04 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-05 00:00:00', 3.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-06 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-07 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-08 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-09 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-10 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-11 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-12 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-13 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-14 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-15 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-16 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-17 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-18 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-19 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-20 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-21 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-22 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-23 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-24 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-25 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-26 00:00:00', 1.28199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-27 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-28 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-29 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-30 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-10-31 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-01 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-02 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-03 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-04 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-05 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-06 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-07 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-08 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-09 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-10 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-11 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-12 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-13 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-14 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-15 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-16 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-17 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-18 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-19 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-20 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-21 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-22 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-23 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-24 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-25 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-26 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-27 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-28 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-29 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-11-30 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-01 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-02 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-03 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-04 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-05 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-06 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-07 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-08 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-09 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-10 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-11 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-12 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-13 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-14 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-15 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-16 00:00:00', 0.846000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-17 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-18 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-19 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-20 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-21 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-22 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-23 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-24 00:00:00', 1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-25 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-26 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-27 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-28 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-29 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-30 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1993-12-31 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-01 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-02 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-03 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-04 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-05 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-06 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-07 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-08 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-09 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-10 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-11 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-12 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-13 00:00:00', 0.887000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-14 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-15 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-16 00:00:00', 1.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-17 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-18 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-19 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-20 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-21 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-22 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-23 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-24 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-25 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-26 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-27 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-28 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-29 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-30 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-01-31 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-01 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-02 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-03 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-04 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-05 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-06 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-07 00:00:00', 3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-08 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-09 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-10 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-11 00:00:00', 3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-12 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-13 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-14 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-15 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-16 00:00:00', 4.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-17 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-18 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-19 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-20 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-21 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-22 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-23 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-24 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-25 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-26 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-27 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-02-28 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-01 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-02 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-03 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-04 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-05 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-06 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-07 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-08 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-09 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-10 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-11 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-12 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-13 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-14 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-15 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-16 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-17 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-18 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-19 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-20 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-21 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-22 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-23 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-24 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-25 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-26 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-27 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-28 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-29 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-30 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-03-31 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-01 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-02 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-03 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-04 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-05 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-06 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-07 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-08 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-09 00:00:00', 3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-10 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-11 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-12 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-13 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-14 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-15 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-16 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-17 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-18 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-19 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-20 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-21 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-22 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-23 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-24 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-25 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-26 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-27 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-28 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-29 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-04-30 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-01 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-02 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-03 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-04 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-05 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-06 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-07 00:00:00', 1.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-08 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-09 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-10 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-11 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-12 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-13 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-14 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-15 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-16 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-17 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-18 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-19 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-20 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-21 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-22 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-23 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-24 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-25 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-26 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-27 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-28 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-29 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-30 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-05-31 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-01 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-02 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-03 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-04 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-05 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-06 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-07 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-08 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-09 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-10 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-11 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-12 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-13 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-14 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-15 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-16 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-17 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-18 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-19 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-20 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-21 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-22 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-23 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-24 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-25 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-26 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-27 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-28 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-29 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-06-30 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-01 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-02 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-03 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-04 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-05 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-06 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-07 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-08 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-09 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-10 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-11 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-12 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-13 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-14 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-15 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-16 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-17 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-18 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-19 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-20 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-21 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-22 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-23 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-24 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-25 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-26 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-27 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-28 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-29 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-30 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-07-31 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-01 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-02 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-03 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-04 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-05 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-06 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-07 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-08 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-09 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-10 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-11 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-12 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-13 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-14 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-15 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-16 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-17 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-18 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-19 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-20 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-21 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-22 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-23 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-24 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-25 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-26 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-27 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-28 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-29 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-30 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-08-31 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-01 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-02 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-03 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-04 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-05 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-06 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-07 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-08 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-09 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-10 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-11 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-12 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-13 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-14 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-15 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-16 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-17 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-18 00:00:00', 3.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-19 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-20 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-21 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-22 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-23 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-24 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-25 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-26 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-27 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-28 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-29 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-09-30 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-01 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-02 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-03 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-04 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-05 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-06 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-07 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-08 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-09 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-10 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-11 00:00:00', 1.14900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-12 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-13 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-14 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-15 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-16 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-17 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-18 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-19 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-20 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-21 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-22 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-23 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-24 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-25 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-26 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-27 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-28 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-29 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-30 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-10-31 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-01 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-02 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-03 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-04 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-05 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-06 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-07 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-08 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-09 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-10 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-11 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-12 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-13 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-14 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-15 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-16 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-17 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-18 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-19 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-20 00:00:00', 1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-21 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-22 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-23 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-24 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-25 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-26 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-27 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-28 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-29 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-11-30 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-01 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-02 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-03 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-04 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-05 00:00:00', 5.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-06 00:00:00', 4.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-07 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-08 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-09 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-10 00:00:00', 1.20599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-11 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-12 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-13 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-14 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-15 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-16 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-17 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-18 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-19 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-20 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-21 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-22 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-23 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-24 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-25 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-26 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-27 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-28 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-29 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-30 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1994-12-31 00:00:00', 0.962000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-01 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-02 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-03 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-04 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-05 00:00:00', 1.32799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-06 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-07 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-08 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-09 00:00:00', 0.827000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-10 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-11 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-12 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-13 00:00:00', 2.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-14 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-15 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-16 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-17 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-18 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-19 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-20 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-21 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-22 00:00:00', 0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-23 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-24 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-25 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-26 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-27 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-28 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-29 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-30 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-01-31 00:00:00', 1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-01 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-02 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-03 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-04 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-05 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-06 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-07 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-08 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-09 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-10 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-11 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-12 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-13 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-14 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-15 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-16 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-17 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-18 00:00:00', 3.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-19 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-20 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-21 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-22 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-23 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-24 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-25 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-26 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-27 00:00:00', 2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-02-28 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-01 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-02 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-03 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-04 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-05 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-06 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-07 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-08 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-09 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-10 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-11 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-12 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-13 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-14 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-15 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-16 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-17 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-18 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-19 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-20 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-21 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-22 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-23 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-24 00:00:00', 2.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-25 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-26 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-27 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-28 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-29 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-30 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-03-31 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-01 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-02 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-03 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-04 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-05 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-06 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-07 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-08 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-09 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-10 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-11 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-12 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-13 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-14 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-15 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-16 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-17 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-18 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-19 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-20 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-21 00:00:00', 1.2489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-22 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-23 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-24 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-25 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-26 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-27 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-28 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-29 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-04-30 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-01 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-02 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-03 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-04 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-05 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-06 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-07 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-08 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-09 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-10 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-11 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-12 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-13 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-14 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-15 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-16 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-17 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-18 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-19 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-20 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-21 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-22 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-23 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-24 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-25 00:00:00', 3.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-26 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-27 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-28 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-29 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-30 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-05-31 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-01 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-02 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-03 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-04 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-05 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-06 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-07 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-08 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-09 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-10 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-11 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-12 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-13 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-14 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-15 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-16 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-17 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-18 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-19 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-20 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-21 00:00:00', 1.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-22 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-23 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-24 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-25 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-26 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-27 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-28 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-29 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-06-30 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-01 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-02 00:00:00', 5.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-03 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-04 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-05 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-06 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-07 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-08 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-09 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-10 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-11 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-12 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-13 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-14 00:00:00', 3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-15 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-16 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-17 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-18 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-19 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-20 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-21 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-22 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-23 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-24 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-25 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-26 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-27 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-28 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-29 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-30 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-07-31 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-01 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-02 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-03 00:00:00', 2.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-04 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-05 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-06 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-07 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-08 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-09 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-10 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-11 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-12 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-13 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-14 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-15 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-16 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-17 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-18 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-19 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-20 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-21 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-22 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-23 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-24 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-25 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-26 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-27 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-28 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-29 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-30 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-08-31 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-01 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-02 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-03 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-04 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-05 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-06 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-07 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-08 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-09 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-10 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-11 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-12 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-13 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-14 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-15 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-16 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-17 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-18 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-19 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-20 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-21 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-22 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-23 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-24 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-25 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-26 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-27 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-28 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-29 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-09-30 00:00:00', 1.10399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-01 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-02 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-03 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-04 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-05 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-06 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-07 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-08 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-09 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-10 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-11 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-12 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-13 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-14 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-15 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-16 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-17 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-18 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-19 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-20 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-21 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-22 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-23 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-24 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-25 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-26 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-27 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-28 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-29 00:00:00', 0.745999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-30 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-10-31 00:00:00', 0.670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-01 00:00:00', 0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-02 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-03 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-04 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-05 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-06 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-07 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-08 00:00:00', 1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-09 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-10 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-11 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-12 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-13 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-14 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-15 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-16 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-17 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-18 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-19 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-20 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-21 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-22 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-23 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-24 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-25 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-26 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-27 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-28 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-29 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-11-30 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-01 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-02 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-03 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-04 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-05 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-06 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-07 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-08 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-09 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-10 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-11 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-12 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-13 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-14 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-15 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-16 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-17 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-18 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-19 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-20 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-21 00:00:00', 1.27100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-22 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-23 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-24 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-25 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-26 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-27 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-28 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-29 00:00:00', 0.839999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-30 00:00:00', 0.927999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1995-12-31 00:00:00', 0.861000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-01 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-02 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-03 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-04 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-05 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-06 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-07 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-08 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-09 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-10 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-11 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-12 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-13 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-14 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-15 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-16 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-17 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-18 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-19 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-20 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-21 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-22 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-23 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-24 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-25 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-26 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-27 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-28 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-29 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-30 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-01-31 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-01 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-02 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-03 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-04 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-05 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-06 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-07 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-08 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-09 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-10 00:00:00', 3.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-11 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-12 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-13 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-14 00:00:00', 4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-15 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-16 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-17 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-18 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-19 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-20 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-21 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-22 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-23 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-24 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-25 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-26 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-27 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-28 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-02-29 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-01 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-02 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-03 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-04 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-05 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-06 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-07 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-08 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-09 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-10 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-11 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-12 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-13 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-14 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-15 00:00:00', 4.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-16 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-17 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-18 00:00:00', 3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-19 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-20 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-21 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-22 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-23 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-24 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-25 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-26 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-27 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-28 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-29 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-30 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-03-31 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-01 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-02 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-03 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-04 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-05 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-06 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-07 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-08 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-09 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-10 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-11 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-12 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-13 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-14 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-15 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-16 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-17 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-18 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-19 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-20 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-21 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-22 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-23 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-24 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-25 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-26 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-27 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-28 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-29 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-04-30 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-01 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-02 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-03 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-04 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-05 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-06 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-07 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-08 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-09 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-10 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-11 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-12 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-13 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-14 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-15 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-16 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-17 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-18 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-19 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-20 00:00:00', 1.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-21 00:00:00', 1.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-22 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-23 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-24 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-25 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-26 00:00:00', 1.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-27 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-28 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-29 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-30 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-05-31 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-01 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-02 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-03 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-04 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-05 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-06 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-07 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-08 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-09 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-10 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-11 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-12 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-13 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-14 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-15 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-16 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-17 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-18 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-19 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-20 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-21 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-22 00:00:00', 3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-23 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-24 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-25 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-26 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-27 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-28 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-29 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-06-30 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-01 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-02 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-03 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-04 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-05 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-06 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-07 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-08 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-09 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-10 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-11 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-12 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-13 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-14 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-15 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-16 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-17 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-18 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-19 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-20 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-21 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-22 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-23 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-24 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-25 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-26 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-27 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-28 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-29 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-30 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-07-31 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-01 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-02 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-03 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-04 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-05 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-06 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-07 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-08 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-09 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-10 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-11 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-12 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-13 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-14 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-15 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-16 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-17 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-18 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-19 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-20 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-21 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-22 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-23 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-24 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-25 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-26 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-27 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-28 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-29 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-30 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-08-31 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-01 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-02 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-03 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-04 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-05 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-06 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-07 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-08 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-09 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-10 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-11 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-12 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-13 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-14 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-15 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-16 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-17 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-18 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-19 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-20 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-21 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-22 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-23 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-24 00:00:00', 3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-25 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-26 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-27 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-28 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-29 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-09-30 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-01 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-02 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-03 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-04 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-05 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-06 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-07 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-08 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-09 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-10 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-11 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-12 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-13 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-14 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-15 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-16 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-17 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-18 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-19 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-20 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-21 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-22 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-23 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-24 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-25 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-26 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-27 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-28 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-29 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-30 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-10-31 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-01 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-02 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-03 00:00:00', 0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-04 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-05 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-06 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-07 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-08 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-09 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-10 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-11 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-12 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-13 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-14 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-15 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-16 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-17 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-18 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-19 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-20 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-21 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-22 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-23 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-24 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-25 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-26 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-27 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-28 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-29 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-11-30 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-01 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-02 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-03 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-04 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-05 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-06 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-07 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-08 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-09 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-10 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-11 00:00:00', 1.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-12 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-13 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-14 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-15 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-16 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-17 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-18 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-19 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-20 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-21 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-22 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-23 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-24 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-25 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-26 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-27 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-28 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-29 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-30 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1996-12-31 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-01 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-02 00:00:00', 0.994000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-03 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-04 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-05 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-06 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-07 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-08 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-09 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-10 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-11 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-12 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-13 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-14 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-15 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-16 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-17 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-18 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-19 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-20 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-21 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-22 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-23 00:00:00', 3.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-24 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-25 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-26 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-27 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-28 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-29 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-30 00:00:00', 3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-01-31 00:00:00', 3.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-01 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-02 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-03 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-04 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-05 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-06 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-07 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-08 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-09 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-10 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-11 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-12 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-13 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-14 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-15 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-16 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-17 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-18 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-19 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-20 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-21 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-22 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-23 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-24 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-25 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-26 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-27 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-02-28 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-01 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-02 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-03 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-04 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-05 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-06 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-07 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-08 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-09 00:00:00', 5.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-10 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-11 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-12 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-13 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-14 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-15 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-16 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-17 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-18 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-19 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-20 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-21 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-22 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-23 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-24 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-25 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-26 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-27 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-28 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-29 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-30 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-03-31 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-01 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-02 00:00:00', 3.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-03 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-04 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-05 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-06 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-07 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-08 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-09 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-10 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-11 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-12 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-13 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-14 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-15 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-16 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-17 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-18 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-19 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-20 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-21 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-22 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-23 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-24 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-25 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-26 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-27 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-28 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-29 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-04-30 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-01 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-02 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-03 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-04 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-05 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-06 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-07 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-08 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-09 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-10 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-11 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-12 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-13 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-14 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-15 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-16 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-17 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-18 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-19 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-20 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-21 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-22 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-23 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-24 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-25 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-26 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-27 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-28 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-29 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-30 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-05-31 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-01 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-02 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-03 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-04 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-05 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-06 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-07 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-08 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-09 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-10 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-11 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-12 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-13 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-14 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-15 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-16 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-17 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-18 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-19 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-20 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-21 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-22 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-23 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-24 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-25 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-26 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-27 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-28 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-29 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-06-30 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-01 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-02 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-03 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-04 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-05 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-06 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-07 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-08 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-09 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-10 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-11 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-12 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-13 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-14 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-15 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-16 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-17 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-18 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-19 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-20 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-21 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-22 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-23 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-24 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-25 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-26 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-27 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-28 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-29 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-30 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-07-31 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-01 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-02 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-03 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-04 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-05 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-06 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-07 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-08 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-09 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-10 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-11 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-12 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-13 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-14 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-15 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-16 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-17 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-18 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-19 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-20 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-21 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-22 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-23 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-24 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-25 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-26 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-27 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-28 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-29 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-30 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-08-31 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-01 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-02 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-03 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-04 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-05 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-06 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-07 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-08 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-09 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-10 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-11 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-12 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-13 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-14 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-15 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-16 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-17 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-18 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-19 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-20 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-21 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-22 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-23 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-24 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-25 00:00:00', 2.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-26 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-27 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-28 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-29 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-09-30 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-01 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-02 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-03 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-04 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-05 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-06 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-07 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-08 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-09 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-10 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-11 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-12 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-13 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-14 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-15 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-16 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-17 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-18 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-19 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-20 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-21 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-22 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-23 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-24 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-25 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-26 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-27 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-28 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-29 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-30 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-10-31 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-01 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-02 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-03 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-04 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-05 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-06 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-07 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-08 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-09 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-10 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-11 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-12 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-13 00:00:00', 1.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-14 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-15 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-16 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-17 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-18 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-19 00:00:00', 1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-20 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-21 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-22 00:00:00', 1.10000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-23 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-24 00:00:00', 3.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-25 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-26 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-27 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-28 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-29 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-11-30 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-01 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-02 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-03 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-04 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-05 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-06 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-07 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-08 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-09 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-10 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-11 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-12 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-13 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-14 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-15 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-16 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-17 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-18 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-19 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-20 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-21 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-22 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-23 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-24 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-25 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-26 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-27 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-28 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-29 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-30 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1997-12-31 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-01 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-02 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-03 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-04 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-05 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-06 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-07 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-08 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-09 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-10 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-11 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-12 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-13 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-14 00:00:00', 5.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-15 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-16 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-17 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-18 00:00:00', 3.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-19 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-20 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-21 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-22 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-23 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-24 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-25 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-26 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-27 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-28 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-29 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-30 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-01-31 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-01 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-02 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-03 00:00:00', 2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-04 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-05 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-06 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-07 00:00:00', 2.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-08 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-09 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-10 00:00:00', 5.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-11 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-12 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-13 00:00:00', 4.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-14 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-15 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-16 00:00:00', 5.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-17 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-18 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-19 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-20 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-21 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-22 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-23 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-24 00:00:00', 0.940999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-25 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-26 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-27 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-02-28 00:00:00', 4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-01 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-02 00:00:00', 5.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-03 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-04 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-05 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-06 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-07 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-08 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-09 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-10 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-11 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-12 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-13 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-14 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-15 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-16 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-17 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-18 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-19 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-20 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-21 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-22 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-23 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-24 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-25 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-26 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-27 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-28 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-29 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-30 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-03-31 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-01 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-02 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-03 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-04 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-05 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-06 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-07 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-08 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-09 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-10 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-11 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-12 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-13 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-14 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-15 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-16 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-17 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-18 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-19 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-20 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-21 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-22 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-23 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-24 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-25 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-26 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-27 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-28 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-29 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-04-30 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-01 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-02 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-03 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-04 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-05 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-06 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-07 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-08 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-09 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-10 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-11 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-12 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-13 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-14 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-15 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-16 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-17 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-18 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-19 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-20 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-21 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-22 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-23 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-24 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-25 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-26 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-27 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-28 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-29 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-30 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-05-31 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-01 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-02 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-03 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-04 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-05 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-06 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-07 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-08 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-09 00:00:00', 1.21599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-10 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-11 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-12 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-13 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-14 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-15 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-16 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-17 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-18 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-19 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-20 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-21 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-22 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-23 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-24 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-25 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-26 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-27 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-28 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-29 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-06-30 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-01 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-02 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-03 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-04 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-05 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-06 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-07 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-08 00:00:00', 4.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-09 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-10 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-11 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-12 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-13 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-14 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-15 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-16 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-17 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-18 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-19 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-20 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-21 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-22 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-23 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-24 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-25 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-26 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-27 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-28 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-29 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-30 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-07-31 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-01 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-02 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-03 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-04 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-05 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-06 00:00:00', 1.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-07 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-08 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-09 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-10 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-11 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-12 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-13 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-14 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-15 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-16 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-17 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-18 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-19 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-20 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-21 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-22 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-23 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-24 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-25 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-26 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-27 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-28 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-29 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-30 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-08-31 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-01 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-02 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-03 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-04 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-05 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-06 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-07 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-08 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-09 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-10 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-11 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-12 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-13 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-14 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-15 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-16 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-17 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-18 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-19 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-20 00:00:00', 2.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-21 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-22 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-23 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-24 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-25 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-26 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-27 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-28 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-29 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-09-30 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-01 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-02 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-03 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-04 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-05 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-06 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-07 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-08 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-09 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-10 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-11 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-12 00:00:00', 1.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-13 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-14 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-15 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-16 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-17 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-18 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-19 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-20 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-21 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-22 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-23 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-24 00:00:00', 2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-25 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-26 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-27 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-28 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-29 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-30 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-10-31 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-01 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-02 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-03 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-04 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-05 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-06 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-07 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-08 00:00:00', 1.20899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-09 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-10 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-11 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-12 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-13 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-14 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-15 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-16 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-17 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-18 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-19 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-20 00:00:00', 0.745999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-21 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-22 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-23 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-24 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-25 00:00:00', 1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-26 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-27 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-28 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-29 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-11-30 00:00:00', 3.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-01 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-02 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-03 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-04 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-05 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-06 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-07 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-08 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-09 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-10 00:00:00', 0.998000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-11 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-12 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-13 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-14 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-15 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-16 00:00:00', 1.02499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-17 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-18 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-19 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-20 00:00:00', 1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-21 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-22 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-23 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-24 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-25 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-26 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-27 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-28 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-29 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-30 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1998-12-31 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-02 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-04 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-06 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-08 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-10 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-12 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-14 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-16 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-18 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-20 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-22 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-24 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-26 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-28 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-30 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-01 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-03 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-05 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-07 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-09 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-11 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-13 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-15 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-17 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-19 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-21 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-23 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-25 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-27 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-01 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-03 00:00:00', 3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-04 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-05 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-06 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-07 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-08 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-09 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-10 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-11 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-12 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-13 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-14 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-15 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-16 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-17 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-18 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-19 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-20 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-21 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-22 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-23 00:00:00', 3.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-24 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-25 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-26 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-27 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-28 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-29 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-30 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-03-31 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-01 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-02 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-03 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-04 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-05 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-06 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-07 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-08 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-09 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-10 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-11 00:00:00', 1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-12 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-13 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-14 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-15 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-16 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-17 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-18 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-19 00:00:00', 3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-20 00:00:00', 2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-21 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-22 00:00:00', 3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-23 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-24 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-25 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-26 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-27 00:00:00', 1.1390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-28 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-29 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-04-30 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-01 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-02 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-03 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-04 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-05 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-06 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-07 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-08 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-09 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-10 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-11 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-12 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-13 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-14 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-15 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-16 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-17 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-18 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-19 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-20 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-21 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-22 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-23 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-24 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-25 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-26 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-27 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-28 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-29 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-30 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-05-31 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-01 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-02 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-03 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-04 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-05 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-06 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-07 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-08 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-09 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-10 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-11 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-12 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-13 00:00:00', 2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-14 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-15 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-16 00:00:00', 4.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-17 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-18 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-19 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-20 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-21 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-22 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-23 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-24 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-25 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-26 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-27 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-28 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-29 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-06-30 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-01 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-02 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-03 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-04 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-05 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-06 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-07 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-08 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-09 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-10 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-11 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-12 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-13 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-14 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-15 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-16 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-17 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-18 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-19 00:00:00', 3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-20 00:00:00', 2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-21 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-22 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-23 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-24 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-25 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-26 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-27 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-28 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-29 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-30 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-07-31 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-01 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-02 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-03 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-04 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-05 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-06 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-07 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-08 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-09 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-10 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-11 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-12 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-13 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-14 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-15 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-16 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-17 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-18 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-19 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-20 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-21 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-22 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-23 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-24 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-25 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-26 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-27 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-28 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-29 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-30 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-08-31 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-01 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-02 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-03 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-04 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-05 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-06 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-07 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-08 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-09 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-10 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-11 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-12 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-13 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-14 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-15 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-16 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-17 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-18 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-19 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-20 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-21 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-22 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-23 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-24 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-25 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-26 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-27 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-28 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-29 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-09-30 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-01 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-02 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-03 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-04 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-05 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-06 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-07 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-08 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-09 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-10 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-11 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-12 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-13 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-14 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-15 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-16 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-17 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-18 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-19 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-20 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-21 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-22 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-23 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-24 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-25 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-26 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-27 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-28 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-29 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-30 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-10-31 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-01 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-02 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-03 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-04 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-05 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-06 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-07 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-08 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-09 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-10 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-11 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-12 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-13 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-14 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-15 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-16 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-17 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-18 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-19 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-20 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-21 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-22 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-23 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-24 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-25 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-26 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-27 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-28 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-29 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-11-30 00:00:00', 3.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-01 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-02 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-03 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-04 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-05 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-06 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-07 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-08 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-09 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-10 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-11 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-12 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-13 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-14 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-15 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-16 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-17 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-18 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-19 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-20 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-21 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-22 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-23 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-24 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-25 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-26 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-27 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-28 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-29 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-30 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '1999-12-31 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-01 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-02 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-03 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-04 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-05 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-06 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-07 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-08 00:00:00', 4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-09 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-10 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-11 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-12 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-13 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-14 00:00:00', 1.35099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-15 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-16 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-17 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-18 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-19 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-20 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-21 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-22 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-23 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-24 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-25 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-26 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-27 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-28 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-29 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-30 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-01-31 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-01 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-02 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-03 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-04 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-05 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-06 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-07 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-08 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-09 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-10 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-11 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-12 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-13 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-14 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-15 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-16 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-17 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-18 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-19 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-20 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-21 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-22 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-23 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-24 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-25 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-26 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-27 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-28 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-02-29 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-01 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-02 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-03 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-04 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-05 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-06 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-07 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-08 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-09 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-10 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-11 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-12 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-13 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-14 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-15 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-16 00:00:00', 4.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-17 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-18 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-19 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-20 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-21 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-22 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-23 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-24 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-25 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-26 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-27 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-28 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-29 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-30 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-03-31 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-01 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-02 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-03 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-04 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-05 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-06 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-07 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-08 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-09 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-10 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-11 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-12 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-13 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-14 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-15 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-16 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-17 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-18 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-19 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-20 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-21 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-22 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-23 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-24 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-25 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-26 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-27 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-28 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-29 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-04-30 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-01 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-02 00:00:00', 3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-03 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-04 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-05 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-06 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-07 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-08 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-09 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-10 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-11 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-12 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-13 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-14 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-15 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-16 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-17 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-18 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-19 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-20 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-21 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-22 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-23 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-24 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-25 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-26 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-27 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-28 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-29 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-30 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-05-31 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-01 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-02 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-03 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-04 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-05 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-06 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-07 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-08 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-09 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-10 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-11 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-12 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-13 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-14 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-15 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-16 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-17 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-18 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-19 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-20 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-21 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-22 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-23 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-24 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-25 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-26 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-27 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-28 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-29 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-06-30 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-01 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-02 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-03 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-04 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-05 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-06 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-07 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-08 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-09 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-10 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-11 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-12 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-13 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-14 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-15 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-16 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-17 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-18 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-19 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-20 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-21 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-22 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-23 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-24 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-25 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-26 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-27 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-28 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-29 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-30 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-07-31 00:00:00', 3.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-01 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-02 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-03 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-04 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-05 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-06 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-07 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-08 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-09 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-10 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-11 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-12 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-13 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-14 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-15 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-16 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-17 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-18 00:00:00', 2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-19 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-20 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-21 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-22 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-23 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-24 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-25 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-26 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-27 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-28 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-29 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-30 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-08-31 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-01 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-02 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-03 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-04 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-05 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-06 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-07 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-08 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-09 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-10 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-11 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-12 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-13 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-14 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-15 00:00:00', 2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-16 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-17 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-18 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-19 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-20 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-21 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-22 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-23 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-24 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-25 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-26 00:00:00', 2.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-27 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-28 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-29 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-09-30 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-01 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-02 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-03 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-04 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-05 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-06 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-07 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-08 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-09 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-10 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-11 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-12 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-13 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-14 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-15 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-16 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-17 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-18 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-19 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-20 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-21 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-22 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-23 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-24 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-25 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-26 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-27 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-28 00:00:00', 1.23500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-29 00:00:00', 1.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-30 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-10-31 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-01 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-02 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-03 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-04 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-05 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-06 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-07 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-08 00:00:00', 4.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-09 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-10 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-11 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-12 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-13 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-14 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-15 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-16 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-17 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-18 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-19 00:00:00', 1.13699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-20 00:00:00', 0.856000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-21 00:00:00', 1.02100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-22 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-23 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-24 00:00:00', 1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-25 00:00:00', 0.933000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-26 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-27 00:00:00', 1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-28 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-29 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-11-30 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-01 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-02 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-03 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-04 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-05 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-06 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-07 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-08 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-09 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-10 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-11 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-12 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-13 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-14 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-15 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-16 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-17 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-18 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-19 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-20 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-21 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-22 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-23 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-24 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-25 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-26 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-27 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-28 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-29 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-30 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2000-12-31 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-01 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-02 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-03 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-04 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-05 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-06 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-07 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-08 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-09 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-10 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-11 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-12 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-13 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-14 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-15 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-16 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-17 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-18 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-19 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-20 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-21 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-22 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-23 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-24 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-25 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-26 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-27 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-28 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-29 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-30 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-01-31 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-01 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-02 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-03 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-04 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-05 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-06 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-07 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-08 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-09 00:00:00', 2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-10 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-11 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-12 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-13 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-14 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-15 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-16 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-17 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-18 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-19 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-20 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-21 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-22 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-23 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-24 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-25 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-26 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-27 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-02-28 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-01 00:00:00', 1.38300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-02 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-03 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-04 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-05 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-06 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-07 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-08 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-09 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-10 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-11 00:00:00', 3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-12 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-13 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-14 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-15 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-16 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-17 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-18 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-19 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-20 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-21 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-22 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-23 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-24 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-25 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-26 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-27 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-28 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-29 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-30 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-03-31 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-01 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-02 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-03 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-04 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-05 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-06 00:00:00', 1.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-07 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-08 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-09 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-10 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-11 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-12 00:00:00', 2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-13 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-14 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-15 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-16 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-17 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-18 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-19 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-20 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-21 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-22 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-23 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-24 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-25 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-26 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-27 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-28 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-29 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-04-30 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-01 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-02 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-03 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-04 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-05 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-06 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-07 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-08 00:00:00', 2.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-09 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-10 00:00:00', 3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-11 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-12 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-13 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-14 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-15 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-16 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-17 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-18 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-19 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-20 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-21 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-22 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-23 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-24 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-25 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-26 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-27 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-28 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-29 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-30 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-05-31 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-01 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-02 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-03 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-04 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-05 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-06 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-07 00:00:00', 2.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-08 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-09 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-10 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-11 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-12 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-13 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-14 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-15 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-16 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-17 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-18 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-19 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-20 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-21 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-22 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-23 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-24 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-25 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-26 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-27 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-28 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-29 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-06-30 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-01 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-02 00:00:00', 3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-03 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-04 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-05 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-06 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-07 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-08 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-09 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-10 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-11 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-12 00:00:00', 3.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-13 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-14 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-15 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-16 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-17 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-18 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-19 00:00:00', 3.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-20 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-21 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-22 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-23 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-24 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-25 00:00:00', 2.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-26 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-27 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-28 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-29 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-30 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-07-31 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-01 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-02 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-03 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-04 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-05 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-06 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-07 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-08 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-09 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-10 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-11 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-12 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-13 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-14 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-15 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-16 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-17 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-18 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-19 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-20 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-21 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-22 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-23 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-24 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-25 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-26 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-27 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-28 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-29 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-30 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-08-31 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-01 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-02 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-03 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-04 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-05 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-06 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-07 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-08 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-09 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-10 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-11 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-12 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-13 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-14 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-15 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-16 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-17 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-18 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-19 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-20 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-21 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-22 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-23 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-24 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-25 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-26 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-27 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-28 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-29 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-09-30 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-01 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-02 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-03 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-04 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-05 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-06 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-07 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-08 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-09 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-10 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-11 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-12 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-13 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-14 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-15 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-16 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-17 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-18 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-19 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-20 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-21 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-22 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-23 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-24 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-25 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-26 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-27 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-28 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-29 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-30 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-10-31 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-01 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-02 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-03 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-04 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-05 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-06 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-07 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-08 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-09 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-10 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-11 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-12 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-13 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-14 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-15 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-16 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-17 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-18 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-19 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-20 00:00:00', 3.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-21 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-22 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-23 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-24 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-25 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-26 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-27 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-28 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-29 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-11-30 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-01 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-02 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-03 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-04 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-05 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-06 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-07 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-08 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-09 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-10 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-11 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-12 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-13 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-14 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-15 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-16 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-17 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-18 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-19 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-20 00:00:00', 2.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-21 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-22 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-23 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-24 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-25 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-26 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-27 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-28 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-29 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-30 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2001-12-31 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-01 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-02 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-03 00:00:00', 0.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-04 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-05 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-06 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-07 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-08 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-09 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-10 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-11 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-12 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-13 00:00:00', 4.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-14 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-15 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-16 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-17 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-18 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-19 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-20 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-21 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-22 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-23 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-24 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-25 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-26 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-27 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-28 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-29 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-30 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-01-31 00:00:00', 3.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-01 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-02 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-03 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-04 00:00:00', 3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-05 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-06 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-07 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-08 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-09 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-10 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-11 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-12 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-13 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-14 00:00:00', 3.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-15 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-16 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-17 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-18 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-19 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-20 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-21 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-22 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-23 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-24 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-25 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-26 00:00:00', 2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-27 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-02-28 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-01 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-02 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-03 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-04 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-05 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-06 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-07 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-08 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-09 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-10 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-11 00:00:00', 4.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-12 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-13 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-14 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-15 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-16 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-17 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-18 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-19 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-20 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-21 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-22 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-23 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-24 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-25 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-26 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-27 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-28 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-29 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-30 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-03-31 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-01 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-02 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-03 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-04 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-05 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-06 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-07 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-08 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-09 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-10 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-11 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-12 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-13 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-14 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-15 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-16 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-17 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-18 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-19 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-20 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-21 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-22 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-23 00:00:00', 2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-24 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-25 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-26 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-27 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-28 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-29 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-04-30 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-01 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-02 00:00:00', 1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-03 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-04 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-05 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-06 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-07 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-08 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-09 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-10 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-11 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-12 00:00:00', 1.99199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-13 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-14 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-15 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-16 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-17 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-18 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-19 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-20 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-21 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-22 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-23 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-24 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-25 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-26 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-27 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-28 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-29 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-30 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-05-31 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-01 00:00:00', 2.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-02 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-03 00:00:00', 2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-04 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-05 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-06 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-07 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-08 00:00:00', 3.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-09 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-10 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-11 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-12 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-13 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-14 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-15 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-16 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-17 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-18 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-19 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-20 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-21 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-22 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-23 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-24 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-25 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-26 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-27 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-28 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-29 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-06-30 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-01 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-02 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-03 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-04 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-05 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-06 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-07 00:00:00', 2.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-08 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-09 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-10 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-11 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-12 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-13 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-14 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-15 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-16 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-17 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-18 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-19 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-20 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-21 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-22 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-23 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-24 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-25 00:00:00', 2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-26 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-27 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-28 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-29 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-30 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-07-31 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-01 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-02 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-03 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-04 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-05 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-06 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-07 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-08 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-09 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-10 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-11 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-12 00:00:00', 3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-13 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-14 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-15 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-16 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-17 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-18 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-19 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-20 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-21 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-22 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-23 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-24 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-25 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-26 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-27 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-28 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-29 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-30 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-08-31 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-01 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-02 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-03 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-04 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-05 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-06 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-07 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-08 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-09 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-10 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-11 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-12 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-13 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-14 00:00:00', 2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-15 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-16 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-17 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-18 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-19 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-20 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-21 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-22 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-23 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-24 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-25 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-26 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-27 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-28 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-29 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-09-30 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-01 00:00:00', 2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-02 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-03 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-04 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-05 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-06 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-07 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-08 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-09 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-10 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-11 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-12 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-13 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-14 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-15 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-16 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-17 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-18 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-19 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-20 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-21 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-22 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-23 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-24 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-25 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-26 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-27 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-28 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-29 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-30 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-10-31 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-01 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-02 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-03 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-04 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-05 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-06 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-07 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-08 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-09 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-10 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-11 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-12 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-13 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-14 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-15 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-16 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-17 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-18 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-19 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-20 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-21 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-22 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-23 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-24 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-25 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-26 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-27 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-28 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-29 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-11-30 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-01 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-02 00:00:00', 3.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-03 00:00:00', 5.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-04 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-05 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-06 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-07 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-08 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-09 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-10 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-11 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-12 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-13 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-14 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-15 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-16 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-17 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-18 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-19 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-20 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-21 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-22 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-23 00:00:00', 4.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-24 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-25 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-26 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-27 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-28 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-29 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-30 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2002-12-31 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-01 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-02 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-03 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-04 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-05 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-06 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-07 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-08 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-09 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-10 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-11 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-12 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-13 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-14 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-15 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-16 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-17 00:00:00', 2.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-18 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-19 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-20 00:00:00', 3.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-21 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-22 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-23 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-24 00:00:00', 1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-25 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-26 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-27 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-28 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-29 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-30 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-01-31 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-01 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-02 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-03 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-04 00:00:00', 2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-05 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-06 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-07 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-08 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-09 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-10 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-11 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-12 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-13 00:00:00', 4.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-14 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-15 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-16 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-17 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-18 00:00:00', 3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-19 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-20 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-21 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-22 00:00:00', 1.13399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-23 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-24 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-25 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-26 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-27 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-02-28 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-01 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-02 00:00:00', 2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-03 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-04 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-05 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-06 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-07 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-08 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-09 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-10 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-11 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-12 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-13 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-14 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-15 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-16 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-17 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-18 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-19 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-20 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-21 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-22 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-23 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-24 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-25 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-26 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-27 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-28 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-29 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-30 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-03-31 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-01 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-02 00:00:00', 2.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-03 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-04 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-05 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-06 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-07 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-08 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-09 00:00:00', 1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-10 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-11 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-12 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-13 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-14 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-15 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-16 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-17 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-18 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-19 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-20 00:00:00', 2.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-21 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-22 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-23 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-24 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-25 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-26 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-27 00:00:00', 1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-28 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-29 00:00:00', 2.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-04-30 00:00:00', 3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-01 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-02 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-03 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-04 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-05 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-06 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-07 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-08 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-09 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-10 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-11 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-12 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-13 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-14 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-15 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-16 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-17 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-18 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-19 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-20 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-21 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-22 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-23 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-24 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-25 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-26 00:00:00', 4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-27 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-28 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-29 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-30 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-05-31 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-01 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-02 00:00:00', 1.83099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-03 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-04 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-05 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-06 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-07 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-08 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-09 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-10 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-11 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-12 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-13 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-14 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-15 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-16 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-17 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-18 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-19 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-20 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-21 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-22 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-23 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-24 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-25 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-26 00:00:00', 3.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-27 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-28 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-29 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-06-30 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-01 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-02 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-03 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-04 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-05 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-06 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-07 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-08 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-09 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-10 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-11 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-12 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-13 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-14 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-15 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-16 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-17 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-18 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-19 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-20 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-21 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-22 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-23 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-24 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-25 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-26 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-27 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-28 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-29 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-30 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-07-31 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-01 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-02 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-03 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-04 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-05 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-06 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-07 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-08 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-09 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-10 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-11 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-12 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-13 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-14 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-15 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-16 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-17 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-18 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-19 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-20 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-21 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-22 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-23 00:00:00', 2.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-24 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-25 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-26 00:00:00', 2.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-27 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-28 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-29 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-30 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-08-31 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-01 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-02 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-03 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-04 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-05 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-06 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-07 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-08 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-09 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-10 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-11 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-12 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-13 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-14 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-15 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-16 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-17 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-18 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-19 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-20 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-21 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-22 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-23 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-24 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-25 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-26 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-27 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-28 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-29 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-09-30 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-01 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-02 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-03 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-04 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-05 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-06 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-07 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-08 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-09 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-10 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-11 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-12 00:00:00', 1.73199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-13 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-14 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-15 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-16 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-17 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-18 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-19 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-20 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-21 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-22 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-23 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-24 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-25 00:00:00', 1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-26 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-27 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-28 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-29 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-30 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-10-31 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-01 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-02 00:00:00', 1.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-03 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-04 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-05 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-06 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-07 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-08 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-09 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-10 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-11 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-12 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-13 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-14 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-15 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-16 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-17 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-18 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-19 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-20 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-21 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-22 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-23 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-24 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-25 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-26 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-27 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-28 00:00:00', 0.862999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-29 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-11-30 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-01 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-02 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-03 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-04 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-05 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-06 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-07 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-08 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-09 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-10 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-11 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-12 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-13 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-14 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-15 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-16 00:00:00', 0.921000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-17 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-18 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-19 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-20 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-21 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-22 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-23 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-24 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-25 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-26 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-27 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-28 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-29 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-30 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2003-12-31 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-01 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-02 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-03 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-04 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-05 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-06 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-07 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-08 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-09 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-10 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-11 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-12 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-13 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-14 00:00:00', 1.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-15 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-16 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-17 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-18 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-19 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-20 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-21 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-22 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-23 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-24 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-25 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-26 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-27 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-28 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-29 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-30 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-01-31 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-01 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-02 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-03 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-04 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-05 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-06 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-07 00:00:00', 3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-08 00:00:00', 2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-09 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-10 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-11 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-12 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-13 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-14 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-15 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-16 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-17 00:00:00', 3.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-18 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-19 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-20 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-21 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-22 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-23 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-24 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-25 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-26 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-27 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-28 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-02-29 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-01 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-02 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-03 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-04 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-05 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-06 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-07 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-08 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-09 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-10 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-11 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-12 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-13 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-14 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-15 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-16 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-17 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-18 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-19 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-20 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-21 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-22 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-23 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-24 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-25 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-26 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-27 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-28 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-29 00:00:00', 1.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-30 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-03-31 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-01 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-02 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-03 00:00:00', 3.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-04 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-05 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-06 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-07 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-08 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-09 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-10 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-11 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-12 00:00:00', 2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-13 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-14 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-15 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-16 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-17 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-18 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-19 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-20 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-21 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-22 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-23 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-24 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-25 00:00:00', 1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-26 00:00:00', 2.99799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-27 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-28 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-29 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-04-30 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-01 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-02 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-03 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-04 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-05 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-06 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-07 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-08 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-09 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-10 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-11 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-12 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-13 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-14 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-15 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-16 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-17 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-18 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-19 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-20 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-21 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-22 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-23 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-24 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-25 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-26 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-27 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-28 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-29 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-30 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-05-31 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-01 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-02 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-03 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-04 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-05 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-06 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-07 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-08 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-09 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-10 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-11 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-12 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-13 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-14 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-15 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-16 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-17 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-18 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-19 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-20 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-21 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-22 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-23 00:00:00', 2.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-24 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-25 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-26 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-27 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-28 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-29 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-06-30 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-01 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-02 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-03 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-04 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-05 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-06 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-07 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-08 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-09 00:00:00', 2.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-10 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-11 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-12 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-13 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-14 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-15 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-16 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-17 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-18 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-19 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-20 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-21 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-22 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-23 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-24 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-25 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-26 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-27 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-28 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-29 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-30 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-07-31 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-01 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-02 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-03 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-04 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-05 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-06 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-07 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-08 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-09 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-10 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-11 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-12 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-13 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-14 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-15 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-16 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-17 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-18 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-19 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-20 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-21 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-22 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-23 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-24 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-25 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-26 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-27 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-28 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-29 00:00:00', 1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-30 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-08-31 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-01 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-02 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-03 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-04 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-05 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-06 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-07 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-08 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-09 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-10 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-11 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-12 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-13 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-14 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-15 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-16 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-17 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-18 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-19 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-20 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-21 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-22 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-23 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-24 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-25 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-26 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-27 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-28 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-29 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-09-30 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-01 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-02 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-03 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-04 00:00:00', 1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-05 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-06 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-07 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-08 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-09 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-10 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-11 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-12 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-13 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-14 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-15 00:00:00', 3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-16 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-17 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-18 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-19 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-20 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-21 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-22 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-23 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-24 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-25 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-26 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-27 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-28 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-29 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-30 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-10-31 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-01 00:00:00', 1.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-02 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-03 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-04 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-05 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-06 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-07 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-08 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-09 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-10 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-11 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-12 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-13 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-14 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-15 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-16 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-17 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-18 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-19 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-20 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-21 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-22 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-23 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-24 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-25 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-26 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-27 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-28 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-29 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-11-30 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-01 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-02 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-03 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-04 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-05 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-06 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-07 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-08 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-09 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-10 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-11 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-12 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-13 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-14 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-15 00:00:00', 2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-16 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-17 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-18 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-19 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-20 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-21 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-22 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-23 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-24 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-25 00:00:00', 2.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-26 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-27 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-28 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-29 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-30 00:00:00', 1.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2004-12-31 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-01 00:00:00', 2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-02 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-03 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-04 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-05 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-06 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-07 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-08 00:00:00', 2.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-09 00:00:00', 1.90999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-10 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-11 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-12 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-13 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-14 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-15 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-16 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-17 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-18 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-19 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-20 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-21 00:00:00', 3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-22 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-23 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-24 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-25 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-26 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-27 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-28 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-29 00:00:00', 2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-30 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-01-31 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-01 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-02 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-03 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-04 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-05 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-06 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-07 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-08 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-09 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-10 00:00:00', 4.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-11 00:00:00', 3.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-12 00:00:00', 4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-13 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-14 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-15 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-16 00:00:00', 2.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-17 00:00:00', 1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-18 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-19 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-20 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-21 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-22 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-23 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-24 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-25 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-26 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-27 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-02-28 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-01 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-02 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-03 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-04 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-05 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-06 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-07 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-08 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-09 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-10 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-11 00:00:00', 2.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-12 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-13 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-14 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-15 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-16 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-17 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-18 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-19 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-20 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-21 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-22 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-23 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-24 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-25 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-26 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-27 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-28 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-29 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-30 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-03-31 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-01 00:00:00', 1.02400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-02 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-03 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-04 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-05 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-06 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-07 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-08 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-09 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-10 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-11 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-12 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-13 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-14 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-15 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-16 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-17 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-18 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-19 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-20 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-21 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-22 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-23 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-24 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-25 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-26 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-27 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-28 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-29 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-04-30 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-01 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-02 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-03 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-04 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-05 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-06 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-07 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-08 00:00:00', 1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-09 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-10 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-11 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-12 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-13 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-14 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-15 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-16 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-17 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-18 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-19 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-20 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-21 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-22 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-23 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-24 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-25 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-26 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-27 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-28 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-29 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-30 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-05-31 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-01 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-02 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-03 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-04 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-05 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-06 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-07 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-08 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-09 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-10 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-11 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-12 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-13 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-14 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-15 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-16 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-17 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-18 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-19 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-20 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-21 00:00:00', 2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-22 00:00:00', 1.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-23 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-24 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-25 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-26 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-27 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-28 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-29 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-06-30 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-01 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-02 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-03 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-04 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-05 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-06 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-07 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-08 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-09 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-10 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-11 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-12 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-13 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-14 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-15 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-16 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-17 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-18 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-19 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-20 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-21 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-22 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-23 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-24 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-25 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-26 00:00:00', 2.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-27 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-28 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-29 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-30 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-07-31 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-01 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-02 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-03 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-04 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-05 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-06 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-07 00:00:00', 1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-08 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-09 00:00:00', 2.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-10 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-11 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-12 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-13 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-14 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-15 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-16 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-17 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-18 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-19 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-20 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-21 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-22 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-23 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-24 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-25 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-26 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-27 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-28 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-29 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-30 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-08-31 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-01 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-02 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-03 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-04 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-05 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-06 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-07 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-08 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-09 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-10 00:00:00', 2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-11 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-12 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-13 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-14 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-15 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-16 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-17 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-18 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-19 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-20 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-21 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-22 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-23 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-24 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-25 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-26 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-27 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-28 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-29 00:00:00', 2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-09-30 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-01 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-02 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-03 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-04 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-05 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-06 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-07 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-08 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-09 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-10 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-11 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-12 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-13 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-14 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-15 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-16 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-17 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-18 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-19 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-20 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-21 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-22 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-23 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-24 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-25 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-26 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-27 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-28 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-29 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-30 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-10-31 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-01 00:00:00', 1.20599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-02 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-03 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-04 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-05 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-06 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-07 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-08 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-09 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-10 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-11 00:00:00', 3.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-12 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-13 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-14 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-15 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-16 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-17 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-18 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-19 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-20 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-21 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-22 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-23 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-24 00:00:00', 3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-25 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-26 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-27 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-28 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-29 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-11-30 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-01 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-02 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-03 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-04 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-05 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-06 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-07 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-08 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-09 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-10 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-11 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-12 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-13 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-14 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-15 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-16 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-17 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-18 00:00:00', 1.06700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-19 00:00:00', 1.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-20 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-21 00:00:00', 1.04100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-22 00:00:00', 1.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-23 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-24 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-25 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-26 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-27 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-28 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-29 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-30 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2005-12-31 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-01 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-02 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-03 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-04 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-05 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-06 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-07 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-08 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-09 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-10 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-11 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-12 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-13 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-14 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-15 00:00:00', 3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-16 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-17 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-18 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-19 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-20 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-21 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-22 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-23 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-24 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-25 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-26 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-27 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-28 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-29 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-30 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-01-31 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-01 00:00:00', 3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-02 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-03 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-04 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-05 00:00:00', 2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-06 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-07 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-08 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-09 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-10 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-11 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-12 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-13 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-14 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-15 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-16 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-17 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-18 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-19 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-20 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-21 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-22 00:00:00', 2.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-23 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-24 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-25 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-26 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-27 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-02-28 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-01 00:00:00', 2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-02 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-03 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-04 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-05 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-06 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-07 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-08 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-09 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-10 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-11 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-12 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-13 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-14 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-15 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-16 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-17 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-18 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-19 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-20 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-21 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-22 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-23 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-24 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-25 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-26 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-27 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-28 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-29 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-30 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-03-31 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-01 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-02 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-03 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-04 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-05 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-06 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-07 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-08 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-09 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-10 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-11 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-12 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-13 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-14 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-15 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-16 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-17 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-18 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-19 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-20 00:00:00', 1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-21 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-22 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-23 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-24 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-25 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-26 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-27 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-28 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-29 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-04-30 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-01 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-02 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-03 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-04 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-05 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-06 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-07 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-08 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-09 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-10 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-11 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-12 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-13 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-14 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-15 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-16 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-17 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-18 00:00:00', 2.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-19 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-20 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-21 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-22 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-23 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-24 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-25 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-26 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-27 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-28 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-29 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-30 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-05-31 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-01 00:00:00', 1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-02 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-03 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-04 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-05 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-06 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-07 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-08 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-09 00:00:00', 1.54499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-10 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-11 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-12 00:00:00', 2.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-13 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-14 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-15 00:00:00', 3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-16 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-17 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-18 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-19 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-20 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-21 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-22 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-23 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-24 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-25 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-26 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-27 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-28 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-29 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-06-30 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-01 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-02 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-03 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-04 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-05 00:00:00', 3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-06 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-07 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-08 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-09 00:00:00', 3.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-10 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-11 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-12 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-13 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-14 00:00:00', 2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-15 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-16 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-17 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-18 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-19 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-20 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-21 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-22 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-23 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-24 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-25 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-26 00:00:00', 2.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-27 00:00:00', 2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-28 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-29 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-30 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-07-31 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-01 00:00:00', 2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-02 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-03 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-04 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-05 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-06 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-07 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-08 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-09 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-10 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-11 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-12 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-13 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-14 00:00:00', 3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-15 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-16 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-17 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-18 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-19 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-20 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-21 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-22 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-23 00:00:00', 2.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-24 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-25 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-26 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-27 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-28 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-29 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-30 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-08-31 00:00:00', 2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-01 00:00:00', 3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-02 00:00:00', 2.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-03 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-04 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-05 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-06 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-07 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-08 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-09 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-10 00:00:00', 2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-11 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-12 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-13 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-14 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-15 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-16 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-17 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-18 00:00:00', 3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-19 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-20 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-21 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-22 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-23 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-24 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-25 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-26 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-27 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-28 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-29 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-09-30 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-01 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-02 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-03 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-04 00:00:00', 2.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-05 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-06 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-07 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-08 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-09 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-10 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-11 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-12 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-13 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-14 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-15 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-16 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-17 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-18 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-19 00:00:00', 1.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-20 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-21 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-22 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-23 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-24 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-25 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-26 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-27 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-28 00:00:00', 1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-29 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-30 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-10-31 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-01 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-02 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-03 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-04 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-05 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-06 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-07 00:00:00', 1.32799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-08 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-09 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-10 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-11 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-12 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-13 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-14 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-15 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-16 00:00:00', 2.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-17 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-18 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-19 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-20 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-21 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-22 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-23 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-24 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-25 00:00:00', 1.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-26 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-27 00:00:00', 2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-28 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-29 00:00:00', 3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-11-30 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-01 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-02 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-03 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-04 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-05 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-06 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-07 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-08 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-09 00:00:00', 1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-10 00:00:00', 1.21599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-11 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-12 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-13 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-14 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-15 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-16 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-17 00:00:00', 1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-18 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-19 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-20 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-21 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-22 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-23 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-24 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-25 00:00:00', 3.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-26 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-27 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-28 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-29 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-30 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2006-12-31 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-01 00:00:00', 3.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-02 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-03 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-04 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-05 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-06 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-07 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-08 00:00:00', 2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-09 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-10 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-11 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-12 00:00:00', 2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-13 00:00:00', 2.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-14 00:00:00', 3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-15 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-16 00:00:00', 2.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-17 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-18 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-19 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-20 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-21 00:00:00', 2.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-22 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-23 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-24 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-25 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-26 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-27 00:00:00', 1.14900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-28 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-29 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-30 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-01-31 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-01 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-02 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-03 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-04 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-05 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-06 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-07 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-08 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-09 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-10 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-11 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-12 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-13 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-14 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-15 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-16 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-17 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-18 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-19 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-20 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-21 00:00:00', 4.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-22 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-23 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-24 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-25 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-26 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-27 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-02-28 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-01 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-02 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-03 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-04 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-05 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-06 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-07 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-08 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-09 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-10 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-11 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-12 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-13 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-14 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-15 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-16 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-17 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-18 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-19 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-20 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-21 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-22 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-23 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-24 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-25 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-26 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-27 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-28 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-29 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-30 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-03-31 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-01 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-02 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-03 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-04 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-05 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-06 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-07 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-08 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-09 00:00:00', 1.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-10 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-11 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-12 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-13 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-14 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-15 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-16 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-17 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-18 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-19 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-20 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-21 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-22 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-23 00:00:00', 1.27100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-24 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-25 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-26 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-27 00:00:00', 1.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-28 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-29 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-04-30 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-01 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-02 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-03 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-04 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-05 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-06 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-07 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-08 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-09 00:00:00', 2.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-10 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-11 00:00:00', 1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-12 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-13 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-14 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-15 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-16 00:00:00', 2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-17 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-18 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-19 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-20 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-21 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-22 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-23 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-24 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-25 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-26 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-27 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-28 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-29 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-30 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-05-31 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-01 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-02 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-03 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-04 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-05 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-06 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-07 00:00:00', 2.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-08 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-09 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-10 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-11 00:00:00', 3.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-12 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-13 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-14 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-15 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-16 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-17 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-18 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-19 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-20 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-21 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-22 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-23 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-24 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-25 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-26 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-27 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-28 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-29 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-06-30 00:00:00', 2.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-01 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-02 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-03 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-04 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-05 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-06 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-07 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-08 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-09 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-10 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-11 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-12 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-13 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-14 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-15 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-16 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-17 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-18 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-19 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-20 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-21 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-22 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-23 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-24 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-25 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-26 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-27 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-28 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-29 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-30 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-07-31 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-01 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-02 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-03 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-04 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-05 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-06 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-07 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-08 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-09 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-10 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-11 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-12 00:00:00', 2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-13 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-14 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-15 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-16 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-17 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-18 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-19 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-20 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-21 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-22 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-23 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-24 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-25 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-26 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-27 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-28 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-29 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-30 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-08-31 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-01 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-02 00:00:00', 1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-03 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-04 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-05 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-06 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-07 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-08 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-09 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-10 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-11 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-12 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-13 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-14 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-15 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-16 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-17 00:00:00', 2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-18 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-19 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-20 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-21 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-22 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-23 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-24 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-25 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-26 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-27 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-28 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-29 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-09-30 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-01 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-02 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-03 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-04 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-05 00:00:00', 1.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-06 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-07 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-08 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-09 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-10 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-11 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-12 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-13 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-14 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-15 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-16 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-17 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-18 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-19 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-20 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-21 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-22 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-23 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-24 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-25 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-26 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-27 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-28 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-29 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-30 00:00:00', 1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-10-31 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-01 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-02 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-03 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-04 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-05 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-06 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-07 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-08 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-09 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-10 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-11 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-12 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-13 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-14 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-15 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-16 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-17 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-18 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-19 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-20 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-21 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-22 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-23 00:00:00', 1.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-24 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-25 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-26 00:00:00', 2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-27 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-28 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-29 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-11-30 00:00:00', 3.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-01 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-02 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-03 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-04 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-05 00:00:00', 2.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-06 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-07 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-08 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-09 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-10 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-11 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-12 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-13 00:00:00', 3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-14 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-15 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-16 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-17 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-18 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-19 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-20 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-21 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-22 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-23 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-24 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-25 00:00:00', 1.38600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-26 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-27 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-28 00:00:00', 1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-29 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-30 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2007-12-31 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-01 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-02 00:00:00', 2.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-03 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-04 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-05 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-06 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-07 00:00:00', 5.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-08 00:00:00', 4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-09 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-10 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-11 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-12 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-13 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-14 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-15 00:00:00', 2.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-16 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-17 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-18 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-19 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-20 00:00:00', 2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-21 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-22 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-23 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-24 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-25 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-26 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-27 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-28 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-29 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-30 00:00:00', 1.94900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-01-31 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-01 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-02 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-03 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-04 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-05 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-06 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-07 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-08 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-09 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-10 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-11 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-12 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-13 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-14 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-15 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-16 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-17 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-18 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-19 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-20 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-21 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-22 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-23 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-24 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-25 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-26 00:00:00', 1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-27 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-28 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-02-29 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-01 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-02 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-03 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-04 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-05 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-06 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-07 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-08 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-09 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-10 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-11 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-12 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-13 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-14 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-15 00:00:00', 4.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-16 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-17 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-18 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-19 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-20 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-21 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-22 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-23 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-24 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-25 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-26 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-27 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-28 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-29 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-30 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-03-31 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-01 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-02 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-03 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-04 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-05 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-06 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-07 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-08 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-09 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-10 00:00:00', 1.45899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-11 00:00:00', 1.53199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-12 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-13 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-14 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-15 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-16 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-17 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-18 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-19 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-20 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-21 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-22 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-23 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-24 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-25 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-26 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-27 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-28 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-29 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-04-30 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-01 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-02 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-03 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-04 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-05 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-06 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-07 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-08 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-09 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-10 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-11 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-12 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-13 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-14 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-15 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-16 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-17 00:00:00', 2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-18 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-19 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-20 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-21 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-22 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-23 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-24 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-25 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-26 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-27 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-28 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-29 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-30 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-05-31 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-01 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-02 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-03 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-04 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-05 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-06 00:00:00', 2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-07 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-08 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-09 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-10 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-11 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-12 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-13 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-14 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-15 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-16 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-17 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-18 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-19 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-20 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-21 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-22 00:00:00', 2.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-23 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-24 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-25 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-26 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-27 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-28 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-29 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-06-30 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-01 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-02 00:00:00', 2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-03 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-04 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-05 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-06 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-07 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-08 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-09 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-10 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-11 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-12 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-13 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-14 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-15 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-16 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-17 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-18 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-19 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-20 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-21 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-22 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-23 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-24 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-25 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-26 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-27 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-28 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-29 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-30 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-07-31 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-01 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-02 00:00:00', 2.25900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-03 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-04 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-05 00:00:00', 2.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-06 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-07 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-08 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-09 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-10 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-11 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-12 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-13 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-14 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-15 00:00:00', 2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-16 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-17 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-18 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-19 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-20 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-21 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-22 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-23 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-24 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-25 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-26 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-27 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-28 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-29 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-30 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-08-31 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-01 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-02 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-03 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-04 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-05 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-06 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-07 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-08 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-09 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-10 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-11 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-12 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-13 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-14 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-15 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-16 00:00:00', 1.74800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-17 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-18 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-19 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-20 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-21 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-22 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-23 00:00:00', 2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-24 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-25 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-26 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-27 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-28 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-29 00:00:00', 2.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-09-30 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-01 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-02 00:00:00', 1.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-03 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-04 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-05 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-06 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-07 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-08 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-09 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-10 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-11 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-12 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-13 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-14 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-15 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-16 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-17 00:00:00', 2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-18 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-19 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-20 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-21 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-22 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-23 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-24 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-25 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-26 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-27 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-28 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-29 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-30 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-10-31 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-01 00:00:00', 3.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-02 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-03 00:00:00', 1.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-04 00:00:00', 1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-05 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-06 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-07 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-08 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-09 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-10 00:00:00', 3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-11 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-12 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-13 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-14 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-15 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-16 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-17 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-18 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-19 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-20 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-21 00:00:00', 2.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-22 00:00:00', 3.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-23 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-24 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-25 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-26 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-27 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-28 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-29 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-11-30 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-01 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-02 00:00:00', 1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-03 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-04 00:00:00', 0.925999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-05 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-06 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-07 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-08 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-09 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-10 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-11 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-12 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-13 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-14 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-15 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-16 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-17 00:00:00', 4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-18 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-19 00:00:00', 3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-20 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-21 00:00:00', 2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-22 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-23 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-24 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-25 00:00:00', 1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-26 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-27 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-28 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-29 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-30 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2008-12-31 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-01 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-02 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-03 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-04 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-05 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-06 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-07 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-08 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-09 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-10 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-11 00:00:00', 4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-12 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-13 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-14 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-15 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-16 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-17 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-18 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-19 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-20 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-21 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-22 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-23 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-24 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-25 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-26 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-27 00:00:00', 3.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-28 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-29 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-30 00:00:00', 4.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-01-31 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-01 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-02 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-03 00:00:00', 5.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-04 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-05 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-06 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-07 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-08 00:00:00', 2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-09 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-10 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-11 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-12 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-13 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-14 00:00:00', 4.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-15 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-16 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-17 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-18 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-19 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-20 00:00:00', 4.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-21 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-22 00:00:00', 3.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-23 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-24 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-25 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-26 00:00:00', 2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-27 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-02-28 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-01 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-02 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-03 00:00:00', 5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-04 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-05 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-06 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-07 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-08 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-09 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-10 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-11 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-12 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-13 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-14 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-15 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-16 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-17 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-18 00:00:00', 4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-19 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-20 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-21 00:00:00', 2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-22 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-23 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-24 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-25 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-26 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-27 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-28 00:00:00', 2.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-29 00:00:00', 2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-30 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-03-31 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-01 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-02 00:00:00', 4.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-03 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-04 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-05 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-06 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-07 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-08 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-09 00:00:00', 3.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-10 00:00:00', 3.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-11 00:00:00', 2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-12 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-13 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-14 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-15 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-16 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-17 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-18 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-19 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-20 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-21 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-22 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-23 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-24 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-25 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-26 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-27 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-28 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-29 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-04-30 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-01 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-02 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-03 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-04 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-05 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-06 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-07 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-08 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-09 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-10 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-11 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-12 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-13 00:00:00', 2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-14 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-15 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-16 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-17 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-18 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-19 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-20 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-21 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-22 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-23 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-24 00:00:00', 2.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-25 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-26 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-27 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-28 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-29 00:00:00', 2.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-30 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-05-31 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-01 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-02 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-03 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-04 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-05 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-06 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-07 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-08 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-09 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-10 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-11 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-12 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-13 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-14 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-15 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-16 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-17 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-18 00:00:00', 2.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-19 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-20 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-21 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-22 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-23 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-24 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-25 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-26 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-27 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-28 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-29 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-06-30 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-01 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-02 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-03 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-04 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-05 00:00:00', 3.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-06 00:00:00', 2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-07 00:00:00', 2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-08 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-09 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-10 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-11 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-12 00:00:00', 2.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-13 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-14 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-15 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-16 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-17 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-18 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-19 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-20 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-21 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-22 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-23 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-24 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-25 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-26 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-27 00:00:00', 3.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-28 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-29 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-30 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-07-31 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-01 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-02 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-03 00:00:00', 2.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-04 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-05 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-06 00:00:00', 2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-07 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-08 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-09 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-10 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-11 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-12 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-13 00:00:00', 2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-14 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-15 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-16 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-17 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-18 00:00:00', 2.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-19 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-20 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-21 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-22 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-23 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-24 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-25 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-26 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-27 00:00:00', 2.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-28 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-29 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-30 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-08-31 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-01 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-02 00:00:00', 2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-03 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-04 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-05 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-06 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-07 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-08 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-09 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-10 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-11 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-12 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-13 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-14 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-15 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-16 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-17 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-18 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-19 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-20 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-21 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-22 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-23 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-24 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-25 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-26 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-27 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-28 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-29 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-09-30 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-01 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-02 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-03 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-04 00:00:00', 1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-05 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-06 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-07 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-08 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-09 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-10 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-11 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-12 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-13 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-14 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-15 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-16 00:00:00', 1.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-17 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-18 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-19 00:00:00', 1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-20 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-21 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-22 00:00:00', 1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-23 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-24 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-25 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-26 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-27 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-28 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-29 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-30 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-10-31 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-01 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-02 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-03 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-04 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-05 00:00:00', 1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-06 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-07 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-08 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-09 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-10 00:00:00', 1.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-11 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-12 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-13 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-14 00:00:00', 2.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-15 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-16 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-17 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-18 00:00:00', 1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-19 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-20 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-21 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-22 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-23 00:00:00', 4.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-24 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-25 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-26 00:00:00', 2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-27 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-28 00:00:00', 3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-29 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-11-30 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-01 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-02 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-03 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-04 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-05 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-06 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-07 00:00:00', 2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-08 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-09 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-10 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-11 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-12 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-13 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-14 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-15 00:00:00', 3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-16 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-17 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-18 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-19 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-20 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-21 00:00:00', 3.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-22 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-23 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-24 00:00:00', 1.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-25 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-26 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-27 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-28 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-29 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-30 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2009-12-31 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-01 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-02 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-03 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-04 00:00:00', 3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-05 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-06 00:00:00', 3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-07 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-08 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-09 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-10 00:00:00', 1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-11 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-12 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-13 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-14 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-15 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-16 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-17 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-18 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-19 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-20 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-21 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-22 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-23 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-24 00:00:00', 2.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-25 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-26 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-27 00:00:00', 3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-28 00:00:00', 4.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-29 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-30 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-01-31 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-01 00:00:00', 2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-02 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-03 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-04 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-05 00:00:00', 3.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-06 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-07 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-08 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-09 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-10 00:00:00', 3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-11 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-12 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-13 00:00:00', 5.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-14 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-15 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-16 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-17 00:00:00', 3.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-18 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-19 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-20 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-21 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-22 00:00:00', 4.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-23 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-24 00:00:00', 4.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-25 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-26 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-27 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-02-28 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-01 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-02 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-03 00:00:00', 3.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-04 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-05 00:00:00', 3.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-06 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-07 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-08 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-09 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-10 00:00:00', 2.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-11 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-12 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-13 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-14 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-15 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-16 00:00:00', 2.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-17 00:00:00', 3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-18 00:00:00', 3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-19 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-20 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-21 00:00:00', 3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-22 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-23 00:00:00', 2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-24 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-25 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-26 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-27 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-28 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-29 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-30 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-03-31 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-01 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-02 00:00:00', 2.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-03 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-04 00:00:00', 2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-05 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-06 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-07 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-08 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-09 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-10 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-11 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-12 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-13 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-14 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-15 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-16 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-17 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-18 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-19 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-20 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-21 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-22 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-23 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-24 00:00:00', 1.39699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-25 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-26 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-27 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-28 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-29 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-04-30 00:00:00', 2.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-01 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-02 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-03 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-04 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-05 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-06 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-07 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-08 00:00:00', 1.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-09 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-10 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-11 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-12 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-13 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-14 00:00:00', 1.75800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-15 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-16 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-17 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-18 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-19 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-20 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-21 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-22 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-23 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-24 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-25 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-26 00:00:00', 2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-27 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-28 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-29 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-30 00:00:00', 1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-05-31 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-01 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-02 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-03 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-04 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-05 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-06 00:00:00', 2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-07 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-08 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-09 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-10 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-11 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-12 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-13 00:00:00', 2.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-14 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-15 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-16 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-17 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-18 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-19 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-20 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-21 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-22 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-23 00:00:00', 2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-24 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-25 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-26 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-27 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-28 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-29 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-06-30 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-01 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-02 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-03 00:00:00', 1.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-04 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-05 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-06 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-07 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-08 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-09 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-10 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-11 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-12 00:00:00', 2.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-13 00:00:00', 2.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-14 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-15 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-16 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-17 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-18 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-19 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-20 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-21 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-22 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-23 00:00:00', 2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-24 00:00:00', 2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-25 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-26 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-27 00:00:00', 3.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-28 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-29 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-30 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-07-31 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-01 00:00:00', 2.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-02 00:00:00', 2.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-03 00:00:00', 2.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-04 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-05 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-06 00:00:00', 1.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-07 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-08 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-09 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-10 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-11 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-12 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-13 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-14 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-15 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-16 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-17 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-18 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-19 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-20 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-21 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-22 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-23 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-24 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-25 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-26 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-27 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-28 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-29 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-30 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-08-31 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-01 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-02 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-03 00:00:00', 2.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-04 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-05 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-06 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-07 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-08 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-09 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-10 00:00:00', 2.6530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-11 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-12 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-13 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-14 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-15 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-16 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-17 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-18 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-19 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-20 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-21 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-22 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-23 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-24 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-25 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-26 00:00:00', 2.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-27 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-28 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-29 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-09-30 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-01 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-02 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-03 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-04 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-05 00:00:00', 2.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-06 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-07 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-08 00:00:00', 1.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-09 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-10 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-11 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-12 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-13 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-14 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-15 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-16 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-17 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-18 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-19 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-20 00:00:00', 2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-21 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-22 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-23 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-24 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-25 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-26 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-27 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-28 00:00:00', 2.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-29 00:00:00', 3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-30 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-10-31 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-01 00:00:00', 1.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-02 00:00:00', 3.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-03 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-04 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-05 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-06 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-07 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-08 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-09 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-10 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-11 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-12 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-13 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-14 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-15 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-16 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-17 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-18 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-19 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-20 00:00:00', 2.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-21 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-22 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-23 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-24 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-25 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-26 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-27 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-28 00:00:00', 0.998000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-29 00:00:00', 1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-11-30 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-01 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-02 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-03 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-04 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-05 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-06 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-07 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-08 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-09 00:00:00', 0.978999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-10 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-11 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-12 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-13 00:00:00', 0.990999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-14 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-15 00:00:00', 4.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-16 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-17 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-18 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-19 00:00:00', 2.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-20 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-21 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-22 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-23 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-24 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-25 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-26 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-27 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-28 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-29 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-30 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2010-12-31 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-01 00:00:00', 1.11000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-02 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-03 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-04 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-05 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-06 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-07 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-08 00:00:00', 1.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-09 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-10 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-11 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-12 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-13 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-14 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-15 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-16 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-17 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-18 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-19 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-20 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-21 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-22 00:00:00', 1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-23 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-24 00:00:00', 1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-25 00:00:00', 0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-26 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-27 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-28 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-29 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-30 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-01-31 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-01 00:00:00', 2.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-02 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-03 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-04 00:00:00', 5.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-05 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-06 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-07 00:00:00', 2.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-08 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-09 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-10 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-11 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-12 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-13 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-14 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-15 00:00:00', 2.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-16 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-17 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-18 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-19 00:00:00', 2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-20 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-21 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-22 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-23 00:00:00', 3.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-24 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-25 00:00:00', 3.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-26 00:00:00', 2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-27 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-02-28 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-01 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-02 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-03 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-04 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-05 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-06 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-07 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-08 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-09 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-10 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-11 00:00:00', 1.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-12 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-13 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-14 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-15 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-16 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-17 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-18 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-19 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-20 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-21 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-22 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-23 00:00:00', 1.0700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-24 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-25 00:00:00', 3.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-26 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-27 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-28 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-29 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-30 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-03-31 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-01 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-02 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-03 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-04 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-05 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-06 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-07 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-08 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-09 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-10 00:00:00', 2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-11 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-12 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-13 00:00:00', 1.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-14 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-15 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-16 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-17 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-18 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-19 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-20 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-21 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-22 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-23 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-24 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-25 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-26 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-27 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-28 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-29 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-04-30 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-01 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-02 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-03 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-04 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-05 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-06 00:00:00', 2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-07 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-08 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-09 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-10 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-11 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-12 00:00:00', 1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-13 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-14 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-15 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-16 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-17 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-18 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-19 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-20 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-21 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-22 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-23 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-24 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-25 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-26 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-27 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-28 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-29 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-30 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-05-31 00:00:00', 2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-01 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-02 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-03 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-04 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-05 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-06 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-07 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-08 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-09 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-10 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-11 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-12 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-13 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-14 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-15 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-16 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-17 00:00:00', 2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-18 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-19 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-20 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-21 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-22 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-23 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-24 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-25 00:00:00', 1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-26 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-27 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-28 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-29 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-06-30 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-01 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-02 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-03 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-04 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-05 00:00:00', 2.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-06 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-07 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-08 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-09 00:00:00', 2.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-10 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-11 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-12 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-13 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-14 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-15 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-16 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-17 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-18 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-19 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-20 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-21 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-22 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-23 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-24 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-25 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-26 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-27 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-28 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-29 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-30 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-07-31 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-01 00:00:00', 2.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-02 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-03 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-04 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-05 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-06 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-07 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-08 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-09 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-10 00:00:00', 1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-11 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-12 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-13 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-14 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-15 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-16 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-17 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-18 00:00:00', 2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-19 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-20 00:00:00', 2.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-21 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-22 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-23 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-24 00:00:00', 2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-25 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-26 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-27 00:00:00', 1.16299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-28 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-29 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-30 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-08-31 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-01 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-02 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-03 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-04 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-05 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-06 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-07 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-08 00:00:00', 2.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-09 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-10 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-11 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-12 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-13 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-14 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-15 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-16 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-17 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-18 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-19 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-20 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-21 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-22 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-23 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-24 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-25 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-26 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-27 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-28 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-29 00:00:00', 1.02100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-09-30 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-01 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-02 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-03 00:00:00', 1.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-04 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-05 00:00:00', 2.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-06 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-07 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-08 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-09 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-10 00:00:00', 1.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-11 00:00:00', 1.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-12 00:00:00', 2.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-13 00:00:00', 2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-14 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-15 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-16 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-17 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-18 00:00:00', 1.03799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-19 00:00:00', 0.991999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-20 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-21 00:00:00', 1.36000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-22 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-23 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-24 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-25 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-26 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-27 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-28 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-29 00:00:00', 1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-30 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-10-31 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-01 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-02 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-03 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-04 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-05 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-06 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-07 00:00:00', 3.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-08 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-09 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-10 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-11 00:00:00', 0.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-12 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-13 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-14 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-15 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-16 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-17 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-18 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-19 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-20 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-21 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-22 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-23 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-24 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-25 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-26 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-27 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-28 00:00:00', 2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-29 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-11-30 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-01 00:00:00', 2.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-02 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-03 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-04 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-05 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-06 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-07 00:00:00', 1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-08 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-09 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-10 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-11 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-12 00:00:00', 2.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-13 00:00:00', 1.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-14 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-15 00:00:00', 0.933000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-16 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-17 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-18 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-19 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-20 00:00:00', 3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-21 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-22 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-23 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-24 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-25 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-26 00:00:00', 1.14600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-27 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-28 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-29 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-30 00:00:00', 2.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2011-12-31 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-01 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-02 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-03 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-04 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-05 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-06 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-07 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-08 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-09 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-10 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-11 00:00:00', 0.996999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-12 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-13 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-14 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-15 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-16 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-17 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-18 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-19 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-20 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-21 00:00:00', 1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-22 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-23 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-24 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-25 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-26 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-27 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-28 00:00:00', 1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-29 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-30 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-01-31 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-01 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-02 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-03 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-04 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-05 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-06 00:00:00', 1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-07 00:00:00', 1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-08 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-09 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-10 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-11 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-12 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-13 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-14 00:00:00', 2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-15 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-16 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-17 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-18 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-19 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-20 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-21 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-22 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-23 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-24 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-25 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-26 00:00:00', 3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-27 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-28 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-02-29 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-01 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-02 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-03 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-04 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-05 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-06 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-07 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-08 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-09 00:00:00', 1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-10 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-11 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-12 00:00:00', 4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-13 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-14 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-15 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-16 00:00:00', 3.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-17 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-18 00:00:00', 3.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-19 00:00:00', 3.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-20 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-21 00:00:00', 1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-22 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-23 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-24 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-25 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-26 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-27 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-28 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-29 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-30 00:00:00', 1.14900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-03-31 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-01 00:00:00', 3.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-02 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-03 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-04 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-05 00:00:00', 1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-06 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-07 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-08 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-09 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-10 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-11 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-12 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-13 00:00:00', 1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-14 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-15 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-16 00:00:00', 0.864000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-17 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-18 00:00:00', 1.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-19 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-20 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-21 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-22 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-23 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-24 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-25 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-26 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-27 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-28 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-29 00:00:00', 2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-04-30 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-01 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-02 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-03 00:00:00', 1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-04 00:00:00', 1.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-05 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-06 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-07 00:00:00', 1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-08 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-09 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-10 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-11 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-12 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-13 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-14 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-15 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-16 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-17 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-18 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-19 00:00:00', 1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-20 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-21 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-22 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-23 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-24 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-25 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-26 00:00:00', 1.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-27 00:00:00', 1.00499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-28 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-29 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-30 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-05-31 00:00:00', 1.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-01 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-02 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-03 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-04 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-05 00:00:00', 2.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-06 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-07 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-08 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-09 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-10 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-11 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-12 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-13 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-14 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-15 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-16 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-17 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-18 00:00:00', 1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-19 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-20 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-21 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-22 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-23 00:00:00', 1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-24 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-25 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-26 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-27 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-28 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-29 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-06-30 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-01 00:00:00', 1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-02 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-03 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-04 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-05 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-06 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-07 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-08 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-09 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-10 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-11 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-12 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-13 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-14 00:00:00', 1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-15 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-16 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-17 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-18 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-19 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-20 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-21 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-22 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-23 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-24 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-25 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-26 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-27 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-28 00:00:00', 1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-29 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-30 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-07-31 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-01 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-02 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-03 00:00:00', 1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-04 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-05 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-06 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-07 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-08 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-09 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-10 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-11 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-12 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-13 00:00:00', 1.84300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-14 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-15 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-16 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-17 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-18 00:00:00', 2.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-19 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-20 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-21 00:00:00', 1.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-22 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-23 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-24 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-25 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-26 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-27 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-28 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-29 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-30 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-08-31 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-01 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-02 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-03 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-04 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-05 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-06 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-07 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-08 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-09 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-10 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-11 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-12 00:00:00', 1.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-13 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-14 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-15 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-16 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-17 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-18 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-19 00:00:00', 1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-20 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-21 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-22 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-23 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-24 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-25 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-26 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-27 00:00:00', 1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-28 00:00:00', 1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-29 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-09-30 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-01 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-02 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-03 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-04 00:00:00', 1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-05 00:00:00', 1.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-06 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-07 00:00:00', 1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-08 00:00:00', 1.05799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-09 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-10 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-11 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-12 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-13 00:00:00', 1.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-14 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-15 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-16 00:00:00', 1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-17 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-18 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-19 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-20 00:00:00', 1.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-21 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-22 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-23 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-24 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-25 00:00:00', 1.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-26 00:00:00', 1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-27 00:00:00', 0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-28 00:00:00', 1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-29 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-30 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-10-31 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-01 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-02 00:00:00', 1.59399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-03 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-04 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-05 00:00:00', 0.954999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-06 00:00:00', 0.981000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-07 00:00:00', 0.880999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-08 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-09 00:00:00', 0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-10 00:00:00', 0.913999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-11 00:00:00', 1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-12 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-13 00:00:00', 1.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-14 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-15 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-16 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-17 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-18 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-19 00:00:00', 2.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-20 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-21 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-22 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-23 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-24 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-25 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-26 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-27 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-28 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-29 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-11-30 00:00:00', 1.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-01 00:00:00', 1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-02 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-03 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-04 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-05 00:00:00', 1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-06 00:00:00', 1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-07 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-08 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-09 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-10 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-11 00:00:00', 1.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-12 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-13 00:00:00', 2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-14 00:00:00', 1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-15 00:00:00', 2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-16 00:00:00', 1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-17 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-18 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-19 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-20 00:00:00', 1.55400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-21 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-22 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-23 00:00:00', 2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-24 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-25 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-26 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-27 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-28 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-29 00:00:00', 1.12699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-30 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2012-12-31 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-01 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-02 00:00:00', 1.81799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-03 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-04 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-05 00:00:00', 1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-06 00:00:00', 1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-07 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-08 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-09 00:00:00', 2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-10 00:00:00', 2.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-11 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-12 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-13 00:00:00', 1.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-14 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-15 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-16 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-17 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-18 00:00:00', 1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-19 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-20 00:00:00', 1.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-21 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-22 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-23 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-24 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-25 00:00:00', 2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-26 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-27 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-28 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-29 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-30 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-01-31 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-01 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-02 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-03 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-04 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-05 00:00:00', 1.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-06 00:00:00', 1.1950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-07 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-08 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-09 00:00:00', 1.26100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-10 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-11 00:00:00', 1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-12 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-13 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-14 00:00:00', 0.930999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-15 00:00:00', 1.13399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-16 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-17 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-18 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-19 00:00:00', 1.21599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-20 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-21 00:00:00', 1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-22 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-23 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-24 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-25 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-26 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-27 00:00:00', 3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-02-28 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-01 00:00:00', 2.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-02 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-03 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-04 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-05 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-06 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-07 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-08 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-09 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-10 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-11 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-12 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-13 00:00:00', 2.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-14 00:00:00', 1.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-15 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-16 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-17 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-18 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-19 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-20 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-21 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-22 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-23 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-24 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-25 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-26 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-27 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-28 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-29 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-30 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-03-31 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-01 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-02 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-03 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-04 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-05 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-06 00:00:00', 2.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-07 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-08 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-09 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-10 00:00:00', 1.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-11 00:00:00', 1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-12 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-13 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-14 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-15 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-16 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-17 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-18 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-19 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-20 00:00:00', 1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-21 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-22 00:00:00', 3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-23 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-24 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-25 00:00:00', 3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-26 00:00:00', 2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-27 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-28 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-29 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-04-30 00:00:00', 0.884999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-01 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-02 00:00:00', 1.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-03 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-04 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-05 00:00:00', 1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-06 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-07 00:00:00', 1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-08 00:00:00', 1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-09 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-10 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-11 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-12 00:00:00', 1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-13 00:00:00', 1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-14 00:00:00', 1.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-15 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-16 00:00:00', 1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-17 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-18 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-19 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-20 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-21 00:00:00', 2.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-22 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-23 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-24 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-25 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-26 00:00:00', 1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-27 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-28 00:00:00', 1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-29 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-30 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-05-31 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-01 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-02 00:00:00', 1.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-03 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-04 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-05 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-06 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-07 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-08 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-09 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-10 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-11 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-12 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-13 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-14 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-15 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-16 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-17 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-18 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-19 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-20 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-21 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-22 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-23 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-24 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-25 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-26 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-27 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-28 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-29 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-06-30 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-01 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-02 00:00:00', 1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-03 00:00:00', 1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-04 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-05 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-06 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-07 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-08 00:00:00', 2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-09 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-10 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-11 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-12 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-13 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-14 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-15 00:00:00', 2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-16 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-17 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-18 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-19 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-20 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-21 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-22 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-23 00:00:00', 1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-24 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-25 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-26 00:00:00', 2.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-27 00:00:00', 2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-28 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-29 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-30 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-07-31 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-01 00:00:00', 1.98500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-02 00:00:00', 1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-03 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-04 00:00:00', 2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-05 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-06 00:00:00', 1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-07 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-08 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-09 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-10 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-11 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-12 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-13 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-14 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-15 00:00:00', 1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-16 00:00:00', 1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-17 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-18 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-19 00:00:00', 1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-20 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-21 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-22 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-23 00:00:00', 2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-24 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-25 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-26 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-27 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-28 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-29 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-30 00:00:00', 1.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-08-31 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-01 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-02 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-03 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-04 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-05 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-06 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-07 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-08 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-09 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-10 00:00:00', 1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-11 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-12 00:00:00', 1.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-13 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-14 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-15 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-16 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-17 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-18 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-19 00:00:00', 1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-20 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-21 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-22 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-23 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-24 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-25 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-26 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-27 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-28 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-29 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-09-30 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-01 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-02 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-03 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-04 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-05 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-06 00:00:00', 1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-07 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-08 00:00:00', 1.10099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-09 00:00:00', 1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-10 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-11 00:00:00', 1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-12 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-13 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-14 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-15 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-16 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-17 00:00:00', 1.11000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-18 00:00:00', 1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-19 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-20 00:00:00', 1.05799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-21 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-22 00:00:00', 2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-23 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-24 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-25 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-26 00:00:00', 5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-27 00:00:00', 2.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-28 00:00:00', 1.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-29 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-30 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-10-31 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-01 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-02 00:00:00', 1.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-03 00:00:00', 0.880999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-04 00:00:00', 0.893999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-05 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-06 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-07 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-08 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-09 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-10 00:00:00', 1.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-11 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-12 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-13 00:00:00', 1.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-14 00:00:00', 0.815999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-15 00:00:00', 0.638000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-16 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-17 00:00:00', 2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-18 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-19 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-20 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-21 00:00:00', 1.10399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-22 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-23 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-24 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-25 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-26 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-27 00:00:00', 1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-28 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-29 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-11-30 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-01 00:00:00', 2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-02 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-03 00:00:00', 2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-04 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-05 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-06 00:00:00', 1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-07 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-08 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-09 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-10 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-11 00:00:00', 3.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-12 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-13 00:00:00', 1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-14 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-15 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-16 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-17 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-18 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-19 00:00:00', 1.30700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-20 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-21 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-22 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-23 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-24 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-25 00:00:00', 1.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-26 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-27 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-28 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-29 00:00:00', 1.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-30 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2013-12-31 00:00:00', 0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-01 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-02 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-03 00:00:00', 2.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-04 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-05 00:00:00', 1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-06 00:00:00', 1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-07 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-08 00:00:00', 0.888000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-09 00:00:00', 1.02499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-10 00:00:00', 1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-11 00:00:00', 1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-12 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-13 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-14 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-15 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-16 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-17 00:00:00', 0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-18 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-19 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-20 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-21 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-22 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-23 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-24 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-25 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-26 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-27 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-28 00:00:00', 1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-29 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-30 00:00:00', 2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-01-31 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-01 00:00:00', 2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-02 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-03 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-04 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-05 00:00:00', 1.65699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-06 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-07 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-08 00:00:00', 1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-09 00:00:00', 1.32799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-10 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-11 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-12 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-13 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-14 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-15 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-16 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-17 00:00:00', 1.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-18 00:00:00', 2.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-19 00:00:00', 1.13999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-20 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-21 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-22 00:00:00', 3.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-23 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-24 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-25 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-26 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-27 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-02-28 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-01 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-02 00:00:00', 0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-03 00:00:00', 1.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-04 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-05 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-06 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-07 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-08 00:00:00', 2.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-09 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-10 00:00:00', 1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-11 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-12 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-13 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-14 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-15 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-16 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-17 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-18 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-19 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-20 00:00:00', 1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-21 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-22 00:00:00', 2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-23 00:00:00', 3.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-24 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-25 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-26 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-27 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-28 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-29 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-30 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-03-31 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-01 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-02 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-03 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-04 00:00:00', 3.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-05 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-06 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-07 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-08 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-09 00:00:00', 2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-10 00:00:00', 2.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-11 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-12 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-13 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-14 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-15 00:00:00', 1.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-16 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-17 00:00:00', 1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-18 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-19 00:00:00', 1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-20 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-21 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-22 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-23 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-24 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-25 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-26 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-27 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-28 00:00:00', 1.37300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-29 00:00:00', 1.29100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-04-30 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-01 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-02 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-03 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-04 00:00:00', 1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-05 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-06 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-07 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-08 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-09 00:00:00', 1.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-10 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-11 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-12 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-13 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-14 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-15 00:00:00', 1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-16 00:00:00', 1.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-17 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-18 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-19 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-20 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-21 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-22 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-23 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-24 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-25 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-26 00:00:00', 1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-27 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-28 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-29 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-30 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-05-31 00:00:00', 1.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-01 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-02 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-03 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-04 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-05 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-06 00:00:00', 1.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-07 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-08 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-09 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-10 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-11 00:00:00', 2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-12 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-13 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-14 00:00:00', 1.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-15 00:00:00', 1.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-16 00:00:00', 1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-17 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-18 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-19 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-20 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-21 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-22 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-23 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-24 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-25 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-26 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-27 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-28 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-29 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-06-30 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-01 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-02 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-03 00:00:00', 1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-04 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-05 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-06 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-07 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-08 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-09 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-10 00:00:00', 1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-11 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-12 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-13 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-14 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-15 00:00:00', 2.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-16 00:00:00', 1.62699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-17 00:00:00', 1.58099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-18 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-19 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-20 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-21 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-22 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-23 00:00:00', 2.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-24 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-25 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-26 00:00:00', 1.94200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-27 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-28 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-29 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-30 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (35, '2014-07-31 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-01 00:00:00', 16.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-02 00:00:00', 15.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-03 00:00:00', 15.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-04 00:00:00', 14.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-05 00:00:00', 16.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-06 00:00:00', 16.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-07 00:00:00', 16.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-08 00:00:00', 11.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-09 00:00:00', 7.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-10 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-11 00:00:00', 10.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-12 00:00:00', 9.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-13 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-14 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-15 00:00:00', 7.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-16 00:00:00', 8.13599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-17 00:00:00', 6.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-18 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-19 00:00:00', 3.99600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-20 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-21 00:00:00', 7.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-22 00:00:00', 11.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-23 00:00:00', 8.58899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-24 00:00:00', 11.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-25 00:00:00', 8.10999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-26 00:00:00', 2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-27 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-28 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-29 00:00:00', -1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-30 00:00:00', -0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-01-31 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-01 00:00:00', 7.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-02 00:00:00', 9.41899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-03 00:00:00', 12.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-04 00:00:00', 10.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-05 00:00:00', 11.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-06 00:00:00', 8.44200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-07 00:00:00', 14.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-08 00:00:00', 12.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-09 00:00:00', 15.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-10 00:00:00', 13.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-11 00:00:00', 14.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-12 00:00:00', 12.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-13 00:00:00', 13.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-14 00:00:00', 13.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-15 00:00:00', 17.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-16 00:00:00', 19.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-17 00:00:00', 16.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-18 00:00:00', 11.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-19 00:00:00', 2.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-20 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-21 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-22 00:00:00', 5.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-23 00:00:00', 7.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-24 00:00:00', 6.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-25 00:00:00', 8.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-26 00:00:00', 11.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-27 00:00:00', 7.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-02-28 00:00:00', 7.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-01 00:00:00', 6.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-02 00:00:00', 3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-03 00:00:00', 3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-04 00:00:00', 5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-05 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-06 00:00:00', 2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-07 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-08 00:00:00', 2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-09 00:00:00', 8.07699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-10 00:00:00', 11.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-11 00:00:00', 10.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-12 00:00:00', 13.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-13 00:00:00', 12.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-14 00:00:00', 14.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-15 00:00:00', 16.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-16 00:00:00', 11.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-17 00:00:00', 16.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-18 00:00:00', 17.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-19 00:00:00', 20.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-20 00:00:00', 21.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-21 00:00:00', 22.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-22 00:00:00', 21.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-23 00:00:00', 22.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-24 00:00:00', 24.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-25 00:00:00', 20.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-26 00:00:00', 18.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-27 00:00:00', 22.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-28 00:00:00', 23.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-29 00:00:00', 21.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-30 00:00:00', 18.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-03-31 00:00:00', 17.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-01 00:00:00', 21.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-02 00:00:00', 15.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-03 00:00:00', 19.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-04 00:00:00', 14.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-05 00:00:00', 22.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-06 00:00:00', 24.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-07 00:00:00', 23.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-08 00:00:00', 25.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-09 00:00:00', 27.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-10 00:00:00', 31.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-11 00:00:00', 30.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-12 00:00:00', 30.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-13 00:00:00', 29.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-14 00:00:00', 26.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-15 00:00:00', 28.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-16 00:00:00', 28.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-17 00:00:00', 28.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-18 00:00:00', 12.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-19 00:00:00', 16.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-20 00:00:00', 23.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-21 00:00:00', 25.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-22 00:00:00', 28.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-23 00:00:00', 30.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-24 00:00:00', 30.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-25 00:00:00', 28.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-26 00:00:00', 33.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-27 00:00:00', 19.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-28 00:00:00', 21.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-29 00:00:00', 23.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-04-30 00:00:00', 17.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-01 00:00:00', 18.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-02 00:00:00', 24.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-03 00:00:00', 28.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-04 00:00:00', 30.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-05 00:00:00', 27.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-06 00:00:00', 28.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-07 00:00:00', 29.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-08 00:00:00', 23.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-09 00:00:00', 23.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-10 00:00:00', 22.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-11 00:00:00', 20.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-12 00:00:00', 26.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-13 00:00:00', 25.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-14 00:00:00', 24.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-15 00:00:00', 25.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-16 00:00:00', 26.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-17 00:00:00', 29.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-18 00:00:00', 25.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-19 00:00:00', 26.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-20 00:00:00', 26.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-21 00:00:00', 29.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-22 00:00:00', 29.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-23 00:00:00', 30.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-24 00:00:00', 27.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-25 00:00:00', 25.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-26 00:00:00', 27.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-27 00:00:00', 27.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-28 00:00:00', 23.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-29 00:00:00', 27.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-30 00:00:00', 29.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-05-31 00:00:00', 30.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-01 00:00:00', 30.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-02 00:00:00', 32.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-03 00:00:00', 34.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-04 00:00:00', 37.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-05 00:00:00', 33.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-06 00:00:00', 35.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-07 00:00:00', 35.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-08 00:00:00', 37.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-09 00:00:00', 37.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-10 00:00:00', 38.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-11 00:00:00', 34.0120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-12 00:00:00', 32.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-13 00:00:00', 33.7739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-14 00:00:00', 34.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-15 00:00:00', 36.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-16 00:00:00', 36.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-17 00:00:00', 36.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-18 00:00:00', 35.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-19 00:00:00', 35.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-20 00:00:00', 36.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-21 00:00:00', 37.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-22 00:00:00', 40.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-23 00:00:00', 41.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-24 00:00:00', 42.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-25 00:00:00', 41.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-26 00:00:00', 38.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-27 00:00:00', 36.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-28 00:00:00', 35.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-29 00:00:00', 35.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-06-30 00:00:00', 36.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-01 00:00:00', 37.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-02 00:00:00', 39.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-03 00:00:00', 37.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-04 00:00:00', 37.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-05 00:00:00', 38.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-06 00:00:00', 39.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-07 00:00:00', 42.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-08 00:00:00', 43.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-09 00:00:00', 43.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-10 00:00:00', 44.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-11 00:00:00', 43.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-12 00:00:00', 42.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-13 00:00:00', 40.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-14 00:00:00', 38.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-15 00:00:00', 40.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-16 00:00:00', 41.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-17 00:00:00', 42.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-18 00:00:00', 43.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-19 00:00:00', 45.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-20 00:00:00', 39.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-21 00:00:00', 37.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-22 00:00:00', 37.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-23 00:00:00', 35.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-24 00:00:00', 38.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-25 00:00:00', 39.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-26 00:00:00', 40.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-27 00:00:00', 39.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-28 00:00:00', 42.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-29 00:00:00', 41.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-30 00:00:00', 42.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-07-31 00:00:00', 44.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-01 00:00:00', 44.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-02 00:00:00', 42.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-03 00:00:00', 40.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-04 00:00:00', 35.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-05 00:00:00', 35.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-06 00:00:00', 35.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-07 00:00:00', 33.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-08 00:00:00', 37.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-09 00:00:00', 37.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-10 00:00:00', 38.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-11 00:00:00', 38.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-12 00:00:00', 39.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-13 00:00:00', 38.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-14 00:00:00', 38.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-15 00:00:00', 38.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-16 00:00:00', 39.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-17 00:00:00', 39.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-18 00:00:00', 41.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-19 00:00:00', 41.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-20 00:00:00', 33.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-21 00:00:00', 32.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-22 00:00:00', 31.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-23 00:00:00', 32.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-24 00:00:00', 33.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-25 00:00:00', 34.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-26 00:00:00', 35.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-27 00:00:00', 36.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-28 00:00:00', 33.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-29 00:00:00', 32.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-30 00:00:00', 32.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-08-31 00:00:00', 35.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-01 00:00:00', 34.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-02 00:00:00', 33.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-03 00:00:00', 34.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-04 00:00:00', 34.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-05 00:00:00', 34.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-06 00:00:00', 36.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-07 00:00:00', 35.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-08 00:00:00', 38.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-09 00:00:00', 36.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-10 00:00:00', 36.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-11 00:00:00', 36.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-12 00:00:00', 38.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-13 00:00:00', 36.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-14 00:00:00', 35.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-15 00:00:00', 30.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-16 00:00:00', 30.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-17 00:00:00', 31.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-18 00:00:00', 30.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-19 00:00:00', 30.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-20 00:00:00', 31.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-21 00:00:00', 30.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-22 00:00:00', 29.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-23 00:00:00', 27.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-24 00:00:00', 25.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-25 00:00:00', 28.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-26 00:00:00', 28.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-27 00:00:00', 28.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-28 00:00:00', 27.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-29 00:00:00', 27.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-09-30 00:00:00', 29.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-01 00:00:00', 28.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-02 00:00:00', 29.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-03 00:00:00', 29.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-04 00:00:00', 30.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-05 00:00:00', 30.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-06 00:00:00', 31.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-07 00:00:00', 31.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-08 00:00:00', 29.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-09 00:00:00', 26.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-10 00:00:00', 22.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-11 00:00:00', 24.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-12 00:00:00', 23.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-13 00:00:00', 25.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-14 00:00:00', 25.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-15 00:00:00', 25.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-16 00:00:00', 25.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-17 00:00:00', 26.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-18 00:00:00', 26.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-19 00:00:00', 26.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-20 00:00:00', 21.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-21 00:00:00', 25.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-22 00:00:00', 27.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-23 00:00:00', 28.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-24 00:00:00', 29.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-25 00:00:00', 30.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-26 00:00:00', 29.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-27 00:00:00', 29.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-28 00:00:00', 25.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-29 00:00:00', 26.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-30 00:00:00', 21.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-10-31 00:00:00', 21.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-01 00:00:00', 21.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-02 00:00:00', 24.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-03 00:00:00', 26.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-04 00:00:00', 25.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-05 00:00:00', 15.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-06 00:00:00', 8.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-07 00:00:00', 11.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-08 00:00:00', 11.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-09 00:00:00', 16.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-10 00:00:00', 18.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-11 00:00:00', 10.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-12 00:00:00', 10.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-13 00:00:00', 7.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-14 00:00:00', 11.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-15 00:00:00', 14.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-16 00:00:00', 14.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-17 00:00:00', 16.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-18 00:00:00', 13.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-19 00:00:00', 13.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-20 00:00:00', 9.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-21 00:00:00', 9.89500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-22 00:00:00', 9.36900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-23 00:00:00', 12.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-24 00:00:00', 13.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-25 00:00:00', 15.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-26 00:00:00', 16.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-27 00:00:00', 17.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-28 00:00:00', 18.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-29 00:00:00', 18.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-11-30 00:00:00', 21.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-01 00:00:00', 20.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-02 00:00:00', 16.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-03 00:00:00', 12.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-04 00:00:00', 11.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-05 00:00:00', 11.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-06 00:00:00', 14.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-07 00:00:00', 15.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-08 00:00:00', 16.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-09 00:00:00', 15.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-10 00:00:00', 12.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-11 00:00:00', 14.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-12 00:00:00', 14.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-13 00:00:00', 14.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-14 00:00:00', 13.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-15 00:00:00', 12.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-16 00:00:00', 14.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-17 00:00:00', 11.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-18 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-19 00:00:00', 6.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-20 00:00:00', 7.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-21 00:00:00', 8.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-22 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-23 00:00:00', 0.856000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-24 00:00:00', 6.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-25 00:00:00', 8.18700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-26 00:00:00', 6.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-27 00:00:00', 7.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-28 00:00:00', 9.93700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-29 00:00:00', 7.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-30 00:00:00', 7.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1979-12-31 00:00:00', 8.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-01 00:00:00', 6.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-02 00:00:00', 7.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-03 00:00:00', 8.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-04 00:00:00', 10.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-05 00:00:00', 9.62600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-06 00:00:00', 11.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-07 00:00:00', 15.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-08 00:00:00', 10.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-09 00:00:00', 7.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-10 00:00:00', 2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-11 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-12 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-13 00:00:00', 9.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-14 00:00:00', 10.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-15 00:00:00', 5.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-16 00:00:00', 0.837000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-17 00:00:00', 6.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-18 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-19 00:00:00', 7.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-20 00:00:00', 8.12399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-21 00:00:00', 7.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-22 00:00:00', 5.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-23 00:00:00', 6.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-24 00:00:00', 0.930999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-25 00:00:00', -2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-26 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-27 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-28 00:00:00', -0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-29 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-30 00:00:00', 7.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-01-31 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-01 00:00:00', -2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-02 00:00:00', -5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-03 00:00:00', -5.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-04 00:00:00', -6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-05 00:00:00', -0.229000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-06 00:00:00', 0.674000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-07 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-08 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-09 00:00:00', 1.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-10 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-11 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-12 00:00:00', 8.98700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-13 00:00:00', 6.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-14 00:00:00', 7.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-15 00:00:00', 12.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-16 00:00:00', 12.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-17 00:00:00', 10.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-18 00:00:00', 9.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-19 00:00:00', 10.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-20 00:00:00', 9.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-21 00:00:00', 5.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-22 00:00:00', 6.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-23 00:00:00', 9.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-24 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-25 00:00:00', 7.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-26 00:00:00', 7.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-27 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-28 00:00:00', 4.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-02-29 00:00:00', 7.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-01 00:00:00', 8.93299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-02 00:00:00', 6.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-03 00:00:00', 7.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-04 00:00:00', 7.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-05 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-06 00:00:00', 5.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-07 00:00:00', 11.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-08 00:00:00', 5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-09 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-10 00:00:00', 7.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-11 00:00:00', 8.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-12 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-13 00:00:00', 14.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-14 00:00:00', 10.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-15 00:00:00', 10.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-16 00:00:00', 11.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-17 00:00:00', 7.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-18 00:00:00', 12.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-19 00:00:00', 17.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-20 00:00:00', 12.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-21 00:00:00', 15.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-22 00:00:00', 17.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-23 00:00:00', 15.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-24 00:00:00', 18.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-25 00:00:00', 19.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-26 00:00:00', 20.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-27 00:00:00', 13.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-28 00:00:00', 11.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-29 00:00:00', 17.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-30 00:00:00', 22.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-03-31 00:00:00', 23.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-01 00:00:00', 18.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-02 00:00:00', 20.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-03 00:00:00', 20.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-04 00:00:00', 23.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-05 00:00:00', 22.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-06 00:00:00', 24.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-07 00:00:00', 26.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-08 00:00:00', 28.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-09 00:00:00', 28.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-10 00:00:00', 29.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-11 00:00:00', 28.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-12 00:00:00', 27.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-13 00:00:00', 28.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-14 00:00:00', 28.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-15 00:00:00', 30.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-16 00:00:00', 31.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-17 00:00:00', 32.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-18 00:00:00', 22.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-19 00:00:00', 25.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-20 00:00:00', 26.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-21 00:00:00', 26.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-22 00:00:00', 26.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-23 00:00:00', 28.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-24 00:00:00', 30.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-25 00:00:00', 29.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-26 00:00:00', 30.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-27 00:00:00', 29.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-28 00:00:00', 29.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-29 00:00:00', 31.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-04-30 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-01 00:00:00', 33.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-02 00:00:00', 34.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-03 00:00:00', 33.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-04 00:00:00', 34.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-05 00:00:00', 35.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-06 00:00:00', 36.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-07 00:00:00', 33.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-08 00:00:00', 29.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-09 00:00:00', 29.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-10 00:00:00', 29.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-11 00:00:00', 23.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-12 00:00:00', 26.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-13 00:00:00', 28.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-14 00:00:00', 30.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-15 00:00:00', 32.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-16 00:00:00', 28.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-17 00:00:00', 27.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-18 00:00:00', 29.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-19 00:00:00', 28.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-20 00:00:00', 31.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-21 00:00:00', 31.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-22 00:00:00', 34.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-23 00:00:00', 34.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-24 00:00:00', 35.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-25 00:00:00', 36.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-26 00:00:00', 36.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-27 00:00:00', 36.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-28 00:00:00', 35.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-29 00:00:00', 35.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-30 00:00:00', 36.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-05-31 00:00:00', 34.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-01 00:00:00', 31.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-02 00:00:00', 31.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-03 00:00:00', 33.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-04 00:00:00', 35.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-05 00:00:00', 36.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-06 00:00:00', 38.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-07 00:00:00', 37.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-08 00:00:00', 40.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-09 00:00:00', 41.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-10 00:00:00', 43.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-11 00:00:00', 40.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-12 00:00:00', 32.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-13 00:00:00', 31.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-14 00:00:00', 34.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-15 00:00:00', 35.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-16 00:00:00', 37.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-17 00:00:00', 38.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-18 00:00:00', 40.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-19 00:00:00', 39.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-20 00:00:00', 39.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-21 00:00:00', 39.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-22 00:00:00', 41.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-23 00:00:00', 40.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-24 00:00:00', 36.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-25 00:00:00', 35.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-26 00:00:00', 36.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-27 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-28 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-29 00:00:00', 37.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-06-30 00:00:00', 37.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-01 00:00:00', 39.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-02 00:00:00', 41.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-03 00:00:00', 42.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-04 00:00:00', 40.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-05 00:00:00', 41.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-06 00:00:00', 41.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-07 00:00:00', 42.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-08 00:00:00', 42.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-09 00:00:00', 42.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-10 00:00:00', 43.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-11 00:00:00', 43.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-12 00:00:00', 38.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-13 00:00:00', 39.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-14 00:00:00', 41.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-15 00:00:00', 42.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-16 00:00:00', 43.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-17 00:00:00', 43.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-18 00:00:00', 38.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-19 00:00:00', 34.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-20 00:00:00', 36.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-21 00:00:00', 38.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-22 00:00:00', 38.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-23 00:00:00', 38.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-24 00:00:00', 39.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-25 00:00:00', 41.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-26 00:00:00', 40.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-27 00:00:00', 40.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-28 00:00:00', 40.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-29 00:00:00', 37.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-30 00:00:00', 38.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-07-31 00:00:00', 40.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-01 00:00:00', 42.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-02 00:00:00', 41.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-03 00:00:00', 37.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-04 00:00:00', 38.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-05 00:00:00', 42.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-06 00:00:00', 40.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-07 00:00:00', 38.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-08 00:00:00', 34.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-09 00:00:00', 34.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-10 00:00:00', 34.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-11 00:00:00', 36.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-12 00:00:00', 36.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-13 00:00:00', 35.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-14 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-15 00:00:00', 35.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-16 00:00:00', 36.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-17 00:00:00', 37.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-18 00:00:00', 36.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-19 00:00:00', 37.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-20 00:00:00', 39.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-21 00:00:00', 41.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-22 00:00:00', 40.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-23 00:00:00', 36.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-24 00:00:00', 36.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-25 00:00:00', 35.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-26 00:00:00', 36.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-27 00:00:00', 37.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-28 00:00:00', 37.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-29 00:00:00', 37.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-30 00:00:00', 36.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-08-31 00:00:00', 30.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-01 00:00:00', 31.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-02 00:00:00', 31.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-03 00:00:00', 33.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-04 00:00:00', 33.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-05 00:00:00', 34.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-06 00:00:00', 34.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-07 00:00:00', 35.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-08 00:00:00', 37.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-09 00:00:00', 33.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-10 00:00:00', 28.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-11 00:00:00', 29.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-12 00:00:00', 29.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-13 00:00:00', 30.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-14 00:00:00', 31.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-15 00:00:00', 30.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-16 00:00:00', 32.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-17 00:00:00', 34.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-18 00:00:00', 32.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-19 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-20 00:00:00', 33.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-21 00:00:00', 33.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-22 00:00:00', 36.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-23 00:00:00', 31.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-24 00:00:00', 30.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-25 00:00:00', 29.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-26 00:00:00', 30.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-27 00:00:00', 29.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-28 00:00:00', 28.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-29 00:00:00', 30.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-09-30 00:00:00', 31.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-01 00:00:00', 31.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-02 00:00:00', 31.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-03 00:00:00', 32.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-04 00:00:00', 32.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-05 00:00:00', 33.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-06 00:00:00', 32.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-07 00:00:00', 26.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-08 00:00:00', 25.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-09 00:00:00', 25.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-10 00:00:00', 18.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-11 00:00:00', 16.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-12 00:00:00', 22.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-13 00:00:00', 23.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-14 00:00:00', 24.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-15 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-16 00:00:00', 20.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-17 00:00:00', 20.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-18 00:00:00', 23.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-19 00:00:00', 24.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-20 00:00:00', 26.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-21 00:00:00', 18.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-22 00:00:00', 16.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-23 00:00:00', 17.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-24 00:00:00', 20.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-25 00:00:00', 23.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-26 00:00:00', 23.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-27 00:00:00', 23.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-28 00:00:00', 22.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-29 00:00:00', 18.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-30 00:00:00', 20.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-10-31 00:00:00', 20.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-01 00:00:00', 21.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-02 00:00:00', 22.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-03 00:00:00', 19.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-04 00:00:00', 16.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-05 00:00:00', 15.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-06 00:00:00', 16.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-07 00:00:00', 19.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-08 00:00:00', 19.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-09 00:00:00', 22.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-10 00:00:00', 24.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-11 00:00:00', 21.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-12 00:00:00', 24.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-13 00:00:00', 23.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-14 00:00:00', 23.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-15 00:00:00', 21.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-16 00:00:00', 19.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-17 00:00:00', 22.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-18 00:00:00', 20.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-19 00:00:00', 16.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-20 00:00:00', 17.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-21 00:00:00', 16.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-22 00:00:00', 19.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-23 00:00:00', 19.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-24 00:00:00', 14.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-25 00:00:00', 10.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-26 00:00:00', 10.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-27 00:00:00', 12.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-28 00:00:00', 16.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-29 00:00:00', 18.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-11-30 00:00:00', 17.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-01 00:00:00', 15.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-02 00:00:00', 12.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-03 00:00:00', 13.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-04 00:00:00', 15.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-05 00:00:00', 15.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-06 00:00:00', 16.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-07 00:00:00', 19.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-08 00:00:00', 20.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-09 00:00:00', 15.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-10 00:00:00', 14.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-11 00:00:00', 13.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-12 00:00:00', 11.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-13 00:00:00', 10.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-14 00:00:00', 6.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-15 00:00:00', 7.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-16 00:00:00', 8.50399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-17 00:00:00', 11.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-18 00:00:00', 8.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-19 00:00:00', 12.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-20 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-21 00:00:00', 6.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-22 00:00:00', 10.6129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-23 00:00:00', 13.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-24 00:00:00', 12.6059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-25 00:00:00', 12.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-26 00:00:00', 7.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-27 00:00:00', 5.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-28 00:00:00', 5.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-29 00:00:00', 8.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-30 00:00:00', 10.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1980-12-31 00:00:00', 6.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-01 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-02 00:00:00', 4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-03 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-04 00:00:00', 7.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-05 00:00:00', 6.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-06 00:00:00', 8.62100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-07 00:00:00', 9.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-08 00:00:00', 10.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-09 00:00:00', 6.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-10 00:00:00', 8.71599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-11 00:00:00', 11.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-12 00:00:00', 11.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-13 00:00:00', 10.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-14 00:00:00', 6.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-15 00:00:00', 3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-16 00:00:00', 6.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-17 00:00:00', 9.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-18 00:00:00', 10.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-19 00:00:00', 13.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-20 00:00:00', 11.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-21 00:00:00', 10.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-22 00:00:00', 12.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-23 00:00:00', 7.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-24 00:00:00', 3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-25 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-26 00:00:00', 8.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-27 00:00:00', 9.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-28 00:00:00', 8.24400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-29 00:00:00', 9.62800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-30 00:00:00', 6.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-01-31 00:00:00', 5.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-01 00:00:00', 7.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-02 00:00:00', 6.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-03 00:00:00', 8.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-04 00:00:00', 5.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-05 00:00:00', 8.78600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-06 00:00:00', 11.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-07 00:00:00', 11.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-08 00:00:00', 13.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-09 00:00:00', 13.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-10 00:00:00', 13.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-11 00:00:00', 10.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-12 00:00:00', 8.66899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-13 00:00:00', 8.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-14 00:00:00', 9.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-15 00:00:00', 11.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-16 00:00:00', 10.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-17 00:00:00', 8.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-18 00:00:00', 9.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-19 00:00:00', 13.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-20 00:00:00', 12.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-21 00:00:00', 16.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-22 00:00:00', 13.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-23 00:00:00', 7.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-24 00:00:00', 5.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-25 00:00:00', 9.35999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-26 00:00:00', 7.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-27 00:00:00', 11.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-02-28 00:00:00', 7.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-01 00:00:00', 7.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-02 00:00:00', 11.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-03 00:00:00', 13.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-04 00:00:00', 16.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-05 00:00:00', 13.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-06 00:00:00', 14.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-07 00:00:00', 15.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-08 00:00:00', 16.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-09 00:00:00', 13.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-10 00:00:00', 15.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-11 00:00:00', 15.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-12 00:00:00', 19.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-13 00:00:00', 20.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-14 00:00:00', 21.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-15 00:00:00', 20.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-16 00:00:00', 18.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-17 00:00:00', 13.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-18 00:00:00', 14.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-19 00:00:00', 15.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-20 00:00:00', 13.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-21 00:00:00', 16.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-22 00:00:00', 20.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-23 00:00:00', 23.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-24 00:00:00', 20.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-25 00:00:00', 23.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-26 00:00:00', 19.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-27 00:00:00', 22.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-28 00:00:00', 26.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-29 00:00:00', 21.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-30 00:00:00', 18.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-03-31 00:00:00', 20.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-01 00:00:00', 23.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-02 00:00:00', 20.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-03 00:00:00', 7.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-04 00:00:00', 12.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-05 00:00:00', 17.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-06 00:00:00', 20.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-07 00:00:00', 21.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-08 00:00:00', 21.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-09 00:00:00', 26.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-10 00:00:00', 21.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-11 00:00:00', 18.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-12 00:00:00', 13.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-13 00:00:00', 21.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-14 00:00:00', 7.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-15 00:00:00', 18.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-16 00:00:00', 23.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-17 00:00:00', 27.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-18 00:00:00', 32.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-19 00:00:00', 21.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-20 00:00:00', 19.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-21 00:00:00', 22.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-22 00:00:00', 24.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-23 00:00:00', 27.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-24 00:00:00', 30.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-25 00:00:00', 31.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-26 00:00:00', 32.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-27 00:00:00', 33.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-28 00:00:00', 30.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-29 00:00:00', 31.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-04-30 00:00:00', 27.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-01 00:00:00', 31.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-02 00:00:00', 33.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-03 00:00:00', 33.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-04 00:00:00', 22.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-05 00:00:00', 26.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-06 00:00:00', 29.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-07 00:00:00', 30.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-08 00:00:00', 23.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-09 00:00:00', 29.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-10 00:00:00', 30.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-11 00:00:00', 30.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-12 00:00:00', 30.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-13 00:00:00', 32.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-14 00:00:00', 26.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-15 00:00:00', 31.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-16 00:00:00', 34.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-17 00:00:00', 34.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-18 00:00:00', 29.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-19 00:00:00', 28.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-20 00:00:00', 27.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-21 00:00:00', 30.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-22 00:00:00', 32.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-23 00:00:00', 33.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-24 00:00:00', 37.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-25 00:00:00', 35.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-26 00:00:00', 35.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-27 00:00:00', 35.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-28 00:00:00', 36.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-29 00:00:00', 33.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-30 00:00:00', 27.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-05-31 00:00:00', 27.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-01 00:00:00', 27.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-02 00:00:00', 29.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-03 00:00:00', 32.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-04 00:00:00', 32.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-05 00:00:00', 35.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-06 00:00:00', 35.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-07 00:00:00', 30.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-08 00:00:00', 30.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-09 00:00:00', 31.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-10 00:00:00', 31.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-11 00:00:00', 31.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-12 00:00:00', 33.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-13 00:00:00', 33.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-14 00:00:00', 32.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-15 00:00:00', 37.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-16 00:00:00', 38.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-17 00:00:00', 40.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-18 00:00:00', 39.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-19 00:00:00', 40.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-20 00:00:00', 40.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-21 00:00:00', 38.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-22 00:00:00', 39.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-23 00:00:00', 39.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-24 00:00:00', 39.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-25 00:00:00', 39.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-26 00:00:00', 38.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-27 00:00:00', 39.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-28 00:00:00', 38.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-29 00:00:00', 39.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-06-30 00:00:00', 37.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-01 00:00:00', 36.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-02 00:00:00', 37.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-03 00:00:00', 37.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-04 00:00:00', 40.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-05 00:00:00', 39.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-06 00:00:00', 41.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-07 00:00:00', 41.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-08 00:00:00', 36.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-09 00:00:00', 40.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-10 00:00:00', 39.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-11 00:00:00', 41.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-12 00:00:00', 42.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-13 00:00:00', 44.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-14 00:00:00', 45.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-15 00:00:00', 42.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-16 00:00:00', 39.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-17 00:00:00', 38.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-18 00:00:00', 38.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-19 00:00:00', 38.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-20 00:00:00', 38.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-21 00:00:00', 40.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-22 00:00:00', 35.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-23 00:00:00', 33.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-24 00:00:00', 32.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-25 00:00:00', 35.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-26 00:00:00', 38.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-27 00:00:00', 38.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-28 00:00:00', 38.4129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-29 00:00:00', 37.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-30 00:00:00', 35.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-07-31 00:00:00', 37.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-01 00:00:00', 35.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-02 00:00:00', 36.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-03 00:00:00', 35.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-04 00:00:00', 35.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-05 00:00:00', 35.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-06 00:00:00', 37.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-07 00:00:00', 37.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-08 00:00:00', 39.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-09 00:00:00', 41.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-10 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-11 00:00:00', 39.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-12 00:00:00', 36.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-13 00:00:00', 35.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-14 00:00:00', 36.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-15 00:00:00', 37.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-16 00:00:00', 37.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-17 00:00:00', 38.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-18 00:00:00', 38.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-19 00:00:00', 35.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-20 00:00:00', 34.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-21 00:00:00', 33.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-22 00:00:00', 33.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-23 00:00:00', 33.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-24 00:00:00', 35.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-25 00:00:00', 34.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-26 00:00:00', 33.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-27 00:00:00', 33.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-28 00:00:00', 33.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-29 00:00:00', 34.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-30 00:00:00', 34.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-08-31 00:00:00', 35.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-01 00:00:00', 35.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-02 00:00:00', 32.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-03 00:00:00', 31.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-04 00:00:00', 31.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-05 00:00:00', 31.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-06 00:00:00', 31.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-07 00:00:00', 31.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-08 00:00:00', 32.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-09 00:00:00', 32.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-10 00:00:00', 31.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-11 00:00:00', 31.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-12 00:00:00', 33.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-13 00:00:00', 34.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-14 00:00:00', 36.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-15 00:00:00', 37.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-16 00:00:00', 37.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-17 00:00:00', 37.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-18 00:00:00', 37.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-19 00:00:00', 37.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-20 00:00:00', 36.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-21 00:00:00', 35.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-22 00:00:00', 33.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-23 00:00:00', 21.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-24 00:00:00', 21.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-25 00:00:00', 26.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-26 00:00:00', 28.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-27 00:00:00', 27.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-28 00:00:00', 27.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-29 00:00:00', 25.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-09-30 00:00:00', 26.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-01 00:00:00', 24.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-02 00:00:00', 21.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-03 00:00:00', 22.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-04 00:00:00', 24.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-05 00:00:00', 24.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-06 00:00:00', 23.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-07 00:00:00', 22.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-08 00:00:00', 24.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-09 00:00:00', 25.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-10 00:00:00', 24.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-11 00:00:00', 23.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-12 00:00:00', 24.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-13 00:00:00', 26.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-14 00:00:00', 21.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-15 00:00:00', 22.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-16 00:00:00', 22.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-17 00:00:00', 25.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-18 00:00:00', 22.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-19 00:00:00', 18.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-20 00:00:00', 16.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-21 00:00:00', 20.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-22 00:00:00', 21.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-23 00:00:00', 18.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-24 00:00:00', 18.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-25 00:00:00', 19.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-26 00:00:00', 18.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-27 00:00:00', 19.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-28 00:00:00', 18.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-29 00:00:00', 18.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-30 00:00:00', 17.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-10-31 00:00:00', 18.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-01 00:00:00', 19.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-02 00:00:00', 21.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-03 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-04 00:00:00', 21.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-05 00:00:00', 23.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-06 00:00:00', 24.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-07 00:00:00', 19.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-08 00:00:00', 16.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-09 00:00:00', 17.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-10 00:00:00', 16.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-11 00:00:00', 18.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-12 00:00:00', 19.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-13 00:00:00', 21.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-14 00:00:00', 22.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-15 00:00:00', 20.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-16 00:00:00', 17.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-17 00:00:00', 16.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-18 00:00:00', 17.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-19 00:00:00', 18.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-20 00:00:00', 18.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-21 00:00:00', 17.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-22 00:00:00', 17.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-23 00:00:00', 14.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-24 00:00:00', 8.93700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-25 00:00:00', 11.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-26 00:00:00', 12.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-27 00:00:00', 13.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-28 00:00:00', 15.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-29 00:00:00', 14.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-11-30 00:00:00', 14.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-01 00:00:00', 12.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-02 00:00:00', 8.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-03 00:00:00', 10.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-04 00:00:00', 10.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-05 00:00:00', 13.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-06 00:00:00', 12.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-07 00:00:00', 11.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-08 00:00:00', 8.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-09 00:00:00', 12.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-10 00:00:00', 12.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-11 00:00:00', 13.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-12 00:00:00', 14.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-13 00:00:00', 14.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-14 00:00:00', 13.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-15 00:00:00', 12.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-16 00:00:00', 11.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-17 00:00:00', 15.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-18 00:00:00', 15.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-19 00:00:00', 16.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-20 00:00:00', 12.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-21 00:00:00', 9.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-22 00:00:00', 10.9940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-23 00:00:00', 13.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-24 00:00:00', 15.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-25 00:00:00', 12.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-26 00:00:00', 12.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-27 00:00:00', 7.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-28 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-29 00:00:00', 7.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-30 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1981-12-31 00:00:00', 7.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-01 00:00:00', 7.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-02 00:00:00', 9.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-03 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-04 00:00:00', 9.54399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-05 00:00:00', 12.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-06 00:00:00', 14.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-07 00:00:00', 17.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-08 00:00:00', 16.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-09 00:00:00', 16.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-10 00:00:00', 14.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-11 00:00:00', 12.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-12 00:00:00', 7.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-13 00:00:00', 5.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-14 00:00:00', 5.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-15 00:00:00', 7.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-16 00:00:00', 7.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-17 00:00:00', 9.48900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-18 00:00:00', 7.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-19 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-20 00:00:00', 0.832000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-21 00:00:00', -0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-22 00:00:00', -1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-23 00:00:00', 0.104000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-24 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-25 00:00:00', 3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-26 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-27 00:00:00', 6.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-28 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-29 00:00:00', 5.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-30 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-01-31 00:00:00', 6.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-01 00:00:00', 9.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-02 00:00:00', 8.26799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-03 00:00:00', 8.10299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-04 00:00:00', 9.37399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-05 00:00:00', 10.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-06 00:00:00', 7.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-07 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-08 00:00:00', 5.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-09 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-10 00:00:00', 5.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-11 00:00:00', 5.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-12 00:00:00', 5.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-13 00:00:00', 7.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-14 00:00:00', 11.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-15 00:00:00', 7.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-16 00:00:00', 7.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-17 00:00:00', 10.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-18 00:00:00', 11.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-19 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-20 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-21 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-22 00:00:00', 8.45199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-23 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-24 00:00:00', 8.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-25 00:00:00', 11.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-26 00:00:00', 8.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-27 00:00:00', 9.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-02-28 00:00:00', 9.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-01 00:00:00', 8.80500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-02 00:00:00', 10.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-03 00:00:00', 11.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-04 00:00:00', 6.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-05 00:00:00', 7.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-06 00:00:00', 7.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-07 00:00:00', 9.17099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-08 00:00:00', 9.12600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-09 00:00:00', 8.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-10 00:00:00', 10.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-11 00:00:00', 13.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-12 00:00:00', 14.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-13 00:00:00', 11.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-14 00:00:00', 15.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-15 00:00:00', 14.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-16 00:00:00', 13.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-17 00:00:00', 13.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-18 00:00:00', 15.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-19 00:00:00', 13.8970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-20 00:00:00', 13.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-21 00:00:00', 11.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-22 00:00:00', 14.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-23 00:00:00', 17.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-24 00:00:00', 18.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-25 00:00:00', 18.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-26 00:00:00', 11.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-27 00:00:00', 12.2440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-28 00:00:00', 13.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-29 00:00:00', 12.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-30 00:00:00', 10.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-03-31 00:00:00', 13.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-01 00:00:00', 16.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-02 00:00:00', 20.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-03 00:00:00', 14.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-04 00:00:00', 14.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-05 00:00:00', 12.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-06 00:00:00', 17.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-07 00:00:00', 22.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-08 00:00:00', 24.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-09 00:00:00', 25.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-10 00:00:00', 26.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-11 00:00:00', 23.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-12 00:00:00', 26.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-13 00:00:00', 27.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-14 00:00:00', 26.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-15 00:00:00', 24.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-16 00:00:00', 24.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-17 00:00:00', 26.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-18 00:00:00', 26.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-19 00:00:00', 29.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-20 00:00:00', 30.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-21 00:00:00', 30.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-22 00:00:00', 31.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-23 00:00:00', 32.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-24 00:00:00', 26.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-25 00:00:00', 28.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-26 00:00:00', 26.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-27 00:00:00', 26.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-28 00:00:00', 28.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-29 00:00:00', 29.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-04-30 00:00:00', 32.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-01 00:00:00', 33.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-02 00:00:00', 32.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-03 00:00:00', 35.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-04 00:00:00', 34.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-05 00:00:00', 33.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-06 00:00:00', 32.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-07 00:00:00', 34.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-08 00:00:00', 34.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-09 00:00:00', 31.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-10 00:00:00', 27.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-11 00:00:00', 24.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-12 00:00:00', 26.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-13 00:00:00', 30.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-14 00:00:00', 28.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-15 00:00:00', 29.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-16 00:00:00', 32.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-17 00:00:00', 34.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-18 00:00:00', 33.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-19 00:00:00', 34.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-20 00:00:00', 36.0120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-21 00:00:00', 37.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-22 00:00:00', 32.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-23 00:00:00', 35.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-24 00:00:00', 34.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-25 00:00:00', 30.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-26 00:00:00', 28.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-27 00:00:00', 29.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-28 00:00:00', 31.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-29 00:00:00', 27.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-30 00:00:00', 30.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-05-31 00:00:00', 30.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-01 00:00:00', 32.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-02 00:00:00', 35.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-03 00:00:00', 34.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-04 00:00:00', 35.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-05 00:00:00', 38.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-06 00:00:00', 38.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-07 00:00:00', 37.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-08 00:00:00', 35.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-09 00:00:00', 38.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-10 00:00:00', 40.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-11 00:00:00', 39.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-12 00:00:00', 39.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-13 00:00:00', 39.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-14 00:00:00', 35.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-15 00:00:00', 35.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-16 00:00:00', 36.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-17 00:00:00', 33.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-18 00:00:00', 33.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-19 00:00:00', 35.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-20 00:00:00', 36.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-21 00:00:00', 39.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-22 00:00:00', 38.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-23 00:00:00', 39.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-24 00:00:00', 39.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-25 00:00:00', 39.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-26 00:00:00', 37.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-27 00:00:00', 38.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-28 00:00:00', 38.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-29 00:00:00', 39.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-06-30 00:00:00', 28.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-01 00:00:00', 30.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-02 00:00:00', 33.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-03 00:00:00', 36.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-04 00:00:00', 38.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-05 00:00:00', 37.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-06 00:00:00', 37.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-07 00:00:00', 36.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-08 00:00:00', 36.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-09 00:00:00', 36.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-10 00:00:00', 37.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-11 00:00:00', 39.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-12 00:00:00', 35.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-13 00:00:00', 37.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-14 00:00:00', 38.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-15 00:00:00', 40.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-16 00:00:00', 40.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-17 00:00:00', 40.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-18 00:00:00', 40.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-19 00:00:00', 42.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-20 00:00:00', 40.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-21 00:00:00', 39.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-22 00:00:00', 40.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-23 00:00:00', 40.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-24 00:00:00', 41.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-25 00:00:00', 39.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-26 00:00:00', 42.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-27 00:00:00', 42.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-28 00:00:00', 42.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-29 00:00:00', 42.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-30 00:00:00', 42.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-07-31 00:00:00', 43.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-01 00:00:00', 44.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-02 00:00:00', 44.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-03 00:00:00', 42.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-04 00:00:00', 41.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-05 00:00:00', 43.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-06 00:00:00', 43.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-07 00:00:00', 43.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-08 00:00:00', 42.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-09 00:00:00', 42.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-10 00:00:00', 40.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-11 00:00:00', 34.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-12 00:00:00', 34.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-13 00:00:00', 37.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-14 00:00:00', 37.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-15 00:00:00', 37.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-16 00:00:00', 33.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-17 00:00:00', 34.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-18 00:00:00', 36.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-19 00:00:00', 36.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-20 00:00:00', 37.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-21 00:00:00', 36.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-22 00:00:00', 34.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-23 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-24 00:00:00', 29.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-25 00:00:00', 28.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-26 00:00:00', 31.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-27 00:00:00', 32.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-28 00:00:00', 34.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-29 00:00:00', 32.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-30 00:00:00', 32.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-08-31 00:00:00', 33.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-01 00:00:00', 34.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-02 00:00:00', 33.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-03 00:00:00', 32.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-04 00:00:00', 33.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-05 00:00:00', 33.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-06 00:00:00', 32.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-07 00:00:00', 32.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-08 00:00:00', 31.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-09 00:00:00', 32.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-10 00:00:00', 32.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-11 00:00:00', 33.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-12 00:00:00', 33.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-13 00:00:00', 34.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-14 00:00:00', 33.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-15 00:00:00', 32.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-16 00:00:00', 32.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-17 00:00:00', 27.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-18 00:00:00', 28.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-19 00:00:00', 29.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-20 00:00:00', 24.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-21 00:00:00', 23.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-22 00:00:00', 24.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-23 00:00:00', 24.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-24 00:00:00', 26.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-25 00:00:00', 26.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-26 00:00:00', 25.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-27 00:00:00', 27.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-28 00:00:00', 27.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-29 00:00:00', 27.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-09-30 00:00:00', 26.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-01 00:00:00', 27.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-02 00:00:00', 29.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-03 00:00:00', 30.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-04 00:00:00', 27.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-05 00:00:00', 28.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-06 00:00:00', 28.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-07 00:00:00', 22.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-08 00:00:00', 20.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-09 00:00:00', 21.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-10 00:00:00', 26.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-11 00:00:00', 23.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-12 00:00:00', 24.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-13 00:00:00', 26.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-14 00:00:00', 28.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-15 00:00:00', 28.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-16 00:00:00', 28.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-17 00:00:00', 26.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-18 00:00:00', 26.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-19 00:00:00', 26.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-20 00:00:00', 25.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-21 00:00:00', 27.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-22 00:00:00', 24.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-23 00:00:00', 21.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-24 00:00:00', 17.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-25 00:00:00', 10.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-26 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-27 00:00:00', 10.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-28 00:00:00', 16.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-29 00:00:00', 20.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-30 00:00:00', 20.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-10-31 00:00:00', 16.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-01 00:00:00', 14.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-02 00:00:00', 12.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-03 00:00:00', 9.87100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-04 00:00:00', 15.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-05 00:00:00', 16.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-06 00:00:00', 18.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-07 00:00:00', 21.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-08 00:00:00', 19.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-09 00:00:00', 21.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-10 00:00:00', 13.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-11 00:00:00', 8.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-12 00:00:00', 12.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-13 00:00:00', 10.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-14 00:00:00', 6.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-15 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-16 00:00:00', 6.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-17 00:00:00', 9.53600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-18 00:00:00', 7.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-19 00:00:00', 10.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-20 00:00:00', 9.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-21 00:00:00', 9.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-22 00:00:00', 11.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-23 00:00:00', 11.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-24 00:00:00', 5.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-25 00:00:00', 8.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-26 00:00:00', 9.55500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-27 00:00:00', 9.30300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-28 00:00:00', 9.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-29 00:00:00', 4.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-11-30 00:00:00', 6.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-01 00:00:00', 2.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-02 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-03 00:00:00', 8.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-04 00:00:00', 10.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-05 00:00:00', 10.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-06 00:00:00', 8.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-07 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-08 00:00:00', 2.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-09 00:00:00', -2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-10 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-11 00:00:00', 1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-12 00:00:00', 2.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-13 00:00:00', 2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-14 00:00:00', 5.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-15 00:00:00', 8.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-16 00:00:00', 6.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-17 00:00:00', 8.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-18 00:00:00', 11.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-19 00:00:00', 10.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-20 00:00:00', 10.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-21 00:00:00', 9.66399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-22 00:00:00', 10.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-23 00:00:00', 9.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-24 00:00:00', 11.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-25 00:00:00', 10.2899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-26 00:00:00', 11.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-27 00:00:00', 6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-28 00:00:00', 7.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-29 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-30 00:00:00', 6.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1982-12-31 00:00:00', 5.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-01 00:00:00', 7.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-02 00:00:00', 9.14299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-03 00:00:00', 9.66199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-04 00:00:00', 8.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-05 00:00:00', 6.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-06 00:00:00', 9.75300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-07 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-08 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-09 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-10 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-11 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-12 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-13 00:00:00', 7.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-14 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-15 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-16 00:00:00', 9.59099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-17 00:00:00', 8.74199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-18 00:00:00', 12.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-19 00:00:00', 11.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-20 00:00:00', 14.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-21 00:00:00', 16.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-22 00:00:00', 10.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-23 00:00:00', 12.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-24 00:00:00', 14.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-25 00:00:00', 11.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-26 00:00:00', 9.01299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-27 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-28 00:00:00', -0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-29 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-30 00:00:00', 1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-01-31 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-01 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-02 00:00:00', 5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-03 00:00:00', 5.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-04 00:00:00', 5.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-05 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-06 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-07 00:00:00', 5.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-08 00:00:00', 5.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-09 00:00:00', 5.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-10 00:00:00', 4.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-11 00:00:00', 8.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-12 00:00:00', 9.97000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-13 00:00:00', 8.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-14 00:00:00', 9.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-15 00:00:00', 12.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-16 00:00:00', 13.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-17 00:00:00', 15.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-18 00:00:00', 15.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-19 00:00:00', 14.2440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-20 00:00:00', 12.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-21 00:00:00', 11.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-22 00:00:00', 12.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-23 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-24 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-25 00:00:00', 7.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-26 00:00:00', 10.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-27 00:00:00', 11.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-02-28 00:00:00', 8.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-01 00:00:00', 9.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-02 00:00:00', 9.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-03 00:00:00', 10.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-04 00:00:00', 11.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-05 00:00:00', 14.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-06 00:00:00', 15.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-07 00:00:00', 8.84500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-08 00:00:00', 8.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-09 00:00:00', 12.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-10 00:00:00', 13.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-11 00:00:00', 10.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-12 00:00:00', 13.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-13 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-14 00:00:00', 9.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-15 00:00:00', 11.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-16 00:00:00', 11.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-17 00:00:00', 8.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-18 00:00:00', 7.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-19 00:00:00', 8.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-20 00:00:00', 7.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-21 00:00:00', 9.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-22 00:00:00', 12.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-23 00:00:00', 11.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-24 00:00:00', 14.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-25 00:00:00', 8.87600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-26 00:00:00', 6.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-27 00:00:00', 10.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-28 00:00:00', 11.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-29 00:00:00', 13.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-30 00:00:00', 14.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-03-31 00:00:00', 17.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-01 00:00:00', 18.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-02 00:00:00', 20.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-03 00:00:00', 23.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-04 00:00:00', 20.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-05 00:00:00', 21.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-06 00:00:00', 21.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-07 00:00:00', 18.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-08 00:00:00', 21.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-09 00:00:00', 18.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-10 00:00:00', 19.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-11 00:00:00', 21.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-12 00:00:00', 17.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-13 00:00:00', 19.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-14 00:00:00', 19.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-15 00:00:00', 19.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-16 00:00:00', 17.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-17 00:00:00', 20.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-18 00:00:00', 24.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-19 00:00:00', 25.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-20 00:00:00', 27.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-21 00:00:00', 28.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-22 00:00:00', 25.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-23 00:00:00', 27.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-24 00:00:00', 28.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-25 00:00:00', 30.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-26 00:00:00', 27.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-27 00:00:00', 25.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-28 00:00:00', 27.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-29 00:00:00', 19.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-04-30 00:00:00', 20.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-01 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-02 00:00:00', 27.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-03 00:00:00', 24.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-04 00:00:00', 24.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-05 00:00:00', 28.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-06 00:00:00', 32.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-07 00:00:00', 35.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-08 00:00:00', 28.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-09 00:00:00', 32.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-10 00:00:00', 32.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-11 00:00:00', 29.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-12 00:00:00', 31.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-13 00:00:00', 30.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-14 00:00:00', 32.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-15 00:00:00', 32.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-16 00:00:00', 33.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-17 00:00:00', 34.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-18 00:00:00', 34.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-19 00:00:00', 31.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-20 00:00:00', 32.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-21 00:00:00', 32.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-22 00:00:00', 30.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-23 00:00:00', 32.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-24 00:00:00', 33.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-25 00:00:00', 35.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-26 00:00:00', 36.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-27 00:00:00', 36.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-28 00:00:00', 35.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-29 00:00:00', 35.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-30 00:00:00', 30.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-05-31 00:00:00', 24.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-01 00:00:00', 27.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-02 00:00:00', 28.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-03 00:00:00', 32.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-04 00:00:00', 33.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-05 00:00:00', 34.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-06 00:00:00', 34.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-07 00:00:00', 35.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-08 00:00:00', 34.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-09 00:00:00', 34.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-10 00:00:00', 35.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-11 00:00:00', 36.0120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-12 00:00:00', 37.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-13 00:00:00', 38.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-14 00:00:00', 37.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-15 00:00:00', 36.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-16 00:00:00', 35.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-17 00:00:00', 35.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-18 00:00:00', 34.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-19 00:00:00', 39.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-20 00:00:00', 38.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-21 00:00:00', 39.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-22 00:00:00', 40.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-23 00:00:00', 40.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-24 00:00:00', 44.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-25 00:00:00', 42.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-26 00:00:00', 42.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-27 00:00:00', 42.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-28 00:00:00', 42.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-29 00:00:00', 41.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-06-30 00:00:00', 41.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-01 00:00:00', 40.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-02 00:00:00', 37.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-03 00:00:00', 36.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-04 00:00:00', 37.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-05 00:00:00', 37.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-06 00:00:00', 37.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-07 00:00:00', 38.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-08 00:00:00', 40.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-09 00:00:00', 41.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-10 00:00:00', 41.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-11 00:00:00', 40.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-12 00:00:00', 39.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-13 00:00:00', 39.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-14 00:00:00', 40.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-15 00:00:00', 40.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-16 00:00:00', 41.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-17 00:00:00', 43.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-18 00:00:00', 41.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-19 00:00:00', 39.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-20 00:00:00', 39.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-21 00:00:00', 42.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-22 00:00:00', 45.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-23 00:00:00', 45.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-24 00:00:00', 46.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-25 00:00:00', 44.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-26 00:00:00', 39.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-27 00:00:00', 39.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-28 00:00:00', 45.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-29 00:00:00', 45.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-30 00:00:00', 45.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-07-31 00:00:00', 45.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-01 00:00:00', 44.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-02 00:00:00', 40.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-03 00:00:00', 41.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-04 00:00:00', 42.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-05 00:00:00', 42.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-06 00:00:00', 41.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-07 00:00:00', 39.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-08 00:00:00', 37.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-09 00:00:00', 36.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-10 00:00:00', 36.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-11 00:00:00', 37.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-12 00:00:00', 37.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-13 00:00:00', 39.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-14 00:00:00', 39.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-15 00:00:00', 40.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-16 00:00:00', 41.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-17 00:00:00', 39.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-18 00:00:00', 39.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-19 00:00:00', 39.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-20 00:00:00', 39.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-21 00:00:00', 39.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-22 00:00:00', 39.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-23 00:00:00', 40.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-24 00:00:00', 40.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-25 00:00:00', 38.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-26 00:00:00', 34.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-27 00:00:00', 34.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-28 00:00:00', 36.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-29 00:00:00', 38.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-30 00:00:00', 40.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-08-31 00:00:00', 40.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-01 00:00:00', 24.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-03 00:00:00', 26.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-05 00:00:00', 28.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-07 00:00:00', 30.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-09 00:00:00', 28.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-11 00:00:00', 32.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-13 00:00:00', 28.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-15 00:00:00', 23.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-17 00:00:00', 22.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-19 00:00:00', 23.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-21 00:00:00', 26.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-23 00:00:00', 26.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-25 00:00:00', 27.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-27 00:00:00', 19.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-29 00:00:00', 20.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-01 00:00:00', 23.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-03 00:00:00', 18.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-05 00:00:00', 19.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-07 00:00:00', 20.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-09 00:00:00', 19.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-11 00:00:00', 18.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-13 00:00:00', 20.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-15 00:00:00', 20.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-17 00:00:00', 20.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-19 00:00:00', 20.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-21 00:00:00', 21.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-23 00:00:00', 19.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-25 00:00:00', 22.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-27 00:00:00', 23.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-29 00:00:00', 20.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-30 00:00:00', 22.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-10-31 00:00:00', 23.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-01 00:00:00', 24.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-02 00:00:00', 20.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-03 00:00:00', 17.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-04 00:00:00', 16.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-05 00:00:00', 9.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-06 00:00:00', 12.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-07 00:00:00', 18.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-08 00:00:00', 18.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-09 00:00:00', 16.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-10 00:00:00', 17.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-11 00:00:00', 19.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-12 00:00:00', 20.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-13 00:00:00', 23.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-14 00:00:00', 24.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-15 00:00:00', 24.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-16 00:00:00', 21.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-17 00:00:00', 17.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-18 00:00:00', 19.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-19 00:00:00', 20.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-20 00:00:00', 20.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-21 00:00:00', 20.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-22 00:00:00', 21.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-23 00:00:00', 21.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-24 00:00:00', 22.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-25 00:00:00', 20.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-26 00:00:00', 13.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-27 00:00:00', 11.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-28 00:00:00', 16.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-29 00:00:00', 20.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-11-30 00:00:00', 20.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-01 00:00:00', 19.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-02 00:00:00', 19.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-03 00:00:00', 16.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-04 00:00:00', 8.44499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-05 00:00:00', 11.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-06 00:00:00', 12.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-07 00:00:00', 14.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-08 00:00:00', 14.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-09 00:00:00', 15.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-10 00:00:00', 11.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-11 00:00:00', 15.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-12 00:00:00', 16.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-13 00:00:00', 13.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-14 00:00:00', 11.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-15 00:00:00', 9.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-16 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-17 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-18 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-19 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-20 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-21 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-22 00:00:00', 1.27799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-23 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-24 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-25 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-26 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-27 00:00:00', 9.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-28 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-29 00:00:00', 6.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-30 00:00:00', 8.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1983-12-31 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-01 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-02 00:00:00', 10.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-03 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-04 00:00:00', 7.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-05 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-06 00:00:00', 3.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-07 00:00:00', 7.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-08 00:00:00', 7.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-09 00:00:00', 9.58100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-10 00:00:00', 10.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-11 00:00:00', 6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-12 00:00:00', 5.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-13 00:00:00', 7.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-14 00:00:00', 7.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-15 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-16 00:00:00', 3.51799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-17 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-18 00:00:00', 0.842000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-19 00:00:00', 0.748000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-20 00:00:00', 0.954999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-21 00:00:00', 0.115999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-22 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-23 00:00:00', 1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-24 00:00:00', 1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-25 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-26 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-27 00:00:00', 1.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-28 00:00:00', 3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-29 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-30 00:00:00', 7.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-01-31 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-01 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-02 00:00:00', 1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-03 00:00:00', -0.873000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-04 00:00:00', -2.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-05 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-06 00:00:00', -1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-07 00:00:00', -4.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-08 00:00:00', -0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-09 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-10 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-11 00:00:00', 0.887000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-12 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-13 00:00:00', 5.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-14 00:00:00', 6.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-15 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-16 00:00:00', -0.788999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-17 00:00:00', -1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-18 00:00:00', -3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-19 00:00:00', -4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-20 00:00:00', -6.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-21 00:00:00', -5.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-22 00:00:00', -2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-23 00:00:00', -2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-24 00:00:00', 0.143000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-25 00:00:00', -0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-26 00:00:00', 0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-27 00:00:00', 1.2489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-28 00:00:00', 0.68199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-02-29 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-01 00:00:00', 2.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-02 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-03 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-04 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-05 00:00:00', 1.18200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-06 00:00:00', 5.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-07 00:00:00', 7.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-08 00:00:00', 7.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-09 00:00:00', 8.70400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-10 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-11 00:00:00', 6.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-12 00:00:00', 9.84599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-13 00:00:00', 12.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-14 00:00:00', 14.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-15 00:00:00', 14.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-16 00:00:00', 17.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-17 00:00:00', 8.66199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-18 00:00:00', 9.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-19 00:00:00', 13.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-20 00:00:00', 17.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-21 00:00:00', 16.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-22 00:00:00', 19.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-23 00:00:00', 20.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-24 00:00:00', 22.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-25 00:00:00', 17.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-26 00:00:00', 20.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-27 00:00:00', 16.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-28 00:00:00', 15.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-29 00:00:00', 17.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-30 00:00:00', 19.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-03-31 00:00:00', 16.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-01 00:00:00', 18.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-02 00:00:00', 18.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-03 00:00:00', 17.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-04 00:00:00', 16.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-05 00:00:00', 11.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-06 00:00:00', 17.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-07 00:00:00', 18.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-08 00:00:00', 19.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-09 00:00:00', 22.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-10 00:00:00', 22.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-11 00:00:00', 25.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-12 00:00:00', 27.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-13 00:00:00', 17.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-14 00:00:00', 20.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-15 00:00:00', 22.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-16 00:00:00', 26.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-17 00:00:00', 27.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-18 00:00:00', 30.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-19 00:00:00', 17.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-20 00:00:00', 17.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-21 00:00:00', 23.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-22 00:00:00', 26.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-23 00:00:00', 31.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-24 00:00:00', 32.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-25 00:00:00', 31.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-26 00:00:00', 29.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-27 00:00:00', 22.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-28 00:00:00', 23.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-29 00:00:00', 26.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-04-30 00:00:00', 26.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-01 00:00:00', 27.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-02 00:00:00', 31.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-03 00:00:00', 24.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-04 00:00:00', 28.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-05 00:00:00', 30.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-06 00:00:00', 32.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-07 00:00:00', 26.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-08 00:00:00', 27.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-09 00:00:00', 28.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-10 00:00:00', 30.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-11 00:00:00', 30.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-12 00:00:00', 26.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-13 00:00:00', 26.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-14 00:00:00', 27.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-15 00:00:00', 27.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-16 00:00:00', 27.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-17 00:00:00', 29.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-18 00:00:00', 32.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-19 00:00:00', 27.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-20 00:00:00', 30.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-21 00:00:00', 32.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-22 00:00:00', 34.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-23 00:00:00', 31.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-24 00:00:00', 34.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-25 00:00:00', 36.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-26 00:00:00', 37.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-27 00:00:00', 39.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-28 00:00:00', 35.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-29 00:00:00', 38.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-30 00:00:00', 40.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-05-31 00:00:00', 40.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-01 00:00:00', 37.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-02 00:00:00', 35.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-03 00:00:00', 34.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-04 00:00:00', 36.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-05 00:00:00', 36.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-06 00:00:00', 34.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-07 00:00:00', 35.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-08 00:00:00', 35.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-09 00:00:00', 38.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-10 00:00:00', 37.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-11 00:00:00', 37.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-12 00:00:00', 39.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-13 00:00:00', 39.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-14 00:00:00', 37.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-15 00:00:00', 39.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-16 00:00:00', 33.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-17 00:00:00', 32.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-18 00:00:00', 33.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-19 00:00:00', 34.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-20 00:00:00', 36.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-21 00:00:00', 36.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-22 00:00:00', 38.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-23 00:00:00', 40.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-24 00:00:00', 41.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-25 00:00:00', 41.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-26 00:00:00', 41.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-27 00:00:00', 39.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-28 00:00:00', 37.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-29 00:00:00', 38.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-06-30 00:00:00', 37.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-01 00:00:00', 38.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-02 00:00:00', 40.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-03 00:00:00', 38.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-04 00:00:00', 39.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-05 00:00:00', 40.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-06 00:00:00', 40.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-07 00:00:00', 40.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-08 00:00:00', 37.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-09 00:00:00', 41.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-10 00:00:00', 39.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-11 00:00:00', 41.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-12 00:00:00', 41.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-13 00:00:00', 42.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-14 00:00:00', 41.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-15 00:00:00', 42.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-16 00:00:00', 40.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-17 00:00:00', 41.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-18 00:00:00', 41.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-19 00:00:00', 41.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-20 00:00:00', 40.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-21 00:00:00', 40.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-22 00:00:00', 39.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-23 00:00:00', 40.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-24 00:00:00', 40.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-25 00:00:00', 41.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-26 00:00:00', 41.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-27 00:00:00', 40.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-28 00:00:00', 41.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-29 00:00:00', 40.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-30 00:00:00', 41.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-07-31 00:00:00', 40.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-01 00:00:00', 40.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-02 00:00:00', 41.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-03 00:00:00', 42.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-04 00:00:00', 41.7739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-05 00:00:00', 42.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-06 00:00:00', 38.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-07 00:00:00', 39.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-08 00:00:00', 41.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-09 00:00:00', 41.6570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-10 00:00:00', 39.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-11 00:00:00', 41.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-12 00:00:00', 38.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-13 00:00:00', 37.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-14 00:00:00', 38.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-15 00:00:00', 38.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-16 00:00:00', 39.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-17 00:00:00', 40.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-18 00:00:00', 41.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-19 00:00:00', 42.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-20 00:00:00', 43.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-21 00:00:00', 40.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-22 00:00:00', 37.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-23 00:00:00', 39.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-24 00:00:00', 40.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-25 00:00:00', 38.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-26 00:00:00', 37.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-27 00:00:00', 38.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-28 00:00:00', 39.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-29 00:00:00', 41.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-30 00:00:00', 40.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-08-31 00:00:00', 37.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-01 00:00:00', 35.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-02 00:00:00', 35.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-03 00:00:00', 34.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-04 00:00:00', 35.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-05 00:00:00', 34.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-06 00:00:00', 28.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-07 00:00:00', 29.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-08 00:00:00', 31.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-09 00:00:00', 32.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-10 00:00:00', 35.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-11 00:00:00', 33.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-12 00:00:00', 33.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-13 00:00:00', 33.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-14 00:00:00', 31.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-15 00:00:00', 32.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-16 00:00:00', 32.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-17 00:00:00', 32.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-18 00:00:00', 29.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-19 00:00:00', 25.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-20 00:00:00', 25.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-21 00:00:00', 28.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-22 00:00:00', 27.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-23 00:00:00', 27.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-24 00:00:00', 27.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-25 00:00:00', 28.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-26 00:00:00', 27.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-27 00:00:00', 26.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-28 00:00:00', 27.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-29 00:00:00', 27.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-09-30 00:00:00', 27.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-01 00:00:00', 25.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-02 00:00:00', 26.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-03 00:00:00', 26.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-04 00:00:00', 26.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-05 00:00:00', 26.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-06 00:00:00', 26.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-07 00:00:00', 26.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-08 00:00:00', 18.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-09 00:00:00', 16.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-10 00:00:00', 20.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-11 00:00:00', 22.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-12 00:00:00', 19.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-13 00:00:00', 19.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-14 00:00:00', 21.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-15 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-16 00:00:00', 23.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-17 00:00:00', 23.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-18 00:00:00', 25.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-19 00:00:00', 28.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-20 00:00:00', 29.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-21 00:00:00', 18.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-22 00:00:00', 14.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-23 00:00:00', 15.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-24 00:00:00', 18.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-25 00:00:00', 18.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-26 00:00:00', 17.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-27 00:00:00', 16.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-28 00:00:00', 17.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-29 00:00:00', 15.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-30 00:00:00', 16.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-10-31 00:00:00', 20.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-01 00:00:00', 19.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-02 00:00:00', 19.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-03 00:00:00', 22.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-04 00:00:00', 17.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-05 00:00:00', 21.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-06 00:00:00', 21.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-07 00:00:00', 19.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-08 00:00:00', 16.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-09 00:00:00', 14.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-10 00:00:00', 17.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-11 00:00:00', 15.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-12 00:00:00', 18.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-13 00:00:00', 17.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-14 00:00:00', 18.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-15 00:00:00', 15.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-16 00:00:00', 11.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-17 00:00:00', 8.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-18 00:00:00', 12.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-19 00:00:00', 11.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-20 00:00:00', 10.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-21 00:00:00', 7.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-22 00:00:00', 7.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-23 00:00:00', 8.64299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-24 00:00:00', 11.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-25 00:00:00', 13.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-26 00:00:00', 14.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-27 00:00:00', 10.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-28 00:00:00', 11.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-29 00:00:00', 13.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-11-30 00:00:00', 11.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-01 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-02 00:00:00', -0.69300001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-03 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-04 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-05 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-06 00:00:00', 0.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-07 00:00:00', 2.78099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-08 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-09 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-10 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-11 00:00:00', 6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-12 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-13 00:00:00', 5.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-14 00:00:00', 6.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-15 00:00:00', 5.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-16 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-17 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-18 00:00:00', 3.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-19 00:00:00', 1.05799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-20 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-21 00:00:00', -3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-22 00:00:00', -1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-23 00:00:00', -0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-24 00:00:00', -1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-25 00:00:00', -1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-26 00:00:00', -2.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-27 00:00:00', 0.280999988317489624, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-28 00:00:00', 0.78200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-29 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-30 00:00:00', -4.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1984-12-31 00:00:00', -2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-01 00:00:00', -0.377000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-02 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-03 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-04 00:00:00', 5.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-05 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-06 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-07 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-08 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-09 00:00:00', 6.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-10 00:00:00', 7.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-11 00:00:00', 7.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-12 00:00:00', 9.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-13 00:00:00', 8.18299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-14 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-15 00:00:00', 5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-16 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-17 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-18 00:00:00', -1.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-19 00:00:00', 2.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-20 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-21 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-22 00:00:00', 7.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-23 00:00:00', 7.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-24 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-25 00:00:00', 1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-26 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-27 00:00:00', 8.06700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-28 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-29 00:00:00', 8.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-30 00:00:00', 10.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-01-31 00:00:00', 10.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-01 00:00:00', 9.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-02 00:00:00', 9.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-03 00:00:00', 9.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-04 00:00:00', 11.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-05 00:00:00', 9.83600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-06 00:00:00', 12.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-07 00:00:00', 6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-08 00:00:00', 6.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-09 00:00:00', 9.18999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-10 00:00:00', 9.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-11 00:00:00', 8.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-12 00:00:00', 12.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-13 00:00:00', 15.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-14 00:00:00', 14.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-15 00:00:00', 15.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-16 00:00:00', 15.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-17 00:00:00', 17.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-18 00:00:00', 8.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-19 00:00:00', 8.35999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-20 00:00:00', 10.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-21 00:00:00', 14.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-22 00:00:00', 16.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-23 00:00:00', 12.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-24 00:00:00', 6.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-25 00:00:00', 11.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-26 00:00:00', 15.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-27 00:00:00', 17.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-02-28 00:00:00', 8.25599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-01 00:00:00', 9.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-02 00:00:00', 9.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-03 00:00:00', 8.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-04 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-05 00:00:00', 3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-06 00:00:00', 1.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-07 00:00:00', 5.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-08 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-09 00:00:00', 5.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-10 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-11 00:00:00', 5.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-12 00:00:00', 6.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-13 00:00:00', 10.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-14 00:00:00', 11.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-15 00:00:00', 9.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-16 00:00:00', 13.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-17 00:00:00', 12.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-18 00:00:00', 14.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-19 00:00:00', 17.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-20 00:00:00', 16.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-21 00:00:00', 17.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-22 00:00:00', 22.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-23 00:00:00', 16.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-24 00:00:00', 18.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-25 00:00:00', 16.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-26 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-27 00:00:00', 17.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-28 00:00:00', 17.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-29 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-30 00:00:00', 18.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-03-31 00:00:00', 22.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-01 00:00:00', 23.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-02 00:00:00', 19.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-03 00:00:00', 20.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-04 00:00:00', 21.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-05 00:00:00', 18.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-06 00:00:00', 14.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-07 00:00:00', 16.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-08 00:00:00', 18.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-09 00:00:00', 14.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-10 00:00:00', 17.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-11 00:00:00', 22.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-12 00:00:00', 21.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-13 00:00:00', 21.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-14 00:00:00', 22.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-15 00:00:00', 24.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-16 00:00:00', 22.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-17 00:00:00', 13.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-18 00:00:00', 16.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-19 00:00:00', 23.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-20 00:00:00', 28.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-21 00:00:00', 30.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-22 00:00:00', 30.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-23 00:00:00', 29.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-24 00:00:00', 30.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-25 00:00:00', 32.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-26 00:00:00', 31.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-27 00:00:00', 31.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-28 00:00:00', 30.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-29 00:00:00', 32.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-04-30 00:00:00', 25.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-01 00:00:00', 21.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-02 00:00:00', 26.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-03 00:00:00', 28.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-04 00:00:00', 28.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-05 00:00:00', 31.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-06 00:00:00', 31.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-07 00:00:00', 27.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-08 00:00:00', 27.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-09 00:00:00', 27.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-10 00:00:00', 27.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-11 00:00:00', 27.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-12 00:00:00', 28.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-13 00:00:00', 26.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-14 00:00:00', 26.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-15 00:00:00', 31.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-16 00:00:00', 32.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-17 00:00:00', 34.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-18 00:00:00', 35.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-19 00:00:00', 35.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-20 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-21 00:00:00', 34.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-22 00:00:00', 36.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-23 00:00:00', 32.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-24 00:00:00', 29.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-25 00:00:00', 28.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-26 00:00:00', 31.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-27 00:00:00', 33.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-28 00:00:00', 35.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-29 00:00:00', 35.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-30 00:00:00', 36.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-05-31 00:00:00', 35.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-01 00:00:00', 37.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-02 00:00:00', 35.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-03 00:00:00', 35.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-04 00:00:00', 39.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-05 00:00:00', 39.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-06 00:00:00', 35.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-07 00:00:00', 36.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-08 00:00:00', 36.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-09 00:00:00', 38.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-10 00:00:00', 34.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-11 00:00:00', 33.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-12 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-13 00:00:00', 37.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-14 00:00:00', 40, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-15 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-16 00:00:00', 39.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-17 00:00:00', 40.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-18 00:00:00', 38.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-19 00:00:00', 38.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-20 00:00:00', 38.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-21 00:00:00', 39.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-22 00:00:00', 42.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-23 00:00:00', 42.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-24 00:00:00', 40.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-25 00:00:00', 42.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-26 00:00:00', 42.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-27 00:00:00', 41.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-28 00:00:00', 39.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-29 00:00:00', 39.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-06-30 00:00:00', 38.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-01 00:00:00', 39.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-02 00:00:00', 41.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-03 00:00:00', 40.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-04 00:00:00', 41.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-05 00:00:00', 42.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-06 00:00:00', 42.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-07 00:00:00', 39.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-08 00:00:00', 38.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-09 00:00:00', 40.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-10 00:00:00', 44.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-11 00:00:00', 42.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-12 00:00:00', 42.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-13 00:00:00', 39.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-14 00:00:00', 39.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-15 00:00:00', 42.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-16 00:00:00', 42.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-17 00:00:00', 40.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-18 00:00:00', 34.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-19 00:00:00', 35.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-20 00:00:00', 40.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-21 00:00:00', 40.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-22 00:00:00', 42.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-23 00:00:00', 41.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-24 00:00:00', 41.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-25 00:00:00', 40.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-26 00:00:00', 39.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-27 00:00:00', 41.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-28 00:00:00', 41.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-29 00:00:00', 40.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-30 00:00:00', 37.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-07-31 00:00:00', 37.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-01 00:00:00', 37.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-02 00:00:00', 35.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-03 00:00:00', 36.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-04 00:00:00', 37.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-05 00:00:00', 37.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-06 00:00:00', 39.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-07 00:00:00', 38.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-08 00:00:00', 37.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-09 00:00:00', 35.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-10 00:00:00', 36.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-11 00:00:00', 34.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-12 00:00:00', 35.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-13 00:00:00', 37.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-14 00:00:00', 38.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-15 00:00:00', 36.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-16 00:00:00', 34.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-17 00:00:00', 35.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-18 00:00:00', 36.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-19 00:00:00', 36.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-20 00:00:00', 35.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-21 00:00:00', 35.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-22 00:00:00', 35.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-23 00:00:00', 36.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-24 00:00:00', 35.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-25 00:00:00', 35.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-26 00:00:00', 35.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-27 00:00:00', 33.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-28 00:00:00', 33.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-29 00:00:00', 33.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-30 00:00:00', 31.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-08-31 00:00:00', 32.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-01 00:00:00', 34.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-02 00:00:00', 35.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-03 00:00:00', 35.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-04 00:00:00', 34.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-05 00:00:00', 32.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-06 00:00:00', 32.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-07 00:00:00', 33.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-08 00:00:00', 31.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-09 00:00:00', 32.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-10 00:00:00', 33.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-11 00:00:00', 34.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-12 00:00:00', 33.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-13 00:00:00', 33.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-14 00:00:00', 33.9410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-15 00:00:00', 34.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-16 00:00:00', 34.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-17 00:00:00', 32.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-18 00:00:00', 29.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-19 00:00:00', 30.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-20 00:00:00', 33.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-21 00:00:00', 30.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-22 00:00:00', 29.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-23 00:00:00', 28.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-24 00:00:00', 30.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-25 00:00:00', 30.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-26 00:00:00', 31.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-27 00:00:00', 30.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-28 00:00:00', 32.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-29 00:00:00', 31.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-09-30 00:00:00', 33.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-01 00:00:00', 33.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-02 00:00:00', 30.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-03 00:00:00', 24.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-04 00:00:00', 26.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-05 00:00:00', 23.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-06 00:00:00', 24.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-07 00:00:00', 22.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-08 00:00:00', 24.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-09 00:00:00', 22.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-10 00:00:00', 25.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-11 00:00:00', 26.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-12 00:00:00', 17.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-13 00:00:00', 16.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-14 00:00:00', 17.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-15 00:00:00', 18.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-16 00:00:00', 20.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-17 00:00:00', 20.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-18 00:00:00', 23.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-19 00:00:00', 25.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-20 00:00:00', 25.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-21 00:00:00', 27.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-22 00:00:00', 22.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-23 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-24 00:00:00', 18.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-25 00:00:00', 19.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-26 00:00:00', 20.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-27 00:00:00', 22.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-28 00:00:00', 23.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-29 00:00:00', 21.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-30 00:00:00', 22.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-10-31 00:00:00', 15.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-01 00:00:00', 15.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-02 00:00:00', 19.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-03 00:00:00', 21.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-04 00:00:00', 22.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-05 00:00:00', 20.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-06 00:00:00', 19.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-07 00:00:00', 20.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-08 00:00:00', 19.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-09 00:00:00', 19.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-10 00:00:00', 17.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-11 00:00:00', 18.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-12 00:00:00', 18.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-13 00:00:00', 20.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-14 00:00:00', 21.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-15 00:00:00', 17.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-16 00:00:00', 16.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-17 00:00:00', 17.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-18 00:00:00', 16.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-19 00:00:00', 12.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-20 00:00:00', 10.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-21 00:00:00', 9.67300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-22 00:00:00', 11.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-23 00:00:00', 13.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-24 00:00:00', 8.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-25 00:00:00', 9.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-26 00:00:00', 11.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-27 00:00:00', 14.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-28 00:00:00', 14.800999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-29 00:00:00', 15.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-11-30 00:00:00', 16.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-01 00:00:00', 16.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-02 00:00:00', 18.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-03 00:00:00', 18.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-04 00:00:00', 19.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-05 00:00:00', 13.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-06 00:00:00', 5.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-07 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-08 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-09 00:00:00', 1.24100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-10 00:00:00', 2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-11 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-12 00:00:00', 6.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-13 00:00:00', 7.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-14 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-15 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-16 00:00:00', 5.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-17 00:00:00', 8.82400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-18 00:00:00', 9.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-19 00:00:00', 11.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-20 00:00:00', 14.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-21 00:00:00', 12.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-22 00:00:00', 12.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-23 00:00:00', 11.9469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-24 00:00:00', 8.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-25 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-26 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-27 00:00:00', 4.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-28 00:00:00', 6.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-29 00:00:00', 5.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-30 00:00:00', 8.72799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1985-12-31 00:00:00', 5.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-01 00:00:00', 6.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-02 00:00:00', 7.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-03 00:00:00', 8.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-04 00:00:00', 10.2309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-05 00:00:00', 10.1190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-06 00:00:00', 10.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-07 00:00:00', 11.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-08 00:00:00', 11.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-09 00:00:00', 11.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-10 00:00:00', 12.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-11 00:00:00', 10.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-12 00:00:00', 11.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-13 00:00:00', 12.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-14 00:00:00', 12.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-15 00:00:00', 12.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-16 00:00:00', 8.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-17 00:00:00', 10.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-18 00:00:00', 10.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-19 00:00:00', 12.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-20 00:00:00', 12.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-21 00:00:00', 14.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-22 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-23 00:00:00', 7.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-24 00:00:00', 3.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-25 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-26 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-27 00:00:00', 7.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-28 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-29 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-30 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-01-31 00:00:00', 8.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-01 00:00:00', 9.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-02 00:00:00', 7.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-03 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-04 00:00:00', 8.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-05 00:00:00', 12.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-06 00:00:00', 12.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-07 00:00:00', 14.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-08 00:00:00', 10.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-09 00:00:00', 10.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-10 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-11 00:00:00', 15.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-12 00:00:00', 6.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-13 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-14 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-15 00:00:00', 8.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-16 00:00:00', 10.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-17 00:00:00', 6.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-18 00:00:00', 6.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-19 00:00:00', 10.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-20 00:00:00', 10.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-21 00:00:00', 12.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-22 00:00:00', 12.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-23 00:00:00', 13.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-24 00:00:00', 15.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-25 00:00:00', 15.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-26 00:00:00', 17.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-27 00:00:00', 19.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-02-28 00:00:00', 20.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-01 00:00:00', 18.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-02 00:00:00', 19.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-03 00:00:00', 10.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-04 00:00:00', 14.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-05 00:00:00', 13.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-06 00:00:00', 16.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-07 00:00:00', 21.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-08 00:00:00', 20.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-09 00:00:00', 22.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-10 00:00:00', 14.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-11 00:00:00', 12.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-12 00:00:00', 6.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-13 00:00:00', 9.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-14 00:00:00', 10.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-15 00:00:00', 8.53600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-16 00:00:00', 6.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-17 00:00:00', 4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-18 00:00:00', 8.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-19 00:00:00', 11.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-20 00:00:00', 11.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-21 00:00:00', 14.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-22 00:00:00', 13.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-23 00:00:00', 11.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-24 00:00:00', 13.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-25 00:00:00', 9.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-26 00:00:00', 11.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-27 00:00:00', 8.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-28 00:00:00', 11.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-29 00:00:00', 11.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-30 00:00:00', 8.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-03-31 00:00:00', 11.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-01 00:00:00', 13.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-02 00:00:00', 18.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-03 00:00:00', 19.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-04 00:00:00', 22.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-05 00:00:00', 23.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-06 00:00:00', 22.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-07 00:00:00', 24.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-08 00:00:00', 25.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-09 00:00:00', 23.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-10 00:00:00', 25.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-11 00:00:00', 27.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-12 00:00:00', 25.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-13 00:00:00', 26.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-14 00:00:00', 25.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-15 00:00:00', 27.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-16 00:00:00', 27.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-17 00:00:00', 28.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-18 00:00:00', 29.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-19 00:00:00', 27.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-20 00:00:00', 28.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-21 00:00:00', 26.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-22 00:00:00', 18.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-23 00:00:00', 20.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-24 00:00:00', 20.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-25 00:00:00', 19.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-26 00:00:00', 22.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-27 00:00:00', 24.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-28 00:00:00', 24.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-29 00:00:00', 25.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-04-30 00:00:00', 26.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-01 00:00:00', 29.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-02 00:00:00', 30.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-03 00:00:00', 30.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-04 00:00:00', 33.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-05 00:00:00', 37.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-06 00:00:00', 37.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-07 00:00:00', 35.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-08 00:00:00', 33.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-09 00:00:00', 36.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-10 00:00:00', 33.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-11 00:00:00', 37.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-12 00:00:00', 32.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-13 00:00:00', 34.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-14 00:00:00', 36.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-15 00:00:00', 33.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-16 00:00:00', 30.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-17 00:00:00', 23.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-18 00:00:00', 23.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-19 00:00:00', 25.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-20 00:00:00', 27.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-21 00:00:00', 28.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-22 00:00:00', 29.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-23 00:00:00', 31.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-24 00:00:00', 36.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-25 00:00:00', 34.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-26 00:00:00', 33.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-27 00:00:00', 32.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-28 00:00:00', 33.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-29 00:00:00', 31.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-30 00:00:00', 22.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-01 00:00:00', 32.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-02 00:00:00', 32.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-03 00:00:00', 35.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-04 00:00:00', 32.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-05 00:00:00', 33.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-06 00:00:00', 35.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-07 00:00:00', 34.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-08 00:00:00', 36.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-09 00:00:00', 37.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-10 00:00:00', 35.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-11 00:00:00', 32.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-12 00:00:00', 35.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-13 00:00:00', 36.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-14 00:00:00', 37.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-15 00:00:00', 33.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-16 00:00:00', 35.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-17 00:00:00', 36.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-18 00:00:00', 41.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-19 00:00:00', 43.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-20 00:00:00', 40.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-21 00:00:00', 38.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-22 00:00:00', 38.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-23 00:00:00', 40.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-24 00:00:00', 39.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-25 00:00:00', 39.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-26 00:00:00', 39.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-27 00:00:00', 37.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-28 00:00:00', 37.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-29 00:00:00', 39.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-06-30 00:00:00', 40.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-01 00:00:00', 40.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-02 00:00:00', 41.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-03 00:00:00', 42.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-04 00:00:00', 40.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-05 00:00:00', 39.4760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-06 00:00:00', 39.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-07 00:00:00', 39.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-08 00:00:00', 38.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-09 00:00:00', 37.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-10 00:00:00', 37.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-11 00:00:00', 37.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-12 00:00:00', 39.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-13 00:00:00', 39.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-14 00:00:00', 41.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-15 00:00:00', 42.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-16 00:00:00', 42.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-17 00:00:00', 42.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-18 00:00:00', 43.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-19 00:00:00', 40.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-20 00:00:00', 38.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-21 00:00:00', 38.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-22 00:00:00', 30.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-23 00:00:00', 33.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-24 00:00:00', 34.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-25 00:00:00', 36.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-26 00:00:00', 38.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-27 00:00:00', 40.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-28 00:00:00', 41.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-29 00:00:00', 43.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-30 00:00:00', 40.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-07-31 00:00:00', 40.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-01 00:00:00', 41.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-02 00:00:00', 40.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-03 00:00:00', 41.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-04 00:00:00', 40.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-05 00:00:00', 35.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-06 00:00:00', 36.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-07 00:00:00', 36.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-08 00:00:00', 33.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-09 00:00:00', 34.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-10 00:00:00', 33.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-11 00:00:00', 35.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-12 00:00:00', 37.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-13 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-14 00:00:00', 37.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-15 00:00:00', 39.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-16 00:00:00', 40.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-17 00:00:00', 39.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-18 00:00:00', 39.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-19 00:00:00', 36.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-20 00:00:00', 34.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-21 00:00:00', 33.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-22 00:00:00', 33.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-23 00:00:00', 34.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-24 00:00:00', 35.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-25 00:00:00', 35.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-26 00:00:00', 35.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-27 00:00:00', 35.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-28 00:00:00', 35.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-29 00:00:00', 34.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-30 00:00:00', 33.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-08-31 00:00:00', 33.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-01 00:00:00', 35.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-02 00:00:00', 33.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-03 00:00:00', 33.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-04 00:00:00', 33.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-05 00:00:00', 33.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-06 00:00:00', 33.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-07 00:00:00', 34.5530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-08 00:00:00', 33.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-09 00:00:00', 32.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-10 00:00:00', 31.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-11 00:00:00', 32.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-12 00:00:00', 33.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-13 00:00:00', 30.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-14 00:00:00', 30.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-15 00:00:00', 31.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-16 00:00:00', 32.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-17 00:00:00', 32.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-18 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-19 00:00:00', 31.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-20 00:00:00', 29.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-21 00:00:00', 31.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-22 00:00:00', 31.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-23 00:00:00', 32.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-24 00:00:00', 32.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-25 00:00:00', 34.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-26 00:00:00', 33.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-27 00:00:00', 34.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-28 00:00:00', 33.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-29 00:00:00', 31.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-09-30 00:00:00', 24.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-01 00:00:00', 25.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-02 00:00:00', 29.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-03 00:00:00', 31.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-04 00:00:00', 29.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-05 00:00:00', 32.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-06 00:00:00', 32.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-07 00:00:00', 32.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-08 00:00:00', 26.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-09 00:00:00', 27.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-10 00:00:00', 29.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-11 00:00:00', 30.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-12 00:00:00', 29.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-13 00:00:00', 26.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-14 00:00:00', 22.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-15 00:00:00', 16.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-16 00:00:00', 14.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-17 00:00:00', 16.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-18 00:00:00', 17.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-19 00:00:00', 20.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-20 00:00:00', 23.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-21 00:00:00', 23.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-22 00:00:00', 24.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-23 00:00:00', 26.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-24 00:00:00', 27.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-25 00:00:00', 28.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-26 00:00:00', 27.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-27 00:00:00', 23.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-28 00:00:00', 22.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-29 00:00:00', 21.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-30 00:00:00', 20.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-10-31 00:00:00', 22.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-01 00:00:00', 22.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-02 00:00:00', 23.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-03 00:00:00', 24.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-04 00:00:00', 24.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-05 00:00:00', 26.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-06 00:00:00', 20.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-07 00:00:00', 22.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-08 00:00:00', 23.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-09 00:00:00', 23.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-10 00:00:00', 23.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-11 00:00:00', 19.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-12 00:00:00', 17.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-13 00:00:00', 11.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-14 00:00:00', 10.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-15 00:00:00', 11.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-16 00:00:00', 10.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-17 00:00:00', 11.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-18 00:00:00', 14.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-19 00:00:00', 12.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-20 00:00:00', 11.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-21 00:00:00', 6.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-22 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-23 00:00:00', 10.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-24 00:00:00', 9.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-25 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-26 00:00:00', 7.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-27 00:00:00', 10.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-28 00:00:00', 11.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-29 00:00:00', 11.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-11-30 00:00:00', 13.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-01 00:00:00', 15.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-02 00:00:00', 16.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-03 00:00:00', 15.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-04 00:00:00', 13.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-05 00:00:00', 9.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-06 00:00:00', 9.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-07 00:00:00', 9.48700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-08 00:00:00', 12.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-09 00:00:00', 7.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-10 00:00:00', 5.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-11 00:00:00', -1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-12 00:00:00', -2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-13 00:00:00', -3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-14 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-15 00:00:00', 0.879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-16 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-17 00:00:00', 4.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-18 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-19 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-20 00:00:00', 6.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-21 00:00:00', 6.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-22 00:00:00', 8.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-23 00:00:00', 5.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-24 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-01 00:00:00', 8.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-02 00:00:00', 9.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-03 00:00:00', 11.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-04 00:00:00', 11.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-05 00:00:00', 11.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-06 00:00:00', 12.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-07 00:00:00', 13.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-08 00:00:00', 8.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-09 00:00:00', 11.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-10 00:00:00', 11.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-11 00:00:00', 13.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-12 00:00:00', 8.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-13 00:00:00', 9.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-14 00:00:00', 11.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-15 00:00:00', 8.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-16 00:00:00', 6.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-17 00:00:00', 8.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-18 00:00:00', 8.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-19 00:00:00', 9.12100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-20 00:00:00', 5.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-21 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-22 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-23 00:00:00', 8.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-24 00:00:00', 13.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-25 00:00:00', 14.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-26 00:00:00', 12.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-27 00:00:00', 15.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-28 00:00:00', 15.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-29 00:00:00', 12.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-30 00:00:00', 15.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-01-31 00:00:00', 14.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-01 00:00:00', 10.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-02 00:00:00', 11.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-03 00:00:00', 13.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-04 00:00:00', 15.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-05 00:00:00', 18.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-06 00:00:00', 11.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-07 00:00:00', 3.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-08 00:00:00', 6.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-09 00:00:00', 12.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-10 00:00:00', 16.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-11 00:00:00', 11.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-12 00:00:00', 7.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-13 00:00:00', 11.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-14 00:00:00', 11.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-15 00:00:00', 8.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-16 00:00:00', 8.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-17 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-18 00:00:00', 6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-19 00:00:00', 10.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-20 00:00:00', 12.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-21 00:00:00', 15.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-22 00:00:00', 10.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-23 00:00:00', 7.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-24 00:00:00', 11.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-25 00:00:00', 14.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-26 00:00:00', 17.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-27 00:00:00', 19.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-02-28 00:00:00', 20.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-01 00:00:00', 20.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-02 00:00:00', 15.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-03 00:00:00', 21.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-04 00:00:00', 23.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-05 00:00:00', 16.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-06 00:00:00', 15.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-07 00:00:00', 19.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-08 00:00:00', 18.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-09 00:00:00', 20.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-10 00:00:00', 21.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-11 00:00:00', 21.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-12 00:00:00', 17.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-13 00:00:00', 14.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-14 00:00:00', 20.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-15 00:00:00', 20.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-16 00:00:00', 14.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-17 00:00:00', 18.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-18 00:00:00', 19.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-19 00:00:00', 18.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-20 00:00:00', 16.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-21 00:00:00', 15.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-22 00:00:00', 12.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-23 00:00:00', 14.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-24 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-25 00:00:00', 19.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-26 00:00:00', 21.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-27 00:00:00', 18.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-28 00:00:00', 18.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-29 00:00:00', 18.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-30 00:00:00', 19.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-03-31 00:00:00', 24.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-01 00:00:00', 11.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-02 00:00:00', 16.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-03 00:00:00', 18.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-04 00:00:00', 19.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-05 00:00:00', 18.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-06 00:00:00', 13.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-07 00:00:00', 18.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-08 00:00:00', 14.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-09 00:00:00', 17.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-10 00:00:00', 20.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-11 00:00:00', 20.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-12 00:00:00', 23.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-13 00:00:00', 25.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-14 00:00:00', 21.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-15 00:00:00', 25.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-16 00:00:00', 25.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-17 00:00:00', 26.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-18 00:00:00', 28.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-19 00:00:00', 32.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-20 00:00:00', 29.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-21 00:00:00', 21.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-22 00:00:00', 20.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-23 00:00:00', 22.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-24 00:00:00', 26.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-25 00:00:00', 27.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-26 00:00:00', 29.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-27 00:00:00', 30.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-28 00:00:00', 22.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-29 00:00:00', 26.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-04-30 00:00:00', 23.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-01 00:00:00', 25.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-02 00:00:00', 25.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-03 00:00:00', 27.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-04 00:00:00', 32.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-05 00:00:00', 29.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-06 00:00:00', 28.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-07 00:00:00', 25.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-08 00:00:00', 26.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-09 00:00:00', 28.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-10 00:00:00', 30.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-11 00:00:00', 30.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-12 00:00:00', 32.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-13 00:00:00', 32.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-14 00:00:00', 33.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-15 00:00:00', 33.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-16 00:00:00', 36.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-17 00:00:00', 35.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-18 00:00:00', 31.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-19 00:00:00', 29.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-20 00:00:00', 28.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-21 00:00:00', 31.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-22 00:00:00', 30.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-23 00:00:00', 31.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-24 00:00:00', 34.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-25 00:00:00', 36.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-26 00:00:00', 38.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-27 00:00:00', 33.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-28 00:00:00', 39.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-29 00:00:00', 35.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-30 00:00:00', 34.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-05-31 00:00:00', 34.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-01 00:00:00', 33.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-02 00:00:00', 36.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-03 00:00:00', 35.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-04 00:00:00', 37.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-05 00:00:00', 38.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-06 00:00:00', 40.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-07 00:00:00', 35.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-08 00:00:00', 33.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-09 00:00:00', 30.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-10 00:00:00', 35.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-11 00:00:00', 33.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-12 00:00:00', 33.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-13 00:00:00', 33.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-14 00:00:00', 35.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-15 00:00:00', 35.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-16 00:00:00', 35.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-17 00:00:00', 38.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-18 00:00:00', 38.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-19 00:00:00', 38.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-20 00:00:00', 28.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-21 00:00:00', 29.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-22 00:00:00', 33.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-23 00:00:00', 34.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-24 00:00:00', 37.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-25 00:00:00', 37.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-26 00:00:00', 38.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-27 00:00:00', 38.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-28 00:00:00', 39.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-29 00:00:00', 41.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-06-30 00:00:00', 40.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-01 00:00:00', 40.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-02 00:00:00', 40.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-03 00:00:00', 39.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-04 00:00:00', 37.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-05 00:00:00', 33.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-06 00:00:00', 34.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-07 00:00:00', 36.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-08 00:00:00', 39.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-09 00:00:00', 40.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-10 00:00:00', 41.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-11 00:00:00', 31.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-12 00:00:00', 32.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-13 00:00:00', 33.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-14 00:00:00', 28.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-15 00:00:00', 33.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-16 00:00:00', 35.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-17 00:00:00', 37.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-18 00:00:00', 37.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-19 00:00:00', 35.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-20 00:00:00', 37.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-21 00:00:00', 41.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-22 00:00:00', 42.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-23 00:00:00', 43.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-24 00:00:00', 42.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-25 00:00:00', 36.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-26 00:00:00', 35.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-27 00:00:00', 34.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-28 00:00:00', 36.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-29 00:00:00', 37.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-30 00:00:00', 39.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-07-31 00:00:00', 38.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-01 00:00:00', 37.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-02 00:00:00', 39.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-03 00:00:00', 39.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-04 00:00:00', 39.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-05 00:00:00', 39.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-06 00:00:00', 39.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-07 00:00:00', 40.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-08 00:00:00', 39.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-09 00:00:00', 37.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-10 00:00:00', 39.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-11 00:00:00', 40.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-12 00:00:00', 40.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-13 00:00:00', 41.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-14 00:00:00', 41.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-15 00:00:00', 40.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-16 00:00:00', 40.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-17 00:00:00', 41.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-18 00:00:00', 39.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-19 00:00:00', 40.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-20 00:00:00', 39.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-21 00:00:00', 40.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-22 00:00:00', 40.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-23 00:00:00', 40.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-24 00:00:00', 38.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-25 00:00:00', 36.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-26 00:00:00', 37.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-27 00:00:00', 38.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-28 00:00:00', 37.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-29 00:00:00', 37.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-30 00:00:00', 38.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-08-31 00:00:00', 34.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-01 00:00:00', 34.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-02 00:00:00', 34.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-03 00:00:00', 35.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-04 00:00:00', 36.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-05 00:00:00', 38.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-06 00:00:00', 38.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-07 00:00:00', 36.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-08 00:00:00', 30.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-09 00:00:00', 30.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-10 00:00:00', 28.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-11 00:00:00', 29.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-12 00:00:00', 31.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-13 00:00:00', 32.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-14 00:00:00', 35.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-15 00:00:00', 34.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-16 00:00:00', 32.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-17 00:00:00', 34.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-18 00:00:00', 35.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-19 00:00:00', 32.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-20 00:00:00', 26.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-21 00:00:00', 26.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-22 00:00:00', 31.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-23 00:00:00', 34.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-24 00:00:00', 26.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-25 00:00:00', 28.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-26 00:00:00', 28.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-27 00:00:00', 28.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-28 00:00:00', 29.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-29 00:00:00', 30.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-09-30 00:00:00', 33.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-01 00:00:00', 29.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-02 00:00:00', 28.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-03 00:00:00', 29.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-04 00:00:00', 30.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-05 00:00:00', 32.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-06 00:00:00', 27.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-07 00:00:00', 27.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-08 00:00:00', 23.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-09 00:00:00', 23.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-10 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-11 00:00:00', 15.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-12 00:00:00', 15.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-13 00:00:00', 15.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-14 00:00:00', 16.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-15 00:00:00', 17.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-16 00:00:00', 17.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-17 00:00:00', 17.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-18 00:00:00', 18.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-19 00:00:00', 17.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-20 00:00:00', 19.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-21 00:00:00', 19.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-22 00:00:00', 21.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-23 00:00:00', 23.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-24 00:00:00', 20.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-25 00:00:00', 24.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-26 00:00:00', 17.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-27 00:00:00', 8.51099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-28 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-29 00:00:00', 6.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-30 00:00:00', 12.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-10-31 00:00:00', 13.3629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-01 00:00:00', 17.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-02 00:00:00', 18.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-03 00:00:00', 19.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-04 00:00:00', 16.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-05 00:00:00', 22.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-06 00:00:00', 21.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-07 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-08 00:00:00', 22.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-09 00:00:00', 18.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-10 00:00:00', 19.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-11 00:00:00', 17.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-12 00:00:00', 17.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-13 00:00:00', 17.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-14 00:00:00', 19.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-15 00:00:00', 21.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-16 00:00:00', 16.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-17 00:00:00', 16.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-18 00:00:00', 17.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-19 00:00:00', 17.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-20 00:00:00', 18.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-21 00:00:00', 19.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-22 00:00:00', 19.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-23 00:00:00', 20.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-24 00:00:00', 13.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-25 00:00:00', 10.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-26 00:00:00', 8.46399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-27 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-28 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-29 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-11-30 00:00:00', -1.03199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-01 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-02 00:00:00', -0.365000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-03 00:00:00', -0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-04 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-05 00:00:00', 8.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-06 00:00:00', 10.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-07 00:00:00', 12.7650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-08 00:00:00', 12.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-09 00:00:00', 14.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-10 00:00:00', 16.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-11 00:00:00', 16.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-12 00:00:00', 15.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-13 00:00:00', 17.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-14 00:00:00', 15.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-15 00:00:00', 8.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-16 00:00:00', 11.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-17 00:00:00', 13.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-18 00:00:00', 15.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-19 00:00:00', 17.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-20 00:00:00', 17.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-21 00:00:00', 20.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-22 00:00:00', 16.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-23 00:00:00', 16.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-24 00:00:00', 19.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-25 00:00:00', 17.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-26 00:00:00', 17.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-27 00:00:00', 14.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-28 00:00:00', 13.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-29 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-30 00:00:00', 10.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1987-12-31 00:00:00', 12.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-01 00:00:00', 9.22799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-02 00:00:00', 12.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-03 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-04 00:00:00', 10.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-05 00:00:00', 9.61400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-06 00:00:00', 13.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-07 00:00:00', 12.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-08 00:00:00', 8.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-09 00:00:00', 8.37600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-10 00:00:00', 10.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-11 00:00:00', 9.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-12 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-13 00:00:00', 10.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-14 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-15 00:00:00', 6.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-16 00:00:00', 9.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-17 00:00:00', 6.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-18 00:00:00', 9.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-19 00:00:00', 10.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-20 00:00:00', 7.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-21 00:00:00', -0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-22 00:00:00', 3.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-23 00:00:00', 6.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-24 00:00:00', 6.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-25 00:00:00', 6.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-26 00:00:00', 6.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-27 00:00:00', 9.63799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-28 00:00:00', 11.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-29 00:00:00', 13.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-30 00:00:00', 8.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-01-31 00:00:00', 8.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-01 00:00:00', 10.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-02 00:00:00', 15.3660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-03 00:00:00', 18.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-04 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-05 00:00:00', 6.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-06 00:00:00', 6.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-07 00:00:00', -0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-08 00:00:00', 0.722000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-09 00:00:00', 5.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-10 00:00:00', 11.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-11 00:00:00', 11.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-12 00:00:00', 9.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-13 00:00:00', 10.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-14 00:00:00', 8.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-15 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-16 00:00:00', 6.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-17 00:00:00', 12.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-18 00:00:00', 8.52499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-19 00:00:00', 9.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-20 00:00:00', 11.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-21 00:00:00', 11.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-22 00:00:00', 11.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-23 00:00:00', 12.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-24 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-25 00:00:00', 16.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-26 00:00:00', 11.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-27 00:00:00', 8.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-28 00:00:00', 9.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-02-29 00:00:00', 12.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-01 00:00:00', 15.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-02 00:00:00', 12.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-03 00:00:00', 17.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-04 00:00:00', 18.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-05 00:00:00', 21.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-06 00:00:00', 14.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-07 00:00:00', 10.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-08 00:00:00', 15.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-09 00:00:00', 12.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-10 00:00:00', 15.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-11 00:00:00', 16.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-12 00:00:00', 15.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-13 00:00:00', 12.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-14 00:00:00', 15.2130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-15 00:00:00', 14.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-16 00:00:00', 12.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-17 00:00:00', 15.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-18 00:00:00', 14.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-19 00:00:00', 16.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-20 00:00:00', 19.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-21 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-22 00:00:00', 16.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-23 00:00:00', 13.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-24 00:00:00', 10.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-25 00:00:00', 6.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-26 00:00:00', 7.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-27 00:00:00', 12.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-28 00:00:00', 11.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-29 00:00:00', 13.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-30 00:00:00', 13.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-03-31 00:00:00', 17.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-01 00:00:00', 17.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-02 00:00:00', 17.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-03 00:00:00', 14.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-04 00:00:00', 15.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-05 00:00:00', 17.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-06 00:00:00', 20.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-07 00:00:00', 20.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-08 00:00:00', 21.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-09 00:00:00', 17.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-10 00:00:00', 19.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-11 00:00:00', 23.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-12 00:00:00', 26.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-13 00:00:00', 29.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-14 00:00:00', 30.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-15 00:00:00', 31.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-16 00:00:00', 34.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-17 00:00:00', 22.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-18 00:00:00', 26.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-19 00:00:00', 26.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-20 00:00:00', 30.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-21 00:00:00', 31.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-22 00:00:00', 31.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-23 00:00:00', 32.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-24 00:00:00', 33.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-25 00:00:00', 34.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-26 00:00:00', 34.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-27 00:00:00', 33.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-28 00:00:00', 35.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-29 00:00:00', 25.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-04-30 00:00:00', 25.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-01 00:00:00', 27.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-02 00:00:00', 26.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-03 00:00:00', 27.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-04 00:00:00', 23.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-05 00:00:00', 23.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-06 00:00:00', 23.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-07 00:00:00', 26.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-08 00:00:00', 29.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-09 00:00:00', 30.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-10 00:00:00', 33.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-11 00:00:00', 33.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-12 00:00:00', 34.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-13 00:00:00', 34.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-14 00:00:00', 34.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-15 00:00:00', 32.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-16 00:00:00', 26.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-17 00:00:00', 27.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-18 00:00:00', 27.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-19 00:00:00', 30.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-20 00:00:00', 33.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-21 00:00:00', 33.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-22 00:00:00', 32.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-23 00:00:00', 32.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-24 00:00:00', 31.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-25 00:00:00', 34.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-26 00:00:00', 36.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-27 00:00:00', 35.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-28 00:00:00', 36.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-29 00:00:00', 39.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-30 00:00:00', 38.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-05-31 00:00:00', 31.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-01 00:00:00', 31.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-02 00:00:00', 33.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-03 00:00:00', 35.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-04 00:00:00', 35.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-05 00:00:00', 35.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-06 00:00:00', 35.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-07 00:00:00', 35.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-08 00:00:00', 33.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-09 00:00:00', 35.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-10 00:00:00', 34.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-11 00:00:00', 37.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-12 00:00:00', 38.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-13 00:00:00', 39.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-14 00:00:00', 42.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-15 00:00:00', 40.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-16 00:00:00', 42.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-17 00:00:00', 42.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-18 00:00:00', 44.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-19 00:00:00', 42.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-20 00:00:00', 43.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-21 00:00:00', 40.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-22 00:00:00', 41.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-23 00:00:00', 43.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-24 00:00:00', 45.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-25 00:00:00', 46.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-26 00:00:00', 39.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-27 00:00:00', 37.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-28 00:00:00', 33.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-29 00:00:00', 35.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-06-30 00:00:00', 37.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-01 00:00:00', 41.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-02 00:00:00', 44.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-03 00:00:00', 42.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-04 00:00:00', 42.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-05 00:00:00', 41.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-06 00:00:00', 39.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-07 00:00:00', 39.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-08 00:00:00', 42.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-09 00:00:00', 40.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-10 00:00:00', 43.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-11 00:00:00', 44.5789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-12 00:00:00', 44.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-13 00:00:00', 42.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-14 00:00:00', 41.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-15 00:00:00', 39.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-16 00:00:00', 41.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-17 00:00:00', 40.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-18 00:00:00', 41.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-19 00:00:00', 43.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-20 00:00:00', 41.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-21 00:00:00', 40.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-22 00:00:00', 38.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-23 00:00:00', 35.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-24 00:00:00', 34.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-25 00:00:00', 38.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-26 00:00:00', 39.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-27 00:00:00', 40.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-28 00:00:00', 41.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-29 00:00:00', 39.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-30 00:00:00', 42.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-07-31 00:00:00', 40.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-01 00:00:00', 38.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-02 00:00:00', 36.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-03 00:00:00', 35.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-04 00:00:00', 36.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-05 00:00:00', 39.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-06 00:00:00', 40.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-07 00:00:00', 40.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-08 00:00:00', 39.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-09 00:00:00', 37.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-10 00:00:00', 39.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-11 00:00:00', 39.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-12 00:00:00', 39.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-13 00:00:00', 39.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-14 00:00:00', 40.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-15 00:00:00', 36.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-16 00:00:00', 35.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-17 00:00:00', 37.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-18 00:00:00', 36.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-19 00:00:00', 36.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-20 00:00:00', 37.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-21 00:00:00', 38.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-22 00:00:00', 34.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-23 00:00:00', 34.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-24 00:00:00', 33.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-25 00:00:00', 32.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-26 00:00:00', 31.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-27 00:00:00', 32.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-28 00:00:00', 33.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-29 00:00:00', 34.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-30 00:00:00', 36.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-08-31 00:00:00', 37.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-01 00:00:00', 37.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-02 00:00:00', 35.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-03 00:00:00', 36.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-04 00:00:00', 36.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-05 00:00:00', 38.9550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-06 00:00:00', 40.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-07 00:00:00', 38.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-08 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-09 00:00:00', 34.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-10 00:00:00', 36.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-11 00:00:00', 37.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-12 00:00:00', 37.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-13 00:00:00', 37.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-14 00:00:00', 34.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-15 00:00:00', 31.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-16 00:00:00', 30.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-17 00:00:00', 29.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-18 00:00:00', 32.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-19 00:00:00', 32.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-20 00:00:00', 32.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-21 00:00:00', 33.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-22 00:00:00', 24.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-23 00:00:00', 26.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-24 00:00:00', 26.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-25 00:00:00', 24.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-26 00:00:00', 24.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-27 00:00:00', 25.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-28 00:00:00', 24.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-29 00:00:00', 23.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-09-30 00:00:00', 24.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-01 00:00:00', 25.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-02 00:00:00', 23.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-03 00:00:00', 22.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-04 00:00:00', 21.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-05 00:00:00', 25.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-06 00:00:00', 24.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-07 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-08 00:00:00', 24.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-09 00:00:00', 25.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-10 00:00:00', 25.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-11 00:00:00', 25.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-12 00:00:00', 24.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-13 00:00:00', 24.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-14 00:00:00', 22.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-15 00:00:00', 24.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-16 00:00:00', 19.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-17 00:00:00', 19.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-18 00:00:00', 21.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-19 00:00:00', 20.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-20 00:00:00', 22.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-21 00:00:00', 23.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-22 00:00:00', 26.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-23 00:00:00', 19.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-24 00:00:00', 19.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-25 00:00:00', 20.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-26 00:00:00', 21.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-27 00:00:00', 25.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-28 00:00:00', 25.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-29 00:00:00', 20.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-30 00:00:00', 22.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-10-31 00:00:00', 23.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-01 00:00:00', 21.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-02 00:00:00', 25.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-03 00:00:00', 24.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-04 00:00:00', 24.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-05 00:00:00', 25.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-06 00:00:00', 21.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-07 00:00:00', 21.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-08 00:00:00', 23.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-09 00:00:00', 25.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-10 00:00:00', 26.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-11 00:00:00', 26.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-12 00:00:00', 26.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-13 00:00:00', 26.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-14 00:00:00', 26.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-15 00:00:00', 18.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-16 00:00:00', 15.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-17 00:00:00', 21.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-18 00:00:00', 20.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-19 00:00:00', 20.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-20 00:00:00', 22.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-21 00:00:00', 17.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-22 00:00:00', 13.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-23 00:00:00', 13.0819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-24 00:00:00', 13.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-25 00:00:00', 13.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-26 00:00:00', 14.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-27 00:00:00', 15.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-28 00:00:00', 17.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-29 00:00:00', 19.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-11-30 00:00:00', 16.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-01 00:00:00', 17.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-02 00:00:00', 19.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-03 00:00:00', 19.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-04 00:00:00', 19.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-05 00:00:00', 16.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-06 00:00:00', 16.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-07 00:00:00', 15.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-08 00:00:00', 18.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-09 00:00:00', 17.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-10 00:00:00', 17.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-11 00:00:00', 18.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-12 00:00:00', 18.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-13 00:00:00', 16.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-14 00:00:00', 13.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-15 00:00:00', 13.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-16 00:00:00', 10.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-17 00:00:00', 12.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-18 00:00:00', 11.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-19 00:00:00', 15.5819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-20 00:00:00', 13.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-21 00:00:00', 11.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-22 00:00:00', 8.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-23 00:00:00', 8.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-24 00:00:00', 9.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-25 00:00:00', 9.00100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-26 00:00:00', 10.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-27 00:00:00', 10.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-28 00:00:00', 12.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-29 00:00:00', 9.04399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-30 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1988-12-31 00:00:00', 10.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-01 00:00:00', 8.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-02 00:00:00', 11.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-03 00:00:00', 10.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-04 00:00:00', 4.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-05 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-06 00:00:00', 0.107000000774860382, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-07 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-08 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-09 00:00:00', 6.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-10 00:00:00', 5.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-11 00:00:00', 7.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-12 00:00:00', 8.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-13 00:00:00', 5.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-14 00:00:00', 7.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-15 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-16 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-17 00:00:00', 9.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-18 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-19 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-20 00:00:00', 6.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-21 00:00:00', 9.55500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-22 00:00:00', 6.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-23 00:00:00', 8.72799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-24 00:00:00', 11.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-25 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-26 00:00:00', 7.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-27 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-28 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-29 00:00:00', 5.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-30 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-01-31 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-01 00:00:00', 5.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-02 00:00:00', 8.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-03 00:00:00', 5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-04 00:00:00', 4.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-05 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-06 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-07 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-08 00:00:00', 5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-09 00:00:00', 6.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-10 00:00:00', 9.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-11 00:00:00', 10.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-12 00:00:00', 6.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-13 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-14 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-15 00:00:00', 6.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-16 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-17 00:00:00', 4.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-18 00:00:00', 6.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-19 00:00:00', 9.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-20 00:00:00', 4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-21 00:00:00', 8.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-22 00:00:00', 10.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-23 00:00:00', 11.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-24 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-25 00:00:00', 7.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-26 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-27 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-02-28 00:00:00', 9.69499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-01 00:00:00', 12.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-02 00:00:00', 12.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-03 00:00:00', 14.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-04 00:00:00', 15.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-05 00:00:00', 17.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-06 00:00:00', 17.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-07 00:00:00', 17.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-08 00:00:00', 12.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-09 00:00:00', 12.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-10 00:00:00', 15.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-11 00:00:00', 15.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-12 00:00:00', 18.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-13 00:00:00', 11.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-14 00:00:00', 14.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-15 00:00:00', 19.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-16 00:00:00', 23.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-17 00:00:00', 18.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-18 00:00:00', 18.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-19 00:00:00', 18.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-20 00:00:00', 15.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-21 00:00:00', 18.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-22 00:00:00', 13.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-23 00:00:00', 15.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-24 00:00:00', 18.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-25 00:00:00', 20.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-26 00:00:00', 22.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-27 00:00:00', 24.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-28 00:00:00', 25.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-29 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-30 00:00:00', 21.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-03-31 00:00:00', 13.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-01 00:00:00', 12.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-02 00:00:00', 10.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-03 00:00:00', 14.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-04 00:00:00', 16.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-05 00:00:00', 19.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-06 00:00:00', 22.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-07 00:00:00', 21.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-08 00:00:00', 18.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-09 00:00:00', 18.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-10 00:00:00', 19.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-11 00:00:00', 21.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-12 00:00:00', 20.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-13 00:00:00', 23.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-14 00:00:00', 26.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-15 00:00:00', 29.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-16 00:00:00', 23.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-17 00:00:00', 25.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-18 00:00:00', 23.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-19 00:00:00', 25.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-20 00:00:00', 27.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-21 00:00:00', 26.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-22 00:00:00', 25.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-23 00:00:00', 25.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-24 00:00:00', 26.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-25 00:00:00', 26.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-26 00:00:00', 28.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-27 00:00:00', 28.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-28 00:00:00', 28.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-29 00:00:00', 30.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-04-30 00:00:00', 19.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-01 00:00:00', 13.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-02 00:00:00', 14.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-03 00:00:00', 9.03899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-04 00:00:00', 14.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-05 00:00:00', 15.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-06 00:00:00', 20.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-07 00:00:00', 26.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-08 00:00:00', 21.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-09 00:00:00', 22.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-10 00:00:00', 25.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-11 00:00:00', 28.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-12 00:00:00', 30.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-13 00:00:00', 31.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-14 00:00:00', 27.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-15 00:00:00', 27.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-16 00:00:00', 30.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-17 00:00:00', 29.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-18 00:00:00', 30.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-19 00:00:00', 33.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-20 00:00:00', 29.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-21 00:00:00', 29.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-22 00:00:00', 30.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-23 00:00:00', 29.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-24 00:00:00', 31.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-25 00:00:00', 32.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-26 00:00:00', 34.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-27 00:00:00', 36.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-28 00:00:00', 39.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-29 00:00:00', 38.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-30 00:00:00', 38.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-05-31 00:00:00', 37.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-01 00:00:00', 39.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-02 00:00:00', 38.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-03 00:00:00', 37.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-04 00:00:00', 37.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-05 00:00:00', 36.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-06 00:00:00', 34.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-07 00:00:00', 34.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-08 00:00:00', 35.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-09 00:00:00', 32.9490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-10 00:00:00', 34.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-11 00:00:00', 36.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-12 00:00:00', 39.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-13 00:00:00', 37.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-14 00:00:00', 37.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-15 00:00:00', 36.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-16 00:00:00', 36.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-17 00:00:00', 37.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-18 00:00:00', 38.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-19 00:00:00', 34.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-20 00:00:00', 33.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-21 00:00:00', 33.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-22 00:00:00', 35.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-23 00:00:00', 36.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-24 00:00:00', 38.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-25 00:00:00', 41.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-26 00:00:00', 41.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-27 00:00:00', 40.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-28 00:00:00', 39.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-29 00:00:00', 41.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-06-30 00:00:00', 39.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-01 00:00:00', 39.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-02 00:00:00', 38.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-03 00:00:00', 38.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-04 00:00:00', 37.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-05 00:00:00', 37.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-06 00:00:00', 38.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-07 00:00:00', 39.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-08 00:00:00', 41.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-09 00:00:00', 44.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-10 00:00:00', 44.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-11 00:00:00', 44.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-12 00:00:00', 41.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-13 00:00:00', 37.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-14 00:00:00', 37.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-15 00:00:00', 37.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-16 00:00:00', 37.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-17 00:00:00', 38.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-18 00:00:00', 37.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-19 00:00:00', 38.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-20 00:00:00', 37.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-21 00:00:00', 37.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-22 00:00:00', 39.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-23 00:00:00', 36.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-24 00:00:00', 36.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-25 00:00:00', 37.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-26 00:00:00', 36.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-27 00:00:00', 39.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-28 00:00:00', 39.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-29 00:00:00', 40.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-30 00:00:00', 38.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-07-31 00:00:00', 36.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-01 00:00:00', 37.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-02 00:00:00', 38.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-03 00:00:00', 40.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-04 00:00:00', 38.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-05 00:00:00', 39.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-06 00:00:00', 39.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-07 00:00:00', 39.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-08 00:00:00', 40.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-09 00:00:00', 40.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-10 00:00:00', 39.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-11 00:00:00', 41.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-12 00:00:00', 42.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-13 00:00:00', 40.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-14 00:00:00', 37.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-15 00:00:00', 36.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-16 00:00:00', 37.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-17 00:00:00', 38.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-18 00:00:00', 38.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-19 00:00:00', 34.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-20 00:00:00', 33.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-21 00:00:00', 35.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-22 00:00:00', 35.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-23 00:00:00', 35.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-24 00:00:00', 36.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-25 00:00:00', 36.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-26 00:00:00', 36.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-27 00:00:00', 34.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-28 00:00:00', 33.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-29 00:00:00', 33.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-30 00:00:00', 34.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-08-31 00:00:00', 33.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-01 00:00:00', 34.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-02 00:00:00', 36.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-03 00:00:00', 37.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-04 00:00:00', 32.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-05 00:00:00', 28.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-06 00:00:00', 30.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-07 00:00:00', 31.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-08 00:00:00', 32.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-09 00:00:00', 34.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-10 00:00:00', 34.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-11 00:00:00', 34.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-12 00:00:00', 34.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-13 00:00:00', 34.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-14 00:00:00', 38.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-15 00:00:00', 39.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-16 00:00:00', 35.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-17 00:00:00', 33.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-18 00:00:00', 35.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-19 00:00:00', 35.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-20 00:00:00', 27.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-21 00:00:00', 25.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-22 00:00:00', 17.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-23 00:00:00', 21.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-24 00:00:00', 24.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-25 00:00:00', 26.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-26 00:00:00', 28.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-27 00:00:00', 29.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-28 00:00:00', 31.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-29 00:00:00', 30.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-09-30 00:00:00', 28.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-01 00:00:00', 29.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-02 00:00:00', 31.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-03 00:00:00', 34.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-04 00:00:00', 31.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-05 00:00:00', 32.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-06 00:00:00', 31.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-07 00:00:00', 32.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-08 00:00:00', 32.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-09 00:00:00', 30.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-10 00:00:00', 27.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-11 00:00:00', 21.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-12 00:00:00', 21.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-13 00:00:00', 23.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-14 00:00:00', 23.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-15 00:00:00', 23.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-16 00:00:00', 24.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-17 00:00:00', 26.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-18 00:00:00', 27.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-19 00:00:00', 25.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-20 00:00:00', 28.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-21 00:00:00', 25.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-22 00:00:00', 23.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-23 00:00:00', 20.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-24 00:00:00', 16.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-25 00:00:00', 19.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-26 00:00:00', 21.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-27 00:00:00', 19.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-28 00:00:00', 21.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-29 00:00:00', 23.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-30 00:00:00', 20.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-10-31 00:00:00', 24.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-01 00:00:00', 15.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-02 00:00:00', 11.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-03 00:00:00', 14.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-04 00:00:00', 14.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-05 00:00:00', 16.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-06 00:00:00', 16.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-07 00:00:00', 15.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-08 00:00:00', 13.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-09 00:00:00', 13.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-10 00:00:00', 11.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-11 00:00:00', 12.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-12 00:00:00', 14.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-13 00:00:00', 16.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-14 00:00:00', 17.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-15 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-16 00:00:00', 19.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-17 00:00:00', 15.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-18 00:00:00', 14.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-19 00:00:00', 17.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-20 00:00:00', 19.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-21 00:00:00', 16.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-22 00:00:00', 12.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-23 00:00:00', 12.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-24 00:00:00', 13.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-25 00:00:00', 15.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-26 00:00:00', 18.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-27 00:00:00', 18.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-28 00:00:00', 18.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-29 00:00:00', 19.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-11-30 00:00:00', 20.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-01 00:00:00', 21.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-02 00:00:00', 20.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-03 00:00:00', 13.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-04 00:00:00', 12.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-05 00:00:00', 17.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-06 00:00:00', 13.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-07 00:00:00', 13.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-08 00:00:00', 11.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-09 00:00:00', 15.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-10 00:00:00', 13.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-11 00:00:00', 14.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-12 00:00:00', 15.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-13 00:00:00', 17.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-14 00:00:00', 13.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-15 00:00:00', 15.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-16 00:00:00', 12.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-17 00:00:00', 13.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-18 00:00:00', 12.9289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-19 00:00:00', 12.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-20 00:00:00', 10.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-21 00:00:00', 10.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-22 00:00:00', 8.02000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-23 00:00:00', 7.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-24 00:00:00', 10.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-25 00:00:00', 9.10999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-26 00:00:00', 10.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-27 00:00:00', 10.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-28 00:00:00', 6.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-29 00:00:00', 8.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-30 00:00:00', 10.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1989-12-31 00:00:00', 5.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-01 00:00:00', 7.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-02 00:00:00', 7.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-03 00:00:00', 4.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-04 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-05 00:00:00', 9.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-06 00:00:00', 6.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-07 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-08 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-09 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-10 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-11 00:00:00', 0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-12 00:00:00', -0.0850000008940696716, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-13 00:00:00', 0.238000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-14 00:00:00', 1.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-15 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-16 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-17 00:00:00', 5.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-18 00:00:00', 10.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-19 00:00:00', 11.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-20 00:00:00', 7.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-21 00:00:00', 10.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-22 00:00:00', 10.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-23 00:00:00', 14.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-24 00:00:00', 15.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-25 00:00:00', 12.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-26 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-27 00:00:00', -0.368999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-28 00:00:00', 0.595000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-29 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-30 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-01-31 00:00:00', 2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-01 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-02 00:00:00', 6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-03 00:00:00', 10.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-04 00:00:00', 8.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-05 00:00:00', 8.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-06 00:00:00', 5.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-07 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-08 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-09 00:00:00', 7.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-10 00:00:00', 10.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-11 00:00:00', 11.9940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-12 00:00:00', 7.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-13 00:00:00', 6.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-14 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-15 00:00:00', 10.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-16 00:00:00', 10.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-17 00:00:00', 9.56000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-18 00:00:00', 13.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-19 00:00:00', 15.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-20 00:00:00', 15.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-21 00:00:00', 14.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-22 00:00:00', 9.60700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-23 00:00:00', 6.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-24 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-25 00:00:00', 8.57699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-26 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-27 00:00:00', 7.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-02-28 00:00:00', 9.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-01 00:00:00', 12.175999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-02 00:00:00', 14.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-03 00:00:00', 15.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-04 00:00:00', 16.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-05 00:00:00', 15.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-06 00:00:00', 15.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-07 00:00:00', 14.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-08 00:00:00', 18.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-09 00:00:00', 12.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-10 00:00:00', 13.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-11 00:00:00', 15.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-12 00:00:00', 18.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-13 00:00:00', 21.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-14 00:00:00', 23.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-15 00:00:00', 17.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-16 00:00:00', 17.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-17 00:00:00', 11.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-18 00:00:00', 7.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-19 00:00:00', 10.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-20 00:00:00', 11.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-21 00:00:00', 8.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-22 00:00:00', 8.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-23 00:00:00', 11.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-24 00:00:00', 13.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-25 00:00:00', 18.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-26 00:00:00', 19.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-27 00:00:00', 17.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-28 00:00:00', 19.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-29 00:00:00', 20.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-30 00:00:00', 19.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-03-31 00:00:00', 18.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-01 00:00:00', 20.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-02 00:00:00', 24.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-03 00:00:00', 22.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-04 00:00:00', 17.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-05 00:00:00', 22.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-06 00:00:00', 13.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-07 00:00:00', 21.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-08 00:00:00', 13.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-09 00:00:00', 19.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-10 00:00:00', 22.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-11 00:00:00', 21.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-12 00:00:00', 21.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-13 00:00:00', 22.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-14 00:00:00', 23.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-15 00:00:00', 19.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-16 00:00:00', 22.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-17 00:00:00', 14.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-18 00:00:00', 21.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-19 00:00:00', 23.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-20 00:00:00', 17.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-21 00:00:00', 21.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-22 00:00:00', 26.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-23 00:00:00', 28.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-24 00:00:00', 24.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-25 00:00:00', 25.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-26 00:00:00', 24.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-27 00:00:00', 25.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-28 00:00:00', 28.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-29 00:00:00', 31.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-04-30 00:00:00', 33.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-01 00:00:00', 28.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-02 00:00:00', 29.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-03 00:00:00', 33.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-04 00:00:00', 35.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-05 00:00:00', 33.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-06 00:00:00', 33.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-07 00:00:00', 35.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-08 00:00:00', 33.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-09 00:00:00', 32.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-10 00:00:00', 33.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-11 00:00:00', 35.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-12 00:00:00', 37.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-13 00:00:00', 40.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-14 00:00:00', 34.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-15 00:00:00', 27.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-16 00:00:00', 29.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-17 00:00:00', 30.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-18 00:00:00', 31.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-19 00:00:00', 32.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-20 00:00:00', 35.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-21 00:00:00', 35.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-22 00:00:00', 36.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-23 00:00:00', 36.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-24 00:00:00', 35.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-25 00:00:00', 33.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-26 00:00:00', 35.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-27 00:00:00', 38.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-28 00:00:00', 33.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-29 00:00:00', 33.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-30 00:00:00', 32.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-05-31 00:00:00', 32.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-01 00:00:00', 33.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-02 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-03 00:00:00', 35.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-04 00:00:00', 37.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-05 00:00:00', 38.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-06 00:00:00', 37.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-07 00:00:00', 37.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-08 00:00:00', 31.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-09 00:00:00', 33.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-10 00:00:00', 35.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-11 00:00:00', 36.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-12 00:00:00', 36.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-13 00:00:00', 35.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-14 00:00:00', 37.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-15 00:00:00', 39.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-16 00:00:00', 41.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-17 00:00:00', 42.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-18 00:00:00', 43.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-19 00:00:00', 45.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-20 00:00:00', 43.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-21 00:00:00', 43.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-22 00:00:00', 44.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-23 00:00:00', 42.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-24 00:00:00', 41.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-25 00:00:00', 40.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-26 00:00:00', 40.1899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-27 00:00:00', 40.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-28 00:00:00', 41.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-29 00:00:00', 43.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-06-30 00:00:00', 44.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-01 00:00:00', 40.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-02 00:00:00', 39.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-03 00:00:00', 39.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-04 00:00:00', 37.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-05 00:00:00', 38.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-06 00:00:00', 39.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-07 00:00:00', 39.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-08 00:00:00', 39.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-09 00:00:00', 37.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-10 00:00:00', 36.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-11 00:00:00', 36.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-12 00:00:00', 37.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-13 00:00:00', 34.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-14 00:00:00', 35.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-15 00:00:00', 36.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-16 00:00:00', 38.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-17 00:00:00', 40.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-18 00:00:00', 39.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-19 00:00:00', 39.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-20 00:00:00', 38.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-21 00:00:00', 37.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-22 00:00:00', 36.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-23 00:00:00', 37.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-24 00:00:00', 40.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-25 00:00:00', 43.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-26 00:00:00', 39.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-27 00:00:00', 38.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-28 00:00:00', 38.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-29 00:00:00', 40.6570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-30 00:00:00', 42.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-07-31 00:00:00', 42.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-01 00:00:00', 40.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-02 00:00:00', 38.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-03 00:00:00', 39.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-04 00:00:00', 38.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-05 00:00:00', 39.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-06 00:00:00', 41.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-07 00:00:00', 42.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-08 00:00:00', 43.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-09 00:00:00', 43.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-10 00:00:00', 43.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-11 00:00:00', 43.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-12 00:00:00', 41.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-13 00:00:00', 37.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-14 00:00:00', 36.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-15 00:00:00', 37.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-16 00:00:00', 38.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-17 00:00:00', 39.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-18 00:00:00', 39.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-19 00:00:00', 38.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-20 00:00:00', 39.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-21 00:00:00', 40.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-22 00:00:00', 38.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-23 00:00:00', 35.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-24 00:00:00', 35.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-25 00:00:00', 35.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-26 00:00:00', 36.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-27 00:00:00', 38.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-28 00:00:00', 39.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-29 00:00:00', 39.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-30 00:00:00', 36.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-08-31 00:00:00', 34.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-01 00:00:00', 35.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-02 00:00:00', 38.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-03 00:00:00', 34.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-04 00:00:00', 32.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-05 00:00:00', 33.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-06 00:00:00', 35.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-07 00:00:00', 35.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-08 00:00:00', 34.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-09 00:00:00', 34.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-10 00:00:00', 33.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-11 00:00:00', 34.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-12 00:00:00', 34.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-13 00:00:00', 36.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-14 00:00:00', 36.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-15 00:00:00', 37.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-16 00:00:00', 35.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-17 00:00:00', 33.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-18 00:00:00', 33.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-19 00:00:00', 34.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-20 00:00:00', 33.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-21 00:00:00', 35.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-22 00:00:00', 35.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-23 00:00:00', 34.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-24 00:00:00', 29.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-25 00:00:00', 31.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-26 00:00:00', 31.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-27 00:00:00', 31.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-28 00:00:00', 30.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-29 00:00:00', 30.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-09-30 00:00:00', 31.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-01 00:00:00', 31.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-02 00:00:00', 32.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-03 00:00:00', 30.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-04 00:00:00', 31.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-05 00:00:00', 31.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-06 00:00:00', 22.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-07 00:00:00', 23.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-08 00:00:00', 25.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-09 00:00:00', 24.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-10 00:00:00', 27.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-11 00:00:00', 27.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-12 00:00:00', 27.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-13 00:00:00', 25.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-14 00:00:00', 26.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-15 00:00:00', 19.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-16 00:00:00', 14.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-17 00:00:00', 15.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-18 00:00:00', 15.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-19 00:00:00', 13.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-20 00:00:00', 18.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-21 00:00:00', 21.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-22 00:00:00', 22.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-23 00:00:00', 22.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-24 00:00:00', 25.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-25 00:00:00', 26.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-26 00:00:00', 26.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-27 00:00:00', 27.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-28 00:00:00', 24.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-29 00:00:00', 23.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-30 00:00:00', 17.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-10-31 00:00:00', 19.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-01 00:00:00', 19.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-02 00:00:00', 18.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-03 00:00:00', 19.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-04 00:00:00', 23.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-05 00:00:00', 23.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-06 00:00:00', 22.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-07 00:00:00', 23.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-08 00:00:00', 23.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-09 00:00:00', 23.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-10 00:00:00', 24.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-11 00:00:00', 23.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-12 00:00:00', 24.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-13 00:00:00', 24.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-14 00:00:00', 15.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-15 00:00:00', 13.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-16 00:00:00', 14.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-17 00:00:00', 11.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-18 00:00:00', 12.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-19 00:00:00', 15.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-20 00:00:00', 18.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-21 00:00:00', 18.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-22 00:00:00', 17.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-23 00:00:00', 14.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-24 00:00:00', 16.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-25 00:00:00', 17.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-26 00:00:00', 16.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-27 00:00:00', 14.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-28 00:00:00', 15.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-29 00:00:00', 16.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-11-30 00:00:00', 16.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-01 00:00:00', 17.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-02 00:00:00', 17.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-03 00:00:00', 18.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-04 00:00:00', 18.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-05 00:00:00', 18.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-06 00:00:00', 19.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-07 00:00:00', 20.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-08 00:00:00', 15.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-09 00:00:00', 10.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-10 00:00:00', 9.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-11 00:00:00', 8.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-12 00:00:00', 7.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-13 00:00:00', 4.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-14 00:00:00', 6.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-15 00:00:00', 6.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-16 00:00:00', 5.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-17 00:00:00', 7.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-18 00:00:00', 10.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-19 00:00:00', 13.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-20 00:00:00', 8.61400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-21 00:00:00', 11.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-22 00:00:00', 7.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-23 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-24 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-25 00:00:00', 5.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-26 00:00:00', 4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-27 00:00:00', 0.379999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-28 00:00:00', -1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-29 00:00:00', -3.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-30 00:00:00', -4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1990-12-31 00:00:00', -2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-01 00:00:00', -1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-02 00:00:00', 0.691999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-03 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-04 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-05 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-06 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-07 00:00:00', 5.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-08 00:00:00', 4.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-09 00:00:00', 8.50300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-10 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-11 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-12 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-13 00:00:00', 5.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-14 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-15 00:00:00', 9.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-16 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-17 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-18 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-19 00:00:00', 6.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-20 00:00:00', 6.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-21 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-22 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-23 00:00:00', 3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-24 00:00:00', 6.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-25 00:00:00', 5.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-26 00:00:00', 10.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-27 00:00:00', 7.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-28 00:00:00', 8.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-29 00:00:00', 8.74699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-30 00:00:00', 10.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-01-31 00:00:00', 10.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-01 00:00:00', 11.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-02 00:00:00', 8.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-03 00:00:00', 10.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-04 00:00:00', 7.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-05 00:00:00', 8.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-06 00:00:00', 6.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-07 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-08 00:00:00', 9.68500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-09 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-10 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-11 00:00:00', 5.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-12 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-13 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-14 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-15 00:00:00', -0.709999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-16 00:00:00', 2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-17 00:00:00', 5.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-18 00:00:00', 7.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-19 00:00:00', 10.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-20 00:00:00', 12.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-21 00:00:00', 13.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-22 00:00:00', 13.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-23 00:00:00', 8.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-24 00:00:00', 4.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-25 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-26 00:00:00', 6.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-27 00:00:00', 8.71300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-02-28 00:00:00', 13.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-01 00:00:00', 16.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-02 00:00:00', 9.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-03 00:00:00', 11.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-04 00:00:00', 10.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-05 00:00:00', 9.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-06 00:00:00', 11.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-07 00:00:00', 8.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-08 00:00:00', 8.57900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-09 00:00:00', 10.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-10 00:00:00', 12.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-11 00:00:00', 12.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-12 00:00:00', 5.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-13 00:00:00', 11.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-14 00:00:00', 15.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-15 00:00:00', 15.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-16 00:00:00', 13.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-17 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-18 00:00:00', 9.47099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-19 00:00:00', 14.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-20 00:00:00', 11.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-21 00:00:00', 12.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-22 00:00:00', 12.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-23 00:00:00', 14.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-24 00:00:00', 18.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-25 00:00:00', 18.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-26 00:00:00', 19.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-27 00:00:00', 21.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-28 00:00:00', 24.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-29 00:00:00', 19.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-30 00:00:00', 19.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-03-31 00:00:00', 24.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-01 00:00:00', 27.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-02 00:00:00', 20.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-03 00:00:00', 21.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-04 00:00:00', 25.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-05 00:00:00', 27.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-06 00:00:00', 22.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-07 00:00:00', 21.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-08 00:00:00', 20.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-09 00:00:00', 18.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-10 00:00:00', 20.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-11 00:00:00', 22.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-12 00:00:00', 21.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-13 00:00:00', 22.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-14 00:00:00', 19.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-15 00:00:00', 16.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-16 00:00:00', 17.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-17 00:00:00', 21.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-18 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-19 00:00:00', 27.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-20 00:00:00', 28.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-21 00:00:00', 28.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-22 00:00:00', 26.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-23 00:00:00', 28.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-24 00:00:00', 29.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-25 00:00:00', 27.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-26 00:00:00', 29.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-27 00:00:00', 27.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-28 00:00:00', 29.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-29 00:00:00', 28.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-04-30 00:00:00', 27.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-01 00:00:00', 25.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-02 00:00:00', 23.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-03 00:00:00', 27.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-04 00:00:00', 29.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-05 00:00:00', 23.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-06 00:00:00', 27.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-07 00:00:00', 28.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-08 00:00:00', 26.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-09 00:00:00', 27.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-10 00:00:00', 29.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-11 00:00:00', 31.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-12 00:00:00', 28.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-13 00:00:00', 29.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-14 00:00:00', 29.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-15 00:00:00', 26.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-16 00:00:00', 28.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-17 00:00:00', 30.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-18 00:00:00', 33.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-19 00:00:00', 30.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-20 00:00:00', 29.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-21 00:00:00', 22.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-22 00:00:00', 29.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-23 00:00:00', 30.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-24 00:00:00', 28.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-25 00:00:00', 26.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-26 00:00:00', 28.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-27 00:00:00', 31.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-28 00:00:00', 32.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-29 00:00:00', 32.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-30 00:00:00', 34.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-05-31 00:00:00', 36.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-01 00:00:00', 39.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-02 00:00:00', 38.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-03 00:00:00', 39.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-04 00:00:00', 38.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-05 00:00:00', 40.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-06 00:00:00', 36.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-07 00:00:00', 38.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-08 00:00:00', 38.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-09 00:00:00', 35.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-10 00:00:00', 33.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-11 00:00:00', 33.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-12 00:00:00', 37.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-13 00:00:00', 40.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-14 00:00:00', 39.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-15 00:00:00', 36.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-16 00:00:00', 37.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-17 00:00:00', 38.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-18 00:00:00', 36.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-19 00:00:00', 34.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-20 00:00:00', 35.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-21 00:00:00', 35.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-22 00:00:00', 36.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-23 00:00:00', 29.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-24 00:00:00', 28.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-25 00:00:00', 30.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-26 00:00:00', 34.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-27 00:00:00', 35.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-28 00:00:00', 36.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-29 00:00:00', 38.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-06-30 00:00:00', 38.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-01 00:00:00', 38.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-02 00:00:00', 40.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-03 00:00:00', 39.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-04 00:00:00', 39.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-05 00:00:00', 39.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-06 00:00:00', 39.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-07 00:00:00', 39.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-08 00:00:00', 41.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-09 00:00:00', 41.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-10 00:00:00', 40.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-11 00:00:00', 38.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-12 00:00:00', 36.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-13 00:00:00', 34.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-14 00:00:00', 37.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-15 00:00:00', 39.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-16 00:00:00', 39.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-17 00:00:00', 37.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-18 00:00:00', 38.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-19 00:00:00', 38.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-20 00:00:00', 38.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-21 00:00:00', 38.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-22 00:00:00', 38.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-23 00:00:00', 38.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-24 00:00:00', 38.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-25 00:00:00', 38.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-26 00:00:00', 38.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-27 00:00:00', 39.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-28 00:00:00', 39.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-29 00:00:00', 41.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-30 00:00:00', 41.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-07-31 00:00:00', 40.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-01 00:00:00', 39.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-02 00:00:00', 38.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-03 00:00:00', 39.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-04 00:00:00', 40.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-05 00:00:00', 40.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-06 00:00:00', 39.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-07 00:00:00', 39.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-08 00:00:00', 36.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-09 00:00:00', 34.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-10 00:00:00', 34.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-11 00:00:00', 37.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-12 00:00:00', 38.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-13 00:00:00', 40.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-14 00:00:00', 39.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-15 00:00:00', 39.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-16 00:00:00', 38.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-17 00:00:00', 38.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-18 00:00:00', 39.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-19 00:00:00', 41.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-20 00:00:00', 37.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-21 00:00:00', 34.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-22 00:00:00', 33.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-23 00:00:00', 32.9490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-24 00:00:00', 34.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-25 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-26 00:00:00', 37.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-27 00:00:00', 37.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-28 00:00:00', 37.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-29 00:00:00', 36.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-30 00:00:00', 35.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-08-31 00:00:00', 36.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-01 00:00:00', 36.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-02 00:00:00', 37.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-03 00:00:00', 38.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-04 00:00:00', 38.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-05 00:00:00', 37.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-06 00:00:00', 33.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-07 00:00:00', 33.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-08 00:00:00', 35.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-09 00:00:00', 36.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-10 00:00:00', 35.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-11 00:00:00', 35.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-12 00:00:00', 33.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-13 00:00:00', 33.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-14 00:00:00', 33.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-15 00:00:00', 32.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-16 00:00:00', 31.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-17 00:00:00', 29.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-18 00:00:00', 26.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-19 00:00:00', 28.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-20 00:00:00', 30.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-21 00:00:00', 33.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-22 00:00:00', 35.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-23 00:00:00', 33.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-24 00:00:00', 33.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-25 00:00:00', 31.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-26 00:00:00', 25.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-27 00:00:00', 17.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-28 00:00:00', 20.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-29 00:00:00', 19.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-09-30 00:00:00', 19.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-01 00:00:00', 22.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-02 00:00:00', 23.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-03 00:00:00', 25.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-04 00:00:00', 27.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-05 00:00:00', 27.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-06 00:00:00', 26.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-07 00:00:00', 25.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-08 00:00:00', 24.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-09 00:00:00', 24.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-10 00:00:00', 25.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-11 00:00:00', 19.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-12 00:00:00', 20.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-13 00:00:00', 19.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-14 00:00:00', 17.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-15 00:00:00', 20.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-16 00:00:00', 22.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-17 00:00:00', 24.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-18 00:00:00', 19.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-19 00:00:00', 23.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-20 00:00:00', 25.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-21 00:00:00', 23.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-22 00:00:00', 23.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-23 00:00:00', 24.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-24 00:00:00', 25.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-25 00:00:00', 25.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-26 00:00:00', 25.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-27 00:00:00', 25.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-28 00:00:00', 24.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-29 00:00:00', 23.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-30 00:00:00', 23.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-10-31 00:00:00', 24.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-01 00:00:00', 22.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-02 00:00:00', 23.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-03 00:00:00', 22.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-04 00:00:00', 20.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-05 00:00:00', 24.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-06 00:00:00', 23.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-07 00:00:00', 21.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-08 00:00:00', 15.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-09 00:00:00', 16.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-10 00:00:00', 16.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-11 00:00:00', 17.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-12 00:00:00', 18.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-13 00:00:00', 12.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-14 00:00:00', 15.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-15 00:00:00', 17.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-16 00:00:00', 16.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-17 00:00:00', 13.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-18 00:00:00', 16.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-19 00:00:00', 17.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-20 00:00:00', 13.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-21 00:00:00', 8.79399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-22 00:00:00', 14.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-23 00:00:00', 9.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-24 00:00:00', 12.2130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-25 00:00:00', 15.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-26 00:00:00', 15.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-27 00:00:00', 10.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-28 00:00:00', 8.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-29 00:00:00', 7.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-11-30 00:00:00', 10.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-01 00:00:00', 11.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-02 00:00:00', 15.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-03 00:00:00', 14.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-04 00:00:00', 14.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-05 00:00:00', 15.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-06 00:00:00', 13.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-07 00:00:00', 14.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-08 00:00:00', 13.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-09 00:00:00', 11.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-10 00:00:00', 11.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-11 00:00:00', 10.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-12 00:00:00', 11.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-13 00:00:00', 11.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-14 00:00:00', 9.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-15 00:00:00', 9.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-16 00:00:00', 8.75599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-17 00:00:00', 8.24199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-18 00:00:00', 5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-19 00:00:00', 7.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-20 00:00:00', 4.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-21 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-22 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-23 00:00:00', 9.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-24 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-25 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-26 00:00:00', 9.09300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-27 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-28 00:00:00', 7.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-29 00:00:00', 6.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-30 00:00:00', 6.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1991-12-31 00:00:00', 4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-01 00:00:00', 6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-02 00:00:00', 8.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-03 00:00:00', 9.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-04 00:00:00', 7.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-05 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-06 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-07 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-08 00:00:00', 6.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-09 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-10 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-11 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-12 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-13 00:00:00', 8.84799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-14 00:00:00', 10.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-15 00:00:00', 7.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-16 00:00:00', 9.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-17 00:00:00', 12.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-18 00:00:00', 9.80500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-19 00:00:00', 11.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-20 00:00:00', 13.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-21 00:00:00', 12.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-22 00:00:00', 13.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-23 00:00:00', 8.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-24 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-25 00:00:00', 6.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-26 00:00:00', 5.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-27 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-28 00:00:00', 3.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-29 00:00:00', 0.839999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-30 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-01-31 00:00:00', 6.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-01 00:00:00', 8.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-02 00:00:00', 9.27700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-03 00:00:00', 10.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-04 00:00:00', 12.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-05 00:00:00', 10.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-06 00:00:00', 10.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-07 00:00:00', 8.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-08 00:00:00', 9.91199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-09 00:00:00', 10.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-10 00:00:00', 10.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-11 00:00:00', 10.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-12 00:00:00', 6.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-13 00:00:00', 4.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-14 00:00:00', 6.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-15 00:00:00', 9.60499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-16 00:00:00', 8.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-17 00:00:00', 6.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-18 00:00:00', 11.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-19 00:00:00', 10.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-20 00:00:00', 13.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-21 00:00:00', 14.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-22 00:00:00', 13.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-23 00:00:00', 13.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-24 00:00:00', 15.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-25 00:00:00', 16.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-26 00:00:00', 16.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-27 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-28 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-02-29 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-01 00:00:00', 10.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-02 00:00:00', 12.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-03 00:00:00', 8.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-04 00:00:00', 9.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-05 00:00:00', 11.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-06 00:00:00', 13.6059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-07 00:00:00', 14.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-08 00:00:00', 11.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-09 00:00:00', 12.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-10 00:00:00', 11.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-11 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-12 00:00:00', 5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-13 00:00:00', 6.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-14 00:00:00', 9.88599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-15 00:00:00', 14.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-16 00:00:00', 11.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-17 00:00:00', 11.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-18 00:00:00', 15.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-19 00:00:00', 12.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-20 00:00:00', 10.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-21 00:00:00', 15.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-22 00:00:00', 16.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-23 00:00:00', 17.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-24 00:00:00', 17.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-25 00:00:00', 17.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-26 00:00:00', 7.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-27 00:00:00', 12.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-28 00:00:00', 16.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-29 00:00:00', 13.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-30 00:00:00', 11.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-03-31 00:00:00', 19.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-01 00:00:00', 20.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-02 00:00:00', 18.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-03 00:00:00', 19.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-04 00:00:00', 19.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-05 00:00:00', 22.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-06 00:00:00', 17.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-07 00:00:00', 18.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-08 00:00:00', 22.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-09 00:00:00', 23.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-10 00:00:00', 21.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-11 00:00:00', 20.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-12 00:00:00', 21.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-13 00:00:00', 25.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-14 00:00:00', 27.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-15 00:00:00', 28.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-16 00:00:00', 25.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-17 00:00:00', 21.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-18 00:00:00', 24.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-19 00:00:00', 28.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-20 00:00:00', 24.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-21 00:00:00', 23.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-22 00:00:00', 24.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-23 00:00:00', 29.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-24 00:00:00', 26.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-25 00:00:00', 28.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-26 00:00:00', 28.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-27 00:00:00', 29.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-28 00:00:00', 27.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-29 00:00:00', 26.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-04-30 00:00:00', 26.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-01 00:00:00', 22.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-02 00:00:00', 14.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-03 00:00:00', 17.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-04 00:00:00', 19.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-05 00:00:00', 21.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-06 00:00:00', 20.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-07 00:00:00', 20.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-08 00:00:00', 23.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-09 00:00:00', 27.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-10 00:00:00', 30.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-11 00:00:00', 29.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-12 00:00:00', 29.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-13 00:00:00', 30.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-14 00:00:00', 31.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-15 00:00:00', 23.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-16 00:00:00', 27.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-17 00:00:00', 26.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-18 00:00:00', 25.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-19 00:00:00', 27.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-20 00:00:00', 28.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-21 00:00:00', 30.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-22 00:00:00', 32.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-23 00:00:00', 31.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-24 00:00:00', 32.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-25 00:00:00', 29.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-26 00:00:00', 27.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-27 00:00:00', 27.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-28 00:00:00', 27.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-29 00:00:00', 29.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-30 00:00:00', 30.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-05-31 00:00:00', 32.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-01 00:00:00', 33.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-02 00:00:00', 32.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-03 00:00:00', 34.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-04 00:00:00', 35.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-05 00:00:00', 36.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-06 00:00:00', 36.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-07 00:00:00', 34.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-08 00:00:00', 34.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-09 00:00:00', 34.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-10 00:00:00', 35.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-11 00:00:00', 36.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-12 00:00:00', 36.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-13 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-14 00:00:00', 29.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-15 00:00:00', 34.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-16 00:00:00', 34.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-17 00:00:00', 34.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-18 00:00:00', 35.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-19 00:00:00', 39.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-20 00:00:00', 40.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-21 00:00:00', 36.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-22 00:00:00', 36.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-23 00:00:00', 36.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-24 00:00:00', 36.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-25 00:00:00', 36.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-26 00:00:00', 37.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-27 00:00:00', 38.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-28 00:00:00', 39.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-29 00:00:00', 38.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-06-30 00:00:00', 40.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-01 00:00:00', 37.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-02 00:00:00', 35.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-03 00:00:00', 35.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-04 00:00:00', 37.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-05 00:00:00', 39.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-06 00:00:00', 41.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-07 00:00:00', 43.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-08 00:00:00', 40.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-09 00:00:00', 37.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-10 00:00:00', 39.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-11 00:00:00', 41.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-12 00:00:00', 40.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-13 00:00:00', 38.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-14 00:00:00', 36.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-15 00:00:00', 36.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-16 00:00:00', 37.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-17 00:00:00', 37.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-18 00:00:00', 38.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-19 00:00:00', 40.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-20 00:00:00', 41.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-21 00:00:00', 40.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-22 00:00:00', 40.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-23 00:00:00', 38.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-24 00:00:00', 38.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-25 00:00:00', 40.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-26 00:00:00', 39.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-27 00:00:00', 41.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-28 00:00:00', 41.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-29 00:00:00', 38.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-30 00:00:00', 37.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-07-31 00:00:00', 36.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-01 00:00:00', 40.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-02 00:00:00', 39.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-03 00:00:00', 39.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-04 00:00:00', 39.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-05 00:00:00', 36.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-06 00:00:00', 33.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-07 00:00:00', 34.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-08 00:00:00', 32.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-09 00:00:00', 32.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-10 00:00:00', 33.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-11 00:00:00', 35.4129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-12 00:00:00', 34.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-13 00:00:00', 34.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-14 00:00:00', 35.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-15 00:00:00', 33.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-16 00:00:00', 31.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-17 00:00:00', 29.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-18 00:00:00', 33.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-19 00:00:00', 35.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-20 00:00:00', 35.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-21 00:00:00', 35.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-22 00:00:00', 35.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-23 00:00:00', 37.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-24 00:00:00', 37.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-25 00:00:00', 38.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-26 00:00:00', 39.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-27 00:00:00', 37.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-28 00:00:00', 33.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-29 00:00:00', 34.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-30 00:00:00', 28.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-08-31 00:00:00', 28.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-01 00:00:00', 29.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-02 00:00:00', 25.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-03 00:00:00', 28.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-04 00:00:00', 30.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-05 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-06 00:00:00', 32.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-07 00:00:00', 33.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-08 00:00:00', 33.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-09 00:00:00', 31.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-10 00:00:00', 26.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-11 00:00:00', 28.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-12 00:00:00', 28.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-13 00:00:00', 29.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-14 00:00:00', 30.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-15 00:00:00', 29.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-16 00:00:00', 30.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-17 00:00:00', 30.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-18 00:00:00', 30.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-19 00:00:00', 30.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-20 00:00:00', 29.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-21 00:00:00', 29.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-22 00:00:00', 30.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-23 00:00:00', 31.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-24 00:00:00', 31.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-25 00:00:00', 32.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-26 00:00:00', 33.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-27 00:00:00', 30.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-28 00:00:00', 31.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-29 00:00:00', 27.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-09-30 00:00:00', 24.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-01 00:00:00', 22.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-02 00:00:00', 23.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-03 00:00:00', 25.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-04 00:00:00', 26.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-05 00:00:00', 24.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-06 00:00:00', 25.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-07 00:00:00', 21.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-08 00:00:00', 19.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-09 00:00:00', 24.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-10 00:00:00', 27.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-11 00:00:00', 29.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-12 00:00:00', 29.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-13 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-14 00:00:00', 28.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-15 00:00:00', 23.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-16 00:00:00', 16.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-17 00:00:00', 14.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-18 00:00:00', 17.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-19 00:00:00', 21.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-20 00:00:00', 23.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-21 00:00:00', 21.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-22 00:00:00', 21.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-23 00:00:00', 21.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-24 00:00:00', 22.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-25 00:00:00', 23.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-26 00:00:00', 25.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-27 00:00:00', 27.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-28 00:00:00', 26.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-29 00:00:00', 27.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-30 00:00:00', 23.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-10-31 00:00:00', 21.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-01 00:00:00', 21.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-02 00:00:00', 21.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-03 00:00:00', 22.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-04 00:00:00', 12.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-05 00:00:00', 12.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-06 00:00:00', 18.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-07 00:00:00', 20.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-08 00:00:00', 24.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-09 00:00:00', 21.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-10 00:00:00', 24.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-11 00:00:00', 23.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-12 00:00:00', 24.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-13 00:00:00', 25.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-14 00:00:00', 23.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-15 00:00:00', 23.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-16 00:00:00', 21.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-17 00:00:00', 19.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-18 00:00:00', 12.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-19 00:00:00', 10.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-20 00:00:00', 12.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-21 00:00:00', 9.23499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-22 00:00:00', 14.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-23 00:00:00', 20.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-24 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-25 00:00:00', 21.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-26 00:00:00', 22.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-27 00:00:00', 11.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-28 00:00:00', 14.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-29 00:00:00', 17.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-11-30 00:00:00', 18.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-01 00:00:00', 15.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-02 00:00:00', 13.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-03 00:00:00', 10.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-04 00:00:00', 13.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-05 00:00:00', 14.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-06 00:00:00', 12.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-07 00:00:00', 11.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-08 00:00:00', 11.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-09 00:00:00', 13.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-10 00:00:00', 12.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-11 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-12 00:00:00', 8.30099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-13 00:00:00', 11.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-14 00:00:00', 15.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-15 00:00:00', 15.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-16 00:00:00', 17.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-17 00:00:00', 15.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-18 00:00:00', 15.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-19 00:00:00', 14.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-20 00:00:00', 16.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-21 00:00:00', 13.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-22 00:00:00', 15.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-23 00:00:00', 10.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-24 00:00:00', 8.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-25 00:00:00', 9.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-26 00:00:00', 11.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-27 00:00:00', 11.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-28 00:00:00', 12.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-29 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-30 00:00:00', 7.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1992-12-31 00:00:00', 8.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-01 00:00:00', 9.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-02 00:00:00', 6.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-03 00:00:00', 5.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-04 00:00:00', 8.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-05 00:00:00', 5.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-06 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-07 00:00:00', -0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-08 00:00:00', -0.432000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-09 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-10 00:00:00', 5.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-11 00:00:00', 6.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-12 00:00:00', 5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-13 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-14 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-15 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-16 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-17 00:00:00', 5.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-18 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-19 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-20 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-21 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-22 00:00:00', 6.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-23 00:00:00', 7.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-24 00:00:00', 8.04399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-25 00:00:00', 11.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-26 00:00:00', 11.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-27 00:00:00', 14.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-28 00:00:00', 13.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-29 00:00:00', 14.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-30 00:00:00', 14.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-01-31 00:00:00', 13.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-01 00:00:00', 14.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-02 00:00:00', 14.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-03 00:00:00', 17.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-04 00:00:00', 12.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-05 00:00:00', 15.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-06 00:00:00', 12.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-07 00:00:00', 14.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-08 00:00:00', 12.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-09 00:00:00', 14.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-10 00:00:00', 10.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-11 00:00:00', 14.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-12 00:00:00', 16.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-13 00:00:00', 12.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-14 00:00:00', 9.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-15 00:00:00', 12.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-16 00:00:00', 6.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-17 00:00:00', -0.425000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-18 00:00:00', -1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-19 00:00:00', 1.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-20 00:00:00', 6.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-21 00:00:00', 9.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-22 00:00:00', 4.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-23 00:00:00', 10.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-24 00:00:00', 7.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-25 00:00:00', 6.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-26 00:00:00', 8.72799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-27 00:00:00', 9.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-02-28 00:00:00', 12.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-01 00:00:00', 9.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-02 00:00:00', 8.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-03 00:00:00', 8.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-04 00:00:00', 14.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-05 00:00:00', 12.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-06 00:00:00', 16.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-07 00:00:00', 15.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-08 00:00:00', 18.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-09 00:00:00', 16.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-10 00:00:00', 14.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-11 00:00:00', 11.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-12 00:00:00', 13.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-13 00:00:00', 7.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-14 00:00:00', 8.27000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-15 00:00:00', 10.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-16 00:00:00', 10.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-17 00:00:00', 11.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-18 00:00:00', 12.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-19 00:00:00', 15.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-20 00:00:00', 8.57699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-21 00:00:00', 15.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-22 00:00:00', 13.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-23 00:00:00', 9.62399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-24 00:00:00', 8.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-25 00:00:00', 9.89700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-26 00:00:00', 12.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-27 00:00:00', 17.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-28 00:00:00', 17.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-29 00:00:00', 19.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-30 00:00:00', 20.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-03-31 00:00:00', 19.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-01 00:00:00', 16.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-02 00:00:00', 17.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-03 00:00:00', 21.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-04 00:00:00', 24.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-05 00:00:00', 22.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-06 00:00:00', 24.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-07 00:00:00', 23.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-08 00:00:00', 23.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-09 00:00:00', 25.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-10 00:00:00', 24.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-11 00:00:00', 25.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-12 00:00:00', 28.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-13 00:00:00', 27.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-14 00:00:00', 25.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-15 00:00:00', 21.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-16 00:00:00', 21.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-17 00:00:00', 24.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-18 00:00:00', 28.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-19 00:00:00', 30.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-20 00:00:00', 31.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-21 00:00:00', 33.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-22 00:00:00', 31.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-23 00:00:00', 33.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-24 00:00:00', 18.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-25 00:00:00', 22.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-26 00:00:00', 27.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-27 00:00:00', 25.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-28 00:00:00', 25.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-29 00:00:00', 23.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-04-30 00:00:00', 28.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-01 00:00:00', 29.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-02 00:00:00', 29.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-03 00:00:00', 29.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-04 00:00:00', 31.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-05 00:00:00', 29.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-06 00:00:00', 30.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-07 00:00:00', 32.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-08 00:00:00', 23.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-09 00:00:00', 17.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-10 00:00:00', 19.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-11 00:00:00', 20.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-12 00:00:00', 24.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-13 00:00:00', 27.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-14 00:00:00', 30.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-15 00:00:00', 29.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-16 00:00:00', 25.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-17 00:00:00', 29.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-18 00:00:00', 29.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-19 00:00:00', 32.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-20 00:00:00', 33.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-21 00:00:00', 27.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-22 00:00:00', 33.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-23 00:00:00', 34.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-24 00:00:00', 32.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-25 00:00:00', 30.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-26 00:00:00', 30.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-27 00:00:00', 34.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-28 00:00:00', 37.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-29 00:00:00', 34.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-30 00:00:00', 28.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-05-31 00:00:00', 28.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-01 00:00:00', 33.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-02 00:00:00', 31.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-03 00:00:00', 33.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-04 00:00:00', 37.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-05 00:00:00', 35.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-06 00:00:00', 33.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-07 00:00:00', 34.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-08 00:00:00', 34.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-09 00:00:00', 36.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-10 00:00:00', 39.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-11 00:00:00', 39.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-12 00:00:00', 38.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-13 00:00:00', 35.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-14 00:00:00', 36.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-15 00:00:00', 35.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-16 00:00:00', 37.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-17 00:00:00', 38.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-18 00:00:00', 40.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-19 00:00:00', 38.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-20 00:00:00', 40.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-21 00:00:00', 40.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-22 00:00:00', 39.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-23 00:00:00', 33.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-24 00:00:00', 34.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-25 00:00:00', 35.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-26 00:00:00', 35.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-27 00:00:00', 37.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-28 00:00:00', 38.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-29 00:00:00', 40.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-06-30 00:00:00', 42.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-01 00:00:00', 41.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-02 00:00:00', 42.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-03 00:00:00', 41.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-04 00:00:00', 42.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-05 00:00:00', 41.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-06 00:00:00', 41.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-07 00:00:00', 42.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-08 00:00:00', 38.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-09 00:00:00', 36.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-10 00:00:00', 36.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-11 00:00:00', 37.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-12 00:00:00', 36.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-13 00:00:00', 38.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-14 00:00:00', 40.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-15 00:00:00', 39.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-16 00:00:00', 40.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-17 00:00:00', 40.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-18 00:00:00', 38.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-19 00:00:00', 39.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-20 00:00:00', 41.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-21 00:00:00', 41.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-22 00:00:00', 38.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-23 00:00:00', 35.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-24 00:00:00', 31.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-25 00:00:00', 35.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-26 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-27 00:00:00', 37.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-28 00:00:00', 38.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-29 00:00:00', 37.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-30 00:00:00', 37.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-07-31 00:00:00', 35.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-01 00:00:00', 36.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-02 00:00:00', 37.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-03 00:00:00', 36.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-04 00:00:00', 35.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-05 00:00:00', 35.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-06 00:00:00', 36.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-07 00:00:00', 36.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-08 00:00:00', 36.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-09 00:00:00', 36.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-10 00:00:00', 34.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-11 00:00:00', 33.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-12 00:00:00', 34.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-13 00:00:00', 36.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-14 00:00:00', 36.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-15 00:00:00', 37.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-16 00:00:00', 37.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-17 00:00:00', 36.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-18 00:00:00', 34.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-19 00:00:00', 32.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-20 00:00:00', 33.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-21 00:00:00', 34.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-22 00:00:00', 34.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-23 00:00:00', 36.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-24 00:00:00', 33.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-25 00:00:00', 32.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-26 00:00:00', 35.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-27 00:00:00', 37.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-28 00:00:00', 37.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-29 00:00:00', 37.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-30 00:00:00', 38.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-08-31 00:00:00', 38.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-01 00:00:00', 38.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-02 00:00:00', 37.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-03 00:00:00', 34.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-04 00:00:00', 36.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-05 00:00:00', 36.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-06 00:00:00', 35.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-07 00:00:00', 35.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-08 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-09 00:00:00', 34.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-10 00:00:00', 35.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-11 00:00:00', 35.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-12 00:00:00', 32.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-13 00:00:00', 34.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-14 00:00:00', 34.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-15 00:00:00', 36.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-16 00:00:00', 28.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-17 00:00:00', 29.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-18 00:00:00', 32.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-19 00:00:00', 33.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-20 00:00:00', 33.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-21 00:00:00', 32.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-22 00:00:00', 33.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-23 00:00:00', 28.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-24 00:00:00', 27.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-25 00:00:00', 30.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-26 00:00:00', 30.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-27 00:00:00', 28.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-28 00:00:00', 27.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-29 00:00:00', 29.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-09-30 00:00:00', 30.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-01 00:00:00', 31.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-02 00:00:00', 33.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-03 00:00:00', 27.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-04 00:00:00', 25.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-05 00:00:00', 15.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-06 00:00:00', 18.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-07 00:00:00', 12.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-08 00:00:00', 14.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-09 00:00:00', 16.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-10 00:00:00', 17.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-11 00:00:00', 20.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-12 00:00:00', 23.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-13 00:00:00', 22.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-14 00:00:00', 22.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-15 00:00:00', 23.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-16 00:00:00', 21.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-17 00:00:00', 21.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-18 00:00:00', 21.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-19 00:00:00', 21.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-20 00:00:00', 22.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-21 00:00:00', 20.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-22 00:00:00', 18.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-23 00:00:00', 19.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-24 00:00:00', 19.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-25 00:00:00', 17.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-26 00:00:00', 20.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-27 00:00:00', 22.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-28 00:00:00', 24.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-29 00:00:00', 24.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-30 00:00:00', 22.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-10-31 00:00:00', 23.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-01 00:00:00', 25.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-02 00:00:00', 18.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-03 00:00:00', 17.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-04 00:00:00', 11.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-05 00:00:00', 11.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-06 00:00:00', 10.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-07 00:00:00', 15.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-08 00:00:00', 11.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-09 00:00:00', 15.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-10 00:00:00', 19.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-11 00:00:00', 20.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-12 00:00:00', 23.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-13 00:00:00', 20.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-14 00:00:00', 22.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-15 00:00:00', 16.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-16 00:00:00', 15.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-17 00:00:00', 7.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-18 00:00:00', 10.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-19 00:00:00', 17.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-20 00:00:00', 14.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-21 00:00:00', 9.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-22 00:00:00', 6.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-23 00:00:00', 8.47799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-24 00:00:00', 13.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-25 00:00:00', 14.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-26 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-27 00:00:00', 6.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-28 00:00:00', 10.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-29 00:00:00', 13.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-11-30 00:00:00', 6.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-01 00:00:00', 5.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-02 00:00:00', 6.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-03 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-04 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-05 00:00:00', 10.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-06 00:00:00', 8.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-07 00:00:00', 3.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-08 00:00:00', 9.69699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-09 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-10 00:00:00', 8.49600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-11 00:00:00', 10.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-12 00:00:00', 12.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-13 00:00:00', 8.16899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-14 00:00:00', 11.6920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-15 00:00:00', 12.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-16 00:00:00', 7.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-17 00:00:00', 7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-18 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-19 00:00:00', 11.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-20 00:00:00', 12.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-21 00:00:00', 7.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-22 00:00:00', 10.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-23 00:00:00', 13.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-24 00:00:00', 14.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-25 00:00:00', 14.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-26 00:00:00', 12.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-27 00:00:00', 10.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-28 00:00:00', 10.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-29 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-30 00:00:00', 11.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1993-12-31 00:00:00', 8.61699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-01 00:00:00', 5.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-02 00:00:00', 7.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-03 00:00:00', 7.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-04 00:00:00', 10.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-05 00:00:00', 11.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-06 00:00:00', 12.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-07 00:00:00', 6.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-08 00:00:00', 6.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-09 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-10 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-11 00:00:00', 5.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-12 00:00:00', 7.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-13 00:00:00', 10.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-14 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-15 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-16 00:00:00', 8.03600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-17 00:00:00', 7.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-18 00:00:00', 4.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-19 00:00:00', 2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-20 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-21 00:00:00', 6.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-22 00:00:00', 4.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-23 00:00:00', 10.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-24 00:00:00', 5.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-25 00:00:00', 10.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-26 00:00:00', 8.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-27 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-28 00:00:00', 9.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-29 00:00:00', 9.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-30 00:00:00', 10.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-01-31 00:00:00', 8.65400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-01 00:00:00', 12.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-02 00:00:00', 11.560999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-03 00:00:00', 13.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-04 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-05 00:00:00', 3.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-06 00:00:00', 8.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-07 00:00:00', 5.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-08 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-09 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-10 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-11 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-12 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-13 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-14 00:00:00', 8.95600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-15 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-16 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-17 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-18 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-19 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-20 00:00:00', -0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-21 00:00:00', 0.0130000002682209015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-22 00:00:00', 3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-23 00:00:00', 7.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-24 00:00:00', 10.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-25 00:00:00', 9.26500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-26 00:00:00', 8.94200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-27 00:00:00', 9.97500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-02-28 00:00:00', 13.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-01 00:00:00', 14.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-02 00:00:00', 12.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-03 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-04 00:00:00', 11.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-05 00:00:00', 14.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-06 00:00:00', 16.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-07 00:00:00', 18.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-08 00:00:00', 18.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-09 00:00:00', 13.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-10 00:00:00', 13.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-11 00:00:00', 12.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-12 00:00:00', 15.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-13 00:00:00', 15.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-14 00:00:00', 13.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-15 00:00:00', 18.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-16 00:00:00', 19.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-17 00:00:00', 15.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-18 00:00:00', 16.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-19 00:00:00', 19.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-20 00:00:00', 19.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-21 00:00:00', 19.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-22 00:00:00', 21.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-23 00:00:00', 23.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-24 00:00:00', 23.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-25 00:00:00', 15.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-26 00:00:00', 19.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-27 00:00:00', 21.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-28 00:00:00', 23.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-29 00:00:00', 23.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-30 00:00:00', 24.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-03-31 00:00:00', 25.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-01 00:00:00', 23.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-02 00:00:00', 23.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-03 00:00:00', 17.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-04 00:00:00', 13.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-05 00:00:00', 8.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-06 00:00:00', 8.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-07 00:00:00', 13.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-08 00:00:00', 15.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-09 00:00:00', 11.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-10 00:00:00', 16.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-11 00:00:00', 21.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-12 00:00:00', 23.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-13 00:00:00', 21.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-14 00:00:00', 22.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-15 00:00:00', 21.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-16 00:00:00', 22.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-17 00:00:00', 24.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-18 00:00:00', 24.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-19 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-20 00:00:00', 23.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-21 00:00:00', 23.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-22 00:00:00', 25.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-23 00:00:00', 26.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-24 00:00:00', 28.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-25 00:00:00', 31.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-26 00:00:00', 32.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-27 00:00:00', 33.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-28 00:00:00', 25.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-29 00:00:00', 25.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-04-30 00:00:00', 22.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-01 00:00:00', 26.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-02 00:00:00', 28.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-03 00:00:00', 31.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-04 00:00:00', 32.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-05 00:00:00', 32.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-06 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-07 00:00:00', 27.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-08 00:00:00', 25.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-09 00:00:00', 25.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-10 00:00:00', 27.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-11 00:00:00', 30.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-12 00:00:00', 31.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-13 00:00:00', 31.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-14 00:00:00', 33.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-15 00:00:00', 34.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-16 00:00:00', 35.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-17 00:00:00', 33.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-18 00:00:00', 31.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-19 00:00:00', 27.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-20 00:00:00', 30.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-21 00:00:00', 33.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-22 00:00:00', 33.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-23 00:00:00', 31.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-24 00:00:00', 30.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-25 00:00:00', 32.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-26 00:00:00', 34.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-27 00:00:00', 34.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-28 00:00:00', 37.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-29 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-30 00:00:00', 36.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-05-31 00:00:00', 33.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-01 00:00:00', 34.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-02 00:00:00', 35.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-03 00:00:00', 36.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-04 00:00:00', 37.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-05 00:00:00', 37.8170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-06 00:00:00', 37.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-07 00:00:00', 36.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-08 00:00:00', 34.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-09 00:00:00', 34.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-10 00:00:00', 34.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-11 00:00:00', 34.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-12 00:00:00', 33.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-13 00:00:00', 34.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-14 00:00:00', 34.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-15 00:00:00', 38.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-16 00:00:00', 37.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-17 00:00:00', 39.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-18 00:00:00', 41.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-19 00:00:00', 43.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-20 00:00:00', 40.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-21 00:00:00', 40.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-22 00:00:00', 40.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-23 00:00:00', 41.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-24 00:00:00', 39.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-25 00:00:00', 38.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-26 00:00:00', 38.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-27 00:00:00', 38.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-28 00:00:00', 40.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-29 00:00:00', 41.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-06-30 00:00:00', 43.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-01 00:00:00', 41.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-02 00:00:00', 39.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-03 00:00:00', 38.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-04 00:00:00', 39.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-05 00:00:00', 41.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-06 00:00:00', 42.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-07 00:00:00', 43.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-08 00:00:00', 44.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-09 00:00:00', 44.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-10 00:00:00', 42.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-11 00:00:00', 37.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-12 00:00:00', 37.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-13 00:00:00', 36.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-14 00:00:00', 37.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-15 00:00:00', 37.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-16 00:00:00', 39.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-17 00:00:00', 40.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-18 00:00:00', 41.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-19 00:00:00', 40.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-20 00:00:00', 38.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-21 00:00:00', 39.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-22 00:00:00', 41.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-23 00:00:00', 41.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-24 00:00:00', 39.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-25 00:00:00', 39.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-26 00:00:00', 40.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-27 00:00:00', 41.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-28 00:00:00', 39.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-29 00:00:00', 38.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-30 00:00:00', 38.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-07-31 00:00:00', 39.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-01 00:00:00', 41.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-02 00:00:00', 43.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-03 00:00:00', 44.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-04 00:00:00', 44.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-05 00:00:00', 43.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-06 00:00:00', 42.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-07 00:00:00', 40.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-08 00:00:00', 37.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-09 00:00:00', 35.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-10 00:00:00', 34.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-11 00:00:00', 38.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-12 00:00:00', 39.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-13 00:00:00', 40.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-14 00:00:00', 41.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-15 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-16 00:00:00', 37.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-17 00:00:00', 36.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-18 00:00:00', 37.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-19 00:00:00', 38.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-20 00:00:00', 39.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-21 00:00:00', 40.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-22 00:00:00', 38.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-23 00:00:00', 38.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-24 00:00:00', 39.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-25 00:00:00', 39.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-26 00:00:00', 40.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-27 00:00:00', 38.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-28 00:00:00', 36.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-29 00:00:00', 36.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-30 00:00:00', 36.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-08-31 00:00:00', 35.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-01 00:00:00', 34.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-02 00:00:00', 33.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-03 00:00:00', 35.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-04 00:00:00', 32.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-05 00:00:00', 28.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-06 00:00:00', 27.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-07 00:00:00', 27.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-08 00:00:00', 29.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-09 00:00:00', 30.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-10 00:00:00', 29.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-11 00:00:00', 30.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-12 00:00:00', 30.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-13 00:00:00', 29.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-14 00:00:00', 26.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-15 00:00:00', 24.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-16 00:00:00', 25.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-17 00:00:00', 25.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-18 00:00:00', 23.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-19 00:00:00', 20.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-20 00:00:00', 20.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-21 00:00:00', 21.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-22 00:00:00', 24.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-23 00:00:00', 25.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-24 00:00:00', 27.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-25 00:00:00', 27.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-26 00:00:00', 28.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-27 00:00:00', 29.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-28 00:00:00', 30.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-29 00:00:00', 29.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-09-30 00:00:00', 29.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-01 00:00:00', 30.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-02 00:00:00', 29.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-03 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-04 00:00:00', 26.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-05 00:00:00', 26.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-06 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-07 00:00:00', 25.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-08 00:00:00', 26.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-09 00:00:00', 24.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-10 00:00:00', 23.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-11 00:00:00', 21.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-12 00:00:00', 20.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-13 00:00:00', 21.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-14 00:00:00', 22.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-15 00:00:00', 24.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-16 00:00:00', 23.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-17 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-18 00:00:00', 25.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-19 00:00:00', 27.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-20 00:00:00', 28.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-21 00:00:00', 27.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-22 00:00:00', 26.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-23 00:00:00', 22.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-24 00:00:00', 15.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-25 00:00:00', 12.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-26 00:00:00', 8.55500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-27 00:00:00', 17.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-28 00:00:00', 18.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-29 00:00:00', 19.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-30 00:00:00', 19.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-10-31 00:00:00', 20.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-01 00:00:00', 18.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-02 00:00:00', 18.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-03 00:00:00', 19.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-04 00:00:00', 21.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-05 00:00:00', 23.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-06 00:00:00', 24.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-07 00:00:00', 19.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-08 00:00:00', 22.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-09 00:00:00', 26.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-10 00:00:00', 18.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-11 00:00:00', 16.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-12 00:00:00', 18.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-13 00:00:00', 18.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-14 00:00:00', 18.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-15 00:00:00', 20.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-16 00:00:00', 18.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-17 00:00:00', 19.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-18 00:00:00', 17.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-19 00:00:00', 17.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-20 00:00:00', 18.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-21 00:00:00', 19.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-22 00:00:00', 19.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-23 00:00:00', 20.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-24 00:00:00', 19.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-25 00:00:00', 14.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-26 00:00:00', 17.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-27 00:00:00', 15.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-28 00:00:00', 18.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-29 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-11-30 00:00:00', 18.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-01 00:00:00', 19.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-02 00:00:00', 15.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-03 00:00:00', 16.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-04 00:00:00', 16.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-05 00:00:00', 15.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-06 00:00:00', 11.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-07 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-08 00:00:00', 0.698000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-09 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-10 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-11 00:00:00', 6.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-12 00:00:00', 7.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-13 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-14 00:00:00', 7.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-15 00:00:00', 7.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-16 00:00:00', 8.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-17 00:00:00', 8.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-18 00:00:00', 11.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-19 00:00:00', 14.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-20 00:00:00', 12.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-21 00:00:00', 10.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-22 00:00:00', 6.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-23 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-24 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-25 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-26 00:00:00', 3.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-27 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-28 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-29 00:00:00', 4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-30 00:00:00', 7.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1994-12-31 00:00:00', 10.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-01 00:00:00', 11.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-02 00:00:00', 9.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-03 00:00:00', 10.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-04 00:00:00', 12.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-05 00:00:00', 12.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-06 00:00:00', 8.26799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-07 00:00:00', 3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-08 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-09 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-10 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-11 00:00:00', 8.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-12 00:00:00', 9.06200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-13 00:00:00', 8.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-14 00:00:00', 8.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-15 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-16 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-17 00:00:00', 7.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-18 00:00:00', 7.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-19 00:00:00', 8.42099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-20 00:00:00', 7.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-21 00:00:00', 8.15699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-22 00:00:00', 8.37800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-23 00:00:00', 5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-24 00:00:00', 7.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-25 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-26 00:00:00', 7.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-27 00:00:00', 9.69699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-28 00:00:00', 10.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-29 00:00:00', 11.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-30 00:00:00', 13.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-01-31 00:00:00', 14.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-01 00:00:00', 14.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-02 00:00:00', 15.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-03 00:00:00', 15.6920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-04 00:00:00', 15.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-05 00:00:00', 14.814000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-06 00:00:00', 10.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-07 00:00:00', 9.50100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-08 00:00:00', 12.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-09 00:00:00', 9.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-10 00:00:00', 11.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-11 00:00:00', 8.59599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-12 00:00:00', 10.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-13 00:00:00', 11.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-14 00:00:00', 10.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-15 00:00:00', 10.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-16 00:00:00', 11.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-17 00:00:00', 7.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-18 00:00:00', 2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-19 00:00:00', 4.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-20 00:00:00', 7.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-21 00:00:00', 9.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-22 00:00:00', 9.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-23 00:00:00', 11.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-24 00:00:00', 14.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-25 00:00:00', 9.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-26 00:00:00', 4.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-27 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-02-28 00:00:00', 5.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-01 00:00:00', 7.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-02 00:00:00', 10.1579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-03 00:00:00', 8.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-04 00:00:00', 7.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-05 00:00:00', 7.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-06 00:00:00', 5.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-07 00:00:00', 8.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-08 00:00:00', 8.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-09 00:00:00', 9.55300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-10 00:00:00', 10.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-11 00:00:00', 14.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-12 00:00:00', 15.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-13 00:00:00', 15.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-14 00:00:00', 17.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-15 00:00:00', 16.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-16 00:00:00', 20.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-17 00:00:00', 22.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-18 00:00:00', 21.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-19 00:00:00', 15.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-20 00:00:00', 15.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-21 00:00:00', 12.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-22 00:00:00', 13.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-23 00:00:00', 14.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-24 00:00:00', 18.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-25 00:00:00', 19.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-26 00:00:00', 21.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-27 00:00:00', 14.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-28 00:00:00', 16.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-29 00:00:00', 15.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-30 00:00:00', 17.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-03-31 00:00:00', 20.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-01 00:00:00', 14.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-02 00:00:00', 16.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-03 00:00:00', 23.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-04 00:00:00', 23.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-05 00:00:00', 25.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-06 00:00:00', 26.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-07 00:00:00', 16.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-08 00:00:00', 18.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-09 00:00:00', 20.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-10 00:00:00', 22.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-11 00:00:00', 25.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-12 00:00:00', 25.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-13 00:00:00', 28.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-14 00:00:00', 26.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-15 00:00:00', 24.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-16 00:00:00', 27.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-17 00:00:00', 24.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-18 00:00:00', 25.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-19 00:00:00', 25.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-20 00:00:00', 24.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-21 00:00:00', 24.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-22 00:00:00', 27.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-23 00:00:00', 25.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-24 00:00:00', 27.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-25 00:00:00', 27.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-26 00:00:00', 28.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-27 00:00:00', 25.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-28 00:00:00', 27.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-29 00:00:00', 28.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-04-30 00:00:00', 29.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-01 00:00:00', 29.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-02 00:00:00', 31.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-03 00:00:00', 32.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-04 00:00:00', 36.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-05 00:00:00', 34.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-06 00:00:00', 36.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-07 00:00:00', 37.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-08 00:00:00', 39.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-09 00:00:00', 37.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-10 00:00:00', 33.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-11 00:00:00', 33.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-12 00:00:00', 36.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-13 00:00:00', 33.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-14 00:00:00', 34.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-15 00:00:00', 35.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-16 00:00:00', 32.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-17 00:00:00', 28.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-18 00:00:00', 30.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-19 00:00:00', 29.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-20 00:00:00', 29.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-21 00:00:00', 31.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-22 00:00:00', 32.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-23 00:00:00', 30.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-24 00:00:00', 29.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-25 00:00:00', 27.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-26 00:00:00', 24.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-27 00:00:00', 26.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-28 00:00:00', 28.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-29 00:00:00', 29.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-30 00:00:00', 30.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-05-31 00:00:00', 31.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-01 00:00:00', 32.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-02 00:00:00', 32.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-03 00:00:00', 33.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-04 00:00:00', 34.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-05 00:00:00', 37.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-06 00:00:00', 38.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-07 00:00:00', 39.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-08 00:00:00', 40.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-09 00:00:00', 36.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-10 00:00:00', 33.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-11 00:00:00', 36.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-12 00:00:00', 37.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-13 00:00:00', 38.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-14 00:00:00', 38.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-15 00:00:00', 42.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-16 00:00:00', 43.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-17 00:00:00', 40.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-18 00:00:00', 39.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-19 00:00:00', 38.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-20 00:00:00', 37.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-21 00:00:00', 36.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-22 00:00:00', 36.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-23 00:00:00', 38.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-24 00:00:00', 35.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-25 00:00:00', 33.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-26 00:00:00', 37.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-27 00:00:00', 36.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-28 00:00:00', 37.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-29 00:00:00', 40.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-06-30 00:00:00', 40.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-01 00:00:00', 41.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-02 00:00:00', 42.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-03 00:00:00', 41.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-04 00:00:00', 40.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-05 00:00:00', 39.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-06 00:00:00', 40.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-07 00:00:00', 42.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-08 00:00:00', 40.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-09 00:00:00', 40.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-10 00:00:00', 42.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-11 00:00:00', 42.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-12 00:00:00', 40.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-13 00:00:00', 42.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-14 00:00:00', 41.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-15 00:00:00', 45.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-16 00:00:00', 43.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-17 00:00:00', 44.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-18 00:00:00', 45.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-19 00:00:00', 42.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-20 00:00:00', 38.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-21 00:00:00', 39.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-22 00:00:00', 43.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-23 00:00:00', 42.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-24 00:00:00', 36.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-25 00:00:00', 34.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-26 00:00:00', 36.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-27 00:00:00', 38.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-28 00:00:00', 39.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-29 00:00:00', 39.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-30 00:00:00', 39.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-07-31 00:00:00', 40.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-01 00:00:00', 41.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-02 00:00:00', 41.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-03 00:00:00', 41.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-04 00:00:00', 42.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-05 00:00:00', 40.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-06 00:00:00', 36.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-07 00:00:00', 35.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-08 00:00:00', 37.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-09 00:00:00', 38.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-10 00:00:00', 40.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-11 00:00:00', 41.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-12 00:00:00', 41.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-13 00:00:00', 40.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-14 00:00:00', 40.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-15 00:00:00', 39.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-16 00:00:00', 38.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-17 00:00:00', 37.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-18 00:00:00', 37.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-19 00:00:00', 39.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-20 00:00:00', 39.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-21 00:00:00', 37.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-22 00:00:00', 36.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-23 00:00:00', 39.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-24 00:00:00', 41.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-25 00:00:00', 36.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-26 00:00:00', 36.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-27 00:00:00', 36.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-28 00:00:00', 36.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-29 00:00:00', 36.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-30 00:00:00', 33.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-08-31 00:00:00', 33.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-01 00:00:00', 33.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-02 00:00:00', 30.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-03 00:00:00', 29.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-04 00:00:00', 29.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-05 00:00:00', 29.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-06 00:00:00', 32.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-07 00:00:00', 32.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-08 00:00:00', 32.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-09 00:00:00', 34.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-10 00:00:00', 34.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-11 00:00:00', 33.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-12 00:00:00', 34.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-13 00:00:00', 31.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-14 00:00:00', 33.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-15 00:00:00', 32.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-16 00:00:00', 33.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-17 00:00:00', 33.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-18 00:00:00', 35.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-19 00:00:00', 35.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-20 00:00:00', 36.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-21 00:00:00', 37.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-22 00:00:00', 25.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-23 00:00:00', 24.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-24 00:00:00', 30.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-25 00:00:00', 33.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-26 00:00:00', 33.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-27 00:00:00', 33.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-28 00:00:00', 24.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-29 00:00:00', 27.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-09-30 00:00:00', 29.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-01 00:00:00', 31.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-02 00:00:00', 28.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-03 00:00:00', 27.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-04 00:00:00', 27.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-05 00:00:00', 30.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-06 00:00:00', 31.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-07 00:00:00', 30.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-08 00:00:00', 31.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-09 00:00:00', 28.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-10 00:00:00', 28.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-11 00:00:00', 25.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-12 00:00:00', 27.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-13 00:00:00', 19.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-14 00:00:00', 16.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-15 00:00:00', 22.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-16 00:00:00', 23.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-17 00:00:00', 21.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-18 00:00:00', 8.14500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-19 00:00:00', 11.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-20 00:00:00', 7.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-21 00:00:00', 17.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-22 00:00:00', 20.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-23 00:00:00', 19.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-24 00:00:00', 21.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-25 00:00:00', 19.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-26 00:00:00', 17.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-27 00:00:00', 15.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-28 00:00:00', 11.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-29 00:00:00', 16.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-30 00:00:00', 18.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-10-31 00:00:00', 19.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-01 00:00:00', 22.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-02 00:00:00', 19.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-03 00:00:00', 22.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-04 00:00:00', 23.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-05 00:00:00', 23.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-06 00:00:00', 23.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-07 00:00:00', 22.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-08 00:00:00', 24.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-09 00:00:00', 23.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-10 00:00:00', 24.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-11 00:00:00', 23.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-12 00:00:00', 23.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-13 00:00:00', 17.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-14 00:00:00', 19.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-15 00:00:00', 17.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-16 00:00:00', 11.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-17 00:00:00', 12.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-18 00:00:00', 13.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-19 00:00:00', 14.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-20 00:00:00', 17.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-21 00:00:00', 17.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-22 00:00:00', 15.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-23 00:00:00', 15.6129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-24 00:00:00', 16.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-25 00:00:00', 18.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-26 00:00:00', 17.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-27 00:00:00', 9.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-28 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-29 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-11-30 00:00:00', 7.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-01 00:00:00', 9.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-02 00:00:00', 9.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-03 00:00:00', 9.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-04 00:00:00', 10.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-05 00:00:00', 8.47500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-06 00:00:00', 10.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-07 00:00:00', 6.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-08 00:00:00', 9.44499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-09 00:00:00', 7.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-10 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-11 00:00:00', 3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-12 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-13 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-14 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-15 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-16 00:00:00', 6.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-17 00:00:00', 9.38599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-18 00:00:00', 5.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-19 00:00:00', 6.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-20 00:00:00', 1.69200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-21 00:00:00', 1.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-22 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-23 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-24 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-25 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-26 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-27 00:00:00', 1.92599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-28 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-29 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-30 00:00:00', 9.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1995-12-31 00:00:00', 6.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-01 00:00:00', 10.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-02 00:00:00', 8.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-03 00:00:00', 4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-04 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-05 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-06 00:00:00', 8.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-07 00:00:00', 10.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-08 00:00:00', 7.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-09 00:00:00', 6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-10 00:00:00', -2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-11 00:00:00', -3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-12 00:00:00', -0.624000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-13 00:00:00', -3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-14 00:00:00', -4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-15 00:00:00', -5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-16 00:00:00', -4.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-17 00:00:00', -0.0570000000298023224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-18 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-19 00:00:00', 0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-20 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-21 00:00:00', -0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-22 00:00:00', 0.207000002264976501, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-23 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-24 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-25 00:00:00', 0.173999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-26 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-27 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-28 00:00:00', 0.592000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-29 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-30 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-01-31 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-01 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-02 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-03 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-04 00:00:00', 0.312999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-05 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-06 00:00:00', 5.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-07 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-08 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-09 00:00:00', 8.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-10 00:00:00', 10.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-11 00:00:00', 13.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-12 00:00:00', 9.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-13 00:00:00', 2.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-14 00:00:00', 0.391999989748001099, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-15 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-16 00:00:00', 2.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-17 00:00:00', 8.21300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-18 00:00:00', 11.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-19 00:00:00', 14.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-20 00:00:00', 15.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-21 00:00:00', 10.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-22 00:00:00', 10.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-23 00:00:00', 7.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-24 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-25 00:00:00', 5.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-26 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-27 00:00:00', 2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-28 00:00:00', 3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-02-29 00:00:00', 6.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-01 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-02 00:00:00', 9.28699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-03 00:00:00', 12.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-04 00:00:00', 14.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-05 00:00:00', 14.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-06 00:00:00', 12.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-07 00:00:00', 13.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-08 00:00:00', 14.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-09 00:00:00', 12.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-10 00:00:00', 15.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-11 00:00:00', 14.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-12 00:00:00', 15.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-13 00:00:00', 17.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-14 00:00:00', 19.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-15 00:00:00', 10.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-16 00:00:00', 11.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-17 00:00:00', 11.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-18 00:00:00', 9.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-19 00:00:00', 9.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-20 00:00:00', 7.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-21 00:00:00', 10.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-22 00:00:00', 14.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-23 00:00:00', 17.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-24 00:00:00', 12.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-25 00:00:00', 18.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-26 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-27 00:00:00', 12.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-28 00:00:00', 13.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-29 00:00:00', 12.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-30 00:00:00', 13.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-03-31 00:00:00', 14.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-01 00:00:00', 19.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-02 00:00:00', 16.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-03 00:00:00', 12.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-04 00:00:00', 9.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-05 00:00:00', 11.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-06 00:00:00', 14.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-07 00:00:00', 15.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-08 00:00:00', 19.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-09 00:00:00', 20.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-10 00:00:00', 19.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-11 00:00:00', 23.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-12 00:00:00', 21.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-13 00:00:00', 23.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-14 00:00:00', 28.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-15 00:00:00', 29.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-16 00:00:00', 20.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-17 00:00:00', 17.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-18 00:00:00', 21.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-19 00:00:00', 28.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-20 00:00:00', 27.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-21 00:00:00', 28.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-22 00:00:00', 26.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-23 00:00:00', 28.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-24 00:00:00', 28.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-25 00:00:00', 28.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-26 00:00:00', 26.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-27 00:00:00', 24.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-28 00:00:00', 28.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-29 00:00:00', 19.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-04-30 00:00:00', 24.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-01 00:00:00', 26.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-02 00:00:00', 22.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-03 00:00:00', 23.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-04 00:00:00', 23.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-05 00:00:00', 23.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-06 00:00:00', 25.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-07 00:00:00', 27.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-08 00:00:00', 27.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-09 00:00:00', 27.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-10 00:00:00', 27.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-11 00:00:00', 29.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-12 00:00:00', 26.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-13 00:00:00', 29.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-14 00:00:00', 30.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-15 00:00:00', 30.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-16 00:00:00', 31.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-17 00:00:00', 32.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-18 00:00:00', 33.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-19 00:00:00', 30.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-20 00:00:00', 28.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-21 00:00:00', 30.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-22 00:00:00', 31.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-23 00:00:00', 23.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-24 00:00:00', 32.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-25 00:00:00', 35.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-26 00:00:00', 35.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-27 00:00:00', 31.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-28 00:00:00', 29.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-29 00:00:00', 30.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-30 00:00:00', 33.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-05-31 00:00:00', 35.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-01 00:00:00', 35.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-02 00:00:00', 36.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-03 00:00:00', 37.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-04 00:00:00', 38.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-05 00:00:00', 37.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-06 00:00:00', 38.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-07 00:00:00', 41.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-08 00:00:00', 38.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-09 00:00:00', 39.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-10 00:00:00', 41.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-11 00:00:00', 39.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-12 00:00:00', 34.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-13 00:00:00', 35.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-14 00:00:00', 35.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-15 00:00:00', 32.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-16 00:00:00', 29.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-17 00:00:00', 29.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-18 00:00:00', 31.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-19 00:00:00', 34.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-20 00:00:00', 36.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-21 00:00:00', 36.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-22 00:00:00', 38.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-23 00:00:00', 39.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-24 00:00:00', 38.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-25 00:00:00', 39.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-26 00:00:00', 38.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-27 00:00:00', 37.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-28 00:00:00', 35.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-29 00:00:00', 33.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-06-30 00:00:00', 35.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-01 00:00:00', 39.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-02 00:00:00', 40.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-03 00:00:00', 37.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-04 00:00:00', 35.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-05 00:00:00', 36.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-06 00:00:00', 37.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-07 00:00:00', 39.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-08 00:00:00', 41.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-09 00:00:00', 41.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-10 00:00:00', 38.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-11 00:00:00', 36.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-12 00:00:00', 37.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-13 00:00:00', 35.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-14 00:00:00', 31.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-15 00:00:00', 32.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-16 00:00:00', 33.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-17 00:00:00', 35.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-18 00:00:00', 38.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-19 00:00:00', 37.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-20 00:00:00', 36.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-21 00:00:00', 36.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-22 00:00:00', 39.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-23 00:00:00', 37.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-24 00:00:00', 39.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-25 00:00:00', 40.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-26 00:00:00', 40.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-27 00:00:00', 41.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-28 00:00:00', 41.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-29 00:00:00', 41.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-30 00:00:00', 40.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-07-31 00:00:00', 41.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-01 00:00:00', 41.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-02 00:00:00', 36.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-03 00:00:00', 38.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-04 00:00:00', 39.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-05 00:00:00', 40.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-06 00:00:00', 39.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-07 00:00:00', 39.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-08 00:00:00', 38.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-09 00:00:00', 40.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-10 00:00:00', 40.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-11 00:00:00', 41.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-12 00:00:00', 41.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-13 00:00:00', 40.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-14 00:00:00', 40.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-15 00:00:00', 35.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-16 00:00:00', 32.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-17 00:00:00', 31.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-18 00:00:00', 32.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-19 00:00:00', 32.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-20 00:00:00', 33.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-21 00:00:00', 34.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-22 00:00:00', 34.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-23 00:00:00', 33.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-24 00:00:00', 34.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-25 00:00:00', 35.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-26 00:00:00', 36.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-27 00:00:00', 37.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-28 00:00:00', 37.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-29 00:00:00', 34.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-30 00:00:00', 26.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-08-31 00:00:00', 30.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-01 00:00:00', 31.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-02 00:00:00', 31.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-03 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-04 00:00:00', 31.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-05 00:00:00', 33.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-06 00:00:00', 34.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-07 00:00:00', 35.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-08 00:00:00', 35.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-09 00:00:00', 37.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-10 00:00:00', 38.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-11 00:00:00', 39.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-12 00:00:00', 40.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-13 00:00:00', 38.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-14 00:00:00', 37.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-15 00:00:00', 34.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-16 00:00:00', 32.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-17 00:00:00', 31.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-18 00:00:00', 33.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-19 00:00:00', 33.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-20 00:00:00', 35.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-21 00:00:00', 33.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-22 00:00:00', 36.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-23 00:00:00', 34.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-24 00:00:00', 31.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-25 00:00:00', 27.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-26 00:00:00', 28.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-27 00:00:00', 29.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-28 00:00:00', 30.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-29 00:00:00', 32.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-09-30 00:00:00', 33.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-01 00:00:00', 28.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-02 00:00:00', 19.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-03 00:00:00', 18.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-04 00:00:00', 22.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-05 00:00:00', 23.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-06 00:00:00', 24.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-07 00:00:00', 25.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-08 00:00:00', 23.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-09 00:00:00', 23.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-10 00:00:00', 25.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-11 00:00:00', 25.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-12 00:00:00', 24.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-13 00:00:00', 27.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-14 00:00:00', 28.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-15 00:00:00', 25.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-16 00:00:00', 18.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-17 00:00:00', 20.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-18 00:00:00', 20.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-19 00:00:00', 17.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-20 00:00:00', 18.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-21 00:00:00', 19.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-22 00:00:00', 21.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-23 00:00:00', 22.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-24 00:00:00', 25.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-25 00:00:00', 25.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-26 00:00:00', 25.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-27 00:00:00', 24.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-28 00:00:00', 25.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-29 00:00:00', 22.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-30 00:00:00', 22.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-10-31 00:00:00', 24.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-01 00:00:00', 16.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-02 00:00:00', 20.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-03 00:00:00', 19.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-04 00:00:00', 18.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-05 00:00:00', 19.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-06 00:00:00', 17.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-07 00:00:00', 20.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-08 00:00:00', 22.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-09 00:00:00', 22.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-10 00:00:00', 20.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-11 00:00:00', 14.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-12 00:00:00', 13.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-13 00:00:00', 6.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-14 00:00:00', 6.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-15 00:00:00', 9.56200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-16 00:00:00', 11.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-17 00:00:00', 10.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-18 00:00:00', 8.50599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-19 00:00:00', 6.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-20 00:00:00', 7.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-21 00:00:00', 8.77200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-22 00:00:00', 10.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-23 00:00:00', 11.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-24 00:00:00', 11.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-25 00:00:00', 10.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-26 00:00:00', 11.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-27 00:00:00', 11.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-28 00:00:00', 12.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-29 00:00:00', 13.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-11-30 00:00:00', 11.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-01 00:00:00', 10.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-02 00:00:00', 8.34099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-03 00:00:00', 7.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-04 00:00:00', 7.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-05 00:00:00', 7.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-06 00:00:00', 6.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-07 00:00:00', 7.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-08 00:00:00', 8.19200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-09 00:00:00', 8.25300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-10 00:00:00', 11.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-11 00:00:00', 13.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-12 00:00:00', 11.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-13 00:00:00', 13.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-14 00:00:00', 14.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-15 00:00:00', 15.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-16 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-17 00:00:00', 13.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-18 00:00:00', 13.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-19 00:00:00', 14.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-20 00:00:00', 14.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-21 00:00:00', 14.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-22 00:00:00', 15.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-23 00:00:00', 15.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-24 00:00:00', 12.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-25 00:00:00', 14.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-26 00:00:00', 14.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-27 00:00:00', 15.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-28 00:00:00', 16.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-29 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-30 00:00:00', 19.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1996-12-31 00:00:00', 16.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-01 00:00:00', 16.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-02 00:00:00', 18.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-03 00:00:00', 14.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-04 00:00:00', 11.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-05 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-06 00:00:00', 12.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-07 00:00:00', 13.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-08 00:00:00', 12.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-09 00:00:00', 14.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-10 00:00:00', 15.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-11 00:00:00', 15.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-12 00:00:00', 10.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-13 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-14 00:00:00', 7.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-15 00:00:00', 9.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-16 00:00:00', 12.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-17 00:00:00', 12.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-18 00:00:00', 8.35000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-19 00:00:00', 2.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-20 00:00:00', 3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-21 00:00:00', 5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-22 00:00:00', 7.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-23 00:00:00', 6.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-24 00:00:00', 6.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-25 00:00:00', 7.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-26 00:00:00', 10.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-27 00:00:00', 9.71599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-28 00:00:00', 12.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-29 00:00:00', 6.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-30 00:00:00', 8.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-01-31 00:00:00', 9.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-01 00:00:00', 7.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-02 00:00:00', 2.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-03 00:00:00', 7.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-04 00:00:00', 8.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-05 00:00:00', 9.83100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-06 00:00:00', 11.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-07 00:00:00', 6.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-08 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-09 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-10 00:00:00', 6.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-11 00:00:00', 7.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-12 00:00:00', 9.83800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-13 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-14 00:00:00', 11.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-15 00:00:00', 12.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-16 00:00:00', 13.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-17 00:00:00', 14.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-18 00:00:00', 13.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-19 00:00:00', 14.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-20 00:00:00', 13.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-21 00:00:00', 12.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-22 00:00:00', 11.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-23 00:00:00', 12.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-24 00:00:00', 9.51099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-25 00:00:00', 11.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-26 00:00:00', 13.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-27 00:00:00', 17.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-02-28 00:00:00', 13.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-01 00:00:00', 8.99699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-02 00:00:00', 9.33800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-03 00:00:00', 12.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-04 00:00:00', 16.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-05 00:00:00', 13.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-06 00:00:00', 15.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-07 00:00:00', 14.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-08 00:00:00', 19.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-09 00:00:00', 12.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-10 00:00:00', 9.18999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-11 00:00:00', 10.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-12 00:00:00', 12.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-13 00:00:00', 15.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-14 00:00:00', 11.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-15 00:00:00', 12.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-16 00:00:00', 14.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-17 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-18 00:00:00', 18.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-19 00:00:00', 18.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-20 00:00:00', 18.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-21 00:00:00', 13.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-22 00:00:00', 15.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-23 00:00:00', 17.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-24 00:00:00', 21.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-25 00:00:00', 25.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-26 00:00:00', 22.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-27 00:00:00', 16.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-28 00:00:00', 18.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-29 00:00:00', 20.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-30 00:00:00', 21.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-03-31 00:00:00', 19.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-01 00:00:00', 14.175999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-02 00:00:00', 15.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-03 00:00:00', 17.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-04 00:00:00', 20.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-05 00:00:00', 22.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-06 00:00:00', 19.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-07 00:00:00', 22.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-08 00:00:00', 24.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-09 00:00:00', 25.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-10 00:00:00', 27.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-11 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-12 00:00:00', 18.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-13 00:00:00', 18.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-14 00:00:00', 18.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-15 00:00:00', 18.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-16 00:00:00', 22.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-17 00:00:00', 25.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-18 00:00:00', 26.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-19 00:00:00', 28.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-20 00:00:00', 27.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-21 00:00:00', 25.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-22 00:00:00', 28.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-23 00:00:00', 30.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-24 00:00:00', 30.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-25 00:00:00', 31.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-26 00:00:00', 32.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-27 00:00:00', 32.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-28 00:00:00', 30.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-29 00:00:00', 31.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-04-30 00:00:00', 26.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-01 00:00:00', 29.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-02 00:00:00', 29.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-03 00:00:00', 30.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-04 00:00:00', 29.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-05 00:00:00', 33.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-06 00:00:00', 23.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-07 00:00:00', 19.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-08 00:00:00', 21.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-09 00:00:00', 24.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-10 00:00:00', 26.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-11 00:00:00', 25.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-12 00:00:00', 22.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-13 00:00:00', 23.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-14 00:00:00', 27.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-15 00:00:00', 28.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-16 00:00:00', 22.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-17 00:00:00', 23.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-18 00:00:00', 26.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-19 00:00:00', 31.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-20 00:00:00', 31.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-21 00:00:00', 32.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-22 00:00:00', 32.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-23 00:00:00', 34.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-24 00:00:00', 35.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-25 00:00:00', 35.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-26 00:00:00', 34.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-27 00:00:00', 34.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-28 00:00:00', 36.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-29 00:00:00', 35.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-30 00:00:00', 37.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-05-31 00:00:00', 34.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-01 00:00:00', 36.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-02 00:00:00', 36.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-03 00:00:00', 37.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-04 00:00:00', 32.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-05 00:00:00', 35.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-06 00:00:00', 37.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-07 00:00:00', 36.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-08 00:00:00', 37.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-09 00:00:00', 37.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-10 00:00:00', 37.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-11 00:00:00', 34.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-12 00:00:00', 33.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-13 00:00:00', 36.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-14 00:00:00', 37.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-15 00:00:00', 38.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-16 00:00:00', 41.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-17 00:00:00', 39.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-18 00:00:00', 39.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-19 00:00:00', 32.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-20 00:00:00', 39.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-21 00:00:00', 36.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-22 00:00:00', 37.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-23 00:00:00', 38.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-24 00:00:00', 40.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-25 00:00:00', 41.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-26 00:00:00', 42.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-27 00:00:00', 40.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-28 00:00:00', 38.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-29 00:00:00', 36.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-06-30 00:00:00', 34.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-01 00:00:00', 37.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-02 00:00:00', 38.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-03 00:00:00', 40.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-04 00:00:00', 41.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-05 00:00:00', 40.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-06 00:00:00', 39.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-07 00:00:00', 41.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-08 00:00:00', 41.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-09 00:00:00', 38.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-10 00:00:00', 36.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-11 00:00:00', 38.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-12 00:00:00', 39.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-13 00:00:00', 41.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-14 00:00:00', 42.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-15 00:00:00', 42.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-16 00:00:00', 44.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-17 00:00:00', 43.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-18 00:00:00', 45.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-19 00:00:00', 46.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-20 00:00:00', 46.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-21 00:00:00', 40.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-22 00:00:00', 37.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-23 00:00:00', 38.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-24 00:00:00', 39.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-25 00:00:00', 40.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-26 00:00:00', 42.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-27 00:00:00', 42.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-28 00:00:00', 43.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-29 00:00:00', 40.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-30 00:00:00', 39.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-07-31 00:00:00', 39.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-01 00:00:00', 36.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-02 00:00:00', 34.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-03 00:00:00', 33.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-04 00:00:00', 34.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-05 00:00:00', 36.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-06 00:00:00', 39.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-07 00:00:00', 40.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-08 00:00:00', 42.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-09 00:00:00', 41.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-10 00:00:00', 40.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-11 00:00:00', 38.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-12 00:00:00', 35.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-13 00:00:00', 36.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-14 00:00:00', 39.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-15 00:00:00', 41.1500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-16 00:00:00', 41.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-17 00:00:00', 41.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-18 00:00:00', 40.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-19 00:00:00', 41.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-20 00:00:00', 41.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-21 00:00:00', 40.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-22 00:00:00', 41.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-23 00:00:00', 40.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-24 00:00:00', 37.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-25 00:00:00', 31.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-26 00:00:00', 31.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-27 00:00:00', 33.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-28 00:00:00', 33.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-29 00:00:00', 33.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-30 00:00:00', 34.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-08-31 00:00:00', 37.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-01 00:00:00', 38.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-02 00:00:00', 39.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-03 00:00:00', 40.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-04 00:00:00', 38.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-05 00:00:00', 37.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-06 00:00:00', 33.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-07 00:00:00', 30.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-08 00:00:00', 29.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-09 00:00:00', 28.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-10 00:00:00', 33.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-11 00:00:00', 33.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-12 00:00:00', 34.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-13 00:00:00', 34.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-14 00:00:00', 34.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-15 00:00:00', 31.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-16 00:00:00', 29.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-17 00:00:00', 31.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-18 00:00:00', 31.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-19 00:00:00', 29.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-20 00:00:00', 30.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-21 00:00:00', 29.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-22 00:00:00', 30.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-23 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-24 00:00:00', 31.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-25 00:00:00', 32.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-26 00:00:00', 32.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-27 00:00:00', 32.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-28 00:00:00', 30.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-29 00:00:00', 30.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-09-30 00:00:00', 31.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-01 00:00:00', 30.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-02 00:00:00', 31.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-03 00:00:00', 32.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-04 00:00:00', 32.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-05 00:00:00', 30.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-06 00:00:00', 29.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-07 00:00:00', 29.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-08 00:00:00', 25.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-09 00:00:00', 26.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-10 00:00:00', 24.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-11 00:00:00', 25.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-12 00:00:00', 26.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-13 00:00:00', 27.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-14 00:00:00', 23.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-15 00:00:00', 26.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-16 00:00:00', 26.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-17 00:00:00', 25.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-18 00:00:00', 23.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-19 00:00:00', 25.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-20 00:00:00', 26.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-21 00:00:00', 24.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-22 00:00:00', 22.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-23 00:00:00', 25.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-24 00:00:00', 26.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-25 00:00:00', 19.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-26 00:00:00', 20.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-27 00:00:00', 22.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-28 00:00:00', 23.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-29 00:00:00', 22.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-30 00:00:00', 22.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-10-31 00:00:00', 23.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-01 00:00:00', 22.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-02 00:00:00', 14.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-03 00:00:00', 19.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-04 00:00:00', 22.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-05 00:00:00', 25.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-06 00:00:00', 17.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-07 00:00:00', 15.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-08 00:00:00', 11.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-09 00:00:00', 9.94699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-10 00:00:00', 13.4980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-11 00:00:00', 16.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-12 00:00:00', 18.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-13 00:00:00', 19.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-14 00:00:00', 14.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-15 00:00:00', 13.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-16 00:00:00', 14.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-17 00:00:00', 16.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-18 00:00:00', 16.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-19 00:00:00', 16.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-20 00:00:00', 18.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-21 00:00:00', 18.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-22 00:00:00', 16.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-23 00:00:00', 16.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-24 00:00:00', 10.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-25 00:00:00', 7.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-26 00:00:00', 8.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-27 00:00:00', 10.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-28 00:00:00', 11.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-29 00:00:00', 11.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-11-30 00:00:00', 12.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-01 00:00:00', 14.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-02 00:00:00', 9.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-03 00:00:00', 10.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-04 00:00:00', 11.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-05 00:00:00', 13.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-06 00:00:00', 13.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-07 00:00:00', 15.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-08 00:00:00', 14.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-09 00:00:00', 14.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-10 00:00:00', 12.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-11 00:00:00', 17.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-12 00:00:00', 9.56700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-13 00:00:00', 10.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-14 00:00:00', 12.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-15 00:00:00', 13.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-16 00:00:00', 12.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-17 00:00:00', 12.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-18 00:00:00', 8.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-19 00:00:00', 7.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-20 00:00:00', 7.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-21 00:00:00', 10.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-22 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-23 00:00:00', 8.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-24 00:00:00', 9.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-25 00:00:00', 7.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-26 00:00:00', 10.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-27 00:00:00', 7.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-28 00:00:00', 5.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-29 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-30 00:00:00', 8.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1997-12-31 00:00:00', 8.78400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-01 00:00:00', 10.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-02 00:00:00', 11.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-03 00:00:00', 10.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-04 00:00:00', 7.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-05 00:00:00', 8.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-06 00:00:00', 7.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-07 00:00:00', 7.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-08 00:00:00', 5.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-09 00:00:00', 7.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-10 00:00:00', 9.27000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-11 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-12 00:00:00', 6.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-13 00:00:00', 8.72799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-14 00:00:00', 6.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-15 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-16 00:00:00', 4.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-17 00:00:00', 3.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-18 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-19 00:00:00', 6.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-20 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-21 00:00:00', 7.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-22 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-23 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-24 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-25 00:00:00', 8.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-26 00:00:00', 10.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-27 00:00:00', 10.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-28 00:00:00', 6.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-29 00:00:00', 9.83800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-30 00:00:00', 10.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-01-31 00:00:00', 12.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-01 00:00:00', 10.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-02 00:00:00', 9.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-03 00:00:00', 9.40699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-04 00:00:00', 10.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-05 00:00:00', 7.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-06 00:00:00', 11.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-07 00:00:00', 12.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-08 00:00:00', 9.01099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-09 00:00:00', 10.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-10 00:00:00', 10.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-11 00:00:00', 5.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-12 00:00:00', 11.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-13 00:00:00', 11.2899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-14 00:00:00', 9.68799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-15 00:00:00', 10.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-16 00:00:00', 5.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-17 00:00:00', 0.804000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-18 00:00:00', 2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-19 00:00:00', 8.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-20 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-21 00:00:00', 7.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-22 00:00:00', 7.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-23 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-24 00:00:00', 5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-25 00:00:00', 7.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-26 00:00:00', 12.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-27 00:00:00', 10.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-02-28 00:00:00', 12.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-01 00:00:00', 7.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-02 00:00:00', 9.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-03 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-04 00:00:00', 5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-05 00:00:00', 8.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-06 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-07 00:00:00', 6.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-08 00:00:00', 8.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-09 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-10 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-11 00:00:00', 14.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-12 00:00:00', 13.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-13 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-14 00:00:00', 15.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-15 00:00:00', 17.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-16 00:00:00', 18.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-17 00:00:00', 16.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-18 00:00:00', 18.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-19 00:00:00', 16.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-20 00:00:00', 17.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-21 00:00:00', 18.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-22 00:00:00', 13.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-23 00:00:00', 16.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-24 00:00:00', 17.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-25 00:00:00', 20.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-26 00:00:00', 16.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-27 00:00:00', 17.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-28 00:00:00', 20.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-29 00:00:00', 19.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-30 00:00:00', 23.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-03-31 00:00:00', 26.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-01 00:00:00', 23.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-02 00:00:00', 21.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-03 00:00:00', 21.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-04 00:00:00', 23.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-05 00:00:00', 26.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-06 00:00:00', 25.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-07 00:00:00', 20.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-08 00:00:00', 13.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-09 00:00:00', 19.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-10 00:00:00', 22.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-11 00:00:00', 23.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-12 00:00:00', 25.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-13 00:00:00', 24.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-14 00:00:00', 28.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-15 00:00:00', 29.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-16 00:00:00', 30.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-17 00:00:00', 31.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-18 00:00:00', 31.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-19 00:00:00', 32.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-20 00:00:00', 28.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-21 00:00:00', 29.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-22 00:00:00', 31.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-23 00:00:00', 33.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-24 00:00:00', 27.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-25 00:00:00', 18.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-26 00:00:00', 21.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-27 00:00:00', 23.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-28 00:00:00', 27.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-29 00:00:00', 27.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-04-30 00:00:00', 29.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-01 00:00:00', 29.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-02 00:00:00', 21.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-03 00:00:00', 20.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-04 00:00:00', 23.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-05 00:00:00', 22.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-06 00:00:00', 22.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-07 00:00:00', 25.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-08 00:00:00', 27.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-09 00:00:00', 27.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-10 00:00:00', 29.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-11 00:00:00', 29.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-12 00:00:00', 30.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-13 00:00:00', 28.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-14 00:00:00', 34.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-15 00:00:00', 36.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-16 00:00:00', 33.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-17 00:00:00', 34.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-18 00:00:00', 30.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-19 00:00:00', 31.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-20 00:00:00', 32.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-21 00:00:00', 34.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-22 00:00:00', 36.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-23 00:00:00', 36.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-24 00:00:00', 36.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-25 00:00:00', 37.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-26 00:00:00', 34.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-27 00:00:00', 31.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-28 00:00:00', 27.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-29 00:00:00', 29.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-30 00:00:00', 32.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-05-31 00:00:00', 32.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-01 00:00:00', 32.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-02 00:00:00', 35.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-03 00:00:00', 33.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-04 00:00:00', 34.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-05 00:00:00', 33.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-06 00:00:00', 33.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-07 00:00:00', 32.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-08 00:00:00', 34.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-09 00:00:00', 35.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-10 00:00:00', 32.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-11 00:00:00', 30.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-12 00:00:00', 28.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-13 00:00:00', 30.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-14 00:00:00', 29.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-15 00:00:00', 34.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-16 00:00:00', 36.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-17 00:00:00', 35.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-18 00:00:00', 34.9550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-19 00:00:00', 35.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-20 00:00:00', 39.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-21 00:00:00', 36.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-22 00:00:00', 34.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-23 00:00:00', 34.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-24 00:00:00', 37.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-25 00:00:00', 40.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-26 00:00:00', 39.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-27 00:00:00', 39.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-28 00:00:00', 39.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-29 00:00:00', 40.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-06-30 00:00:00', 38.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-01 00:00:00', 35.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-02 00:00:00', 35.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-03 00:00:00', 37.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-04 00:00:00', 39.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-05 00:00:00', 39.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-06 00:00:00', 41.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-07 00:00:00', 45.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-08 00:00:00', 44.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-09 00:00:00', 45.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-10 00:00:00', 45.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-11 00:00:00', 43.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-12 00:00:00', 39.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-13 00:00:00', 39.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-14 00:00:00', 40.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-15 00:00:00', 40.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-16 00:00:00', 38.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-17 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-18 00:00:00', 40.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-19 00:00:00', 38.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-20 00:00:00', 37.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-21 00:00:00', 38.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-22 00:00:00', 39.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-23 00:00:00', 37.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-24 00:00:00', 38.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-25 00:00:00', 36.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-26 00:00:00', 31.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-27 00:00:00', 37.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-28 00:00:00', 37.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-29 00:00:00', 38.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-30 00:00:00', 38.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-07-31 00:00:00', 39.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-01 00:00:00', 39.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-02 00:00:00', 39.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-03 00:00:00', 39.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-04 00:00:00', 38.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-05 00:00:00', 34.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-06 00:00:00', 35.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-07 00:00:00', 37.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-08 00:00:00', 36.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-09 00:00:00', 37.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-10 00:00:00', 38.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-11 00:00:00', 39.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-12 00:00:00', 40.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-13 00:00:00', 39.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-14 00:00:00', 41.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-15 00:00:00', 37.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-16 00:00:00', 36.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-17 00:00:00', 36.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-18 00:00:00', 37.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-19 00:00:00', 39.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-20 00:00:00', 37.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-21 00:00:00', 34.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-22 00:00:00', 35.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-23 00:00:00', 36.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-24 00:00:00', 37.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-25 00:00:00', 36.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-26 00:00:00', 36.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-27 00:00:00', 37.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-28 00:00:00', 37.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-29 00:00:00', 36.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-30 00:00:00', 36.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-08-31 00:00:00', 36.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-01 00:00:00', 37.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-02 00:00:00', 39.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-03 00:00:00', 39.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-04 00:00:00', 39.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-05 00:00:00', 39.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-06 00:00:00', 39.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-07 00:00:00', 39.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-08 00:00:00', 36.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-09 00:00:00', 33.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-10 00:00:00', 33.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-11 00:00:00', 32.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-12 00:00:00', 28.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-13 00:00:00', 26.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-14 00:00:00', 27.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-15 00:00:00', 30.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-16 00:00:00', 31.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-17 00:00:00', 33.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-18 00:00:00', 34.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-19 00:00:00', 32.1899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-20 00:00:00', 31.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-21 00:00:00', 32.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-22 00:00:00', 31.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-23 00:00:00', 31.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-24 00:00:00', 32.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-25 00:00:00', 34.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-26 00:00:00', 35.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-27 00:00:00', 34.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-28 00:00:00', 30.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-29 00:00:00', 29.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-09-30 00:00:00', 29.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-01 00:00:00', 31.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-02 00:00:00', 32.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-03 00:00:00', 29.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-04 00:00:00', 29.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-05 00:00:00', 30.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-06 00:00:00', 29.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-07 00:00:00', 29.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-08 00:00:00', 30.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-09 00:00:00', 21.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-10 00:00:00', 15.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-11 00:00:00', 20.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-12 00:00:00', 24.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-13 00:00:00', 24.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-14 00:00:00', 21.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-15 00:00:00', 23.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-16 00:00:00', 25.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-17 00:00:00', 26.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-18 00:00:00', 27.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-19 00:00:00', 24.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-20 00:00:00', 26.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-21 00:00:00', 23.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-22 00:00:00', 23.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-23 00:00:00', 22.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-24 00:00:00', 21.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-25 00:00:00', 13.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-26 00:00:00', 16.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-27 00:00:00', 19.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-28 00:00:00', 20.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-29 00:00:00', 18.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-30 00:00:00', 21.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-10-31 00:00:00', 24.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-01 00:00:00', 26.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-02 00:00:00', 25.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-03 00:00:00', 24.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-04 00:00:00', 25.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-05 00:00:00', 21.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-06 00:00:00', 22.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-07 00:00:00', 22.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-08 00:00:00', 21.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-09 00:00:00', 22.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-10 00:00:00', 22.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-11 00:00:00', 24.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-12 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-13 00:00:00', 15.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-14 00:00:00', 16.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-15 00:00:00', 20.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-16 00:00:00', 21.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-17 00:00:00', 20.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-18 00:00:00', 20.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-19 00:00:00', 20.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-20 00:00:00', 20.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-21 00:00:00', 16.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-22 00:00:00', 17.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-23 00:00:00', 15.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-24 00:00:00', 14.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-25 00:00:00', 15.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-26 00:00:00', 16.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-27 00:00:00', 15.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-28 00:00:00', 12.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-29 00:00:00', 9.70600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-11-30 00:00:00', 7.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-01 00:00:00', 13.4280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-02 00:00:00', 10.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-03 00:00:00', 10.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-04 00:00:00', 13.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-05 00:00:00', 15.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-06 00:00:00', 10.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-07 00:00:00', 12.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-08 00:00:00', 15.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-09 00:00:00', 17.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-10 00:00:00', 16.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-11 00:00:00', 18.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-12 00:00:00', 20.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-13 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-14 00:00:00', 18.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-15 00:00:00', 14.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-16 00:00:00', 16.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-17 00:00:00', 17.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-18 00:00:00', 18.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-19 00:00:00', 16.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-20 00:00:00', 11.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-21 00:00:00', 14.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-22 00:00:00', 12.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-23 00:00:00', 13.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-24 00:00:00', 14.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-25 00:00:00', 11.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-26 00:00:00', 13.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-27 00:00:00', 14.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-28 00:00:00', 14.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-29 00:00:00', 10.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-30 00:00:00', 9.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1998-12-31 00:00:00', 14.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-02 00:00:00', 8.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-04 00:00:00', 9.85700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-06 00:00:00', 11.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-08 00:00:00', 10.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-10 00:00:00', 11.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-12 00:00:00', 9.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-14 00:00:00', 10.2489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-16 00:00:00', 13.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-18 00:00:00', 9.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-20 00:00:00', 15.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-22 00:00:00', 16.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-24 00:00:00', 14.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-26 00:00:00', 15.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-28 00:00:00', 16.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-30 00:00:00', 14.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-01 00:00:00', 16.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-03 00:00:00', 16.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-05 00:00:00', 17.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-07 00:00:00', 17.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-09 00:00:00', 16.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-11 00:00:00', 13.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-13 00:00:00', 13.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-15 00:00:00', 13.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-17 00:00:00', 14.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-19 00:00:00', 14.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-21 00:00:00', 17.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-23 00:00:00', 16.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-25 00:00:00', 18.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-27 00:00:00', 14.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-01 00:00:00', 12.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-03 00:00:00', 14.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-04 00:00:00', 10.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-05 00:00:00', 9.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-06 00:00:00', 12.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-07 00:00:00', 6.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-08 00:00:00', 12.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-09 00:00:00', 14.3900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-10 00:00:00', 17.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-11 00:00:00', 18.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-12 00:00:00', 18.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-13 00:00:00', 17.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-14 00:00:00', 13.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-15 00:00:00', 14.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-16 00:00:00', 11.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-17 00:00:00', 14.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-18 00:00:00', 15.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-19 00:00:00', 7.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-20 00:00:00', 10.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-21 00:00:00', 15.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-22 00:00:00', 19.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-23 00:00:00', 20.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-24 00:00:00', 18.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-25 00:00:00', 19.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-26 00:00:00', 20.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-27 00:00:00', 20.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-28 00:00:00', 20.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-29 00:00:00', 17.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-30 00:00:00', 20.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-03-31 00:00:00', 18.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-01 00:00:00', 18.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-02 00:00:00', 20.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-03 00:00:00', 23.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-04 00:00:00', 24.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-05 00:00:00', 26.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-06 00:00:00', 24.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-07 00:00:00', 16.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-08 00:00:00', 21.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-09 00:00:00', 24.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-10 00:00:00', 15.9530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-11 00:00:00', 20.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-12 00:00:00', 20.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-13 00:00:00', 20.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-14 00:00:00', 22.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-15 00:00:00', 26.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-16 00:00:00', 30.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-17 00:00:00', 29.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-18 00:00:00', 28.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-19 00:00:00', 24.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-20 00:00:00', 26.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-21 00:00:00', 26.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-22 00:00:00', 22.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-23 00:00:00', 20.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-24 00:00:00', 23.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-25 00:00:00', 25.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-26 00:00:00', 28.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-27 00:00:00', 29.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-28 00:00:00', 30.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-29 00:00:00', 30.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-04-30 00:00:00', 30.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-01 00:00:00', 29.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-02 00:00:00', 31.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-03 00:00:00', 29.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-04 00:00:00', 31.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-05 00:00:00', 32.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-06 00:00:00', 31.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-07 00:00:00', 33.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-08 00:00:00', 33.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-09 00:00:00', 33.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-10 00:00:00', 32.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-11 00:00:00', 33.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-12 00:00:00', 26.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-13 00:00:00', 28.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-14 00:00:00', 32.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-15 00:00:00', 35.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-16 00:00:00', 33.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-17 00:00:00', 36.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-18 00:00:00', 36.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-19 00:00:00', 37.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-20 00:00:00', 37.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-21 00:00:00', 39.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-22 00:00:00', 27.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-23 00:00:00', 27.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-24 00:00:00', 28.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-25 00:00:00', 28.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-26 00:00:00', 28.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-27 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-28 00:00:00', 33.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-29 00:00:00', 32.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-30 00:00:00', 33.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-05-31 00:00:00', 34.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-01 00:00:00', 34.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-02 00:00:00', 33.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-03 00:00:00', 34.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-04 00:00:00', 35.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-05 00:00:00', 35.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-06 00:00:00', 37.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-07 00:00:00', 40.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-08 00:00:00', 37.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-09 00:00:00', 34.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-10 00:00:00', 33.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-11 00:00:00', 34.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-12 00:00:00', 34.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-13 00:00:00', 36.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-14 00:00:00', 37.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-15 00:00:00', 38.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-16 00:00:00', 37.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-17 00:00:00', 34.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-18 00:00:00', 34.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-19 00:00:00', 35.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-20 00:00:00', 36.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-21 00:00:00', 36.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-22 00:00:00', 37.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-23 00:00:00', 35.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-24 00:00:00', 34.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-25 00:00:00', 38.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-26 00:00:00', 42.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-27 00:00:00', 44.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-28 00:00:00', 42.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-29 00:00:00', 41.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-06-30 00:00:00', 41.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-01 00:00:00', 40.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-02 00:00:00', 38.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-03 00:00:00', 39.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-04 00:00:00', 40.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-05 00:00:00', 41.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-06 00:00:00', 39.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-07 00:00:00', 39.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-08 00:00:00', 39.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-09 00:00:00', 42.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-10 00:00:00', 39.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-11 00:00:00', 35.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-12 00:00:00', 33.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-13 00:00:00', 29.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-14 00:00:00', 33.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-15 00:00:00', 37.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-16 00:00:00', 41.8170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-17 00:00:00', 41.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-18 00:00:00', 40.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-19 00:00:00', 37.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-20 00:00:00', 37.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-21 00:00:00', 36.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-22 00:00:00', 36.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-23 00:00:00', 36.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-24 00:00:00', 37.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-25 00:00:00', 36.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-26 00:00:00', 36.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-27 00:00:00', 36.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-28 00:00:00', 36.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-29 00:00:00', 38.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-30 00:00:00', 39.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-07-31 00:00:00', 38.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-01 00:00:00', 40.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-02 00:00:00', 39.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-03 00:00:00', 39.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-04 00:00:00', 40.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-05 00:00:00', 42.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-06 00:00:00', 41.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-07 00:00:00', 40.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-08 00:00:00', 40.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-09 00:00:00', 42.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-10 00:00:00', 39.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-11 00:00:00', 37.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-12 00:00:00', 35.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-13 00:00:00', 35.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-14 00:00:00', 33.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-15 00:00:00', 36.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-16 00:00:00', 35.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-17 00:00:00', 37.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-18 00:00:00', 39.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-19 00:00:00', 40.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-20 00:00:00', 40.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-21 00:00:00', 39.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-22 00:00:00', 38.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-23 00:00:00', 39.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-24 00:00:00', 40.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-25 00:00:00', 39.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-26 00:00:00', 38.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-27 00:00:00', 39.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-28 00:00:00', 40.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-29 00:00:00', 40.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-30 00:00:00', 40.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-08-31 00:00:00', 38.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-01 00:00:00', 35.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-02 00:00:00', 34.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-03 00:00:00', 34.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-04 00:00:00', 35.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-05 00:00:00', 33.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-06 00:00:00', 30.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-07 00:00:00', 32.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-08 00:00:00', 32.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-09 00:00:00', 32.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-10 00:00:00', 34.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-11 00:00:00', 35.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-12 00:00:00', 35.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-13 00:00:00', 36.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-14 00:00:00', 38.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-15 00:00:00', 37.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-16 00:00:00', 37.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-17 00:00:00', 37.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-18 00:00:00', 34.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-19 00:00:00', 33.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-20 00:00:00', 33.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-21 00:00:00', 34.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-22 00:00:00', 35.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-23 00:00:00', 35.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-24 00:00:00', 27.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-25 00:00:00', 28.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-26 00:00:00', 27.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-27 00:00:00', 31.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-28 00:00:00', 32.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-29 00:00:00', 24.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-09-30 00:00:00', 26.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-01 00:00:00', 26.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-02 00:00:00', 28.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-03 00:00:00', 27.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-04 00:00:00', 28.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-05 00:00:00', 28.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-06 00:00:00', 27.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-07 00:00:00', 26.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-08 00:00:00', 24.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-09 00:00:00', 25.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-10 00:00:00', 26.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-11 00:00:00', 27.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-12 00:00:00', 27.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-13 00:00:00', 27.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-14 00:00:00', 20.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-15 00:00:00', 25.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-16 00:00:00', 29.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-17 00:00:00', 29.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-18 00:00:00', 27.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-19 00:00:00', 28.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-20 00:00:00', 27.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-21 00:00:00', 26.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-22 00:00:00', 25.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-23 00:00:00', 26.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-24 00:00:00', 28.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-25 00:00:00', 28.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-26 00:00:00', 19.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-27 00:00:00', 19.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-28 00:00:00', 19.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-29 00:00:00', 22.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-30 00:00:00', 24.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-10-31 00:00:00', 22.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-01 00:00:00', 23.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-02 00:00:00', 19.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-03 00:00:00', 15.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-04 00:00:00', 15.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-05 00:00:00', 13.4280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-06 00:00:00', 15.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-07 00:00:00', 16.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-08 00:00:00', 17.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-09 00:00:00', 12.5780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-10 00:00:00', 14.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-11 00:00:00', 10.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-12 00:00:00', 10.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-13 00:00:00', 11.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-14 00:00:00', 14.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-15 00:00:00', 15.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-16 00:00:00', 15.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-17 00:00:00', 15.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-18 00:00:00', 15.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-19 00:00:00', 14.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-20 00:00:00', 14.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-21 00:00:00', 9.92800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-22 00:00:00', 9.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-23 00:00:00', 11.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-24 00:00:00', 9.16199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-25 00:00:00', 13.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-26 00:00:00', 14.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-27 00:00:00', 14.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-28 00:00:00', 17.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-29 00:00:00', 11.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-11-30 00:00:00', 7.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-01 00:00:00', 6.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-02 00:00:00', 10.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-03 00:00:00', 14.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-04 00:00:00', 12.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-05 00:00:00', 13.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-06 00:00:00', 8.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-07 00:00:00', 10.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-08 00:00:00', 11.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-09 00:00:00', 11.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-10 00:00:00', 13.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-11 00:00:00', 8.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-12 00:00:00', 11.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-13 00:00:00', 12.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-14 00:00:00', 13.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-15 00:00:00', 15.2309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-16 00:00:00', 17.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-17 00:00:00', 12.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-18 00:00:00', 7.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-19 00:00:00', 8.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-20 00:00:00', 12.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-21 00:00:00', 13.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-22 00:00:00', 14.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-23 00:00:00', 13.7860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-24 00:00:00', 14.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-25 00:00:00', 6.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-26 00:00:00', 9.52900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-27 00:00:00', 12.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-28 00:00:00', 14.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-29 00:00:00', 15.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-30 00:00:00', 16.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '1999-12-31 00:00:00', 16.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-01 00:00:00', 16.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-02 00:00:00', 16.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-03 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-04 00:00:00', 16.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-05 00:00:00', 15.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-06 00:00:00', 16.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-07 00:00:00', 15.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-08 00:00:00', 10.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-09 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-10 00:00:00', 7.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-11 00:00:00', 5.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-12 00:00:00', 0.483000010251998901, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-13 00:00:00', 0.0280000008642673492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-14 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-15 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-16 00:00:00', 5.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-17 00:00:00', 11.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-18 00:00:00', 7.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-19 00:00:00', 9.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-20 00:00:00', 7.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-21 00:00:00', 13.3900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-22 00:00:00', 11.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-23 00:00:00', 13.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-24 00:00:00', 11.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-25 00:00:00', 8.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-26 00:00:00', 9.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-27 00:00:00', 11.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-28 00:00:00', 14.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-29 00:00:00', 16.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-30 00:00:00', 13.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-01-31 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-01 00:00:00', 8.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-02 00:00:00', 9.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-03 00:00:00', 7.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-04 00:00:00', 9.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-05 00:00:00', 11.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-06 00:00:00', 12.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-07 00:00:00', 14.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-08 00:00:00', 14.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-09 00:00:00', 5.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-10 00:00:00', 5.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-11 00:00:00', 5.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-12 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-13 00:00:00', 10.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-14 00:00:00', 12.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-15 00:00:00', 8.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-16 00:00:00', 7.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-17 00:00:00', 9.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-18 00:00:00', 11.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-19 00:00:00', 11.6029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-20 00:00:00', 11.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-21 00:00:00', 12.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-22 00:00:00', 12.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-23 00:00:00', 13.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-24 00:00:00', 15.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-25 00:00:00', 15.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-26 00:00:00', 14.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-27 00:00:00', 10.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-28 00:00:00', 13.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-02-29 00:00:00', 14.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-01 00:00:00', 11.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-02 00:00:00', 12.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-03 00:00:00', 12.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-04 00:00:00', 9.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-05 00:00:00', 10.9429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-06 00:00:00', 13.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-07 00:00:00', 14.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-08 00:00:00', 17.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-09 00:00:00', 17.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-10 00:00:00', 13.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-11 00:00:00', 16.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-12 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-13 00:00:00', 18.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-14 00:00:00', 20.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-15 00:00:00', 21.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-16 00:00:00', 10.560999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-17 00:00:00', 13.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-18 00:00:00', 16.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-19 00:00:00', 19.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-20 00:00:00', 21.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-21 00:00:00', 20.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-22 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-23 00:00:00', 23.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-24 00:00:00', 25.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-25 00:00:00', 29.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-26 00:00:00', 26.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-27 00:00:00', 15.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-28 00:00:00', 12.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-29 00:00:00', 11.8970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-30 00:00:00', 19.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-03-31 00:00:00', 22.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-01 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-02 00:00:00', 21.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-03 00:00:00', 21.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-04 00:00:00', 20.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-05 00:00:00', 23.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-06 00:00:00', 25.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-07 00:00:00', 27.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-08 00:00:00', 29.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-09 00:00:00', 30.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-10 00:00:00', 31.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-11 00:00:00', 35.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-12 00:00:00', 32.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-13 00:00:00', 30.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-14 00:00:00', 27.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-15 00:00:00', 29.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-16 00:00:00', 28.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-17 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-18 00:00:00', 31.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-19 00:00:00', 31.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-20 00:00:00', 33.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-21 00:00:00', 32.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-22 00:00:00', 34.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-23 00:00:00', 34.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-24 00:00:00', 34.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-25 00:00:00', 32.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-26 00:00:00', 29.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-27 00:00:00', 30.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-28 00:00:00', 28.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-29 00:00:00', 28.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-04-30 00:00:00', 31.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-01 00:00:00', 36.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-02 00:00:00', 34.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-03 00:00:00', 34.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-04 00:00:00', 34.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-05 00:00:00', 36.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-06 00:00:00', 34.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-07 00:00:00', 37.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-08 00:00:00', 39.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-09 00:00:00', 41.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-10 00:00:00', 36.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-11 00:00:00', 33.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-12 00:00:00', 35.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-13 00:00:00', 34.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-14 00:00:00', 34.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-15 00:00:00', 34.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-16 00:00:00', 36.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-17 00:00:00', 37.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-18 00:00:00', 37.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-19 00:00:00', 37.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-20 00:00:00', 38.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-21 00:00:00', 36.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-22 00:00:00', 34.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-23 00:00:00', 33.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-24 00:00:00', 33.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-25 00:00:00', 34.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-26 00:00:00', 34.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-27 00:00:00', 36.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-28 00:00:00', 41.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-29 00:00:00', 37.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-30 00:00:00', 35.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-05-31 00:00:00', 37.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-01 00:00:00', 35.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-02 00:00:00', 32.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-03 00:00:00', 33.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-04 00:00:00', 32.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-05 00:00:00', 35.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-06 00:00:00', 36.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-07 00:00:00', 36.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-08 00:00:00', 37.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-09 00:00:00', 39.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-10 00:00:00', 36.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-11 00:00:00', 36.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-12 00:00:00', 36.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-13 00:00:00', 34.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-14 00:00:00', 29.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-15 00:00:00', 34.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-16 00:00:00', 33.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-17 00:00:00', 34.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-18 00:00:00', 36.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-19 00:00:00', 37.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-20 00:00:00', 38.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-21 00:00:00', 39.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-22 00:00:00', 39.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-23 00:00:00', 38.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-24 00:00:00', 40.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-25 00:00:00', 42.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-26 00:00:00', 40.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-27 00:00:00', 40.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-28 00:00:00', 40.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-29 00:00:00', 39.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-06-30 00:00:00', 39.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-01 00:00:00', 39.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-02 00:00:00', 40.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-03 00:00:00', 39.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-04 00:00:00', 37.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-05 00:00:00', 38.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-06 00:00:00', 39.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-07 00:00:00', 39.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-08 00:00:00', 40.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-09 00:00:00', 40.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-10 00:00:00', 41.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-11 00:00:00', 40.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-12 00:00:00', 40.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-13 00:00:00', 39.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-14 00:00:00', 39.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-15 00:00:00', 37.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-16 00:00:00', 35.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-17 00:00:00', 32.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-18 00:00:00', 35.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-19 00:00:00', 36.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-20 00:00:00', 36.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-21 00:00:00', 37.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-22 00:00:00', 38.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-23 00:00:00', 38.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-24 00:00:00', 38.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-25 00:00:00', 36.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-26 00:00:00', 36.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-27 00:00:00', 37.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-28 00:00:00', 39.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-29 00:00:00', 40.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-30 00:00:00', 41.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-07-31 00:00:00', 42.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-01 00:00:00', 41.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-02 00:00:00', 39.4760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-03 00:00:00', 39.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-04 00:00:00', 39.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-05 00:00:00', 39.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-06 00:00:00', 40.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-07 00:00:00', 41.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-08 00:00:00', 41.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-09 00:00:00', 39.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-10 00:00:00', 38.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-11 00:00:00', 38.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-12 00:00:00', 37.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-13 00:00:00', 37.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-14 00:00:00', 38.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-15 00:00:00', 38.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-16 00:00:00', 38.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-17 00:00:00', 35.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-18 00:00:00', 34.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-19 00:00:00', 35.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-20 00:00:00', 35.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-21 00:00:00', 35.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-22 00:00:00', 36.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-23 00:00:00', 36.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-24 00:00:00', 37.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-25 00:00:00', 37.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-26 00:00:00', 40.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-27 00:00:00', 39.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-28 00:00:00', 39.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-29 00:00:00', 40.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-30 00:00:00', 42.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-08-31 00:00:00', 39.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-01 00:00:00', 37.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-02 00:00:00', 36.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-03 00:00:00', 36.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-04 00:00:00', 37.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-05 00:00:00', 36.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-06 00:00:00', 35.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-07 00:00:00', 34.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-08 00:00:00', 35.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-09 00:00:00', 33.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-10 00:00:00', 32.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-11 00:00:00', 33.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-12 00:00:00', 33.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-13 00:00:00', 35.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-14 00:00:00', 35.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-15 00:00:00', 35.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-16 00:00:00', 37.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-17 00:00:00', 37.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-18 00:00:00', 36.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-19 00:00:00', 35.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-20 00:00:00', 31.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-21 00:00:00', 29.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-22 00:00:00', 29.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-23 00:00:00', 30.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-24 00:00:00', 30.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-25 00:00:00', 28.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-26 00:00:00', 25.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-27 00:00:00', 27.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-28 00:00:00', 29.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-29 00:00:00', 31.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-09-30 00:00:00', 27.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-01 00:00:00', 29.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-02 00:00:00', 24.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-03 00:00:00', 27.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-04 00:00:00', 23.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-05 00:00:00', 20.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-06 00:00:00', 23.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-07 00:00:00', 22.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-08 00:00:00', 22.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-09 00:00:00', 21.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-10 00:00:00', 23.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-11 00:00:00', 24.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-12 00:00:00', 26.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-13 00:00:00', 27.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-14 00:00:00', 26.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-15 00:00:00', 18.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-16 00:00:00', 17.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-17 00:00:00', 22.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-18 00:00:00', 24.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-19 00:00:00', 24.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-20 00:00:00', 25.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-21 00:00:00', 25.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-22 00:00:00', 23.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-23 00:00:00', 21.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-24 00:00:00', 24.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-25 00:00:00', 23.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-26 00:00:00', 25.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-27 00:00:00', 27.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-28 00:00:00', 28.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-29 00:00:00', 27.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-30 00:00:00', 24.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-10-31 00:00:00', 24.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-01 00:00:00', 20.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-02 00:00:00', 21.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-03 00:00:00', 24.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-04 00:00:00', 25.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-05 00:00:00', 20.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-06 00:00:00', 20.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-07 00:00:00', 14.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-08 00:00:00', 11.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-09 00:00:00', 16.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-10 00:00:00', 17.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-11 00:00:00', 11.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-12 00:00:00', 10.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-13 00:00:00', 10.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-14 00:00:00', 15.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-15 00:00:00', 14.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-16 00:00:00', 10.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-17 00:00:00', 9.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-18 00:00:00', 9.58100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-19 00:00:00', 14.2869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-20 00:00:00', 14.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-21 00:00:00', 13.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-22 00:00:00', 15.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-23 00:00:00', 13.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-24 00:00:00', 15.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-25 00:00:00', 15.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-26 00:00:00', 15.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-27 00:00:00', 14.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-28 00:00:00', 13.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-29 00:00:00', 9.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-11-30 00:00:00', 9.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-01 00:00:00', 12.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-02 00:00:00', 8.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-03 00:00:00', 8.52999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-04 00:00:00', 12.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-05 00:00:00', 11.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-06 00:00:00', 12.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-07 00:00:00', 10.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-08 00:00:00', 12.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-09 00:00:00', 12.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-10 00:00:00', 9.64500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-11 00:00:00', 11.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-12 00:00:00', 10.7589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-13 00:00:00', 14.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-14 00:00:00', 13.9189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-15 00:00:00', 14.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-16 00:00:00', 11.2440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-17 00:00:00', 7.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-18 00:00:00', 10.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-19 00:00:00', 11.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-20 00:00:00', 14.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-21 00:00:00', 16.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-22 00:00:00', 17.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-23 00:00:00', 13.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-24 00:00:00', 13.6920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-25 00:00:00', 13.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-26 00:00:00', 16.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-27 00:00:00', 10.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-28 00:00:00', 8.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-29 00:00:00', 11.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-30 00:00:00', 11.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2000-12-31 00:00:00', 11.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-01 00:00:00', 12.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-02 00:00:00', 9.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-03 00:00:00', 10.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-04 00:00:00', 12.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-05 00:00:00', 13.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-06 00:00:00', 10.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-07 00:00:00', 9.66899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-08 00:00:00', 10.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-09 00:00:00', 9.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-10 00:00:00', 10.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-11 00:00:00', 12.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-12 00:00:00', 12.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-13 00:00:00', 12.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-14 00:00:00', 13.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-15 00:00:00', 12.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-16 00:00:00', 6.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-17 00:00:00', 7.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-18 00:00:00', 9.94200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-19 00:00:00', 11.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-20 00:00:00', 10.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-21 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-22 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-23 00:00:00', 4.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-24 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-25 00:00:00', 2.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-26 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-27 00:00:00', 4.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-28 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-29 00:00:00', -2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-30 00:00:00', 0.811999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-01-31 00:00:00', 3.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-01 00:00:00', 6.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-02 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-03 00:00:00', 8.63799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-04 00:00:00', 7.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-05 00:00:00', 9.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-06 00:00:00', 7.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-07 00:00:00', 7.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-08 00:00:00', 10.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-09 00:00:00', 8.93700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-10 00:00:00', 6.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-11 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-12 00:00:00', 9.46399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-13 00:00:00', 10.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-14 00:00:00', 11.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-15 00:00:00', 15.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-16 00:00:00', 13.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-17 00:00:00', 13.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-18 00:00:00', 14.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-19 00:00:00', 16.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-20 00:00:00', 12.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-21 00:00:00', 16.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-22 00:00:00', 10.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-23 00:00:00', 14.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-24 00:00:00', 15.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-25 00:00:00', 15.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-26 00:00:00', 15.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-27 00:00:00', 16.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-02-28 00:00:00', 17.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-01 00:00:00', 17.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-02 00:00:00', 18.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-03 00:00:00', 18.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-04 00:00:00', 20.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-05 00:00:00', 18.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-06 00:00:00', 18.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-07 00:00:00', 20.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-08 00:00:00', 22.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-09 00:00:00', 23.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-10 00:00:00', 23.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-11 00:00:00', 13.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-12 00:00:00', 4.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-13 00:00:00', 9.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-14 00:00:00', 13.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-15 00:00:00', 15.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-16 00:00:00', 19.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-17 00:00:00', 19.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-18 00:00:00', 19.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-19 00:00:00', 16.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-20 00:00:00', 19.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-21 00:00:00', 21.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-22 00:00:00', 23.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-23 00:00:00', 24.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-24 00:00:00', 27.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-25 00:00:00', 27.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-26 00:00:00', 28.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-27 00:00:00', 21.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-28 00:00:00', 17.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-29 00:00:00', 19.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-30 00:00:00', 22.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-03-31 00:00:00', 24.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-01 00:00:00', 25.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-02 00:00:00', 21.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-03 00:00:00', 22.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-04 00:00:00', 27.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-05 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-06 00:00:00', 28.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-07 00:00:00', 32.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-08 00:00:00', 34.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-09 00:00:00', 32.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-10 00:00:00', 32.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-11 00:00:00', 32.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-12 00:00:00', 32.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-13 00:00:00', 32.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-14 00:00:00', 29.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-15 00:00:00', 31.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-16 00:00:00', 30.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-17 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-18 00:00:00', 29.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-19 00:00:00', 25.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-20 00:00:00', 27.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-21 00:00:00', 30.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-22 00:00:00', 32.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-23 00:00:00', 29.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-24 00:00:00', 31.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-25 00:00:00', 32.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-26 00:00:00', 32.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-27 00:00:00', 33.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-28 00:00:00', 33.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-29 00:00:00', 32.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-04-30 00:00:00', 32.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-01 00:00:00', 28.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-02 00:00:00', 31.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-03 00:00:00', 33.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-04 00:00:00', 36.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-05 00:00:00', 37.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-06 00:00:00', 38.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-07 00:00:00', 33.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-08 00:00:00', 35.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-09 00:00:00', 37.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-10 00:00:00', 39.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-11 00:00:00', 38.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-12 00:00:00', 39.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-13 00:00:00', 39.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-14 00:00:00', 39.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-15 00:00:00', 38.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-16 00:00:00', 38.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-17 00:00:00', 39.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-18 00:00:00', 38.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-19 00:00:00', 35.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-20 00:00:00', 33.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-21 00:00:00', 32.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-22 00:00:00', 34.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-23 00:00:00', 35.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-24 00:00:00', 34.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-25 00:00:00', 34.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-26 00:00:00', 37.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-27 00:00:00', 37.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-28 00:00:00', 35.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-29 00:00:00', 35.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-30 00:00:00', 39.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-05-31 00:00:00', 40.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-01 00:00:00', 41.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-02 00:00:00', 37.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-03 00:00:00', 36.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-04 00:00:00', 35.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-05 00:00:00', 36.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-06 00:00:00', 37.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-07 00:00:00', 38.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-08 00:00:00', 38.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-09 00:00:00', 39.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-10 00:00:00', 41.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-11 00:00:00', 39.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-12 00:00:00', 38.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-13 00:00:00', 38.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-14 00:00:00', 36.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-15 00:00:00', 37.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-16 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-17 00:00:00', 37.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-18 00:00:00', 39.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-19 00:00:00', 39.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-20 00:00:00', 41.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-21 00:00:00', 40.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-22 00:00:00', 37.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-23 00:00:00', 38.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-24 00:00:00', 38.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-25 00:00:00', 40.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-26 00:00:00', 41.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-27 00:00:00', 43.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-28 00:00:00', 45.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-29 00:00:00', 45.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-06-30 00:00:00', 44.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-01 00:00:00', 42.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-02 00:00:00', 39.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-03 00:00:00', 38.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-04 00:00:00', 38.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-05 00:00:00', 36.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-06 00:00:00', 37.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-07 00:00:00', 37.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-08 00:00:00', 39.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-09 00:00:00', 39.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-10 00:00:00', 41.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-11 00:00:00', 43.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-12 00:00:00', 43.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-13 00:00:00', 43.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-14 00:00:00', 41.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-15 00:00:00', 38.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-16 00:00:00', 35.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-17 00:00:00', 36.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-18 00:00:00', 38.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-19 00:00:00', 41.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-20 00:00:00', 39.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-21 00:00:00', 38.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-22 00:00:00', 37.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-23 00:00:00', 37.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-24 00:00:00', 38.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-25 00:00:00', 38.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-26 00:00:00', 39.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-27 00:00:00', 40.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-28 00:00:00', 38.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-29 00:00:00', 35.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-30 00:00:00', 33.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-07-31 00:00:00', 36.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-01 00:00:00', 36.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-02 00:00:00', 38.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-03 00:00:00', 38.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-04 00:00:00', 39.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-05 00:00:00', 41.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-06 00:00:00', 39.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-07 00:00:00', 38.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-08 00:00:00', 38.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-09 00:00:00', 37.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-10 00:00:00', 37.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-11 00:00:00', 37.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-12 00:00:00', 38.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-13 00:00:00', 35.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-14 00:00:00', 34.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-15 00:00:00', 34.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-16 00:00:00', 35.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-17 00:00:00', 36.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-18 00:00:00', 37.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-19 00:00:00', 35.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-20 00:00:00', 35.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-21 00:00:00', 36.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-22 00:00:00', 36.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-23 00:00:00', 36.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-24 00:00:00', 36.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-25 00:00:00', 37.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-26 00:00:00', 33.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-27 00:00:00', 36.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-28 00:00:00', 33.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-29 00:00:00', 33.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-30 00:00:00', 34.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-08-31 00:00:00', 36.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-01 00:00:00', 39.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-02 00:00:00', 38.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-03 00:00:00', 35.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-04 00:00:00', 33.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-05 00:00:00', 35.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-06 00:00:00', 35.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-07 00:00:00', 37.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-08 00:00:00', 38.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-09 00:00:00', 39.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-10 00:00:00', 35.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-11 00:00:00', 33.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-12 00:00:00', 31.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-13 00:00:00', 28.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-14 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-15 00:00:00', 30.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-16 00:00:00', 29.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-17 00:00:00', 31.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-18 00:00:00', 31.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-19 00:00:00', 26.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-20 00:00:00', 22.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-21 00:00:00', 25.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-22 00:00:00', 25.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-23 00:00:00', 26.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-24 00:00:00', 28.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-25 00:00:00', 28.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-26 00:00:00', 29.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-27 00:00:00', 32.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-28 00:00:00', 32.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-29 00:00:00', 31.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-09-30 00:00:00', 34.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-01 00:00:00', 33.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-02 00:00:00', 31.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-03 00:00:00', 23.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-04 00:00:00', 24.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-05 00:00:00', 25.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-06 00:00:00', 26.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-07 00:00:00', 30.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-08 00:00:00', 30.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-09 00:00:00', 25.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-10 00:00:00', 20.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-11 00:00:00', 16.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-12 00:00:00', 23.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-13 00:00:00', 24.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-14 00:00:00', 26.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-15 00:00:00', 26.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-16 00:00:00', 26.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-17 00:00:00', 26.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-18 00:00:00', 23.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-19 00:00:00', 23.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-20 00:00:00', 28.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-21 00:00:00', 25.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-22 00:00:00', 26.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-23 00:00:00', 22.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-24 00:00:00', 24.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-25 00:00:00', 26.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-26 00:00:00', 28.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-27 00:00:00', 18.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-28 00:00:00', 17.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-29 00:00:00', 19.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-30 00:00:00', 20.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-10-31 00:00:00', 23.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-01 00:00:00', 20.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-02 00:00:00', 15.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-03 00:00:00', 12.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-04 00:00:00', 18.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-05 00:00:00', 18.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-06 00:00:00', 19.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-07 00:00:00', 20.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-08 00:00:00', 22.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-09 00:00:00', 19.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-10 00:00:00', 18.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-11 00:00:00', 19.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-12 00:00:00', 22.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-13 00:00:00', 24.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-14 00:00:00', 23.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-15 00:00:00', 20.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-16 00:00:00', 21.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-17 00:00:00', 23.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-18 00:00:00', 23.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-19 00:00:00', 24.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-20 00:00:00', 17.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-21 00:00:00', 17.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-22 00:00:00', 20.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-23 00:00:00', 23.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-24 00:00:00', 16.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-25 00:00:00', 14.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-26 00:00:00', 16.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-27 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-28 00:00:00', 16.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-29 00:00:00', 10.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-11-30 00:00:00', 9.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-01 00:00:00', 11.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-02 00:00:00', 8.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-03 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-04 00:00:00', 8.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-05 00:00:00', 12.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-06 00:00:00', 13.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-07 00:00:00', 13.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-08 00:00:00', 12.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-09 00:00:00', 12.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-10 00:00:00', 7.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-11 00:00:00', 8.99600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-12 00:00:00', 11.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-13 00:00:00', 10.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-14 00:00:00', 13.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-15 00:00:00', 12.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-16 00:00:00', 9.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-17 00:00:00', 8.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-18 00:00:00', 9.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-19 00:00:00', 11.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-20 00:00:00', 14.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-21 00:00:00', 15.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-22 00:00:00', 9.76500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-23 00:00:00', 9.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-24 00:00:00', 12.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-25 00:00:00', 13.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-26 00:00:00', 14.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-27 00:00:00', 15.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-28 00:00:00', 15.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-29 00:00:00', 15.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-30 00:00:00', 16.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2001-12-31 00:00:00', 14.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-01 00:00:00', 16.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-02 00:00:00', 18.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-03 00:00:00', 19.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-04 00:00:00', 17.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-05 00:00:00', 16.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-06 00:00:00', 15.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-07 00:00:00', 17.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-08 00:00:00', 18.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-09 00:00:00', 14.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-10 00:00:00', 11.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-11 00:00:00', 12.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-12 00:00:00', 8.61200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-13 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-14 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-15 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-16 00:00:00', 3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-17 00:00:00', 5.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-18 00:00:00', 5.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-19 00:00:00', 5.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-20 00:00:00', 7.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-21 00:00:00', 8.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-22 00:00:00', 9.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-23 00:00:00', 9.16199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-24 00:00:00', 9.34599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-25 00:00:00', 7.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-26 00:00:00', 6.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-27 00:00:00', 7.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-28 00:00:00', 8.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-29 00:00:00', 11.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-30 00:00:00', 12.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-01-31 00:00:00', 11.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-01 00:00:00', 11.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-02 00:00:00', 7.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-03 00:00:00', 8.46599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-04 00:00:00', 7.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-05 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-06 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-07 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-08 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-09 00:00:00', 9.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-10 00:00:00', 11.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-11 00:00:00', 11.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-12 00:00:00', 10.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-13 00:00:00', 14.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-14 00:00:00', 15.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-15 00:00:00', 13.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-16 00:00:00', 15.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-17 00:00:00', 10.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-18 00:00:00', 12.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-19 00:00:00', 11.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-20 00:00:00', 14.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-21 00:00:00', 17.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-22 00:00:00', 13.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-23 00:00:00', 13.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-24 00:00:00', 14.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-25 00:00:00', 15.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-26 00:00:00', 14.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-27 00:00:00', 17.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-02-28 00:00:00', 18.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-01 00:00:00', 13.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-02 00:00:00', 14.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-03 00:00:00', 16.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-04 00:00:00', 18.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-05 00:00:00', 20.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-06 00:00:00', 21.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-07 00:00:00', 7.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-08 00:00:00', 12.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-09 00:00:00', 17.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-10 00:00:00', 18.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-11 00:00:00', 9.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-12 00:00:00', 13.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-13 00:00:00', 17.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-14 00:00:00', 21.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-15 00:00:00', 23.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-16 00:00:00', 25.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-17 00:00:00', 27.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-18 00:00:00', 26.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-19 00:00:00', 28.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-20 00:00:00', 26.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-21 00:00:00', 23.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-22 00:00:00', 23.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-23 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-24 00:00:00', 15.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-25 00:00:00', 20.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-26 00:00:00', 23.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-27 00:00:00', 26.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-28 00:00:00', 28.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-29 00:00:00', 28.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-30 00:00:00', 20.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-03-31 00:00:00', 20.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-01 00:00:00', 19.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-02 00:00:00', 21.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-03 00:00:00', 23.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-04 00:00:00', 21.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-05 00:00:00', 24.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-06 00:00:00', 23.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-07 00:00:00', 25.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-08 00:00:00', 27.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-09 00:00:00', 30.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-10 00:00:00', 31.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-11 00:00:00', 30.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-12 00:00:00', 25.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-13 00:00:00', 29.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-14 00:00:00', 23.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-15 00:00:00', 22.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-16 00:00:00', 26.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-17 00:00:00', 27.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-18 00:00:00', 30.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-19 00:00:00', 33.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-20 00:00:00', 35.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-21 00:00:00', 34.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-22 00:00:00', 24.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-23 00:00:00', 19.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-24 00:00:00', 22.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-25 00:00:00', 24.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-26 00:00:00', 21.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-27 00:00:00', 20.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-28 00:00:00', 22.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-29 00:00:00', 22.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-04-30 00:00:00', 24.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-01 00:00:00', 27.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-02 00:00:00', 27.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-03 00:00:00', 28.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-04 00:00:00', 29.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-05 00:00:00', 29.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-06 00:00:00', 27.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-07 00:00:00', 33.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-08 00:00:00', 34.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-09 00:00:00', 33.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-10 00:00:00', 33.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-11 00:00:00', 35.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-12 00:00:00', 35.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-13 00:00:00', 26.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-14 00:00:00', 24.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-15 00:00:00', 28.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-16 00:00:00', 31.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-17 00:00:00', 29.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-18 00:00:00', 28.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-19 00:00:00', 28.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-20 00:00:00', 28.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-21 00:00:00', 31.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-22 00:00:00', 33.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-23 00:00:00', 34.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-24 00:00:00', 36.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-25 00:00:00', 36.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-26 00:00:00', 36.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-27 00:00:00', 32.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-28 00:00:00', 33.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-29 00:00:00', 33.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-30 00:00:00', 36.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-05-31 00:00:00', 39.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-01 00:00:00', 39.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-02 00:00:00', 40.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-03 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-04 00:00:00', 38.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-05 00:00:00', 36.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-06 00:00:00', 35.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-07 00:00:00', 39.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-08 00:00:00', 32.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-09 00:00:00', 34.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-10 00:00:00', 36.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-11 00:00:00', 37.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-12 00:00:00', 39.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-13 00:00:00', 41.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-14 00:00:00', 41.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-15 00:00:00', 37.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-16 00:00:00', 33.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-17 00:00:00', 33.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-18 00:00:00', 35.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-19 00:00:00', 36.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-20 00:00:00', 38.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-21 00:00:00', 41.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-22 00:00:00', 38.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-23 00:00:00', 34.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-24 00:00:00', 34.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-25 00:00:00', 35.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-26 00:00:00', 38.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-27 00:00:00', 42.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-28 00:00:00', 41.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-29 00:00:00', 39.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-06-30 00:00:00', 40.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-01 00:00:00', 39.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-02 00:00:00', 37.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-03 00:00:00', 37.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-04 00:00:00', 37.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-05 00:00:00', 35.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-06 00:00:00', 35.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-07 00:00:00', 36.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-08 00:00:00', 35.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-09 00:00:00', 36.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-10 00:00:00', 38.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-11 00:00:00', 37.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-12 00:00:00', 38.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-13 00:00:00', 38.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-14 00:00:00', 39.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-15 00:00:00', 39.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-16 00:00:00', 41.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-17 00:00:00', 40.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-18 00:00:00', 41.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-19 00:00:00', 42.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-20 00:00:00', 42.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-21 00:00:00', 36.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-22 00:00:00', 33.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-23 00:00:00', 36.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-24 00:00:00', 38.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-25 00:00:00', 39.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-26 00:00:00', 40.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-27 00:00:00', 38.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-28 00:00:00', 38.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-29 00:00:00', 38.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-30 00:00:00', 38.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-07-31 00:00:00', 37.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-01 00:00:00', 39.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-02 00:00:00', 39.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-03 00:00:00', 40.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-04 00:00:00', 40.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-05 00:00:00', 40.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-06 00:00:00', 40.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-07 00:00:00', 41.5789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-08 00:00:00', 42.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-09 00:00:00', 43.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-10 00:00:00', 42.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-11 00:00:00', 45.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-12 00:00:00', 41.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-13 00:00:00', 34.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-14 00:00:00', 33.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-15 00:00:00', 34.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-16 00:00:00', 36.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-17 00:00:00', 38.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-18 00:00:00', 39.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-19 00:00:00', 39.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-20 00:00:00', 41.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-21 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-22 00:00:00', 37.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-23 00:00:00', 40.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-24 00:00:00', 39.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-25 00:00:00', 40.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-26 00:00:00', 39.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-27 00:00:00', 39.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-28 00:00:00', 39.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-29 00:00:00', 39.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-30 00:00:00', 39.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-08-31 00:00:00', 37.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-01 00:00:00', 34.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-02 00:00:00', 32.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-03 00:00:00', 30.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-04 00:00:00', 30.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-05 00:00:00', 32.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-06 00:00:00', 33.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-07 00:00:00', 31.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-08 00:00:00', 32.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-09 00:00:00', 32.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-10 00:00:00', 33.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-11 00:00:00', 34.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-12 00:00:00', 36.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-13 00:00:00', 36.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-14 00:00:00', 37.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-15 00:00:00', 37.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-16 00:00:00', 37.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-17 00:00:00', 31.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-18 00:00:00', 33.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-19 00:00:00', 32.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-20 00:00:00', 34.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-21 00:00:00', 33.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-22 00:00:00', 33.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-23 00:00:00', 32.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-24 00:00:00', 29.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-25 00:00:00', 29.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-26 00:00:00', 30.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-27 00:00:00', 29.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-28 00:00:00', 29.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-29 00:00:00', 30.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-09-30 00:00:00', 30.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-01 00:00:00', 31.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-02 00:00:00', 32.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-03 00:00:00', 32.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-04 00:00:00', 33.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-05 00:00:00', 33.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-06 00:00:00', 31.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-07 00:00:00', 31.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-08 00:00:00', 31.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-09 00:00:00', 31.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-10 00:00:00', 31.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-11 00:00:00', 31.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-12 00:00:00', 29.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-13 00:00:00', 29.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-14 00:00:00', 29.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-15 00:00:00', 28.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-16 00:00:00', 26.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-17 00:00:00', 26.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-18 00:00:00', 27.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-19 00:00:00', 25.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-20 00:00:00', 25.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-21 00:00:00', 26.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-22 00:00:00', 26.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-23 00:00:00', 21.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-24 00:00:00', 21.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-25 00:00:00', 23.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-26 00:00:00', 25.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-27 00:00:00', 25.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-28 00:00:00', 25.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-29 00:00:00', 25.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-30 00:00:00', 25.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-10-31 00:00:00', 27.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-01 00:00:00', 24.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-02 00:00:00', 26.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-03 00:00:00', 24.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-04 00:00:00', 21.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-05 00:00:00', 21.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-06 00:00:00', 21.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-07 00:00:00', 23.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-08 00:00:00', 20.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-09 00:00:00', 18.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-10 00:00:00', 19.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-11 00:00:00', 20.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-12 00:00:00', 21.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-13 00:00:00', 21.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-14 00:00:00', 20.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-15 00:00:00', 16.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-16 00:00:00', 12.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-17 00:00:00', 16.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-18 00:00:00', 13.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-19 00:00:00', 15.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-20 00:00:00', 18.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-21 00:00:00', 16.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-22 00:00:00', 16.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-23 00:00:00', 16.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-24 00:00:00', 18.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-25 00:00:00', 20.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-26 00:00:00', 18.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-27 00:00:00', 11.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-28 00:00:00', 12.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-29 00:00:00', 13.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-11-30 00:00:00', 11.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-01 00:00:00', 13.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-02 00:00:00', 8.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-03 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-04 00:00:00', -4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-05 00:00:00', -2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-06 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-07 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-08 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-09 00:00:00', 10.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-10 00:00:00', 11.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-11 00:00:00', 10.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-12 00:00:00', 8.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-13 00:00:00', 12.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-14 00:00:00', 8.98200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-15 00:00:00', 7.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-16 00:00:00', 9.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-17 00:00:00', 6.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-18 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-19 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-20 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-21 00:00:00', 9.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-22 00:00:00', 14.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-23 00:00:00', 9.46300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-24 00:00:00', 5.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-25 00:00:00', 7.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-26 00:00:00', 8.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-27 00:00:00', 6.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-28 00:00:00', 5.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-29 00:00:00', 7.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-30 00:00:00', 3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2002-12-31 00:00:00', 8.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-01 00:00:00', 10.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-02 00:00:00', 10.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-03 00:00:00', 11.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-04 00:00:00', 13.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-05 00:00:00', 14.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-06 00:00:00', 12.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-07 00:00:00', 11.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-08 00:00:00', 7.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-09 00:00:00', 9.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-10 00:00:00', 12.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-11 00:00:00', 9.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-12 00:00:00', 10.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-13 00:00:00', 12.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-14 00:00:00', 14.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-15 00:00:00', 14.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-16 00:00:00', 15.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-17 00:00:00', 14.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-18 00:00:00', 15.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-19 00:00:00', 8.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-20 00:00:00', 13.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-21 00:00:00', 9.62100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-22 00:00:00', 10.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-23 00:00:00', 10.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-24 00:00:00', 10.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-25 00:00:00', 8.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-26 00:00:00', 8.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-27 00:00:00', 9.58100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-28 00:00:00', 10.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-29 00:00:00', 7.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-30 00:00:00', 9.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-01-31 00:00:00', 8.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-01 00:00:00', 10.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-02 00:00:00', 12.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-03 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-04 00:00:00', 15.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-05 00:00:00', 18.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-06 00:00:00', 13.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-07 00:00:00', 9.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-08 00:00:00', 11.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-09 00:00:00', 12.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-10 00:00:00', 14.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-11 00:00:00', 16.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-12 00:00:00', 14.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-13 00:00:00', 7.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-14 00:00:00', 11.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-15 00:00:00', 12.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-16 00:00:00', 9.58100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-17 00:00:00', 8.76299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-18 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-19 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-20 00:00:00', 8.66399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-21 00:00:00', 11.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-22 00:00:00', 13.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-23 00:00:00', 13.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-24 00:00:00', 9.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-25 00:00:00', 13.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-26 00:00:00', 11.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-27 00:00:00', 9.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-02-28 00:00:00', 10.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-01 00:00:00', 6.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-02 00:00:00', 5.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-03 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-04 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-05 00:00:00', 9.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-06 00:00:00', 11.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-07 00:00:00', 12.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-08 00:00:00', 16.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-09 00:00:00', 10.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-10 00:00:00', 11.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-11 00:00:00', 15.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-12 00:00:00', 17.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-13 00:00:00', 19.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-14 00:00:00', 16.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-15 00:00:00', 12.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-16 00:00:00', 14.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-17 00:00:00', 18.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-18 00:00:00', 18.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-19 00:00:00', 17.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-20 00:00:00', 20.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-21 00:00:00', 25.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-22 00:00:00', 21.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-23 00:00:00', 21.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-24 00:00:00', 18.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-25 00:00:00', 22.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-26 00:00:00', 25.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-27 00:00:00', 17.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-28 00:00:00', 17.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-29 00:00:00', 19.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-30 00:00:00', 21.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-03-31 00:00:00', 14.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-01 00:00:00', 16.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-02 00:00:00', 16.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-03 00:00:00', 17.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-04 00:00:00', 18.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-05 00:00:00', 19.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-06 00:00:00', 25.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-07 00:00:00', 29.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-08 00:00:00', 32.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-09 00:00:00', 31.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-10 00:00:00', 32.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-11 00:00:00', 31.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-12 00:00:00', 32.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-13 00:00:00', 30.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-14 00:00:00', 28.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-15 00:00:00', 14.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-16 00:00:00', 17.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-17 00:00:00', 22.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-18 00:00:00', 15.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-19 00:00:00', 9.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-20 00:00:00', 15.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-21 00:00:00', 23.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-22 00:00:00', 26.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-23 00:00:00', 28.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-24 00:00:00', 25.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-25 00:00:00', 27.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-26 00:00:00', 27.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-27 00:00:00', 30.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-28 00:00:00', 33.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-29 00:00:00', 30.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-04-30 00:00:00', 24.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-01 00:00:00', 19.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-02 00:00:00', 18.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-03 00:00:00', 20.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-04 00:00:00', 22.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-05 00:00:00', 25.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-06 00:00:00', 27.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-07 00:00:00', 31.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-08 00:00:00', 32.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-09 00:00:00', 30.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-10 00:00:00', 25.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-11 00:00:00', 27.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-12 00:00:00', 26.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-13 00:00:00', 28.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-14 00:00:00', 28.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-15 00:00:00', 29.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-16 00:00:00', 31.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-17 00:00:00', 33.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-18 00:00:00', 33.1899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-19 00:00:00', 32.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-20 00:00:00', 33.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-21 00:00:00', 34.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-22 00:00:00', 34.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-23 00:00:00', 34.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-24 00:00:00', 34.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-25 00:00:00', 32.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-26 00:00:00', 24.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-27 00:00:00', 24.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-28 00:00:00', 28.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-29 00:00:00', 32.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-30 00:00:00', 35.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-05-31 00:00:00', 37.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-01 00:00:00', 36.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-02 00:00:00', 38.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-03 00:00:00', 37.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-04 00:00:00', 36.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-05 00:00:00', 38.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-06 00:00:00', 38.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-07 00:00:00', 30.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-08 00:00:00', 31.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-09 00:00:00', 33.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-10 00:00:00', 34.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-11 00:00:00', 31.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-12 00:00:00', 29.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-13 00:00:00', 34.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-14 00:00:00', 36.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-15 00:00:00', 36.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-16 00:00:00', 36.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-17 00:00:00', 38.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-18 00:00:00', 38.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-19 00:00:00', 39.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-20 00:00:00', 37.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-21 00:00:00', 36.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-22 00:00:00', 36.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-23 00:00:00', 36.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-24 00:00:00', 37.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-25 00:00:00', 40.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-26 00:00:00', 35.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-27 00:00:00', 37.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-28 00:00:00', 37.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-29 00:00:00', 37.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-06-30 00:00:00', 37.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-01 00:00:00', 38.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-02 00:00:00', 42.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-03 00:00:00', 44.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-04 00:00:00', 39.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-05 00:00:00', 36.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-06 00:00:00', 37.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-07 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-08 00:00:00', 40.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-09 00:00:00', 39.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-10 00:00:00', 40.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-11 00:00:00', 42.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-12 00:00:00', 38.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-13 00:00:00', 37.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-14 00:00:00', 38.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-15 00:00:00', 39.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-16 00:00:00', 41.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-17 00:00:00', 40.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-18 00:00:00', 43.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-19 00:00:00', 43.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-20 00:00:00', 44.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-21 00:00:00', 46.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-22 00:00:00', 42.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-23 00:00:00', 39.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-24 00:00:00', 36.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-25 00:00:00', 37.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-26 00:00:00', 38.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-27 00:00:00', 40.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-28 00:00:00', 40.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-29 00:00:00', 38.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-30 00:00:00', 38.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-07-31 00:00:00', 40.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-01 00:00:00', 42.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-02 00:00:00', 41.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-03 00:00:00', 38.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-04 00:00:00', 35.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-05 00:00:00', 34.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-06 00:00:00', 34.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-07 00:00:00', 35.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-08 00:00:00', 35.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-09 00:00:00', 36.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-10 00:00:00', 36.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-11 00:00:00', 37.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-12 00:00:00', 37.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-13 00:00:00', 37.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-14 00:00:00', 39.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-15 00:00:00', 41.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-16 00:00:00', 42.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-17 00:00:00', 41.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-18 00:00:00', 41.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-19 00:00:00', 39.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-20 00:00:00', 36.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-21 00:00:00', 35.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-22 00:00:00', 36.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-23 00:00:00', 36.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-24 00:00:00', 36.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-25 00:00:00', 36.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-26 00:00:00', 36.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-27 00:00:00', 36.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-28 00:00:00', 37.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-29 00:00:00', 37.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-30 00:00:00', 35.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-08-31 00:00:00', 36.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-01 00:00:00', 36.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-02 00:00:00', 36.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-03 00:00:00', 36.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-04 00:00:00', 36.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-05 00:00:00', 36.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-06 00:00:00', 37.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-07 00:00:00', 37.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-08 00:00:00', 37.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-09 00:00:00', 38.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-10 00:00:00', 37.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-11 00:00:00', 37.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-12 00:00:00', 35.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-13 00:00:00', 34.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-14 00:00:00', 34.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-15 00:00:00', 31.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-16 00:00:00', 29.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-17 00:00:00', 31.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-18 00:00:00', 33.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-19 00:00:00', 35.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-20 00:00:00', 37.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-21 00:00:00', 33.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-22 00:00:00', 31.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-23 00:00:00', 29.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-24 00:00:00', 24.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-25 00:00:00', 26.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-26 00:00:00', 24.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-27 00:00:00', 24.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-28 00:00:00', 23.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-29 00:00:00', 25.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-09-30 00:00:00', 26.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-01 00:00:00', 27.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-02 00:00:00', 28.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-03 00:00:00', 31.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-04 00:00:00', 32.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-05 00:00:00', 33.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-06 00:00:00', 26.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-07 00:00:00', 26.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-08 00:00:00', 24.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-09 00:00:00', 23.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-10 00:00:00', 24.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-11 00:00:00', 24.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-12 00:00:00', 24.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-13 00:00:00', 24.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-14 00:00:00', 25.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-15 00:00:00', 24.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-16 00:00:00', 22.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-17 00:00:00', 25.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-18 00:00:00', 26.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-19 00:00:00', 27.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-20 00:00:00', 26.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-21 00:00:00', 25.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-22 00:00:00', 25.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-23 00:00:00', 27.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-24 00:00:00', 25.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-25 00:00:00', 27.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-26 00:00:00', 27.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-27 00:00:00', 27.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-28 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-29 00:00:00', 29.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-30 00:00:00', 29.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-10-31 00:00:00', 30.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-01 00:00:00', 28.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-02 00:00:00', 27.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-03 00:00:00', 27.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-04 00:00:00', 18.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-05 00:00:00', 14.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-06 00:00:00', 15.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-07 00:00:00', 13.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-08 00:00:00', 11.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-09 00:00:00', 16.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-10 00:00:00', 19.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-11 00:00:00', 22.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-12 00:00:00', 19.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-13 00:00:00', 18.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-14 00:00:00', 19.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-15 00:00:00', 15.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-16 00:00:00', 6.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-17 00:00:00', 8.78699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-18 00:00:00', 9.67300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-19 00:00:00', 11.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-20 00:00:00', 13.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-21 00:00:00', 15.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-22 00:00:00', 15.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-23 00:00:00', 9.31999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-24 00:00:00', 10.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-25 00:00:00', 14.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-26 00:00:00', 13.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-27 00:00:00', 14.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-28 00:00:00', 16.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-29 00:00:00', 14.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-11-30 00:00:00', 13.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-01 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-02 00:00:00', 13.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-03 00:00:00', 12.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-04 00:00:00', 12.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-05 00:00:00', 10.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-06 00:00:00', 15.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-07 00:00:00', 15.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-08 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-09 00:00:00', 14.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-10 00:00:00', 14.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-11 00:00:00', 11.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-12 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-13 00:00:00', -1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-14 00:00:00', 0.653999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-15 00:00:00', 5.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-16 00:00:00', 8.22299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-17 00:00:00', 9.23700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-18 00:00:00', 11.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-19 00:00:00', 13.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-20 00:00:00', 15.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-21 00:00:00', 13.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-22 00:00:00', 6.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-23 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-24 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-25 00:00:00', 7.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-26 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-27 00:00:00', 7.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-28 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-29 00:00:00', 7.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-30 00:00:00', 7.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2003-12-31 00:00:00', 5.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-01 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-02 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-03 00:00:00', 6.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-04 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-05 00:00:00', 6.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-06 00:00:00', 7.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-07 00:00:00', 9.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-08 00:00:00', 7.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-09 00:00:00', 12.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-10 00:00:00', 12.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-11 00:00:00', 12.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-12 00:00:00', 10.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-13 00:00:00', 11.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-14 00:00:00', 13.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-15 00:00:00', 14.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-16 00:00:00', 11.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-17 00:00:00', 11.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-18 00:00:00', 12.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-19 00:00:00', 13.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-20 00:00:00', 10.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-21 00:00:00', 9.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-22 00:00:00', 9.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-23 00:00:00', 10.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-24 00:00:00', 11.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-25 00:00:00', 13.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-26 00:00:00', 11.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-27 00:00:00', 13.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-28 00:00:00', 8.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-29 00:00:00', 6.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-30 00:00:00', 6.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-01-31 00:00:00', 6.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-01 00:00:00', 8.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-02 00:00:00', 9.43799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-03 00:00:00', 11.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-04 00:00:00', 10.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-05 00:00:00', 11.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-06 00:00:00', 11.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-07 00:00:00', 10.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-08 00:00:00', 11.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-09 00:00:00', 10.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-10 00:00:00', 13.9289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-11 00:00:00', 17.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-12 00:00:00', 19.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-13 00:00:00', 17.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-14 00:00:00', 18.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-15 00:00:00', 20.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-16 00:00:00', 21.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-17 00:00:00', 14.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-18 00:00:00', 14.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-19 00:00:00', 13.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-20 00:00:00', 17.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-21 00:00:00', 15.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-22 00:00:00', 18.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-23 00:00:00', 19.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-24 00:00:00', 21.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-25 00:00:00', 17.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-26 00:00:00', 17.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-27 00:00:00', 16.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-28 00:00:00', 16.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-02-29 00:00:00', 18.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-01 00:00:00', 16.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-02 00:00:00', 18.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-03 00:00:00', 19.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-04 00:00:00', 19.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-05 00:00:00', 21.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-06 00:00:00', 24.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-07 00:00:00', 29.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-08 00:00:00', 24.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-09 00:00:00', 17.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-10 00:00:00', 17.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-11 00:00:00', 21.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-12 00:00:00', 25.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-13 00:00:00', 22.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-14 00:00:00', 20.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-15 00:00:00', 19.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-16 00:00:00', 19.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-17 00:00:00', 8.32699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-18 00:00:00', 15.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-19 00:00:00', 19.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-20 00:00:00', 19.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-21 00:00:00', 13.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-22 00:00:00', 15.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-23 00:00:00', 16.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-24 00:00:00', 19.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-25 00:00:00', 20.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-26 00:00:00', 23.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-27 00:00:00', 25.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-28 00:00:00', 25.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-29 00:00:00', 27.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-30 00:00:00', 28.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-03-31 00:00:00', 30.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-01 00:00:00', 26.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-02 00:00:00', 24.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-03 00:00:00', 22.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-04 00:00:00', 29.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-05 00:00:00', 31.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-06 00:00:00', 19.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-07 00:00:00', 18.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-08 00:00:00', 21.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-09 00:00:00', 20.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-10 00:00:00', 23.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-11 00:00:00', 24.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-12 00:00:00', 24.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-13 00:00:00', 24.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-14 00:00:00', 28.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-15 00:00:00', 30.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-16 00:00:00', 27.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-17 00:00:00', 28.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-18 00:00:00', 24.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-19 00:00:00', 25.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-20 00:00:00', 29.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-21 00:00:00', 28.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-22 00:00:00', 24.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-23 00:00:00', 27.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-24 00:00:00', 32.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-25 00:00:00', 34.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-26 00:00:00', 31.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-27 00:00:00', 28.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-28 00:00:00', 26.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-29 00:00:00', 22.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-04-30 00:00:00', 22.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-01 00:00:00', 24.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-02 00:00:00', 28.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-03 00:00:00', 31.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-04 00:00:00', 31.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-05 00:00:00', 34.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-06 00:00:00', 30.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-07 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-08 00:00:00', 30.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-09 00:00:00', 31.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-10 00:00:00', 35.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-11 00:00:00', 35.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-12 00:00:00', 37.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-13 00:00:00', 39.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-14 00:00:00', 40.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-15 00:00:00', 40.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-16 00:00:00', 39.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-17 00:00:00', 40.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-18 00:00:00', 38.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-19 00:00:00', 34.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-20 00:00:00', 32.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-21 00:00:00', 35.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-22 00:00:00', 27.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-23 00:00:00', 28.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-24 00:00:00', 33.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-25 00:00:00', 34.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-26 00:00:00', 33.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-27 00:00:00', 32.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-28 00:00:00', 32.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-29 00:00:00', 34.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-30 00:00:00', 36.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-05-31 00:00:00', 35.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-01 00:00:00', 35.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-02 00:00:00', 35.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-03 00:00:00', 38.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-04 00:00:00', 41.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-05 00:00:00', 39.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-06 00:00:00', 35.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-07 00:00:00', 33.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-08 00:00:00', 34.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-09 00:00:00', 35.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-10 00:00:00', 37.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-11 00:00:00', 39.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-12 00:00:00', 40.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-13 00:00:00', 38.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-14 00:00:00', 34.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-15 00:00:00', 37.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-16 00:00:00', 38.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-17 00:00:00', 39.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-18 00:00:00', 39.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-19 00:00:00', 40.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-20 00:00:00', 41.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-21 00:00:00', 41.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-22 00:00:00', 40.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-23 00:00:00', 40.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-24 00:00:00', 38.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-25 00:00:00', 37.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-26 00:00:00', 37.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-27 00:00:00', 35.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-28 00:00:00', 37.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-29 00:00:00', 39.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-06-30 00:00:00', 41.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-01 00:00:00', 40.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-02 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-03 00:00:00', 41.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-04 00:00:00', 41.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-05 00:00:00', 37.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-06 00:00:00', 35.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-07 00:00:00', 37.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-08 00:00:00', 36.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-09 00:00:00', 36.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-10 00:00:00', 38.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-11 00:00:00', 39.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-12 00:00:00', 36.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-13 00:00:00', 37.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-14 00:00:00', 36.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-15 00:00:00', 35.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-16 00:00:00', 34.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-17 00:00:00', 34.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-18 00:00:00', 33.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-19 00:00:00', 30.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-20 00:00:00', 33.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-21 00:00:00', 37.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-22 00:00:00', 37.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-23 00:00:00', 38.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-24 00:00:00', 43.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-25 00:00:00', 42.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-26 00:00:00', 41.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-27 00:00:00', 42.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-28 00:00:00', 42.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-29 00:00:00', 41.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-30 00:00:00', 39.0120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-07-31 00:00:00', 38.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-01 00:00:00', 36.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-02 00:00:00', 34.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-03 00:00:00', 35.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-04 00:00:00', 37.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-05 00:00:00', 40.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-06 00:00:00', 40.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-07 00:00:00', 35.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-08 00:00:00', 34.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-09 00:00:00', 34.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-10 00:00:00', 36.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-11 00:00:00', 36.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-12 00:00:00', 38.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-13 00:00:00', 40.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-14 00:00:00', 42.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-15 00:00:00', 41.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-16 00:00:00', 41.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-17 00:00:00', 38.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-18 00:00:00', 38.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-19 00:00:00', 38.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-20 00:00:00', 37.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-21 00:00:00', 36.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-22 00:00:00', 38.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-23 00:00:00', 39.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-24 00:00:00', 38.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-25 00:00:00', 36.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-26 00:00:00', 35.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-27 00:00:00', 36.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-28 00:00:00', 36.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-29 00:00:00', 36.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-30 00:00:00', 36.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-08-31 00:00:00', 34.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-01 00:00:00', 31.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-02 00:00:00', 32.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-03 00:00:00', 32.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-04 00:00:00', 33.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-05 00:00:00', 35.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-06 00:00:00', 37.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-07 00:00:00', 39.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-08 00:00:00', 38.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-09 00:00:00', 36.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-10 00:00:00', 35.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-11 00:00:00', 37.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-12 00:00:00', 36.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-13 00:00:00', 35.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-14 00:00:00', 32.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-15 00:00:00', 29.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-16 00:00:00', 28.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-17 00:00:00', 28.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-18 00:00:00', 32.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-19 00:00:00', 32.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-20 00:00:00', 30.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-21 00:00:00', 28.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-22 00:00:00', 27.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-23 00:00:00', 31.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-24 00:00:00', 30.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-25 00:00:00', 31.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-26 00:00:00', 30.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-27 00:00:00', 31.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-28 00:00:00', 29.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-29 00:00:00', 29.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-09-30 00:00:00', 29.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-01 00:00:00', 28.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-02 00:00:00', 28.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-03 00:00:00', 29.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-04 00:00:00', 31.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-05 00:00:00', 30.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-06 00:00:00', 28.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-07 00:00:00', 23.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-08 00:00:00', 18.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-09 00:00:00', 17.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-10 00:00:00', 19.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-11 00:00:00', 22.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-12 00:00:00', 23.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-13 00:00:00', 25.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-14 00:00:00', 26.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-15 00:00:00', 19.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-16 00:00:00', 18.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-17 00:00:00', 20.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-18 00:00:00', 20.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-19 00:00:00', 20.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-20 00:00:00', 20.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-21 00:00:00', 23.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-22 00:00:00', 25.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-23 00:00:00', 27.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-24 00:00:00', 21.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-25 00:00:00', 19.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-26 00:00:00', 21.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-27 00:00:00', 18.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-28 00:00:00', 18.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-29 00:00:00', 22.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-30 00:00:00', 22.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-10-31 00:00:00', 21.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-01 00:00:00', 20.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-02 00:00:00', 21.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-03 00:00:00', 23.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-04 00:00:00', 24.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-05 00:00:00', 22.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-06 00:00:00', 22.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-07 00:00:00', 21.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-08 00:00:00', 22.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-09 00:00:00', 20.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-10 00:00:00', 18.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-11 00:00:00', 19.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-12 00:00:00', 17.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-13 00:00:00', 18.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-14 00:00:00', 19.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-15 00:00:00', 19.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-16 00:00:00', 17.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-17 00:00:00', 19.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-18 00:00:00', 20.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-19 00:00:00', 16.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-20 00:00:00', 17.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-21 00:00:00', 16.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-22 00:00:00', 17.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-23 00:00:00', 18.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-24 00:00:00', 19.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-25 00:00:00', 14.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-26 00:00:00', 15.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-27 00:00:00', 19.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-28 00:00:00', 18.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-29 00:00:00', 11.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-11-30 00:00:00', 10.7650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-01 00:00:00', 11.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-02 00:00:00', 14.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-03 00:00:00', 9.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-04 00:00:00', 7.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-05 00:00:00', 12.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-06 00:00:00', 13.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-07 00:00:00', 10.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-08 00:00:00', 14.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-09 00:00:00', 15.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-10 00:00:00', 15.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-11 00:00:00', 17.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-12 00:00:00', 16.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-13 00:00:00', 17.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-14 00:00:00', 13.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-15 00:00:00', 14.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-16 00:00:00', 15.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-17 00:00:00', 17.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-18 00:00:00', 10.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-19 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-20 00:00:00', 7.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-21 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-22 00:00:00', 8.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-23 00:00:00', 6.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-24 00:00:00', 8.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-25 00:00:00', 9.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-26 00:00:00', 10.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-27 00:00:00', 7.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-28 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-29 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-30 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2004-12-31 00:00:00', 8.25100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-01 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-02 00:00:00', 7.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-03 00:00:00', 9.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-04 00:00:00', 12.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-05 00:00:00', 9.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-06 00:00:00', 10.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-07 00:00:00', 7.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-08 00:00:00', 5.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-09 00:00:00', 7.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-10 00:00:00', 7.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-11 00:00:00', 10.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-12 00:00:00', 7.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-13 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-14 00:00:00', 6.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-15 00:00:00', 7.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-16 00:00:00', 8.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-17 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-18 00:00:00', 7.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-19 00:00:00', 8.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-20 00:00:00', 11.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-21 00:00:00', 8.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-22 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-23 00:00:00', 8.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-24 00:00:00', 9.97299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-25 00:00:00', 10.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-26 00:00:00', 7.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-27 00:00:00', 4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-28 00:00:00', 3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-29 00:00:00', 5.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-30 00:00:00', 4.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-01-31 00:00:00', 6.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-01 00:00:00', 8.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-02 00:00:00', 7.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-03 00:00:00', 7.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-04 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-05 00:00:00', 7.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-06 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-07 00:00:00', 7.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-08 00:00:00', 8.35999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-09 00:00:00', 10.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-10 00:00:00', 9.77999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-11 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-12 00:00:00', 3.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-13 00:00:00', 5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-14 00:00:00', 7.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-15 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-16 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-17 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-18 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-19 00:00:00', 5.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-20 00:00:00', 9.97500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-21 00:00:00', 13.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-22 00:00:00', 14.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-23 00:00:00', 8.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-24 00:00:00', 8.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-25 00:00:00', 10.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-26 00:00:00', 14.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-27 00:00:00', 15.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-02-28 00:00:00', 16.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-01 00:00:00', 19.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-02 00:00:00', 21.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-03 00:00:00', 22.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-04 00:00:00', 21.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-05 00:00:00', 23.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-06 00:00:00', 23.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-07 00:00:00', 19.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-08 00:00:00', 21.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-09 00:00:00', 21.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-10 00:00:00', 21.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-11 00:00:00', 24.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-12 00:00:00', 27.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-13 00:00:00', 27.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-14 00:00:00', 22.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-15 00:00:00', 21.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-16 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-17 00:00:00', 16.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-18 00:00:00', 18.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-19 00:00:00', 15.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-20 00:00:00', 19.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-21 00:00:00', 21.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-22 00:00:00', 21.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-23 00:00:00', 22.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-24 00:00:00', 22.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-25 00:00:00', 15.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-26 00:00:00', 17.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-27 00:00:00', 11.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-28 00:00:00', 16.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-29 00:00:00', 19.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-30 00:00:00', 21.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-03-31 00:00:00', 24.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-01 00:00:00', 27.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-02 00:00:00', 28.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-03 00:00:00', 28.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-04 00:00:00', 26.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-05 00:00:00', 15.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-06 00:00:00', 13.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-07 00:00:00', 12.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-08 00:00:00', 12.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-09 00:00:00', 14.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-10 00:00:00', 16.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-11 00:00:00', 20.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-12 00:00:00', 21.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-13 00:00:00', 23.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-14 00:00:00', 24.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-15 00:00:00', 26.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-16 00:00:00', 27.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-17 00:00:00', 30.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-18 00:00:00', 33.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-19 00:00:00', 31.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-20 00:00:00', 31.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-21 00:00:00', 33.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-22 00:00:00', 33.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-23 00:00:00', 33.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-24 00:00:00', 31.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-25 00:00:00', 28.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-26 00:00:00', 28.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-27 00:00:00', 26.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-28 00:00:00', 31.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-29 00:00:00', 32.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-04-30 00:00:00', 33.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-01 00:00:00', 34.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-02 00:00:00', 33.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-03 00:00:00', 32.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-04 00:00:00', 33.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-05 00:00:00', 32.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-06 00:00:00', 32.7739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-07 00:00:00', 28.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-08 00:00:00', 22.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-09 00:00:00', 26.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-10 00:00:00', 29.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-11 00:00:00', 31.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-12 00:00:00', 28.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-13 00:00:00', 27.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-14 00:00:00', 28.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-15 00:00:00', 30.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-16 00:00:00', 30.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-17 00:00:00', 30.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-18 00:00:00', 30.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-19 00:00:00', 25.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-20 00:00:00', 25.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-21 00:00:00', 27.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-22 00:00:00', 29.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-23 00:00:00', 28.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-24 00:00:00', 27.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-25 00:00:00', 30.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-26 00:00:00', 30.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-27 00:00:00', 32.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-28 00:00:00', 33.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-29 00:00:00', 33.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-30 00:00:00', 35.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-05-31 00:00:00', 35.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-01 00:00:00', 36.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-02 00:00:00', 35.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-03 00:00:00', 37.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-04 00:00:00', 38.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-05 00:00:00', 37.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-06 00:00:00', 36.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-07 00:00:00', 36.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-08 00:00:00', 37.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-09 00:00:00', 31.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-10 00:00:00', 27.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-11 00:00:00', 29.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-12 00:00:00', 33.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-13 00:00:00', 34.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-14 00:00:00', 35.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-15 00:00:00', 38.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-16 00:00:00', 40.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-17 00:00:00', 41.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-18 00:00:00', 42.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-19 00:00:00', 40.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-20 00:00:00', 40.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-21 00:00:00', 43.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-22 00:00:00', 45.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-23 00:00:00', 45.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-24 00:00:00', 39.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-25 00:00:00', 36.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-26 00:00:00', 37.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-27 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-28 00:00:00', 38.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-29 00:00:00', 38.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-06-30 00:00:00', 39.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-01 00:00:00', 39.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-02 00:00:00', 39.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-03 00:00:00', 39.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-04 00:00:00', 39.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-05 00:00:00', 39.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-06 00:00:00', 41.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-07 00:00:00', 42.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-08 00:00:00', 43.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-09 00:00:00', 44.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-10 00:00:00', 41.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-11 00:00:00', 41.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-12 00:00:00', 40.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-13 00:00:00', 41.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-14 00:00:00', 38.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-15 00:00:00', 38.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-16 00:00:00', 36.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-17 00:00:00', 36.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-18 00:00:00', 37.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-19 00:00:00', 38.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-20 00:00:00', 39.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-21 00:00:00', 40.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-22 00:00:00', 38.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-23 00:00:00', 38.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-24 00:00:00', 39.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-25 00:00:00', 39.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-26 00:00:00', 38.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-27 00:00:00', 38.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-28 00:00:00', 38.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-29 00:00:00', 38.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-30 00:00:00', 38.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-07-31 00:00:00', 39.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-01 00:00:00', 36.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-02 00:00:00', 35.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-03 00:00:00', 36.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-04 00:00:00', 37.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-05 00:00:00', 38.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-06 00:00:00', 39.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-07 00:00:00', 40.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-08 00:00:00', 38.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-09 00:00:00', 39.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-10 00:00:00', 38.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-11 00:00:00', 37.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-12 00:00:00', 36.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-13 00:00:00', 36.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-14 00:00:00', 37.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-15 00:00:00', 37.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-16 00:00:00', 37.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-17 00:00:00', 36.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-18 00:00:00', 35.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-19 00:00:00', 36.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-20 00:00:00', 36.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-21 00:00:00', 37.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-22 00:00:00', 37.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-23 00:00:00', 37.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-24 00:00:00', 34.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-25 00:00:00', 33.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-26 00:00:00', 34.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-27 00:00:00', 28.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-28 00:00:00', 28.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-29 00:00:00', 29.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-30 00:00:00', 30.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-08-31 00:00:00', 34.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-01 00:00:00', 35.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-02 00:00:00', 34.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-03 00:00:00', 36.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-04 00:00:00', 37.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-05 00:00:00', 39.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-06 00:00:00', 39.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-07 00:00:00', 38.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-08 00:00:00', 35.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-09 00:00:00', 33.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-10 00:00:00', 30.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-11 00:00:00', 32.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-12 00:00:00', 34.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-13 00:00:00', 34.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-14 00:00:00', 33.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-15 00:00:00', 35.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-16 00:00:00', 36.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-17 00:00:00', 35.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-18 00:00:00', 33.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-19 00:00:00', 32.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-20 00:00:00', 32.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-21 00:00:00', 32.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-22 00:00:00', 32.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-23 00:00:00', 31.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-24 00:00:00', 31.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-25 00:00:00', 31.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-26 00:00:00', 30.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-27 00:00:00', 28.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-28 00:00:00', 29.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-29 00:00:00', 30.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-09-30 00:00:00', 31.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-01 00:00:00', 33.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-02 00:00:00', 31.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-03 00:00:00', 28.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-04 00:00:00', 28.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-05 00:00:00', 28.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-06 00:00:00', 32.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-07 00:00:00', 33.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-08 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-09 00:00:00', 30.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-10 00:00:00', 28.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-11 00:00:00', 26.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-12 00:00:00', 23.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-13 00:00:00', 21.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-14 00:00:00', 21.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-15 00:00:00', 20.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-16 00:00:00', 20.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-17 00:00:00', 22.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-18 00:00:00', 24.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-19 00:00:00', 26.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-20 00:00:00', 27.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-21 00:00:00', 28.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-22 00:00:00', 27.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-23 00:00:00', 22.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-24 00:00:00', 16.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-25 00:00:00', 17.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-26 00:00:00', 22.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-27 00:00:00', 19.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-28 00:00:00', 23.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-29 00:00:00', 25.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-30 00:00:00', 26.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-10-31 00:00:00', 22.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-01 00:00:00', 17.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-02 00:00:00', 18.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-03 00:00:00', 20.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-04 00:00:00', 21.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-05 00:00:00', 20.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-06 00:00:00', 21.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-07 00:00:00', 15.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-08 00:00:00', 18.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-09 00:00:00', 22.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-10 00:00:00', 13.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-11 00:00:00', 13.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-12 00:00:00', 15.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-13 00:00:00', 16.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-14 00:00:00', 14.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-15 00:00:00', 13.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-16 00:00:00', 13.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-17 00:00:00', 15.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-18 00:00:00', 19.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-19 00:00:00', 20.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-20 00:00:00', 22.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-21 00:00:00', 20.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-22 00:00:00', 19.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-23 00:00:00', 19.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-24 00:00:00', 15.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-25 00:00:00', 13.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-26 00:00:00', 10.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-27 00:00:00', 9.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-28 00:00:00', 10.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-29 00:00:00', 11.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-11-30 00:00:00', 12.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-01 00:00:00', 14.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-02 00:00:00', 13.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-03 00:00:00', 13.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-04 00:00:00', 13.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-05 00:00:00', 12.6129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-06 00:00:00', 16.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-07 00:00:00', 16.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-08 00:00:00', 11.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-09 00:00:00', 11.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-10 00:00:00', 12.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-11 00:00:00', 12.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-12 00:00:00', 9.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-13 00:00:00', 11.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-14 00:00:00', 9.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-15 00:00:00', 12.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-16 00:00:00', 14.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-17 00:00:00', 15.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-18 00:00:00', 17.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-19 00:00:00', 14.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-20 00:00:00', 14.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-21 00:00:00', 15.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-22 00:00:00', 13.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-23 00:00:00', 14.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-24 00:00:00', 14.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-25 00:00:00', 14.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-26 00:00:00', 15.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-27 00:00:00', 12.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-28 00:00:00', 6.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-29 00:00:00', 6.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-30 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2005-12-31 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-01 00:00:00', 0.861000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-02 00:00:00', -0.968999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-03 00:00:00', -3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-04 00:00:00', -0.0419999994337558746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-05 00:00:00', 0.189999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-06 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-07 00:00:00', 7.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-08 00:00:00', 11.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-09 00:00:00', 10.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-10 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-11 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-12 00:00:00', 6.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-13 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-14 00:00:00', 7.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-15 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-16 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-17 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-18 00:00:00', 5.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-19 00:00:00', 6.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-20 00:00:00', 6.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-21 00:00:00', 7.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-22 00:00:00', 9.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-23 00:00:00', 6.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-24 00:00:00', 7.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-25 00:00:00', 10.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-26 00:00:00', 9.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-27 00:00:00', 10.1190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-28 00:00:00', 6.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-29 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-30 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-01-31 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-01 00:00:00', 6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-02 00:00:00', 9.98499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-03 00:00:00', 12.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-04 00:00:00', 17.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-05 00:00:00', 17.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-06 00:00:00', 16.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-07 00:00:00', 17.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-08 00:00:00', 18.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-09 00:00:00', 19.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-10 00:00:00', 16.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-11 00:00:00', 16.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-12 00:00:00', 18.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-13 00:00:00', 17.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-14 00:00:00', 19.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-15 00:00:00', 18.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-16 00:00:00', 16.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-17 00:00:00', 15.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-18 00:00:00', 16.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-19 00:00:00', 11.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-20 00:00:00', 14.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-21 00:00:00', 13.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-22 00:00:00', 14.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-23 00:00:00', 12.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-24 00:00:00', 6.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-25 00:00:00', 8.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-26 00:00:00', 13.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-27 00:00:00', 16.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-02-28 00:00:00', 18.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-01 00:00:00', 16.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-02 00:00:00', 18.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-03 00:00:00', 20.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-04 00:00:00', 19.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-05 00:00:00', 20.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-06 00:00:00', 14.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-07 00:00:00', 16.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-08 00:00:00', 19.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-09 00:00:00', 22.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-10 00:00:00', 24.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-11 00:00:00', 25.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-12 00:00:00', 20.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-13 00:00:00', 11.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-14 00:00:00', 13.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-15 00:00:00', 14.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-16 00:00:00', 16.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-17 00:00:00', 20.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-18 00:00:00', 21.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-19 00:00:00', 20.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-20 00:00:00', 22.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-21 00:00:00', 20.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-22 00:00:00', 19.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-23 00:00:00', 20.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-24 00:00:00', 22.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-25 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-26 00:00:00', 16.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-27 00:00:00', 20.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-28 00:00:00', 24.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-29 00:00:00', 26.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-30 00:00:00', 27.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-03-31 00:00:00', 19.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-01 00:00:00', 19.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-02 00:00:00', 21.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-03 00:00:00', 23.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-04 00:00:00', 27.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-05 00:00:00', 28.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-06 00:00:00', 26.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-07 00:00:00', 29.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-08 00:00:00', 26.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-09 00:00:00', 15.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-10 00:00:00', 15.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-11 00:00:00', 19.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-12 00:00:00', 21.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-13 00:00:00', 23.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-14 00:00:00', 23.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-15 00:00:00', 23.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-16 00:00:00', 25.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-17 00:00:00', 26.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-18 00:00:00', 27.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-19 00:00:00', 30.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-20 00:00:00', 27.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-21 00:00:00', 25.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-22 00:00:00', 28.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-23 00:00:00', 30.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-24 00:00:00', 34.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-25 00:00:00', 35.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-26 00:00:00', 36.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-27 00:00:00', 37.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-28 00:00:00', 34.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-29 00:00:00', 31.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-04-30 00:00:00', 30.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-01 00:00:00', 31.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-02 00:00:00', 32.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-03 00:00:00', 32.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-04 00:00:00', 32.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-05 00:00:00', 33.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-06 00:00:00', 31.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-07 00:00:00', 31.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-08 00:00:00', 33.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-09 00:00:00', 35.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-10 00:00:00', 37.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-11 00:00:00', 36.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-12 00:00:00', 38.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-13 00:00:00', 39.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-14 00:00:00', 38.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-15 00:00:00', 41.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-16 00:00:00', 41.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-17 00:00:00', 37.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-18 00:00:00', 36.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-19 00:00:00', 36.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-20 00:00:00', 38.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-21 00:00:00', 35.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-22 00:00:00', 36.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-23 00:00:00', 35.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-24 00:00:00', 36.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-25 00:00:00', 34.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-26 00:00:00', 34.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-27 00:00:00', 35.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-28 00:00:00', 35.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-29 00:00:00', 35.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-30 00:00:00', 35.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-05-31 00:00:00', 31.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-01 00:00:00', 33.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-02 00:00:00', 34.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-03 00:00:00', 35.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-04 00:00:00', 33.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-05 00:00:00', 35.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-06 00:00:00', 35.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-07 00:00:00', 32.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-08 00:00:00', 32.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-09 00:00:00', 34.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-10 00:00:00', 34.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-11 00:00:00', 34.9490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-12 00:00:00', 36.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-13 00:00:00', 37.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-14 00:00:00', 41.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-15 00:00:00', 38.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-16 00:00:00', 36.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-17 00:00:00', 38.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-18 00:00:00', 39.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-19 00:00:00', 40.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-20 00:00:00', 40.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-21 00:00:00', 41.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-22 00:00:00', 41.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-23 00:00:00', 41.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-24 00:00:00', 41.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-25 00:00:00', 41.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-26 00:00:00', 41.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-27 00:00:00', 40.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-28 00:00:00', 40.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-29 00:00:00', 40.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-06-30 00:00:00', 39.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-01 00:00:00', 32.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-02 00:00:00', 36.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-03 00:00:00', 38.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-04 00:00:00', 39.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-05 00:00:00', 42.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-06 00:00:00', 42.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-07 00:00:00', 41.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-08 00:00:00', 40.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-09 00:00:00', 43.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-10 00:00:00', 41.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-11 00:00:00', 38.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-12 00:00:00', 33.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-13 00:00:00', 30.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-14 00:00:00', 32.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-15 00:00:00', 33.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-16 00:00:00', 35.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-17 00:00:00', 37.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-18 00:00:00', 37.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-19 00:00:00', 37.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-20 00:00:00', 39.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-21 00:00:00', 40.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-22 00:00:00', 42.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-23 00:00:00', 43.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-24 00:00:00', 41.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-25 00:00:00', 41.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-26 00:00:00', 40.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-27 00:00:00', 41.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-28 00:00:00', 38.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-29 00:00:00', 40.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-30 00:00:00', 43.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-07-31 00:00:00', 43.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-01 00:00:00', 42.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-02 00:00:00', 42.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-03 00:00:00', 41.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-04 00:00:00', 40.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-05 00:00:00', 39.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-06 00:00:00', 38.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-07 00:00:00', 39.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-08 00:00:00', 38.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-09 00:00:00', 40.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-10 00:00:00', 40.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-11 00:00:00', 40.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-12 00:00:00', 39.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-13 00:00:00', 41.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-14 00:00:00', 42.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-15 00:00:00', 37.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-16 00:00:00', 35.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-17 00:00:00', 34.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-18 00:00:00', 35.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-19 00:00:00', 37.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-20 00:00:00', 37.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-21 00:00:00', 37.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-22 00:00:00', 37.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-23 00:00:00', 38.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-24 00:00:00', 39.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-25 00:00:00', 39.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-26 00:00:00', 38.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-27 00:00:00', 36.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-28 00:00:00', 36.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-29 00:00:00', 36.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-30 00:00:00', 37.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-08-31 00:00:00', 36.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-01 00:00:00', 35.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-02 00:00:00', 32.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-03 00:00:00', 31.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-04 00:00:00', 30.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-05 00:00:00', 31.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-06 00:00:00', 35.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-07 00:00:00', 35.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-08 00:00:00', 35.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-09 00:00:00', 35.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-10 00:00:00', 35.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-11 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-12 00:00:00', 32.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-13 00:00:00', 32.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-14 00:00:00', 32.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-15 00:00:00', 32.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-16 00:00:00', 35.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-17 00:00:00', 34.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-18 00:00:00', 28.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-19 00:00:00', 25.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-20 00:00:00', 25.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-21 00:00:00', 27.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-22 00:00:00', 29.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-23 00:00:00', 29.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-24 00:00:00', 29.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-25 00:00:00', 28.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-26 00:00:00', 30.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-27 00:00:00', 32.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-28 00:00:00', 33.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-29 00:00:00', 30.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-09-30 00:00:00', 31.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-01 00:00:00', 30.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-02 00:00:00', 31.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-03 00:00:00', 32.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-04 00:00:00', 33.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-05 00:00:00', 31.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-06 00:00:00', 28.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-07 00:00:00', 29.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-08 00:00:00', 29.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-09 00:00:00', 31.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-10 00:00:00', 32.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-11 00:00:00', 31.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-12 00:00:00', 30.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-13 00:00:00', 30.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-14 00:00:00', 27.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-15 00:00:00', 26.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-16 00:00:00', 29.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-17 00:00:00', 30.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-18 00:00:00', 28.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-19 00:00:00', 27.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-20 00:00:00', 24.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-21 00:00:00', 23.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-22 00:00:00', 25.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-23 00:00:00', 26.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-24 00:00:00', 23.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-25 00:00:00', 21.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-26 00:00:00', 23.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-27 00:00:00', 24.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-28 00:00:00', 26.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-29 00:00:00', 26.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-30 00:00:00', 26.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-10-31 00:00:00', 28.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-01 00:00:00', 27.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-02 00:00:00', 26.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-03 00:00:00', 27.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-04 00:00:00', 26.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-05 00:00:00', 28.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-06 00:00:00', 28.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-07 00:00:00', 27.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-08 00:00:00', 26.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-09 00:00:00', 20.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-10 00:00:00', 14.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-11 00:00:00', 18.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-12 00:00:00', 20.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-13 00:00:00', 18.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-14 00:00:00', 18.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-15 00:00:00', 19.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-16 00:00:00', 16.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-17 00:00:00', 14.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-18 00:00:00', 17.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-19 00:00:00', 18.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-20 00:00:00', 13.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-21 00:00:00', 7.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-22 00:00:00', 6.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-23 00:00:00', 8.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-24 00:00:00', 9.56999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-25 00:00:00', 7.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-26 00:00:00', 8.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-27 00:00:00', 7.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-28 00:00:00', 10.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-29 00:00:00', 10.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-11-30 00:00:00', 10.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-01 00:00:00', 4.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-02 00:00:00', 5.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-03 00:00:00', 9.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-04 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-05 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-06 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-07 00:00:00', 7.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-08 00:00:00', 9.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-09 00:00:00', 9.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-10 00:00:00', 8.02999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-11 00:00:00', 6.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-12 00:00:00', 6.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-13 00:00:00', 9.73499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-14 00:00:00', 10.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-15 00:00:00', 10.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-16 00:00:00', 10.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-17 00:00:00', 9.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-18 00:00:00', 12.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-19 00:00:00', 9.85499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-20 00:00:00', 7.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-21 00:00:00', 13.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-22 00:00:00', 13.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-23 00:00:00', 12.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-24 00:00:00', 6.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-25 00:00:00', 5.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-26 00:00:00', 8.73499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-27 00:00:00', 11.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-28 00:00:00', 13.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-29 00:00:00', 12.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-30 00:00:00', 5.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2006-12-31 00:00:00', 5.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-01 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-02 00:00:00', 0.677999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-03 00:00:00', 1.03799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-04 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-05 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-06 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-07 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-08 00:00:00', 6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-09 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-10 00:00:00', 6.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-11 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-12 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-13 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-14 00:00:00', 1.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-15 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-16 00:00:00', 7.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-17 00:00:00', 7.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-18 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-19 00:00:00', 4.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-20 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-21 00:00:00', 8.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-22 00:00:00', 10.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-23 00:00:00', 11.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-24 00:00:00', 8.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-25 00:00:00', 11.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-26 00:00:00', 13.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-27 00:00:00', 13.560999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-28 00:00:00', 15.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-29 00:00:00', 16.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-30 00:00:00', 17.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-01-31 00:00:00', 17.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-01 00:00:00', 16.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-02 00:00:00', 11.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-03 00:00:00', 13.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-04 00:00:00', 12.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-05 00:00:00', 10.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-06 00:00:00', 13.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-07 00:00:00', 14.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-08 00:00:00', 17.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-09 00:00:00', 10.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-10 00:00:00', 9.06200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-11 00:00:00', 9.95600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-12 00:00:00', 9.75399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-13 00:00:00', 10.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-14 00:00:00', 12.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-15 00:00:00', 13.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-16 00:00:00', 13.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-17 00:00:00', 13.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-18 00:00:00', 11.2869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-19 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-20 00:00:00', 12.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-21 00:00:00', 10.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-22 00:00:00', 11.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-23 00:00:00', 14.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-24 00:00:00', 11.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-25 00:00:00', 10.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-26 00:00:00', 7.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-27 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-02-28 00:00:00', 5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-01 00:00:00', 3.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-02 00:00:00', 5.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-03 00:00:00', 10.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-04 00:00:00', 10.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-05 00:00:00', 13.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-06 00:00:00', 15.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-07 00:00:00', 18.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-08 00:00:00', 16.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-09 00:00:00', 8.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-10 00:00:00', 14.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-11 00:00:00', 11.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-12 00:00:00', 10.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-13 00:00:00', 13.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-14 00:00:00', 15.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-15 00:00:00', 18.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-16 00:00:00', 17.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-17 00:00:00', 15.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-18 00:00:00', 14.0679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-19 00:00:00', 14.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-20 00:00:00', 19.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-21 00:00:00', 19.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-22 00:00:00', 21.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-23 00:00:00', 21.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-24 00:00:00', 20.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-25 00:00:00', 21.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-26 00:00:00', 15.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-27 00:00:00', 25.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-28 00:00:00', 21.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-29 00:00:00', 14.2309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-30 00:00:00', 10.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-03-31 00:00:00', 9.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-01 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-02 00:00:00', 16.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-03 00:00:00', 20.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-04 00:00:00', 23.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-05 00:00:00', 23.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-06 00:00:00', 22.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-07 00:00:00', 24.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-08 00:00:00', 27.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-09 00:00:00', 28.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-10 00:00:00', 31.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-11 00:00:00', 31.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-12 00:00:00', 34.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-13 00:00:00', 36.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-14 00:00:00', 32.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-15 00:00:00', 34.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-16 00:00:00', 33.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-17 00:00:00', 31.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-18 00:00:00', 32.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-19 00:00:00', 32.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-20 00:00:00', 34.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-21 00:00:00', 33.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-22 00:00:00', 30.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-23 00:00:00', 31.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-24 00:00:00', 31.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-25 00:00:00', 32.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-26 00:00:00', 35.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-27 00:00:00', 30.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-28 00:00:00', 32.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-29 00:00:00', 34.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-04-30 00:00:00', 34.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-01 00:00:00', 37.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-02 00:00:00', 33.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-03 00:00:00', 35.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-04 00:00:00', 36.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-05 00:00:00', 35.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-06 00:00:00', 34.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-07 00:00:00', 22.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-08 00:00:00', 27.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-09 00:00:00', 30.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-10 00:00:00', 34.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-11 00:00:00', 35.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-12 00:00:00', 36.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-13 00:00:00', 35.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-14 00:00:00', 38.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-15 00:00:00', 39.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-16 00:00:00', 28.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-17 00:00:00', 22.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-18 00:00:00', 26.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-19 00:00:00', 24.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-20 00:00:00', 27.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-21 00:00:00', 29.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-22 00:00:00', 31.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-23 00:00:00', 32.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-24 00:00:00', 33.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-25 00:00:00', 34.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-26 00:00:00', 34.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-27 00:00:00', 35.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-28 00:00:00', 34.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-29 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-30 00:00:00', 37.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-05-31 00:00:00', 36.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-01 00:00:00', 36.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-02 00:00:00', 38.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-03 00:00:00', 36.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-04 00:00:00', 36.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-05 00:00:00', 33.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-06 00:00:00', 33.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-07 00:00:00', 35.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-08 00:00:00', 37.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-09 00:00:00', 40.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-10 00:00:00', 41.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-11 00:00:00', 41.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-12 00:00:00', 40.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-13 00:00:00', 40.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-14 00:00:00', 40.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-15 00:00:00', 37.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-16 00:00:00', 35.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-17 00:00:00', 36.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-18 00:00:00', 37.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-19 00:00:00', 38.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-20 00:00:00', 39.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-21 00:00:00', 42.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-22 00:00:00', 43.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-23 00:00:00', 45.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-24 00:00:00', 42.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-25 00:00:00', 41.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-26 00:00:00', 41.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-27 00:00:00', 41.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-28 00:00:00', 40.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-29 00:00:00', 38.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-06-30 00:00:00', 39.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-01 00:00:00', 40.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-02 00:00:00', 38.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-03 00:00:00', 39.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-04 00:00:00', 40.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-05 00:00:00', 40.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-06 00:00:00', 40.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-07 00:00:00', 38.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-08 00:00:00', 37.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-09 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-10 00:00:00', 41.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-11 00:00:00', 40.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-12 00:00:00', 39.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-13 00:00:00', 39.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-14 00:00:00', 38.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-15 00:00:00', 38.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-16 00:00:00', 38.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-17 00:00:00', 38.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-18 00:00:00', 40.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-19 00:00:00', 42.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-20 00:00:00', 41.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-21 00:00:00', 36.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-22 00:00:00', 36.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-23 00:00:00', 38.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-24 00:00:00', 39.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-25 00:00:00', 39.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-26 00:00:00', 37.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-27 00:00:00', 36.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-28 00:00:00', 36.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-29 00:00:00', 38.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-30 00:00:00', 38.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-07-31 00:00:00', 38.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-01 00:00:00', 39.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-02 00:00:00', 38.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-03 00:00:00', 37.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-04 00:00:00', 36.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-05 00:00:00', 37.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-06 00:00:00', 37.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-07 00:00:00', 38.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-08 00:00:00', 39.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-09 00:00:00', 40.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-10 00:00:00', 41.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-11 00:00:00', 39.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-12 00:00:00', 33.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-13 00:00:00', 35.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-14 00:00:00', 36.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-15 00:00:00', 36.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-16 00:00:00', 35.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-17 00:00:00', 34.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-18 00:00:00', 36.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-19 00:00:00', 36.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-20 00:00:00', 37.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-21 00:00:00', 36.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-22 00:00:00', 36.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-23 00:00:00', 36.8170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-24 00:00:00', 37.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-25 00:00:00', 37.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-26 00:00:00', 36.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-27 00:00:00', 36.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-28 00:00:00', 36.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-29 00:00:00', 36.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-30 00:00:00', 37.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-08-31 00:00:00', 37.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-01 00:00:00', 37.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-02 00:00:00', 38.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-03 00:00:00', 37.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-04 00:00:00', 36.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-05 00:00:00', 33.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-06 00:00:00', 34.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-07 00:00:00', 34.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-08 00:00:00', 33.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-09 00:00:00', 34.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-10 00:00:00', 35.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-11 00:00:00', 36.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-12 00:00:00', 36.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-13 00:00:00', 35.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-14 00:00:00', 35.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-15 00:00:00', 34.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-16 00:00:00', 33.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-17 00:00:00', 35.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-18 00:00:00', 34.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-19 00:00:00', 33.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-20 00:00:00', 31.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-21 00:00:00', 28.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-22 00:00:00', 26.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-23 00:00:00', 26.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-24 00:00:00', 27.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-25 00:00:00', 27.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-26 00:00:00', 25.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-27 00:00:00', 25.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-28 00:00:00', 23.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-29 00:00:00', 24.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-09-30 00:00:00', 27.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-01 00:00:00', 26.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-02 00:00:00', 24.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-03 00:00:00', 22.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-04 00:00:00', 20.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-05 00:00:00', 20.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-06 00:00:00', 21.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-07 00:00:00', 21.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-08 00:00:00', 22.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-09 00:00:00', 22.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-10 00:00:00', 21.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-11 00:00:00', 23.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-12 00:00:00', 24.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-13 00:00:00', 25.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-14 00:00:00', 26.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-15 00:00:00', 26.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-16 00:00:00', 26.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-17 00:00:00', 26.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-18 00:00:00', 28.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-19 00:00:00', 21.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-20 00:00:00', 20.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-21 00:00:00', 23.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-22 00:00:00', 24.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-23 00:00:00', 22.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-24 00:00:00', 21.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-25 00:00:00', 20.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-26 00:00:00', 19.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-27 00:00:00', 21.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-28 00:00:00', 21.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-29 00:00:00', 18.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-30 00:00:00', 20.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-10-31 00:00:00', 23.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-01 00:00:00', 25.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-02 00:00:00', 24.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-03 00:00:00', 23.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-04 00:00:00', 26.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-05 00:00:00', 21.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-06 00:00:00', 26.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-07 00:00:00', 24.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-08 00:00:00', 24.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-09 00:00:00', 19.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-10 00:00:00', 22.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-11 00:00:00', 22.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-12 00:00:00', 23.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-13 00:00:00', 20.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-14 00:00:00', 18.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-15 00:00:00', 19.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-16 00:00:00', 19.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-17 00:00:00', 19.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-18 00:00:00', 19.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-19 00:00:00', 20.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-20 00:00:00', 18.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-21 00:00:00', 20.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-22 00:00:00', 22.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-23 00:00:00', 20.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-24 00:00:00', 14.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-25 00:00:00', 17.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-26 00:00:00', 17.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-27 00:00:00', 14.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-28 00:00:00', 15.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-29 00:00:00', 18.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-11-30 00:00:00', 13.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-01 00:00:00', 5.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-02 00:00:00', 11.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-03 00:00:00', 13.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-04 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-05 00:00:00', 14.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-06 00:00:00', 12.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-07 00:00:00', 12.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-08 00:00:00', 13.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-09 00:00:00', 8.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-10 00:00:00', 8.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-11 00:00:00', 7.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-12 00:00:00', 7.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-13 00:00:00', 6.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-14 00:00:00', 7.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-15 00:00:00', 10.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-16 00:00:00', 10.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-17 00:00:00', 9.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-18 00:00:00', 7.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-19 00:00:00', 7.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-20 00:00:00', 8.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-21 00:00:00', 8.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-22 00:00:00', 10.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-23 00:00:00', 5.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-24 00:00:00', 6.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-25 00:00:00', 3.79800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-26 00:00:00', 1.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-27 00:00:00', -0.133000001311302185, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-28 00:00:00', -0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-29 00:00:00', 0.243000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-30 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2007-12-31 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-01 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-02 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-03 00:00:00', 7.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-04 00:00:00', 5.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-05 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-06 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-07 00:00:00', 2.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-08 00:00:00', -2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-09 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-10 00:00:00', 0.731999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-11 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-12 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-13 00:00:00', -1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-14 00:00:00', -2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-15 00:00:00', -1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-16 00:00:00', -3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-17 00:00:00', -3.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-18 00:00:00', -2.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-19 00:00:00', -5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-20 00:00:00', -5.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-21 00:00:00', -4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-22 00:00:00', -5.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-23 00:00:00', -4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-24 00:00:00', -2.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-25 00:00:00', -3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-26 00:00:00', -2.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-27 00:00:00', 0.967000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-28 00:00:00', 0.944999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-29 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-30 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-01-31 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-01 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-02 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-03 00:00:00', -0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-04 00:00:00', -0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-05 00:00:00', -2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-06 00:00:00', -2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-07 00:00:00', -1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-08 00:00:00', 0.674000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-09 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-10 00:00:00', -1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-11 00:00:00', 0.224000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-12 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-13 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-14 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-15 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-16 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-17 00:00:00', 6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-18 00:00:00', 8.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-19 00:00:00', 12.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-20 00:00:00', 15.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-21 00:00:00', 8.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-22 00:00:00', 7.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-23 00:00:00', 8.31000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-24 00:00:00', 10.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-25 00:00:00', 12.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-26 00:00:00', 14.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-27 00:00:00', 20.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-28 00:00:00', 17.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-02-29 00:00:00', 17.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-01 00:00:00', 16.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-02 00:00:00', 18.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-03 00:00:00', 20.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-04 00:00:00', 20.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-05 00:00:00', 15.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-06 00:00:00', 10.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-07 00:00:00', 15.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-08 00:00:00', 19.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-09 00:00:00', 17.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-10 00:00:00', 19.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-11 00:00:00', 21.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-12 00:00:00', 20.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-13 00:00:00', 24.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-14 00:00:00', 25.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-15 00:00:00', 27.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-16 00:00:00', 25.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-17 00:00:00', 22.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-18 00:00:00', 22.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-19 00:00:00', 23.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-20 00:00:00', 25.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-21 00:00:00', 26.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-22 00:00:00', 28.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-23 00:00:00', 29.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-24 00:00:00', 29.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-25 00:00:00', 28.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-26 00:00:00', 27.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-27 00:00:00', 29.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-28 00:00:00', 30.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-29 00:00:00', 29.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-30 00:00:00', 30.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-03-31 00:00:00', 26.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-01 00:00:00', 27.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-02 00:00:00', 28.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-03 00:00:00', 30.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-04 00:00:00', 19.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-05 00:00:00', 24.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-06 00:00:00', 23.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-07 00:00:00', 19.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-08 00:00:00', 24.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-09 00:00:00', 28.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-10 00:00:00', 23.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-11 00:00:00', 26.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-12 00:00:00', 26.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-13 00:00:00', 26.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-14 00:00:00', 21.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-15 00:00:00', 21.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-16 00:00:00', 24.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-17 00:00:00', 26.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-18 00:00:00', 28.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-19 00:00:00', 28.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-20 00:00:00', 30.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-21 00:00:00', 31.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-22 00:00:00', 26.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-23 00:00:00', 28.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-24 00:00:00', 30.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-25 00:00:00', 31.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-26 00:00:00', 33.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-27 00:00:00', 33.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-28 00:00:00', 34.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-29 00:00:00', 36.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-04-30 00:00:00', 36.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-01 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-02 00:00:00', 36.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-03 00:00:00', 36.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-04 00:00:00', 30.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-05 00:00:00', 29.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-06 00:00:00', 31.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-07 00:00:00', 35.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-08 00:00:00', 35.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-09 00:00:00', 33.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-10 00:00:00', 34.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-11 00:00:00', 38.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-12 00:00:00', 37.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-13 00:00:00', 35.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-14 00:00:00', 38.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-15 00:00:00', 37.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-16 00:00:00', 33.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-17 00:00:00', 35.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-18 00:00:00', 36.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-19 00:00:00', 36.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-20 00:00:00', 37.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-21 00:00:00', 37.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-22 00:00:00', 34.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-23 00:00:00', 33.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-24 00:00:00', 33.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-25 00:00:00', 32.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-26 00:00:00', 32.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-27 00:00:00', 34.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-28 00:00:00', 36.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-29 00:00:00', 37.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-30 00:00:00', 39.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-05-31 00:00:00', 37.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-01 00:00:00', 38.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-02 00:00:00', 39.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-03 00:00:00', 38.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-04 00:00:00', 40.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-05 00:00:00', 41.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-06 00:00:00', 40.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-07 00:00:00', 39.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-08 00:00:00', 40.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-09 00:00:00', 42.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-10 00:00:00', 41.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-11 00:00:00', 39.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-12 00:00:00', 42.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-13 00:00:00', 44.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-14 00:00:00', 43.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-15 00:00:00', 39.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-16 00:00:00', 39.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-17 00:00:00', 39.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-18 00:00:00', 39.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-19 00:00:00', 40.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-20 00:00:00', 40.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-21 00:00:00', 41.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-22 00:00:00', 40.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-23 00:00:00', 40.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-24 00:00:00', 40.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-25 00:00:00', 42.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-26 00:00:00', 40.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-27 00:00:00', 38.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-28 00:00:00', 38.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-29 00:00:00', 36.1500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-06-30 00:00:00', 35.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-01 00:00:00', 37.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-02 00:00:00', 37.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-03 00:00:00', 40.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-04 00:00:00', 40.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-05 00:00:00', 41.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-06 00:00:00', 41.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-07 00:00:00', 41.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-08 00:00:00', 39.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-09 00:00:00', 38.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-10 00:00:00', 39.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-11 00:00:00', 40.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-12 00:00:00', 41.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-13 00:00:00', 41.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-14 00:00:00', 42.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-15 00:00:00', 41.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-16 00:00:00', 39.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-17 00:00:00', 39.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-18 00:00:00', 40.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-19 00:00:00', 40.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-20 00:00:00', 38.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-21 00:00:00', 39.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-22 00:00:00', 38.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-23 00:00:00', 38.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-24 00:00:00', 38.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-25 00:00:00', 37.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-26 00:00:00', 37.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-27 00:00:00', 38.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-28 00:00:00', 40.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-29 00:00:00', 41.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-30 00:00:00', 42.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-07-31 00:00:00', 43.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-01 00:00:00', 44.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-02 00:00:00', 44.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-03 00:00:00', 45.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-04 00:00:00', 40.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-05 00:00:00', 37.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-06 00:00:00', 40.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-07 00:00:00', 41.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-08 00:00:00', 42.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-09 00:00:00', 43.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-10 00:00:00', 39.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-11 00:00:00', 35.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-12 00:00:00', 35.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-13 00:00:00', 37.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-14 00:00:00', 38.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-15 00:00:00', 37.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-16 00:00:00', 35.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-17 00:00:00', 35.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-18 00:00:00', 36.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-19 00:00:00', 37.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-20 00:00:00', 37.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-21 00:00:00', 37.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-22 00:00:00', 37.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-23 00:00:00', 38.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-24 00:00:00', 38.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-25 00:00:00', 38.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-26 00:00:00', 39.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-27 00:00:00', 38.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-28 00:00:00', 36.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-29 00:00:00', 36.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-30 00:00:00', 36.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-08-31 00:00:00', 35.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-01 00:00:00', 35.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-02 00:00:00', 37.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-03 00:00:00', 36.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-04 00:00:00', 34.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-05 00:00:00', 30.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-06 00:00:00', 29.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-07 00:00:00', 30.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-08 00:00:00', 31.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-09 00:00:00', 33.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-10 00:00:00', 34.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-11 00:00:00', 35.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-12 00:00:00', 39.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-13 00:00:00', 38.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-14 00:00:00', 36.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-15 00:00:00', 34.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-16 00:00:00', 33.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-17 00:00:00', 33.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-18 00:00:00', 32.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-19 00:00:00', 31.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-20 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-21 00:00:00', 27.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-22 00:00:00', 27.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-23 00:00:00', 27.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-24 00:00:00', 29.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-25 00:00:00', 31.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-26 00:00:00', 34.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-27 00:00:00', 32.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-28 00:00:00', 32.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-29 00:00:00', 33.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-09-30 00:00:00', 27.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-01 00:00:00', 29.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-02 00:00:00', 35.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-03 00:00:00', 31.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-04 00:00:00', 28.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-05 00:00:00', 27.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-06 00:00:00', 28.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-07 00:00:00', 27.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-08 00:00:00', 27.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-09 00:00:00', 28.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-10 00:00:00', 30.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-11 00:00:00', 26.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-12 00:00:00', 27.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-13 00:00:00', 23.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-14 00:00:00', 24.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-15 00:00:00', 25.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-16 00:00:00', 25.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-17 00:00:00', 28.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-18 00:00:00', 28.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-19 00:00:00', 25.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-20 00:00:00', 23.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-21 00:00:00', 24.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-22 00:00:00', 24.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-23 00:00:00', 25.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-24 00:00:00', 19.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-25 00:00:00', 19.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-26 00:00:00', 23.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-27 00:00:00', 23.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-28 00:00:00', 13.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-29 00:00:00', 14.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-30 00:00:00', 14.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-10-31 00:00:00', 14.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-01 00:00:00', 12.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-02 00:00:00', 15.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-03 00:00:00', 17.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-04 00:00:00', 22.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-05 00:00:00', 20.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-06 00:00:00', 21.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-07 00:00:00', 22.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-08 00:00:00', 17.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-09 00:00:00', 12.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-10 00:00:00', 12.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-11 00:00:00', 9.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-12 00:00:00', 4.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-13 00:00:00', 6.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-14 00:00:00', 8.58100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-15 00:00:00', 10.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-16 00:00:00', 12.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-17 00:00:00', 10.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-18 00:00:00', 14.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-19 00:00:00', 13.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-20 00:00:00', 14.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-21 00:00:00', 15.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-22 00:00:00', 16.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-23 00:00:00', 20.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-24 00:00:00', 18.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-25 00:00:00', 20.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-26 00:00:00', 21.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-27 00:00:00', 21.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-28 00:00:00', 22.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-29 00:00:00', 20.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-11-30 00:00:00', 20.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-01 00:00:00', 19.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-02 00:00:00', 19.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-03 00:00:00', 16.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-04 00:00:00', 13.9429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-05 00:00:00', 12.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-06 00:00:00', 11.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-07 00:00:00', 13.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-08 00:00:00', 7.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-09 00:00:00', 12.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-10 00:00:00', 13.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-11 00:00:00', 14.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-12 00:00:00', 15.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-13 00:00:00', 15.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-14 00:00:00', 11.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-15 00:00:00', 16.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-16 00:00:00', 9.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-17 00:00:00', 4.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-18 00:00:00', 1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-19 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-20 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-21 00:00:00', 1.4299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-22 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-23 00:00:00', 7.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-24 00:00:00', 12.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-25 00:00:00', 15.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-26 00:00:00', 15.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-27 00:00:00', 8.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-28 00:00:00', 8.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-29 00:00:00', 9.34500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-30 00:00:00', 10.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2008-12-31 00:00:00', 12.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-01 00:00:00', 12.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-02 00:00:00', 10.2869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-03 00:00:00', 7.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-04 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-05 00:00:00', 8.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-06 00:00:00', 9.51799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-07 00:00:00', 9.79599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-08 00:00:00', 12.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-09 00:00:00', 12.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-10 00:00:00', 11.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-11 00:00:00', 6.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-12 00:00:00', 11.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-13 00:00:00', 7.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-14 00:00:00', 6.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-15 00:00:00', 8.67099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-16 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-17 00:00:00', 7.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-18 00:00:00', 11.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-19 00:00:00', 11.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-20 00:00:00', 14.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-21 00:00:00', 14.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-22 00:00:00', 15.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-23 00:00:00', 12.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-24 00:00:00', 11.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-25 00:00:00', 8.37899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-26 00:00:00', 12.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-27 00:00:00', 12.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-28 00:00:00', 14.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-29 00:00:00', 9.15200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-30 00:00:00', 11.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-01-31 00:00:00', 14.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-01 00:00:00', 15.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-02 00:00:00', 15.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-03 00:00:00', 9.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-04 00:00:00', 6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-05 00:00:00', 5.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-06 00:00:00', 8.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-07 00:00:00', 13.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-08 00:00:00', 16.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-09 00:00:00', 12.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-10 00:00:00', 12.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-11 00:00:00', 10.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-12 00:00:00', 12.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-13 00:00:00', 11.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-14 00:00:00', 11.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-15 00:00:00', 13.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-16 00:00:00', 15.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-17 00:00:00', 13.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-18 00:00:00', 16.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-19 00:00:00', 11.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-20 00:00:00', 8.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-21 00:00:00', 14.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-22 00:00:00', 11.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-23 00:00:00', 9.45400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-24 00:00:00', 12.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-25 00:00:00', 12.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-26 00:00:00', 14.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-27 00:00:00', 15.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-02-28 00:00:00', 17.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-01 00:00:00', 18.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-02 00:00:00', 20.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-03 00:00:00', 13.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-04 00:00:00', 15.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-05 00:00:00', 16.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-06 00:00:00', 13.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-07 00:00:00', 14.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-08 00:00:00', 16.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-09 00:00:00', 19.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-10 00:00:00', 19.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-11 00:00:00', 24.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-12 00:00:00', 24.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-13 00:00:00', 25.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-14 00:00:00', 26.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-15 00:00:00', 27.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-16 00:00:00', 27.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-17 00:00:00', 26.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-18 00:00:00', 17.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-19 00:00:00', 17.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-20 00:00:00', 21.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-21 00:00:00', 23.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-22 00:00:00', 23.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-23 00:00:00', 20.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-24 00:00:00', 21.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-25 00:00:00', 24.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-26 00:00:00', 19.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-27 00:00:00', 19.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-28 00:00:00', 23.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-29 00:00:00', 22.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-30 00:00:00', 24.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-03-31 00:00:00', 25.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-01 00:00:00', 23.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-02 00:00:00', 15.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-03 00:00:00', 20.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-04 00:00:00', 24.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-05 00:00:00', 19.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-06 00:00:00', 17.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-07 00:00:00', 17.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-08 00:00:00', 20.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-09 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-10 00:00:00', 21.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-11 00:00:00', 21.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-12 00:00:00', 24.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-13 00:00:00', 24.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-14 00:00:00', 19.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-15 00:00:00', 11.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-16 00:00:00', 17.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-17 00:00:00', 24.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-18 00:00:00', 28.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-19 00:00:00', 29.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-20 00:00:00', 27.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-21 00:00:00', 19.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-22 00:00:00', 21.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-23 00:00:00', 24.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-24 00:00:00', 27.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-25 00:00:00', 25.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-26 00:00:00', 22.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-27 00:00:00', 16.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-28 00:00:00', 19.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-29 00:00:00', 25.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-04-30 00:00:00', 29.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-01 00:00:00', 32.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-02 00:00:00', 30.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-03 00:00:00', 26.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-04 00:00:00', 26.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-05 00:00:00', 26.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-06 00:00:00', 28.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-07 00:00:00', 31.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-08 00:00:00', 27.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-09 00:00:00', 27.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-10 00:00:00', 28.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-11 00:00:00', 29.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-12 00:00:00', 31.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-13 00:00:00', 32.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-14 00:00:00', 32.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-15 00:00:00', 30.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-16 00:00:00', 31.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-17 00:00:00', 35.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-18 00:00:00', 35.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-19 00:00:00', 30.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-20 00:00:00', 31.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-21 00:00:00', 32.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-22 00:00:00', 31.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-23 00:00:00', 34.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-24 00:00:00', 33.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-25 00:00:00', 32.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-26 00:00:00', 35.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-27 00:00:00', 36.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-28 00:00:00', 38.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-29 00:00:00', 37.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-30 00:00:00', 39.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-05-31 00:00:00', 35.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-01 00:00:00', 30.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-02 00:00:00', 29.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-03 00:00:00', 30.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-04 00:00:00', 31.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-05 00:00:00', 31.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-06 00:00:00', 30.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-07 00:00:00', 32.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-08 00:00:00', 32.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-09 00:00:00', 33.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-10 00:00:00', 38.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-11 00:00:00', 36.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-12 00:00:00', 35.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-13 00:00:00', 36.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-14 00:00:00', 37.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-15 00:00:00', 36.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-16 00:00:00', 36.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-17 00:00:00', 36.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-18 00:00:00', 33.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-19 00:00:00', 36.4129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-20 00:00:00', 37.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-21 00:00:00', 38.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-22 00:00:00', 38.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-23 00:00:00', 36.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-24 00:00:00', 39.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-25 00:00:00', 37.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-26 00:00:00', 38.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-27 00:00:00', 39.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-28 00:00:00', 39.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-29 00:00:00', 36.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-06-30 00:00:00', 33.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-01 00:00:00', 35.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-02 00:00:00', 36.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-03 00:00:00', 32.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-04 00:00:00', 33.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-05 00:00:00', 36.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-06 00:00:00', 39.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-07 00:00:00', 41.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-08 00:00:00', 41.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-09 00:00:00', 40.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-10 00:00:00', 39.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-11 00:00:00', 39.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-12 00:00:00', 39.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-13 00:00:00', 37.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-14 00:00:00', 37.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-15 00:00:00', 38.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-16 00:00:00', 40.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-17 00:00:00', 40.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-18 00:00:00', 39.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-19 00:00:00', 40.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-20 00:00:00', 39.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-21 00:00:00', 40.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-22 00:00:00', 40.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-23 00:00:00', 40.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-24 00:00:00', 39.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-25 00:00:00', 41.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-26 00:00:00', 42.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-27 00:00:00', 44.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-28 00:00:00', 43.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-29 00:00:00', 41.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-30 00:00:00', 38.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-07-31 00:00:00', 39.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-01 00:00:00', 40.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-02 00:00:00', 41.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-03 00:00:00', 41.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-04 00:00:00', 38.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-05 00:00:00', 38.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-06 00:00:00', 37.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-07 00:00:00', 37.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-08 00:00:00', 38.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-09 00:00:00', 39.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-10 00:00:00', 41.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-11 00:00:00', 41.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-12 00:00:00', 41.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-13 00:00:00', 44.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-14 00:00:00', 43.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-15 00:00:00', 41.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-16 00:00:00', 38.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-17 00:00:00', 37.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-18 00:00:00', 37.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-19 00:00:00', 35.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-20 00:00:00', 35.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-21 00:00:00', 34.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-22 00:00:00', 35.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-23 00:00:00', 36.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-24 00:00:00', 38.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-25 00:00:00', 33.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-26 00:00:00', 34.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-27 00:00:00', 35.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-28 00:00:00', 38.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-29 00:00:00', 37.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-30 00:00:00', 34.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-08-31 00:00:00', 35.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-01 00:00:00', 35.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-02 00:00:00', 32.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-03 00:00:00', 31.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-04 00:00:00', 31.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-05 00:00:00', 29.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-06 00:00:00', 29.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-07 00:00:00', 29.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-08 00:00:00', 28.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-09 00:00:00', 27.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-10 00:00:00', 28.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-11 00:00:00', 31.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-12 00:00:00', 32.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-13 00:00:00', 35.9550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-14 00:00:00', 36.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-15 00:00:00', 36.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-16 00:00:00', 31.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-17 00:00:00', 32.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-18 00:00:00', 36.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-19 00:00:00', 37.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-20 00:00:00', 36.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-21 00:00:00', 36.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-22 00:00:00', 35.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-23 00:00:00', 34.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-24 00:00:00', 35.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-25 00:00:00', 33.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-26 00:00:00', 28.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-27 00:00:00', 29.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-28 00:00:00', 32.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-29 00:00:00', 32.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-09-30 00:00:00', 35.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-01 00:00:00', 34.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-02 00:00:00', 30.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-03 00:00:00', 26.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-04 00:00:00', 26.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-05 00:00:00', 26.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-06 00:00:00', 27.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-07 00:00:00', 26.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-08 00:00:00', 25.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-09 00:00:00', 22.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-10 00:00:00', 22.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-11 00:00:00', 24.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-12 00:00:00', 26.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-13 00:00:00', 25.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-14 00:00:00', 25.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-15 00:00:00', 26.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-16 00:00:00', 25.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-17 00:00:00', 23.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-18 00:00:00', 22.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-19 00:00:00', 23.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-20 00:00:00', 23.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-21 00:00:00', 22.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-22 00:00:00', 22.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-23 00:00:00', 22.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-24 00:00:00', 20.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-25 00:00:00', 22.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-26 00:00:00', 23.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-27 00:00:00', 22.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-28 00:00:00', 18.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-29 00:00:00', 21.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-30 00:00:00', 22.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-10-31 00:00:00', 25.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-01 00:00:00', 26.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-02 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-03 00:00:00', 26.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-04 00:00:00', 25.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-05 00:00:00', 25.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-06 00:00:00', 25.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-07 00:00:00', 16.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-08 00:00:00', 13.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-09 00:00:00', 10.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-10 00:00:00', 11.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-11 00:00:00', 18.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-12 00:00:00', 17.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-13 00:00:00', 18.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-14 00:00:00', 15.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-15 00:00:00', 11.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-16 00:00:00', 12.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-17 00:00:00', 13.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-18 00:00:00', 15.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-19 00:00:00', 18.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-20 00:00:00', 17.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-21 00:00:00', 17.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-22 00:00:00', 18.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-23 00:00:00', 11.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-24 00:00:00', 11.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-25 00:00:00', 11.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-26 00:00:00', 12.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-27 00:00:00', 13.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-28 00:00:00', 11.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-29 00:00:00', 13.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-11-30 00:00:00', 13.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-01 00:00:00', 12.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-02 00:00:00', 13.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-03 00:00:00', 10.508000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-04 00:00:00', 7.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-05 00:00:00', 8.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-06 00:00:00', 9.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-07 00:00:00', 10.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-08 00:00:00', 12.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-09 00:00:00', 8.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-10 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-11 00:00:00', 8.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-12 00:00:00', 7.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-13 00:00:00', 10.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-14 00:00:00', 11.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-15 00:00:00', 11.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-16 00:00:00', 9.35000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-17 00:00:00', 11.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-18 00:00:00', 12.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-19 00:00:00', 14.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-20 00:00:00', 12.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-21 00:00:00', 11.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-22 00:00:00', 11.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-23 00:00:00', 12.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-24 00:00:00', 12.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-25 00:00:00', 13.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-26 00:00:00', 11.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-27 00:00:00', 12.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-28 00:00:00', 10.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-29 00:00:00', 12.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-30 00:00:00', 14.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2009-12-31 00:00:00', 15.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-01 00:00:00', 17.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-02 00:00:00', 17.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-03 00:00:00', 16.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-04 00:00:00', 15.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-05 00:00:00', 15.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-06 00:00:00', 14.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-07 00:00:00', 6.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-08 00:00:00', 7.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-09 00:00:00', 6.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-10 00:00:00', 6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-11 00:00:00', 8.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-12 00:00:00', 12.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-13 00:00:00', 12.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-14 00:00:00', 14.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-15 00:00:00', 14.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-16 00:00:00', 16.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-17 00:00:00', 15.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-18 00:00:00', 11.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-19 00:00:00', 11.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-20 00:00:00', 17.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-21 00:00:00', 16.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-22 00:00:00', 13.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-23 00:00:00', 10.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-24 00:00:00', 12.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-25 00:00:00', 15.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-26 00:00:00', 16.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-27 00:00:00', 11.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-28 00:00:00', 7.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-29 00:00:00', 8.02200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-30 00:00:00', 12.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-01-31 00:00:00', 11.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-01 00:00:00', 13.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-02 00:00:00', 12.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-03 00:00:00', 13.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-04 00:00:00', 12.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-05 00:00:00', 11.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-06 00:00:00', 11.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-07 00:00:00', 6.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-08 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-09 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-10 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-11 00:00:00', 8.33600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-12 00:00:00', 6.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-13 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-14 00:00:00', -0.0480000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-15 00:00:00', 1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-16 00:00:00', 6.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-17 00:00:00', 11.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-18 00:00:00', 10.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-19 00:00:00', 14.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-20 00:00:00', 16.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-21 00:00:00', 21.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-22 00:00:00', 18.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-23 00:00:00', 16.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-24 00:00:00', 13.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-25 00:00:00', 18.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-26 00:00:00', 14.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-27 00:00:00', 11.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-02-28 00:00:00', 10.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-01 00:00:00', 16.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-02 00:00:00', 17.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-03 00:00:00', 16.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-04 00:00:00', 15.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-05 00:00:00', 17.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-06 00:00:00', 14.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-07 00:00:00', 18.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-08 00:00:00', 21.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-09 00:00:00', 20.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-10 00:00:00', 23.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-11 00:00:00', 25.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-12 00:00:00', 17.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-13 00:00:00', 22.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-14 00:00:00', 25.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-15 00:00:00', 27.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-16 00:00:00', 29.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-17 00:00:00', 31.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-18 00:00:00', 28.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-19 00:00:00', 32.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-20 00:00:00', 18.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-21 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-22 00:00:00', 11.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-23 00:00:00', 15.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-24 00:00:00', 19.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-25 00:00:00', 21.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-26 00:00:00', 22.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-27 00:00:00', 20.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-28 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-29 00:00:00', 24.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-30 00:00:00', 18.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-03-31 00:00:00', 22.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-01 00:00:00', 24.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-02 00:00:00', 25.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-03 00:00:00', 19.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-04 00:00:00', 22.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-05 00:00:00', 25.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-06 00:00:00', 25.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-07 00:00:00', 24.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-08 00:00:00', 29.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-09 00:00:00', 30.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-10 00:00:00', 28.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-11 00:00:00', 27.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-12 00:00:00', 22.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-13 00:00:00', 26.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-14 00:00:00', 32.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-15 00:00:00', 26.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-16 00:00:00', 29.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-17 00:00:00', 27.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-18 00:00:00', 28.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-19 00:00:00', 30.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-20 00:00:00', 23.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-21 00:00:00', 22.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-22 00:00:00', 25.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-23 00:00:00', 28.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-24 00:00:00', 30.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-25 00:00:00', 30.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-26 00:00:00', 29.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-27 00:00:00', 29.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-28 00:00:00', 32.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-29 00:00:00', 30.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-04-30 00:00:00', 33.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-01 00:00:00', 29.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-02 00:00:00', 29.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-03 00:00:00', 32.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-04 00:00:00', 29.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-05 00:00:00', 26.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-06 00:00:00', 29.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-07 00:00:00', 29.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-08 00:00:00', 31.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-09 00:00:00', 31.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-10 00:00:00', 29.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-11 00:00:00', 28.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-12 00:00:00', 31.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-13 00:00:00', 31.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-14 00:00:00', 31.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-15 00:00:00', 32.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-16 00:00:00', 24.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-17 00:00:00', 27.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-18 00:00:00', 30.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-19 00:00:00', 33.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-20 00:00:00', 34.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-21 00:00:00', 26.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-22 00:00:00', 33.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-23 00:00:00', 32.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-24 00:00:00', 32.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-25 00:00:00', 36.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-26 00:00:00', 32.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-27 00:00:00', 31.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-28 00:00:00', 31.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-29 00:00:00', 33.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-30 00:00:00', 36.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-05-31 00:00:00', 37.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-01 00:00:00', 37.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-02 00:00:00', 30.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-03 00:00:00', 31.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-04 00:00:00', 30.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-05 00:00:00', 31.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-06 00:00:00', 32.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-07 00:00:00', 34.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-08 00:00:00', 35.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-09 00:00:00', 36.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-10 00:00:00', 37.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-11 00:00:00', 39.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-12 00:00:00', 38.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-13 00:00:00', 38.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-14 00:00:00', 36.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-15 00:00:00', 38.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-16 00:00:00', 38.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-17 00:00:00', 39.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-18 00:00:00', 39.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-19 00:00:00', 40.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-20 00:00:00', 40.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-21 00:00:00', 41.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-22 00:00:00', 40.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-23 00:00:00', 40.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-24 00:00:00', 34.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-25 00:00:00', 35.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-26 00:00:00', 37.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-27 00:00:00', 39.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-28 00:00:00', 38.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-29 00:00:00', 39.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-06-30 00:00:00', 37.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-01 00:00:00', 37.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-02 00:00:00', 38.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-03 00:00:00', 40.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-04 00:00:00', 40.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-05 00:00:00', 38.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-06 00:00:00', 37.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-07 00:00:00', 39.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-08 00:00:00', 41.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-09 00:00:00', 41.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-10 00:00:00', 42.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-11 00:00:00', 39.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-12 00:00:00', 36.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-13 00:00:00', 37.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-14 00:00:00', 38.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-15 00:00:00', 42.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-16 00:00:00', 45.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-17 00:00:00', 44.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-18 00:00:00', 42.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-19 00:00:00', 39.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-20 00:00:00', 38.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-21 00:00:00', 35.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-22 00:00:00', 33.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-23 00:00:00', 35.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-24 00:00:00', 37.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-25 00:00:00', 36.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-26 00:00:00', 37.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-27 00:00:00', 36.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-28 00:00:00', 37.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-29 00:00:00', 37.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-30 00:00:00', 37.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-07-31 00:00:00', 35.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-01 00:00:00', 36.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-02 00:00:00', 37.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-03 00:00:00', 31.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-04 00:00:00', 33.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-05 00:00:00', 37.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-06 00:00:00', 39.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-07 00:00:00', 39.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-08 00:00:00', 40.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-09 00:00:00', 41.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-10 00:00:00', 38.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-11 00:00:00', 39.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-12 00:00:00', 38.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-13 00:00:00', 38.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-14 00:00:00', 37.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-15 00:00:00', 37.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-16 00:00:00', 38.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-17 00:00:00', 38.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-18 00:00:00', 38.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-19 00:00:00', 39.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-20 00:00:00', 39.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-21 00:00:00', 41.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-22 00:00:00', 42.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-23 00:00:00', 34.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-24 00:00:00', 31.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-25 00:00:00', 31.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-26 00:00:00', 34.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-27 00:00:00', 35.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-28 00:00:00', 37.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-29 00:00:00', 37.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-30 00:00:00', 36.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-08-31 00:00:00', 37.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-01 00:00:00', 39.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-02 00:00:00', 40.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-03 00:00:00', 38.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-04 00:00:00', 36.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-05 00:00:00', 35.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-06 00:00:00', 35.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-07 00:00:00', 35.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-08 00:00:00', 35.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-09 00:00:00', 35.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-10 00:00:00', 33.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-11 00:00:00', 35.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-12 00:00:00', 28.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-13 00:00:00', 26.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-14 00:00:00', 31.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-15 00:00:00', 31.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-16 00:00:00', 21.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-17 00:00:00', 23.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-18 00:00:00', 24.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-19 00:00:00', 27.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-20 00:00:00', 29.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-21 00:00:00', 29.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-22 00:00:00', 28.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-23 00:00:00', 28.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-24 00:00:00', 29.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-25 00:00:00', 29.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-26 00:00:00', 29.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-27 00:00:00', 27.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-28 00:00:00', 25.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-29 00:00:00', 29.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-09-30 00:00:00', 28.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-01 00:00:00', 31.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-02 00:00:00', 32.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-03 00:00:00', 32.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-04 00:00:00', 33.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-05 00:00:00', 33.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-06 00:00:00', 33.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-07 00:00:00', 33.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-08 00:00:00', 28.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-09 00:00:00', 26.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-10 00:00:00', 25.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-11 00:00:00', 28.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-12 00:00:00', 31.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-13 00:00:00', 26.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-14 00:00:00', 28.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-15 00:00:00', 30.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-16 00:00:00', 32.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-17 00:00:00', 31.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-18 00:00:00', 31.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-19 00:00:00', 30.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-20 00:00:00', 28.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-21 00:00:00', 22.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-22 00:00:00', 16.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-23 00:00:00', 20.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-24 00:00:00', 20.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-25 00:00:00', 21.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-26 00:00:00', 20.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-27 00:00:00', 22.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-28 00:00:00', 21.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-29 00:00:00', 19.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-30 00:00:00', 22.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-10-31 00:00:00', 24.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-01 00:00:00', 25.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-02 00:00:00', 20.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-03 00:00:00', 13.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-04 00:00:00', 14.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-05 00:00:00', 12.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-06 00:00:00', 16.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-07 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-08 00:00:00', 23.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-09 00:00:00', 23.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-10 00:00:00', 24.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-11 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-12 00:00:00', 19.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-13 00:00:00', 18.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-14 00:00:00', 18.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-15 00:00:00', 18.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-16 00:00:00', 16.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-17 00:00:00', 16.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-18 00:00:00', 16.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-19 00:00:00', 16.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-20 00:00:00', 15.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-21 00:00:00', 15.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-22 00:00:00', 15.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-23 00:00:00', 17.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-24 00:00:00', 18.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-25 00:00:00', 16.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-26 00:00:00', 15.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-27 00:00:00', 17.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-28 00:00:00', 19.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-29 00:00:00', 18.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-11-30 00:00:00', 15.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-01 00:00:00', 15.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-02 00:00:00', 16.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-03 00:00:00', 19.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-04 00:00:00', 9.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-05 00:00:00', 5.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-06 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-07 00:00:00', 10.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-08 00:00:00', 12.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-09 00:00:00', 14.4980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-10 00:00:00', 14.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-11 00:00:00', 16.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-12 00:00:00', 17.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-13 00:00:00', 18.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-14 00:00:00', 20.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-15 00:00:00', 13.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-16 00:00:00', 11.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-17 00:00:00', 13.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-18 00:00:00', 14.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-19 00:00:00', 16.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-20 00:00:00', 17.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-21 00:00:00', 13.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-22 00:00:00', 6.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-23 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-24 00:00:00', 10.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-25 00:00:00', 9.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-26 00:00:00', 7.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-27 00:00:00', 7.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-28 00:00:00', 8.25800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-29 00:00:00', 9.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-30 00:00:00', 8.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2010-12-31 00:00:00', 9.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-01 00:00:00', 14.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-02 00:00:00', 13.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-03 00:00:00', 8.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-04 00:00:00', 7.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-05 00:00:00', 10.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-06 00:00:00', 11.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-07 00:00:00', 7.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-08 00:00:00', 5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-09 00:00:00', 8.53600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-10 00:00:00', 9.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-11 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-12 00:00:00', 6.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-13 00:00:00', -0.898999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-14 00:00:00', -1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-15 00:00:00', -0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-16 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-17 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-18 00:00:00', 1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-19 00:00:00', 4.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-20 00:00:00', 5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-21 00:00:00', 5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-22 00:00:00', 6.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-23 00:00:00', 5.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-24 00:00:00', 7.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-25 00:00:00', 8.83600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-26 00:00:00', 9.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-27 00:00:00', 12.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-28 00:00:00', 12.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-29 00:00:00', 10.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-30 00:00:00', 10.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-01-31 00:00:00', 12.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-01 00:00:00', 13.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-02 00:00:00', 15.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-03 00:00:00', 13.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-04 00:00:00', 9.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-05 00:00:00', 7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-06 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-07 00:00:00', 5.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-08 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-09 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-10 00:00:00', 8.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-11 00:00:00', 9.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-12 00:00:00', 5.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-13 00:00:00', 5.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-14 00:00:00', 9.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-15 00:00:00', 10.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-16 00:00:00', 11.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-17 00:00:00', 11.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-18 00:00:00', 8.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-19 00:00:00', 3.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-20 00:00:00', 6.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-21 00:00:00', 9.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-22 00:00:00', 7.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-23 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-24 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-25 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-26 00:00:00', -1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-27 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-02-28 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-01 00:00:00', 5.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-02 00:00:00', 6.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-03 00:00:00', 6.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-04 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-05 00:00:00', 6.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-06 00:00:00', 9.09099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-07 00:00:00', 9.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-08 00:00:00', 13.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-09 00:00:00', 17.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-10 00:00:00', 18.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-11 00:00:00', 20.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-12 00:00:00', 22.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-13 00:00:00', 23.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-14 00:00:00', 24.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-15 00:00:00', 13.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-16 00:00:00', 12.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-17 00:00:00', 10.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-18 00:00:00', 15.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-19 00:00:00', 13.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-20 00:00:00', 15.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-21 00:00:00', 19.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-22 00:00:00', 20.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-23 00:00:00', 23.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-24 00:00:00', 24.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-25 00:00:00', 19.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-26 00:00:00', 19.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-27 00:00:00', 13.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-28 00:00:00', 15.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-29 00:00:00', 17.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-30 00:00:00', 17.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-03-31 00:00:00', 17.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-01 00:00:00', 19.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-02 00:00:00', 19.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-03 00:00:00', 14.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-04 00:00:00', 12.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-05 00:00:00', 17.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-06 00:00:00', 20.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-07 00:00:00', 23.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-08 00:00:00', 20.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-09 00:00:00', 18.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-10 00:00:00', 22.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-11 00:00:00', 24.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-12 00:00:00', 27.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-13 00:00:00', 28.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-14 00:00:00', 26.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-15 00:00:00', 20.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-16 00:00:00', 21.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-17 00:00:00', 24.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-18 00:00:00', 25.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-19 00:00:00', 25.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-20 00:00:00', 26.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-21 00:00:00', 29.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-22 00:00:00', 32.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-23 00:00:00', 33.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-24 00:00:00', 34.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-25 00:00:00', 33.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-26 00:00:00', 32.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-27 00:00:00', 31.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-28 00:00:00', 28.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-29 00:00:00', 26.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-04-30 00:00:00', 30.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-01 00:00:00', 33.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-02 00:00:00', 35.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-03 00:00:00', 35.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-04 00:00:00', 35.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-05 00:00:00', 28.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-06 00:00:00', 25.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-07 00:00:00', 29.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-08 00:00:00', 27.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-09 00:00:00', 29.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-10 00:00:00', 24.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-11 00:00:00', 25.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-12 00:00:00', 28.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-13 00:00:00', 31.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-14 00:00:00', 35.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-15 00:00:00', 38.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-16 00:00:00', 39.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-17 00:00:00', 38.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-18 00:00:00', 34.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-19 00:00:00', 30.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-20 00:00:00', 30.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-21 00:00:00', 30.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-22 00:00:00', 31.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-23 00:00:00', 34.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-24 00:00:00', 37.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-25 00:00:00', 35.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-26 00:00:00', 33.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-27 00:00:00', 33.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-28 00:00:00', 33.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-29 00:00:00', 33.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-30 00:00:00', 33.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-05-31 00:00:00', 30.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-01 00:00:00', 28.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-02 00:00:00', 31.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-03 00:00:00', 33.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-04 00:00:00', 32.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-05 00:00:00', 33.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-06 00:00:00', 36.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-07 00:00:00', 39.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-08 00:00:00', 39.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-09 00:00:00', 40.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-10 00:00:00', 38.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-11 00:00:00', 36.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-12 00:00:00', 35.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-13 00:00:00', 35.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-14 00:00:00', 39.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-15 00:00:00', 41.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-16 00:00:00', 39.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-17 00:00:00', 37.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-18 00:00:00', 38.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-19 00:00:00', 38.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-20 00:00:00', 37.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-21 00:00:00', 39.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-22 00:00:00', 38.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-23 00:00:00', 37.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-24 00:00:00', 38.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-25 00:00:00', 34.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-26 00:00:00', 34.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-27 00:00:00', 36.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-28 00:00:00', 37.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-29 00:00:00', 38.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-06-30 00:00:00', 37.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-01 00:00:00', 36.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-02 00:00:00', 36.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-03 00:00:00', 35.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-04 00:00:00', 38.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-05 00:00:00', 39.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-06 00:00:00', 40.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-07 00:00:00', 40.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-08 00:00:00', 38.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-09 00:00:00', 39.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-10 00:00:00', 36.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-11 00:00:00', 39.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-12 00:00:00', 40.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-13 00:00:00', 41.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-14 00:00:00', 36.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-15 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-16 00:00:00', 34.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-17 00:00:00', 35.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-18 00:00:00', 36.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-19 00:00:00', 35.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-20 00:00:00', 34.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-21 00:00:00', 36.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-22 00:00:00', 36.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-23 00:00:00', 39.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-24 00:00:00', 38.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-25 00:00:00', 36.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-26 00:00:00', 36.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-27 00:00:00', 35.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-28 00:00:00', 36.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-29 00:00:00', 37.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-30 00:00:00', 37.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-07-31 00:00:00', 38.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-01 00:00:00', 38.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-02 00:00:00', 40.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-03 00:00:00', 40.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-04 00:00:00', 41.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-05 00:00:00', 40.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-06 00:00:00', 41.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-07 00:00:00', 42.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-08 00:00:00', 38.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-09 00:00:00', 34.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-10 00:00:00', 34.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-11 00:00:00', 35.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-12 00:00:00', 35.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-13 00:00:00', 36.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-14 00:00:00', 37.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-15 00:00:00', 39.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-16 00:00:00', 38.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-17 00:00:00', 38.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-18 00:00:00', 37.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-19 00:00:00', 37.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-20 00:00:00', 39.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-21 00:00:00', 40.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-22 00:00:00', 38.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-23 00:00:00', 39.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-24 00:00:00', 41.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-25 00:00:00', 37.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-26 00:00:00', 35.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-27 00:00:00', 32.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-28 00:00:00', 30.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-29 00:00:00', 29.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-30 00:00:00', 28.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-08-31 00:00:00', 30.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-01 00:00:00', 31.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-02 00:00:00', 32.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-03 00:00:00', 33.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-04 00:00:00', 34.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-05 00:00:00', 35.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-06 00:00:00', 34.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-07 00:00:00', 34.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-08 00:00:00', 33.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-09 00:00:00', 33.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-10 00:00:00', 31.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-11 00:00:00', 33.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-12 00:00:00', 34.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-13 00:00:00', 34.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-14 00:00:00', 32.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-15 00:00:00', 31.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-16 00:00:00', 26.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-17 00:00:00', 30.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-18 00:00:00', 27.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-19 00:00:00', 28.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-20 00:00:00', 28.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-21 00:00:00', 27.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-22 00:00:00', 28.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-23 00:00:00', 25.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-24 00:00:00', 29.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-25 00:00:00', 28.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-26 00:00:00', 29.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-27 00:00:00', 28.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-28 00:00:00', 27.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-29 00:00:00', 25.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-09-30 00:00:00', 26.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-01 00:00:00', 29.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-02 00:00:00', 31.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-03 00:00:00', 30.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-04 00:00:00', 29.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-05 00:00:00', 21.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-06 00:00:00', 22.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-07 00:00:00', 21.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-08 00:00:00', 23.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-09 00:00:00', 24.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-10 00:00:00', 25.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-11 00:00:00', 23.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-12 00:00:00', 22.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-13 00:00:00', 23.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-14 00:00:00', 25.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-15 00:00:00', 27.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-16 00:00:00', 27.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-17 00:00:00', 26.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-18 00:00:00', 25.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-19 00:00:00', 24.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-20 00:00:00', 26.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-21 00:00:00', 26.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-22 00:00:00', 19.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-23 00:00:00', 15.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-24 00:00:00', 18.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-25 00:00:00', 18.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-26 00:00:00', 22.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-27 00:00:00', 23.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-28 00:00:00', 14.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-29 00:00:00', 11.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-30 00:00:00', 11.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-10-31 00:00:00', 12.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-01 00:00:00', 10.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-02 00:00:00', 12.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-03 00:00:00', 12.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-04 00:00:00', 12.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-05 00:00:00', 16.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-06 00:00:00', 17.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-07 00:00:00', 19.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-08 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-09 00:00:00', -0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-10 00:00:00', 5.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-11 00:00:00', 15.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-12 00:00:00', 15.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-13 00:00:00', 17.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-14 00:00:00', 11.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-15 00:00:00', 9.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-16 00:00:00', 13.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-17 00:00:00', 10.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-18 00:00:00', 12.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-19 00:00:00', 11.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-20 00:00:00', 14.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-21 00:00:00', 19.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-22 00:00:00', 12.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-23 00:00:00', 13.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-24 00:00:00', 9.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-25 00:00:00', 12.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-26 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-27 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-28 00:00:00', 4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-29 00:00:00', 9.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-11-30 00:00:00', 13.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-01 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-02 00:00:00', 6.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-03 00:00:00', 8.12100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-04 00:00:00', 5.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-05 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-06 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-07 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-08 00:00:00', 6.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-09 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-10 00:00:00', 9.93000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-11 00:00:00', 11.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-12 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-13 00:00:00', 7.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-14 00:00:00', 7.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-15 00:00:00', 4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-16 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-17 00:00:00', 9.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-18 00:00:00', 7.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-19 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-20 00:00:00', -5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-21 00:00:00', -3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-22 00:00:00', -2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-23 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-24 00:00:00', 5.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-25 00:00:00', 11.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-26 00:00:00', 10.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-27 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-28 00:00:00', 2.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-29 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-30 00:00:00', 3.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2011-12-31 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-01 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-02 00:00:00', 7.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-03 00:00:00', 7.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-04 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-05 00:00:00', -1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-06 00:00:00', -1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-07 00:00:00', -0.674000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-08 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-09 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-10 00:00:00', 4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-11 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-12 00:00:00', 8.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-13 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-14 00:00:00', 5.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-15 00:00:00', 2.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-16 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-17 00:00:00', 6.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-18 00:00:00', 4.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-19 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-20 00:00:00', 3.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-21 00:00:00', 6.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-22 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-23 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-24 00:00:00', 7.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-25 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-26 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-27 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-28 00:00:00', 8.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-29 00:00:00', 10.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-30 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-01-31 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-01 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-02 00:00:00', 9.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-03 00:00:00', 5.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-04 00:00:00', -1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-05 00:00:00', -5.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-06 00:00:00', -3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-07 00:00:00', -0.0640000030398368835, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-08 00:00:00', 2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-09 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-10 00:00:00', 4.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-11 00:00:00', 6.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-12 00:00:00', 0.804000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-13 00:00:00', -2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-14 00:00:00', -0.490000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-15 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-16 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-17 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-18 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-19 00:00:00', 6.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-20 00:00:00', 5.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-21 00:00:00', 1.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-22 00:00:00', -0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-23 00:00:00', 1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-24 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-25 00:00:00', 7.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-26 00:00:00', 9.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-27 00:00:00', 7.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-28 00:00:00', 10.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-02-29 00:00:00', 12.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-01 00:00:00', 13.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-02 00:00:00', 15.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-03 00:00:00', 15.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-04 00:00:00', 9.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-05 00:00:00', 9.08600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-06 00:00:00', 4.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-07 00:00:00', 7.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-08 00:00:00', 9.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-09 00:00:00', 9.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-10 00:00:00', 7.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-11 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-12 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-13 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-14 00:00:00', 11.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-15 00:00:00', 11.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-16 00:00:00', 11.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-17 00:00:00', 15.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-18 00:00:00', 9.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-19 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-20 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-21 00:00:00', 6.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-22 00:00:00', 12.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-23 00:00:00', 16.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-24 00:00:00', 17.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-25 00:00:00', 16.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-26 00:00:00', 17.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-27 00:00:00', 19.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-28 00:00:00', 22.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-29 00:00:00', 19.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-30 00:00:00', 24.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-03-31 00:00:00', 23.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-01 00:00:00', 21.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-02 00:00:00', 23.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-03 00:00:00', 25.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-04 00:00:00', 26.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-05 00:00:00', 25.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-06 00:00:00', 23.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-07 00:00:00', 24.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-08 00:00:00', 26.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-09 00:00:00', 22.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-10 00:00:00', 25.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-11 00:00:00', 24.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-12 00:00:00', 23.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-13 00:00:00', 25.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-14 00:00:00', 26.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-15 00:00:00', 27.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-16 00:00:00', 27.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-17 00:00:00', 27.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-18 00:00:00', 29.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-19 00:00:00', 27.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-20 00:00:00', 28.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-21 00:00:00', 19.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-22 00:00:00', 19.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-23 00:00:00', 21.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-24 00:00:00', 24.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-25 00:00:00', 22.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-26 00:00:00', 24.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-27 00:00:00', 22.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-28 00:00:00', 22.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-29 00:00:00', 20.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-04-30 00:00:00', 24.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-01 00:00:00', 22.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-02 00:00:00', 22.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-03 00:00:00', 25.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-04 00:00:00', 26.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-05 00:00:00', 27.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-06 00:00:00', 27.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-07 00:00:00', 25.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-08 00:00:00', 25.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-09 00:00:00', 29.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-10 00:00:00', 24.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-11 00:00:00', 26.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-12 00:00:00', 24.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-13 00:00:00', 26.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-14 00:00:00', 28.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-15 00:00:00', 28.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-16 00:00:00', 29.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-17 00:00:00', 26.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-18 00:00:00', 25.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-19 00:00:00', 27.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-20 00:00:00', 29.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-21 00:00:00', 28.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-22 00:00:00', 28.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-23 00:00:00', 29.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-24 00:00:00', 30.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-25 00:00:00', 26.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-26 00:00:00', 27.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-27 00:00:00', 29.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-28 00:00:00', 34.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-29 00:00:00', 34.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-30 00:00:00', 34.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-05-31 00:00:00', 34.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-01 00:00:00', 33.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-02 00:00:00', 34.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-03 00:00:00', 37.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-04 00:00:00', 34.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-05 00:00:00', 33.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-06 00:00:00', 32.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-07 00:00:00', 32.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-08 00:00:00', 34.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-09 00:00:00', 35.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-10 00:00:00', 36.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-11 00:00:00', 34.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-12 00:00:00', 34.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-13 00:00:00', 34.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-14 00:00:00', 33.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-15 00:00:00', 35.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-16 00:00:00', 35.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-17 00:00:00', 36.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-18 00:00:00', 36.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-19 00:00:00', 36.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-20 00:00:00', 34.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-21 00:00:00', 33.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-22 00:00:00', 33.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-23 00:00:00', 33.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-24 00:00:00', 33.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-25 00:00:00', 32.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-26 00:00:00', 32.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-27 00:00:00', 33.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-28 00:00:00', 35.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-29 00:00:00', 37.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-06-30 00:00:00', 37.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-01 00:00:00', 37.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-02 00:00:00', 39.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-03 00:00:00', 39.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-04 00:00:00', 38.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-05 00:00:00', 38.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-06 00:00:00', 37.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-07 00:00:00', 37.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-08 00:00:00', 38.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-09 00:00:00', 40.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-10 00:00:00', 39.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-11 00:00:00', 42.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-12 00:00:00', 39.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-13 00:00:00', 36.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-14 00:00:00', 35.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-15 00:00:00', 36.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-16 00:00:00', 36.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-17 00:00:00', 37.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-18 00:00:00', 38.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-19 00:00:00', 40.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-20 00:00:00', 37.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-21 00:00:00', 38.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-22 00:00:00', 39.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-23 00:00:00', 38.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-24 00:00:00', 38.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-25 00:00:00', 36.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-26 00:00:00', 36.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-27 00:00:00', 32.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-28 00:00:00', 32.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-29 00:00:00', 34.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-30 00:00:00', 35.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-07-31 00:00:00', 38.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-01 00:00:00', 38.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-02 00:00:00', 35.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-03 00:00:00', 35.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-04 00:00:00', 34.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-05 00:00:00', 35.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-06 00:00:00', 36.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-07 00:00:00', 37.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-08 00:00:00', 37.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-09 00:00:00', 36.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-10 00:00:00', 36.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-11 00:00:00', 36.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-12 00:00:00', 36.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-13 00:00:00', 37.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-14 00:00:00', 37.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-15 00:00:00', 37.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-16 00:00:00', 37.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-17 00:00:00', 37.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-18 00:00:00', 39.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-19 00:00:00', 39.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-20 00:00:00', 39.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-21 00:00:00', 38.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-22 00:00:00', 40.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-23 00:00:00', 38.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-24 00:00:00', 34.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-25 00:00:00', 33.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-26 00:00:00', 33.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-27 00:00:00', 32.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-28 00:00:00', 34.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-29 00:00:00', 35.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-30 00:00:00', 36.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-08-31 00:00:00', 35.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-01 00:00:00', 34.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-02 00:00:00', 35.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-03 00:00:00', 36.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-04 00:00:00', 29.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-05 00:00:00', 28.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-06 00:00:00', 30.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-07 00:00:00', 30.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-08 00:00:00', 31.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-09 00:00:00', 32.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-10 00:00:00', 34.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-11 00:00:00', 33.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-12 00:00:00', 33.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-13 00:00:00', 30.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-14 00:00:00', 28.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-15 00:00:00', 28.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-16 00:00:00', 27.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-17 00:00:00', 26.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-18 00:00:00', 28.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-19 00:00:00', 28.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-20 00:00:00', 27.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-21 00:00:00', 27.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-22 00:00:00', 27.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-23 00:00:00', 28.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-24 00:00:00', 28.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-25 00:00:00', 27.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-26 00:00:00', 27.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-27 00:00:00', 29.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-28 00:00:00', 28.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-29 00:00:00', 27.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-09-30 00:00:00', 24.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-01 00:00:00', 25.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-02 00:00:00', 23.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-03 00:00:00', 23.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-04 00:00:00', 23.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-05 00:00:00', 24.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-06 00:00:00', 25.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-07 00:00:00', 26.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-08 00:00:00', 25.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-09 00:00:00', 25.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-10 00:00:00', 27.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-11 00:00:00', 26.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-12 00:00:00', 26.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-13 00:00:00', 27.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-14 00:00:00', 19.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-15 00:00:00', 19.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-16 00:00:00', 21.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-17 00:00:00', 20.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-18 00:00:00', 20.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-19 00:00:00', 17.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-20 00:00:00', 15.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-21 00:00:00', 16.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-22 00:00:00', 19.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-23 00:00:00', 19.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-24 00:00:00', 21.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-25 00:00:00', 20.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-26 00:00:00', 22.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-27 00:00:00', 21.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-28 00:00:00', 24.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-29 00:00:00', 24.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-30 00:00:00', 26.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-10-31 00:00:00', 18.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-01 00:00:00', 19.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-02 00:00:00', 19.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-03 00:00:00', 21.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-04 00:00:00', 15.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-05 00:00:00', 15.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-06 00:00:00', 18.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-07 00:00:00', 19.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-08 00:00:00', 20.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-09 00:00:00', 21.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-10 00:00:00', 20.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-11 00:00:00', 21.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-12 00:00:00', 14.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-13 00:00:00', 13.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-14 00:00:00', 17.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-15 00:00:00', 19.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-16 00:00:00', 12.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-17 00:00:00', 11.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-18 00:00:00', 13.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-19 00:00:00', 12.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-20 00:00:00', 9.98200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-21 00:00:00', 9.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-22 00:00:00', 8.51299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-23 00:00:00', 7.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-24 00:00:00', 8.35999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-25 00:00:00', 10.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-26 00:00:00', 11.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-27 00:00:00', 14.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-28 00:00:00', 9.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-29 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-11-30 00:00:00', 10.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-01 00:00:00', 13.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-02 00:00:00', 13.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-03 00:00:00', 14.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-04 00:00:00', 16.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-05 00:00:00', 18.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-06 00:00:00', 17.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-07 00:00:00', 13.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-08 00:00:00', 13.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-09 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-10 00:00:00', 10.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-11 00:00:00', 10.4980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-12 00:00:00', 10.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-13 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-14 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-15 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-16 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-17 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-18 00:00:00', 0.180999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-19 00:00:00', 4.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-20 00:00:00', 8.49600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-21 00:00:00', 13.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-22 00:00:00', 15.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-23 00:00:00', 11.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-24 00:00:00', 9.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-25 00:00:00', 12.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-26 00:00:00', 4.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-27 00:00:00', -0.104000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-28 00:00:00', -7.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-29 00:00:00', -2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-30 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2012-12-31 00:00:00', 2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-01 00:00:00', -1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-02 00:00:00', 1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-03 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-04 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-05 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-06 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-07 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-08 00:00:00', 4.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-09 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-10 00:00:00', 6.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-11 00:00:00', 7.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-12 00:00:00', 1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-13 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-14 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-15 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-16 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-17 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-18 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-19 00:00:00', 6.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-20 00:00:00', 8.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-21 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-22 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-23 00:00:00', 7.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-24 00:00:00', 10.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-25 00:00:00', 12.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-26 00:00:00', 12.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-27 00:00:00', 11.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-28 00:00:00', 12.7860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-29 00:00:00', 12.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-30 00:00:00', 10.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-01-31 00:00:00', 12.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-01 00:00:00', 12.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-02 00:00:00', 11.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-03 00:00:00', 8.12800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-04 00:00:00', 4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-05 00:00:00', 5.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-06 00:00:00', 8.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-07 00:00:00', 12.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-08 00:00:00', 14.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-09 00:00:00', 9.59300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-10 00:00:00', 10.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-11 00:00:00', 10.7860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-12 00:00:00', 11.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-13 00:00:00', 11.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-14 00:00:00', 13.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-15 00:00:00', 9.30099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-16 00:00:00', 11.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-17 00:00:00', 14.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-18 00:00:00', 10.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-19 00:00:00', 11.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-20 00:00:00', 14.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-21 00:00:00', 9.79399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-22 00:00:00', 12.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-23 00:00:00', 11.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-24 00:00:00', 13.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-25 00:00:00', 12.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-26 00:00:00', 7.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-27 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-02-28 00:00:00', 8.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-01 00:00:00', 15.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-02 00:00:00', 19.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-03 00:00:00', 16.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-04 00:00:00', 17.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-05 00:00:00', 21.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-06 00:00:00', 23.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-07 00:00:00', 13.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-08 00:00:00', 2.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-09 00:00:00', 5.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-10 00:00:00', 11.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-11 00:00:00', 16.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-12 00:00:00', 15.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-13 00:00:00', 15.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-14 00:00:00', 19.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-15 00:00:00', 18.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-16 00:00:00', 15.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-17 00:00:00', 14.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-18 00:00:00', 17.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-19 00:00:00', 22.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-20 00:00:00', 14.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-21 00:00:00', 15.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-22 00:00:00', 13.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-23 00:00:00', 10.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-24 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-25 00:00:00', 21.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-26 00:00:00', 13.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-27 00:00:00', 18.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-28 00:00:00', 22.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-29 00:00:00', 23.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-30 00:00:00', 23.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-03-31 00:00:00', 14.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-01 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-02 00:00:00', 15.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-03 00:00:00', 17.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-04 00:00:00', 20.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-05 00:00:00', 17.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-06 00:00:00', 19.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-07 00:00:00', 21.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-08 00:00:00', 25.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-09 00:00:00', 26.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-10 00:00:00', 27.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-11 00:00:00', 28.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-12 00:00:00', 28.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-13 00:00:00', 27.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-14 00:00:00', 26.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-15 00:00:00', 16.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-16 00:00:00', 18.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-17 00:00:00', 20.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-18 00:00:00', 24.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-19 00:00:00', 23.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-20 00:00:00', 24.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-21 00:00:00', 26.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-22 00:00:00', 29.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-23 00:00:00', 22.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-24 00:00:00', 21.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-25 00:00:00', 20.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-26 00:00:00', 17.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-27 00:00:00', 21.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-28 00:00:00', 17.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-29 00:00:00', 12.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-04-30 00:00:00', 15.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-01 00:00:00', 20.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-02 00:00:00', 23.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-03 00:00:00', 25.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-04 00:00:00', 25.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-05 00:00:00', 26.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-06 00:00:00', 29.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-07 00:00:00', 29.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-08 00:00:00', 29.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-09 00:00:00', 31.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-10 00:00:00', 28.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-11 00:00:00', 27.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-12 00:00:00', 26.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-13 00:00:00', 26.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-14 00:00:00', 29.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-15 00:00:00', 31.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-16 00:00:00', 34.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-17 00:00:00', 35.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-18 00:00:00', 36.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-19 00:00:00', 28.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-20 00:00:00', 32.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-21 00:00:00', 29.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-22 00:00:00', 30.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-23 00:00:00', 32.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-24 00:00:00', 32.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-25 00:00:00', 29.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-26 00:00:00', 29.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-27 00:00:00', 27.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-28 00:00:00', 29.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-29 00:00:00', 32.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-30 00:00:00', 35.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-05-31 00:00:00', 37.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-01 00:00:00', 38.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-02 00:00:00', 36.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-03 00:00:00', 34.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-04 00:00:00', 34.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-05 00:00:00', 36.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-06 00:00:00', 36.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-07 00:00:00', 36.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-08 00:00:00', 39.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-09 00:00:00', 37.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-10 00:00:00', 38.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-11 00:00:00', 37.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-12 00:00:00', 37.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-13 00:00:00', 36.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-14 00:00:00', 33.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-15 00:00:00', 31.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-16 00:00:00', 34.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-17 00:00:00', 32.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-18 00:00:00', 34.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-19 00:00:00', 37.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-20 00:00:00', 38.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-21 00:00:00', 40.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-22 00:00:00', 41.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-23 00:00:00', 41.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-24 00:00:00', 40.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-25 00:00:00', 40.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-26 00:00:00', 40.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-27 00:00:00', 36.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-28 00:00:00', 32.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-29 00:00:00', 33.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-06-30 00:00:00', 34.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-01 00:00:00', 34.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-02 00:00:00', 35.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-03 00:00:00', 38.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-04 00:00:00', 39.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-05 00:00:00', 36.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-06 00:00:00', 34.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-07 00:00:00', 34.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-08 00:00:00', 33.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-09 00:00:00', 35.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-10 00:00:00', 35.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-11 00:00:00', 34.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-12 00:00:00', 36.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-13 00:00:00', 39.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-14 00:00:00', 36.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-15 00:00:00', 38.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-16 00:00:00', 37.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-17 00:00:00', 36.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-18 00:00:00', 39.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-19 00:00:00', 40.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-20 00:00:00', 41.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-21 00:00:00', 39.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-22 00:00:00', 36.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-23 00:00:00', 36.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-24 00:00:00', 38.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-25 00:00:00', 36.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-26 00:00:00', 38.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-27 00:00:00', 42.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-28 00:00:00', 42.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-29 00:00:00', 42.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-30 00:00:00', 41.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-07-31 00:00:00', 40.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-01 00:00:00', 39.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-02 00:00:00', 39.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-03 00:00:00', 40.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-04 00:00:00', 39.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-05 00:00:00', 38.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-06 00:00:00', 40.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-07 00:00:00', 36.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-08 00:00:00', 34.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-09 00:00:00', 34.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-10 00:00:00', 36.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-11 00:00:00', 34.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-12 00:00:00', 35.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-13 00:00:00', 33.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-14 00:00:00', 33.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-15 00:00:00', 34.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-16 00:00:00', 33.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-17 00:00:00', 34.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-18 00:00:00', 34.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-19 00:00:00', 34.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-20 00:00:00', 36.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-21 00:00:00', 36.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-22 00:00:00', 36.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-23 00:00:00', 36.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-24 00:00:00', 34.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-25 00:00:00', 34.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-26 00:00:00', 35.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-27 00:00:00', 35.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-28 00:00:00', 37.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-29 00:00:00', 35.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-30 00:00:00', 31.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-08-31 00:00:00', 31.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-01 00:00:00', 32.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-02 00:00:00', 33.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-03 00:00:00', 33.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-04 00:00:00', 33.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-05 00:00:00', 35.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-06 00:00:00', 37.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-07 00:00:00', 34.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-08 00:00:00', 35.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-09 00:00:00', 35.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-10 00:00:00', 36.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-11 00:00:00', 35.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-12 00:00:00', 32.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-13 00:00:00', 32.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-14 00:00:00', 31.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-15 00:00:00', 28.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-16 00:00:00', 26.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-17 00:00:00', 30.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-18 00:00:00', 30.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-19 00:00:00', 34.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-20 00:00:00', 35.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-21 00:00:00', 36.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-22 00:00:00', 34.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-23 00:00:00', 33.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-24 00:00:00', 34.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-25 00:00:00', 35.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-26 00:00:00', 35.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-27 00:00:00', 32.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-28 00:00:00', 31.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-29 00:00:00', 31.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-09-30 00:00:00', 30.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-01 00:00:00', 30.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-02 00:00:00', 31.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-03 00:00:00', 32.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-04 00:00:00', 34.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-05 00:00:00', 34.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-06 00:00:00', 33.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-07 00:00:00', 31.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-08 00:00:00', 28.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-09 00:00:00', 24.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-10 00:00:00', 21.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-11 00:00:00', 20.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-12 00:00:00', 22.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-13 00:00:00', 22.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-14 00:00:00', 23.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-15 00:00:00', 22.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-16 00:00:00', 21.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-17 00:00:00', 22.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-18 00:00:00', 25.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-19 00:00:00', 26.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-20 00:00:00', 27.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-21 00:00:00', 27.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-22 00:00:00', 20.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-23 00:00:00', 14.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-24 00:00:00', 21.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-25 00:00:00', 18.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-26 00:00:00', 13.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-27 00:00:00', 14.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-28 00:00:00', 18.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-29 00:00:00', 19.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-30 00:00:00', 12.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-10-31 00:00:00', 13.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-01 00:00:00', 13.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-02 00:00:00', 16.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-03 00:00:00', 18.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-04 00:00:00', 16.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-05 00:00:00', 16.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-06 00:00:00', 14.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-07 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-08 00:00:00', 16.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-09 00:00:00', 18.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-10 00:00:00', 17.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-11 00:00:00', 16.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-12 00:00:00', 14.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-13 00:00:00', 15.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-14 00:00:00', 17.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-15 00:00:00', 20.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-16 00:00:00', 13.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-17 00:00:00', 17.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-18 00:00:00', 19.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-19 00:00:00', 16.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-20 00:00:00', 11.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-21 00:00:00', 9.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-22 00:00:00', 12.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-23 00:00:00', 10.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-24 00:00:00', 11.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-25 00:00:00', 15.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-26 00:00:00', 15.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-27 00:00:00', 15.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-28 00:00:00', 16.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-29 00:00:00', 16.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-11-30 00:00:00', 19.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-01 00:00:00', 16.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-02 00:00:00', 8.52900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-03 00:00:00', 14.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-04 00:00:00', 16.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-05 00:00:00', 9.12399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-06 00:00:00', 12.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-07 00:00:00', 10.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-08 00:00:00', 11.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-09 00:00:00', 13.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-10 00:00:00', 14.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-11 00:00:00', 8.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-12 00:00:00', 12.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-13 00:00:00', 14.8730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-14 00:00:00', 15.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-15 00:00:00', 17.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-16 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-17 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-18 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-19 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-20 00:00:00', 6.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-21 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-22 00:00:00', 1.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-23 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-24 00:00:00', 2.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-25 00:00:00', 5.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-26 00:00:00', 5.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-27 00:00:00', -0.699999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-28 00:00:00', -3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-29 00:00:00', -1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-30 00:00:00', -2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2013-12-31 00:00:00', 1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-01 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-02 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-03 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-04 00:00:00', 4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-05 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-06 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-07 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-08 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-09 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-10 00:00:00', 3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-11 00:00:00', 6.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-12 00:00:00', 7.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-13 00:00:00', 6.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-14 00:00:00', 9.87399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-15 00:00:00', 7.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-16 00:00:00', 8.14000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-17 00:00:00', 9.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-18 00:00:00', 11.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-19 00:00:00', 12.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-20 00:00:00', 11.9469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-21 00:00:00', 8.33800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-22 00:00:00', 5.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-23 00:00:00', 6.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-24 00:00:00', 7.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-25 00:00:00', 7.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-26 00:00:00', 11.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-27 00:00:00', 12.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-28 00:00:00', 15.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-29 00:00:00', 13.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-30 00:00:00', 11.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-01-31 00:00:00', 6.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-01 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-02 00:00:00', -7.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-03 00:00:00', -9.08100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-04 00:00:00', -6.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-05 00:00:00', -4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-06 00:00:00', -3.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-07 00:00:00', -2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-08 00:00:00', -0.0590000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-09 00:00:00', 1.25800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-10 00:00:00', -0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-11 00:00:00', 1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-12 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-13 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-14 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-15 00:00:00', 2.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-16 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-17 00:00:00', 7.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-18 00:00:00', 9.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-19 00:00:00', 5.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-20 00:00:00', 6.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-21 00:00:00', 10.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-22 00:00:00', 12.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-23 00:00:00', 6.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-24 00:00:00', 5.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-25 00:00:00', 8.74699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-26 00:00:00', 7.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-27 00:00:00', 9.72999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-02-28 00:00:00', 12.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-01 00:00:00', 14.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-02 00:00:00', 15.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-03 00:00:00', 10.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-04 00:00:00', 13.7559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-05 00:00:00', 15.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-06 00:00:00', 9.53400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-07 00:00:00', 9.24600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-08 00:00:00', 13.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-09 00:00:00', 7.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-10 00:00:00', 7.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-11 00:00:00', 10.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-12 00:00:00', 14.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-13 00:00:00', 16.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-14 00:00:00', 9.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-15 00:00:00', 7.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-16 00:00:00', 15.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-17 00:00:00', 13.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-18 00:00:00', 16.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-19 00:00:00', 17.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-20 00:00:00', 14.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-21 00:00:00', 16.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-22 00:00:00', 18.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-23 00:00:00', 10.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-24 00:00:00', 7.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-25 00:00:00', 10.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-26 00:00:00', 13.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-27 00:00:00', 13.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-28 00:00:00', 16.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-29 00:00:00', 18.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-30 00:00:00', 21.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-03-31 00:00:00', 22.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-01 00:00:00', 22.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-02 00:00:00', 18.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-03 00:00:00', 19.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-04 00:00:00', 12.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-05 00:00:00', 13.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-06 00:00:00', 16.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-07 00:00:00', 15.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-08 00:00:00', 17.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-09 00:00:00', 20.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-10 00:00:00', 21.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-11 00:00:00', 16.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-12 00:00:00', 18.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-13 00:00:00', 17.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-14 00:00:00', 21.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-15 00:00:00', 25.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-16 00:00:00', 22.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-17 00:00:00', 22.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-18 00:00:00', 20.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-19 00:00:00', 23.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-20 00:00:00', 25.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-21 00:00:00', 25.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-22 00:00:00', 27.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-23 00:00:00', 27.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-24 00:00:00', 22.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-25 00:00:00', 21.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-26 00:00:00', 22.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-27 00:00:00', 27.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-28 00:00:00', 27.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-29 00:00:00', 22.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-04-30 00:00:00', 27.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-01 00:00:00', 28.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-02 00:00:00', 30.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-03 00:00:00', 30.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-04 00:00:00', 29.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-05 00:00:00', 29.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-06 00:00:00', 29.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-07 00:00:00', 28.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-08 00:00:00', 28.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-09 00:00:00', 25.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-10 00:00:00', 28.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-11 00:00:00', 30.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-12 00:00:00', 27.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-13 00:00:00', 26.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-14 00:00:00', 28.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-15 00:00:00', 31.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-16 00:00:00', 32.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-17 00:00:00', 25.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-18 00:00:00', 23.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-19 00:00:00', 29.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-20 00:00:00', 30.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-21 00:00:00', 30.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-22 00:00:00', 28.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-23 00:00:00', 28.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-24 00:00:00', 30.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-25 00:00:00', 32.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-26 00:00:00', 32.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-27 00:00:00', 34.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-28 00:00:00', 36.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-29 00:00:00', 34.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-30 00:00:00', 25.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-05-31 00:00:00', 26.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-01 00:00:00', 30.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-02 00:00:00', 31.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-03 00:00:00', 30.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-04 00:00:00', 32.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-05 00:00:00', 35.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-06 00:00:00', 33.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-07 00:00:00', 33.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-08 00:00:00', 35.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-09 00:00:00', 35.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-10 00:00:00', 34.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-11 00:00:00', 34.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-12 00:00:00', 36.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-13 00:00:00', 38.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-14 00:00:00', 36.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-15 00:00:00', 36.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-16 00:00:00', 33.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-17 00:00:00', 36.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-18 00:00:00', 33.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-19 00:00:00', 35.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-20 00:00:00', 36.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-21 00:00:00', 36.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-22 00:00:00', 37.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-23 00:00:00', 38.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-24 00:00:00', 37.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-25 00:00:00', 38.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-26 00:00:00', 37.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-27 00:00:00', 40.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-28 00:00:00', 42.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-29 00:00:00', 41.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-06-30 00:00:00', 39.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-01 00:00:00', 40.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-02 00:00:00', 36.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-03 00:00:00', 33.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-04 00:00:00', 34.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-05 00:00:00', 34.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-06 00:00:00', 35.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-07 00:00:00', 37.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-08 00:00:00', 37.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-09 00:00:00', 38.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-10 00:00:00', 38.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-11 00:00:00', 40.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-12 00:00:00', 40.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-13 00:00:00', 39.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-14 00:00:00', 37.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-15 00:00:00', 37.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-16 00:00:00', 35.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-17 00:00:00', 34.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-18 00:00:00', 33.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-19 00:00:00', 34.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-20 00:00:00', 36.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-21 00:00:00', 39.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-22 00:00:00', 42.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-23 00:00:00', 42.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-24 00:00:00', 38.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-25 00:00:00', 37.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-26 00:00:00', 37.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-27 00:00:00', 39.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-28 00:00:00', 42.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-29 00:00:00', 38.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-30 00:00:00', 35.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (36, '2014-07-31 00:00:00', 33.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-01 00:00:00', 15.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-02 00:00:00', 14.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-03 00:00:00', 15.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-04 00:00:00', 14.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-05 00:00:00', 16.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-06 00:00:00', 15.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-07 00:00:00', 15.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-08 00:00:00', 10.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-09 00:00:00', 6.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-10 00:00:00', 7.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-11 00:00:00', 11.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-12 00:00:00', 14.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-13 00:00:00', 5.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-14 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-15 00:00:00', 6.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-16 00:00:00', 7.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-17 00:00:00', 5.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-18 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-19 00:00:00', 3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-20 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-21 00:00:00', 5.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-22 00:00:00', 11.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-23 00:00:00', 8.78199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-24 00:00:00', 12.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-25 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-26 00:00:00', 1.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-27 00:00:00', 1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-28 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-29 00:00:00', -1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-30 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-01-31 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-01 00:00:00', 7.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-02 00:00:00', 8.73200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-03 00:00:00', 11.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-04 00:00:00', 12.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-05 00:00:00', 11.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-06 00:00:00', 8.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-07 00:00:00', 13.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-08 00:00:00', 13.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-09 00:00:00', 15.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-10 00:00:00', 12.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-11 00:00:00', 12.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-12 00:00:00', 11.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-13 00:00:00', 12.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-14 00:00:00', 11.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-15 00:00:00', 14.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-16 00:00:00', 16.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-17 00:00:00', 16.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-18 00:00:00', 8.87100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-19 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-20 00:00:00', -0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-21 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-22 00:00:00', 3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-23 00:00:00', 6.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-24 00:00:00', 8.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-25 00:00:00', 7.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-26 00:00:00', 10.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-27 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-02-28 00:00:00', 6.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-01 00:00:00', 7.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-02 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-03 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-04 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-05 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-06 00:00:00', 1.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-07 00:00:00', 1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-08 00:00:00', 1.40600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-09 00:00:00', 7.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-10 00:00:00', 10.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-11 00:00:00', 10.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-12 00:00:00', 12.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-13 00:00:00', 12.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-14 00:00:00', 13.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-15 00:00:00', 16.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-16 00:00:00', 13.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-17 00:00:00', 15.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-18 00:00:00', 17.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-19 00:00:00', 18.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-20 00:00:00', 20.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-21 00:00:00', 21.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-22 00:00:00', 19.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-23 00:00:00', 21.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-24 00:00:00', 22.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-25 00:00:00', 19.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-26 00:00:00', 18.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-27 00:00:00', 21.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-28 00:00:00', 22.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-29 00:00:00', 19.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-30 00:00:00', 17.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-03-31 00:00:00', 15.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-01 00:00:00', 19.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-02 00:00:00', 14.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-03 00:00:00', 17.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-04 00:00:00', 12.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-05 00:00:00', 20.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-06 00:00:00', 22.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-07 00:00:00', 24.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-08 00:00:00', 24.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-09 00:00:00', 27.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-10 00:00:00', 30.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-11 00:00:00', 29.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-12 00:00:00', 27.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-13 00:00:00', 28.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-14 00:00:00', 23.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-15 00:00:00', 26.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-16 00:00:00', 25.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-17 00:00:00', 27.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-18 00:00:00', 13.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-19 00:00:00', 14.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-20 00:00:00', 20.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-21 00:00:00', 22.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-22 00:00:00', 24.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-23 00:00:00', 29.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-24 00:00:00', 30.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-25 00:00:00', 26.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-26 00:00:00', 30.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-27 00:00:00', 21.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-28 00:00:00', 17.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-29 00:00:00', 22.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-04-30 00:00:00', 14.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-01 00:00:00', 16.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-02 00:00:00', 23.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-03 00:00:00', 27.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-04 00:00:00', 28.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-05 00:00:00', 26.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-06 00:00:00', 25.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-07 00:00:00', 28.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-08 00:00:00', 22.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-09 00:00:00', 21.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-10 00:00:00', 22.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-11 00:00:00', 23.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-12 00:00:00', 21.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-13 00:00:00', 19.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-14 00:00:00', 23.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-15 00:00:00', 23.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-16 00:00:00', 24.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-17 00:00:00', 28.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-18 00:00:00', 24.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-19 00:00:00', 24.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-20 00:00:00', 25.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-21 00:00:00', 24.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-22 00:00:00', 27.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-23 00:00:00', 27.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-24 00:00:00', 25.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-25 00:00:00', 20.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-26 00:00:00', 24.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-27 00:00:00', 26.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-28 00:00:00', 21.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-29 00:00:00', 26.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-30 00:00:00', 27.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-05-31 00:00:00', 29.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-01 00:00:00', 29.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-02 00:00:00', 30.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-03 00:00:00', 32.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-04 00:00:00', 33.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-05 00:00:00', 32.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-06 00:00:00', 33.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-07 00:00:00', 34.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-08 00:00:00', 34.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-09 00:00:00', 35.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-10 00:00:00', 37.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-11 00:00:00', 31.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-12 00:00:00', 31.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-13 00:00:00', 31.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-14 00:00:00', 32.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-15 00:00:00', 34.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-16 00:00:00', 35.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-17 00:00:00', 35.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-18 00:00:00', 34.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-19 00:00:00', 34.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-20 00:00:00', 35.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-21 00:00:00', 36.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-22 00:00:00', 37.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-23 00:00:00', 39.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-24 00:00:00', 40.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-25 00:00:00', 40.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-26 00:00:00', 38.5530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-27 00:00:00', 36.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-28 00:00:00', 34.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-29 00:00:00', 34.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-06-30 00:00:00', 36.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-01 00:00:00', 36.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-02 00:00:00', 35.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-03 00:00:00', 36.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-04 00:00:00', 35.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-05 00:00:00', 36.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-06 00:00:00', 38.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-07 00:00:00', 40.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-08 00:00:00', 41.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-09 00:00:00', 42.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-10 00:00:00', 43.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-11 00:00:00', 42.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-12 00:00:00', 40.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-13 00:00:00', 38.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-14 00:00:00', 37.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-15 00:00:00', 39.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-16 00:00:00', 40.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-17 00:00:00', 41.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-18 00:00:00', 41.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-19 00:00:00', 42.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-20 00:00:00', 41.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-21 00:00:00', 35.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-22 00:00:00', 35.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-23 00:00:00', 35.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-24 00:00:00', 36.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-25 00:00:00', 37.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-26 00:00:00', 38.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-27 00:00:00', 38.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-28 00:00:00', 38.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-29 00:00:00', 40.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-30 00:00:00', 41.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-07-31 00:00:00', 43.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-01 00:00:00', 43.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-02 00:00:00', 42.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-03 00:00:00', 40.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-04 00:00:00', 36.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-05 00:00:00', 32.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-06 00:00:00', 35.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-07 00:00:00', 33.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-08 00:00:00', 36.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-09 00:00:00', 35.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-10 00:00:00', 36.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-11 00:00:00', 37.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-12 00:00:00', 37.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-13 00:00:00', 37.4760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-14 00:00:00', 37.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-15 00:00:00', 38.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-16 00:00:00', 38.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-17 00:00:00', 38.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-18 00:00:00', 40.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-19 00:00:00', 39.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-20 00:00:00', 33.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-21 00:00:00', 31.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-22 00:00:00', 30.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-23 00:00:00', 30.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-24 00:00:00', 31.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-25 00:00:00', 32.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-26 00:00:00', 33.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-27 00:00:00', 33.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-28 00:00:00', 31.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-29 00:00:00', 31.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-30 00:00:00', 30.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-08-31 00:00:00', 32.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-01 00:00:00', 33.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-02 00:00:00', 31.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-03 00:00:00', 33.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-04 00:00:00', 34.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-05 00:00:00', 34.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-06 00:00:00', 35.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-07 00:00:00', 34.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-08 00:00:00', 36.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-09 00:00:00', 34.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-10 00:00:00', 34.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-11 00:00:00', 35.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-12 00:00:00', 34.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-13 00:00:00', 34.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-14 00:00:00', 32.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-15 00:00:00', 30.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-16 00:00:00', 29.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-17 00:00:00', 30.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-18 00:00:00', 29.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-19 00:00:00', 29.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-20 00:00:00', 30.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-21 00:00:00', 30.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-22 00:00:00', 28.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-23 00:00:00', 25.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-24 00:00:00', 24.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-25 00:00:00', 27.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-26 00:00:00', 28.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-27 00:00:00', 27.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-28 00:00:00', 26.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-29 00:00:00', 26.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-09-30 00:00:00', 27.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-01 00:00:00', 27.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-02 00:00:00', 28.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-03 00:00:00', 27.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-04 00:00:00', 28.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-05 00:00:00', 29.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-06 00:00:00', 29.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-07 00:00:00', 30.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-08 00:00:00', 28.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-09 00:00:00', 26.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-10 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-11 00:00:00', 22.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-12 00:00:00', 22.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-13 00:00:00', 24.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-14 00:00:00', 25.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-15 00:00:00', 25.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-16 00:00:00', 25.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-17 00:00:00', 25.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-18 00:00:00', 25.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-19 00:00:00', 25.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-20 00:00:00', 20.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-21 00:00:00', 24.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-22 00:00:00', 25.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-23 00:00:00', 27.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-24 00:00:00', 28.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-25 00:00:00', 28.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-26 00:00:00', 28.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-27 00:00:00', 28.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-28 00:00:00', 24.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-29 00:00:00', 25.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-30 00:00:00', 20.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-10-31 00:00:00', 20.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-01 00:00:00', 20.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-02 00:00:00', 24.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-03 00:00:00', 25.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-04 00:00:00', 25.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-05 00:00:00', 16.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-06 00:00:00', 10.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-07 00:00:00', 10.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-08 00:00:00', 10.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-09 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-10 00:00:00', 16.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-11 00:00:00', 11.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-12 00:00:00', 12.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-13 00:00:00', 7.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-14 00:00:00', 10.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-15 00:00:00', 14.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-16 00:00:00', 14.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-17 00:00:00', 15.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-18 00:00:00', 12.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-19 00:00:00', 13.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-20 00:00:00', 9.39700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-21 00:00:00', 9.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-22 00:00:00', 9.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-23 00:00:00', 12.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-24 00:00:00', 12.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-25 00:00:00', 14.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-26 00:00:00', 16.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-27 00:00:00', 17.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-28 00:00:00', 17.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-29 00:00:00', 18.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-11-30 00:00:00', 20.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-01 00:00:00', 19.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-02 00:00:00', 16.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-03 00:00:00', 10.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-04 00:00:00', 11.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-05 00:00:00', 9.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-06 00:00:00', 13.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-07 00:00:00', 15.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-08 00:00:00', 14.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-09 00:00:00', 14.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-10 00:00:00', 11.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-11 00:00:00', 9.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-12 00:00:00', 10.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-13 00:00:00', 10.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-14 00:00:00', 11.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-15 00:00:00', 8.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-16 00:00:00', 12.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-17 00:00:00', 8.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-18 00:00:00', 5.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-19 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-20 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-21 00:00:00', 11.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-22 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-23 00:00:00', 0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-24 00:00:00', 6.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-25 00:00:00', 9.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-26 00:00:00', 6.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-27 00:00:00', 7.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-28 00:00:00', 9.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-29 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-30 00:00:00', 6.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1979-12-31 00:00:00', 8.51500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-01 00:00:00', 6.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-02 00:00:00', 6.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-03 00:00:00', 8.18799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-04 00:00:00', 9.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-05 00:00:00', 8.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-06 00:00:00', 11.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-07 00:00:00', 15.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-08 00:00:00', 8.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-09 00:00:00', 6.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-10 00:00:00', 3.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-11 00:00:00', 6.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-12 00:00:00', 7.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-13 00:00:00', 9.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-14 00:00:00', 11.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-15 00:00:00', 5.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-16 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-17 00:00:00', 7.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-18 00:00:00', 6.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-19 00:00:00', 6.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-20 00:00:00', 7.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-21 00:00:00', 7.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-22 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-23 00:00:00', 6.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-24 00:00:00', 2.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-25 00:00:00', 0.214000001549720764, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-26 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-27 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-28 00:00:00', -0.677999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-29 00:00:00', 6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-30 00:00:00', 7.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-01-31 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-01 00:00:00', -1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-02 00:00:00', -4.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-03 00:00:00', -6.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-04 00:00:00', -6.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-05 00:00:00', -0.763999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-06 00:00:00', 0.695999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-07 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-08 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-09 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-10 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-11 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-12 00:00:00', 10.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-13 00:00:00', 7.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-14 00:00:00', 6.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-15 00:00:00', 11.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-16 00:00:00', 12.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-17 00:00:00', 9.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-18 00:00:00', 8.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-19 00:00:00', 12.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-20 00:00:00', 8.78699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-21 00:00:00', 6.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-22 00:00:00', 4.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-23 00:00:00', 7.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-24 00:00:00', 4.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-25 00:00:00', 6.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-26 00:00:00', 7.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-27 00:00:00', 5.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-28 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-02-29 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-01 00:00:00', 7.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-02 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-03 00:00:00', 7.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-04 00:00:00', 10.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-05 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-06 00:00:00', 5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-07 00:00:00', 11.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-08 00:00:00', 6.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-09 00:00:00', 5.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-10 00:00:00', 7.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-11 00:00:00', 8.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-12 00:00:00', 9.31999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-13 00:00:00', 14.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-14 00:00:00', 11.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-15 00:00:00', 11.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-16 00:00:00', 12.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-17 00:00:00', 7.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-18 00:00:00', 10.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-19 00:00:00', 15.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-20 00:00:00', 12.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-21 00:00:00', 13.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-22 00:00:00', 14.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-23 00:00:00', 15.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-24 00:00:00', 16.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-25 00:00:00', 16.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-26 00:00:00', 17.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-27 00:00:00', 13.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-28 00:00:00', 12.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-29 00:00:00', 15.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-30 00:00:00', 21.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-03-31 00:00:00', 22.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-01 00:00:00', 16.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-02 00:00:00', 19.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-03 00:00:00', 18.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-04 00:00:00', 22.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-05 00:00:00', 16.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-06 00:00:00', 21.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-07 00:00:00', 24.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-08 00:00:00', 26.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-09 00:00:00', 27.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-10 00:00:00', 27.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-11 00:00:00', 26.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-12 00:00:00', 25.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-13 00:00:00', 25.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-14 00:00:00', 27.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-15 00:00:00', 29.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-16 00:00:00', 30.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-17 00:00:00', 30.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-18 00:00:00', 20.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-19 00:00:00', 23.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-20 00:00:00', 24.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-21 00:00:00', 23.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-22 00:00:00', 24.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-23 00:00:00', 26.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-24 00:00:00', 29.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-25 00:00:00', 25.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-26 00:00:00', 29.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-27 00:00:00', 27.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-28 00:00:00', 26.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-29 00:00:00', 28.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-04-30 00:00:00', 30.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-01 00:00:00', 30.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-02 00:00:00', 31.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-03 00:00:00', 30.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-04 00:00:00', 32.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-05 00:00:00', 32.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-06 00:00:00', 34.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-07 00:00:00', 32.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-08 00:00:00', 26.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-09 00:00:00', 27.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-10 00:00:00', 27.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-11 00:00:00', 21.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-12 00:00:00', 22.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-13 00:00:00', 25.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-14 00:00:00', 29.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-15 00:00:00', 29.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-16 00:00:00', 27.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-17 00:00:00', 25.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-18 00:00:00', 27.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-19 00:00:00', 28.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-20 00:00:00', 28.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-21 00:00:00', 29.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-22 00:00:00', 31.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-23 00:00:00', 32.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-24 00:00:00', 33.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-25 00:00:00', 34.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-26 00:00:00', 35.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-27 00:00:00', 34.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-28 00:00:00', 34.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-29 00:00:00', 34.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-30 00:00:00', 34.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-05-31 00:00:00', 34.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-01 00:00:00', 30.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-02 00:00:00', 28.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-03 00:00:00', 32.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-04 00:00:00', 34.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-05 00:00:00', 34.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-06 00:00:00', 36.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-07 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-08 00:00:00', 38.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-09 00:00:00', 39.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-10 00:00:00', 41.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-11 00:00:00', 40.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-12 00:00:00', 31.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-13 00:00:00', 30.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-14 00:00:00', 32.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-15 00:00:00', 33.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-16 00:00:00', 35.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-17 00:00:00', 37.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-18 00:00:00', 39.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-19 00:00:00', 38.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-20 00:00:00', 37.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-21 00:00:00', 37.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-22 00:00:00', 39.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-23 00:00:00', 39.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-24 00:00:00', 35.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-25 00:00:00', 34.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-26 00:00:00', 34.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-27 00:00:00', 34.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-28 00:00:00', 35.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-29 00:00:00', 36.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-06-30 00:00:00', 36.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-01 00:00:00', 37.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-02 00:00:00', 40.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-03 00:00:00', 40.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-04 00:00:00', 39.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-05 00:00:00', 38.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-06 00:00:00', 39.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-07 00:00:00', 40.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-08 00:00:00', 40.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-09 00:00:00', 41.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-10 00:00:00', 42.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-11 00:00:00', 41.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-12 00:00:00', 37.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-13 00:00:00', 38.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-14 00:00:00', 38.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-15 00:00:00', 39.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-16 00:00:00', 40.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-17 00:00:00', 41.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-18 00:00:00', 39.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-19 00:00:00', 33.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-20 00:00:00', 35.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-21 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-22 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-23 00:00:00', 36.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-24 00:00:00', 38.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-25 00:00:00', 39.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-26 00:00:00', 38.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-27 00:00:00', 39.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-28 00:00:00', 39.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-29 00:00:00', 37.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-30 00:00:00', 37.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-07-31 00:00:00', 39.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-01 00:00:00', 40.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-02 00:00:00', 40.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-03 00:00:00', 36.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-04 00:00:00', 36.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-05 00:00:00', 38.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-06 00:00:00', 39.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-07 00:00:00', 37.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-08 00:00:00', 32.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-09 00:00:00', 33.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-10 00:00:00', 33.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-11 00:00:00', 34.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-12 00:00:00', 35.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-13 00:00:00', 34.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-14 00:00:00', 33.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-15 00:00:00', 33.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-16 00:00:00', 34.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-17 00:00:00', 35.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-18 00:00:00', 35.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-19 00:00:00', 36.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-20 00:00:00', 38.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-21 00:00:00', 39.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-22 00:00:00', 39.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-23 00:00:00', 35.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-24 00:00:00', 36.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-25 00:00:00', 34.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-26 00:00:00', 35.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-27 00:00:00', 35.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-28 00:00:00', 36.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-29 00:00:00', 36.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-30 00:00:00', 35.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-08-31 00:00:00', 29.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-01 00:00:00', 31.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-02 00:00:00', 30.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-03 00:00:00', 32.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-04 00:00:00', 31.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-05 00:00:00', 32.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-06 00:00:00', 32.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-07 00:00:00', 34.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-08 00:00:00', 35.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-09 00:00:00', 32.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-10 00:00:00', 27.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-11 00:00:00', 28.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-12 00:00:00', 27.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-13 00:00:00', 28.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-14 00:00:00', 29.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-15 00:00:00', 28.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-16 00:00:00', 31.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-17 00:00:00', 32.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-18 00:00:00', 31.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-19 00:00:00', 31.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-20 00:00:00', 32.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-21 00:00:00', 32.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-22 00:00:00', 35.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-23 00:00:00', 31.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-24 00:00:00', 29.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-25 00:00:00', 27.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-26 00:00:00', 28.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-27 00:00:00', 27.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-28 00:00:00', 27.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-29 00:00:00', 28.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-09-30 00:00:00', 29.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-01 00:00:00', 29.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-02 00:00:00', 29.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-03 00:00:00', 31.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-04 00:00:00', 30.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-05 00:00:00', 31.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-06 00:00:00', 31.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-07 00:00:00', 26.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-08 00:00:00', 24.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-09 00:00:00', 24.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-10 00:00:00', 17.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-11 00:00:00', 15.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-12 00:00:00', 21.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-13 00:00:00', 23.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-14 00:00:00', 24.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-15 00:00:00', 20.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-16 00:00:00', 18.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-17 00:00:00', 20.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-18 00:00:00', 22.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-19 00:00:00', 23.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-20 00:00:00', 25.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-21 00:00:00', 20.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-22 00:00:00', 15.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-23 00:00:00', 16.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-24 00:00:00', 19.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-25 00:00:00', 22.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-26 00:00:00', 23.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-27 00:00:00', 23.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-28 00:00:00', 21.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-29 00:00:00', 20.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-30 00:00:00', 19.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-10-31 00:00:00', 20.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-01 00:00:00', 20.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-02 00:00:00', 20.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-03 00:00:00', 18.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-04 00:00:00', 15.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-05 00:00:00', 14.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-06 00:00:00', 15.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-07 00:00:00', 19.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-08 00:00:00', 18.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-09 00:00:00', 22.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-10 00:00:00', 24.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-11 00:00:00', 22.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-12 00:00:00', 23.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-13 00:00:00', 23.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-14 00:00:00', 22.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-15 00:00:00', 20.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-16 00:00:00', 18.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-17 00:00:00', 21.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-18 00:00:00', 19.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-19 00:00:00', 14.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-20 00:00:00', 16.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-21 00:00:00', 17.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-22 00:00:00', 18.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-23 00:00:00', 19.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-24 00:00:00', 14.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-25 00:00:00', 9.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-26 00:00:00', 11.0679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-27 00:00:00', 11.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-28 00:00:00', 15.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-29 00:00:00', 17.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-11-30 00:00:00', 18.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-01 00:00:00', 15.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-02 00:00:00', 12.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-03 00:00:00', 13.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-04 00:00:00', 15.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-05 00:00:00', 12.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-06 00:00:00', 13.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-07 00:00:00', 18.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-08 00:00:00', 19.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-09 00:00:00', 14.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-10 00:00:00', 12.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-11 00:00:00', 12.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-12 00:00:00', 10.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-13 00:00:00', 10.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-14 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-15 00:00:00', 6.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-16 00:00:00', 6.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-17 00:00:00', 9.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-18 00:00:00', 8.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-19 00:00:00', 11.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-20 00:00:00', 6.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-21 00:00:00', 6.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-22 00:00:00', 10.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-23 00:00:00', 13.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-24 00:00:00', 11.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-25 00:00:00', 11.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-26 00:00:00', 7.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-27 00:00:00', 4.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-28 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-29 00:00:00', 8.35700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-30 00:00:00', 10.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1980-12-31 00:00:00', 5.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-01 00:00:00', 3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-02 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-03 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-04 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-05 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-06 00:00:00', 7.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-07 00:00:00', 8.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-08 00:00:00', 9.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-09 00:00:00', 7.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-10 00:00:00', 7.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-11 00:00:00', 10.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-12 00:00:00', 12.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-13 00:00:00', 10.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-14 00:00:00', 6.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-15 00:00:00', 3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-16 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-17 00:00:00', 7.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-18 00:00:00', 9.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-19 00:00:00', 12.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-20 00:00:00', 10.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-21 00:00:00', 9.75300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-22 00:00:00', 11.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-23 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-24 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-25 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-26 00:00:00', 7.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-27 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-28 00:00:00', 8.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-29 00:00:00', 8.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-30 00:00:00', 5.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-01-31 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-01 00:00:00', 7.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-02 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-03 00:00:00', 7.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-04 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-05 00:00:00', 7.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-06 00:00:00', 11.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-07 00:00:00', 9.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-08 00:00:00', 11.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-09 00:00:00', 12.3900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-10 00:00:00', 11.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-11 00:00:00', 9.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-12 00:00:00', 9.52499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-13 00:00:00', 8.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-14 00:00:00', 8.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-15 00:00:00', 10.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-16 00:00:00', 7.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-17 00:00:00', 5.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-18 00:00:00', 10.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-19 00:00:00', 12.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-20 00:00:00', 12.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-21 00:00:00', 15.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-22 00:00:00', 14.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-23 00:00:00', 7.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-24 00:00:00', 4.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-25 00:00:00', 9.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-26 00:00:00', 8.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-27 00:00:00', 11.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-02-28 00:00:00', 8.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-01 00:00:00', 5.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-02 00:00:00', 11.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-03 00:00:00', 14.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-04 00:00:00', 17.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-05 00:00:00', 11.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-06 00:00:00', 13.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-07 00:00:00', 14.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-08 00:00:00', 15.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-09 00:00:00', 11.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-10 00:00:00', 13.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-11 00:00:00', 13.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-12 00:00:00', 17.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-13 00:00:00', 19.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-14 00:00:00', 19.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-15 00:00:00', 17.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-16 00:00:00', 14.6029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-17 00:00:00', 12.6920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-18 00:00:00', 12.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-19 00:00:00', 14.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-20 00:00:00', 13.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-21 00:00:00', 14.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-22 00:00:00', 20.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-23 00:00:00', 22.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-24 00:00:00', 19.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-25 00:00:00', 22.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-26 00:00:00', 17.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-27 00:00:00', 20.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-28 00:00:00', 24.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-29 00:00:00', 16.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-30 00:00:00', 14.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-03-31 00:00:00', 18.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-01 00:00:00', 21.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-02 00:00:00', 19.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-03 00:00:00', 10.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-04 00:00:00', 11.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-05 00:00:00', 15.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-06 00:00:00', 18.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-07 00:00:00', 18.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-08 00:00:00', 19.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-09 00:00:00', 24.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-10 00:00:00', 20.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-11 00:00:00', 18.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-12 00:00:00', 12.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-13 00:00:00', 21.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-14 00:00:00', 6.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-15 00:00:00', 8.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-16 00:00:00', 23.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-17 00:00:00', 27.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-18 00:00:00', 31.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-19 00:00:00', 20.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-20 00:00:00', 17.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-21 00:00:00', 20.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-22 00:00:00', 22.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-23 00:00:00', 25.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-24 00:00:00', 29.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-25 00:00:00', 29.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-26 00:00:00', 30.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-27 00:00:00', 31.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-28 00:00:00', 28.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-29 00:00:00', 29.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-04-30 00:00:00', 25.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-01 00:00:00', 30.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-02 00:00:00', 32.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-03 00:00:00', 31.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-04 00:00:00', 23.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-05 00:00:00', 25.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-06 00:00:00', 27.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-07 00:00:00', 29.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-08 00:00:00', 23.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-09 00:00:00', 26.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-10 00:00:00', 27.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-11 00:00:00', 27.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-12 00:00:00', 29.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-13 00:00:00', 32.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-14 00:00:00', 27.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-15 00:00:00', 29.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-16 00:00:00', 32.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-17 00:00:00', 34.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-18 00:00:00', 29.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-19 00:00:00', 24.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-20 00:00:00', 25.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-21 00:00:00', 29.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-22 00:00:00', 29.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-23 00:00:00', 31.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-24 00:00:00', 35.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-25 00:00:00', 33.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-26 00:00:00', 34.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-27 00:00:00', 33.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-28 00:00:00', 34.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-29 00:00:00', 33.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-30 00:00:00', 26.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-05-31 00:00:00', 26.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-01 00:00:00', 26.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-02 00:00:00', 27.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-03 00:00:00', 29.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-04 00:00:00', 29.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-05 00:00:00', 33.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-06 00:00:00', 34.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-07 00:00:00', 30.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-08 00:00:00', 29.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-09 00:00:00', 29.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-10 00:00:00', 29.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-11 00:00:00', 29.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-12 00:00:00', 31.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-13 00:00:00', 32.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-14 00:00:00', 31.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-15 00:00:00', 34.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-16 00:00:00', 35.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-17 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-18 00:00:00', 35.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-19 00:00:00', 36.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-20 00:00:00', 37.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-21 00:00:00', 35.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-22 00:00:00', 38.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-23 00:00:00', 37.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-24 00:00:00', 37.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-25 00:00:00', 37.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-26 00:00:00', 37.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-27 00:00:00', 37.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-28 00:00:00', 37.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-29 00:00:00', 38.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-06-30 00:00:00', 35.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-01 00:00:00', 34.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-02 00:00:00', 35.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-03 00:00:00', 35.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-04 00:00:00', 36.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-05 00:00:00', 36.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-06 00:00:00', 38.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-07 00:00:00', 40.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-08 00:00:00', 35.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-09 00:00:00', 36.4760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-10 00:00:00', 36.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-11 00:00:00', 39.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-12 00:00:00', 40.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-13 00:00:00', 44.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-14 00:00:00', 44.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-15 00:00:00', 42.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-16 00:00:00', 37.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-17 00:00:00', 37.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-18 00:00:00', 35.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-19 00:00:00', 35.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-20 00:00:00', 37.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-21 00:00:00', 39.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-22 00:00:00', 35.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-23 00:00:00', 30.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-24 00:00:00', 30.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-25 00:00:00', 32.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-26 00:00:00', 35.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-27 00:00:00', 36.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-28 00:00:00', 36.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-29 00:00:00', 35.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-30 00:00:00', 33.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-07-31 00:00:00', 34.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-01 00:00:00', 33.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-02 00:00:00', 33.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-03 00:00:00', 33.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-04 00:00:00', 34.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-05 00:00:00', 34.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-06 00:00:00', 36.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-07 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-08 00:00:00', 37.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-09 00:00:00', 38.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-10 00:00:00', 39.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-11 00:00:00', 38.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-12 00:00:00', 34.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-13 00:00:00', 34.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-14 00:00:00', 34.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-15 00:00:00', 35.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-16 00:00:00', 35.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-17 00:00:00', 37.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-18 00:00:00', 36.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-19 00:00:00', 35.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-20 00:00:00', 32.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-21 00:00:00', 32.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-22 00:00:00', 31.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-23 00:00:00', 32.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-24 00:00:00', 33.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-25 00:00:00', 33.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-26 00:00:00', 32.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-27 00:00:00', 32.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-28 00:00:00', 32.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-29 00:00:00', 31.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-30 00:00:00', 32.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-08-31 00:00:00', 34.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-01 00:00:00', 34.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-02 00:00:00', 31.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-03 00:00:00', 30.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-04 00:00:00', 31.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-05 00:00:00', 29.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-06 00:00:00', 30.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-07 00:00:00', 30.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-08 00:00:00', 31.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-09 00:00:00', 31.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-10 00:00:00', 29.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-11 00:00:00', 29.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-12 00:00:00', 31.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-13 00:00:00', 33.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-14 00:00:00', 35.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-15 00:00:00', 36.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-16 00:00:00', 36.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-17 00:00:00', 35.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-18 00:00:00', 35.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-19 00:00:00', 35.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-20 00:00:00', 34.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-21 00:00:00', 33.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-22 00:00:00', 31.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-23 00:00:00', 20.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-24 00:00:00', 20.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-25 00:00:00', 24.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-26 00:00:00', 26.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-27 00:00:00', 27.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-28 00:00:00', 26.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-29 00:00:00', 24.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-09-30 00:00:00', 25.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-01 00:00:00', 22.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-02 00:00:00', 21.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-03 00:00:00', 21.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-04 00:00:00', 22.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-05 00:00:00', 22.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-06 00:00:00', 22.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-07 00:00:00', 21.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-08 00:00:00', 23.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-09 00:00:00', 24.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-10 00:00:00', 22.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-11 00:00:00', 22.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-12 00:00:00', 23.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-13 00:00:00', 24.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-14 00:00:00', 18.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-15 00:00:00', 21.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-16 00:00:00', 20.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-17 00:00:00', 24.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-18 00:00:00', 23.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-19 00:00:00', 16.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-20 00:00:00', 14.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-21 00:00:00', 19.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-22 00:00:00', 20.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-23 00:00:00', 17.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-24 00:00:00', 17.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-25 00:00:00', 19.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-26 00:00:00', 17.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-27 00:00:00', 18.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-28 00:00:00', 17.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-29 00:00:00', 17.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-30 00:00:00', 15.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-10-31 00:00:00', 17.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-01 00:00:00', 18.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-02 00:00:00', 20.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-03 00:00:00', 18.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-04 00:00:00', 20.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-05 00:00:00', 22.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-06 00:00:00', 24.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-07 00:00:00', 19.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-08 00:00:00', 16.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-09 00:00:00', 17.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-10 00:00:00', 15.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-11 00:00:00', 17.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-12 00:00:00', 19.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-13 00:00:00', 20.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-14 00:00:00', 22.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-15 00:00:00', 20.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-16 00:00:00', 16.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-17 00:00:00', 15.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-18 00:00:00', 16.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-19 00:00:00', 17.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-20 00:00:00', 17.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-21 00:00:00', 17.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-22 00:00:00', 16.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-23 00:00:00', 12.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-24 00:00:00', 7.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-25 00:00:00', 9.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-26 00:00:00', 11.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-27 00:00:00', 12.1190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-28 00:00:00', 14.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-29 00:00:00', 13.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-11-30 00:00:00', 13.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-01 00:00:00', 13.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-02 00:00:00', 7.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-03 00:00:00', 9.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-04 00:00:00', 8.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-05 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-06 00:00:00', 10.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-07 00:00:00', 10.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-08 00:00:00', 8.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-09 00:00:00', 11.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-10 00:00:00', 10.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-11 00:00:00', 11.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-12 00:00:00', 12.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-13 00:00:00', 12.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-14 00:00:00', 12.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-15 00:00:00', 11.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-16 00:00:00', 10.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-17 00:00:00', 14.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-18 00:00:00', 14.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-19 00:00:00', 16.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-20 00:00:00', 11.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-21 00:00:00', 8.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-22 00:00:00', 8.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-23 00:00:00', 12.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-24 00:00:00', 13.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-25 00:00:00', 10.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-26 00:00:00', 11.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-27 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-28 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-29 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-30 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1981-12-31 00:00:00', 7.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-01 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-02 00:00:00', 9.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-03 00:00:00', 8.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-04 00:00:00', 9.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-05 00:00:00', 11.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-06 00:00:00', 13.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-07 00:00:00', 17.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-08 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-09 00:00:00', 15.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-10 00:00:00', 14.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-11 00:00:00', 12.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-12 00:00:00', 6.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-13 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-14 00:00:00', 4.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-15 00:00:00', 6.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-16 00:00:00', 5.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-17 00:00:00', 8.32900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-18 00:00:00', 7.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-19 00:00:00', -0.663999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-20 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-21 00:00:00', -0.137999996542930603, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-22 00:00:00', -2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-23 00:00:00', -0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-24 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-25 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-26 00:00:00', 1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-27 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-28 00:00:00', 4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-29 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-30 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-01-31 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-01 00:00:00', 8.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-02 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-03 00:00:00', 6.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-04 00:00:00', 8.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-05 00:00:00', 10.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-06 00:00:00', 7.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-07 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-08 00:00:00', 5.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-09 00:00:00', 5.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-10 00:00:00', 6.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-11 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-12 00:00:00', 4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-13 00:00:00', 7.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-14 00:00:00', 10.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-15 00:00:00', 7.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-16 00:00:00', 5.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-17 00:00:00', 8.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-18 00:00:00', 10.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-19 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-20 00:00:00', -0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-21 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-22 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-23 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-24 00:00:00', 4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-25 00:00:00', 6.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-26 00:00:00', 6.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-27 00:00:00', 7.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-02-28 00:00:00', 9.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-01 00:00:00', 6.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-02 00:00:00', 7.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-03 00:00:00', 7.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-04 00:00:00', 6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-05 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-06 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-07 00:00:00', 6.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-08 00:00:00', 8.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-09 00:00:00', 6.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-10 00:00:00', 8.63099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-11 00:00:00', 9.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-12 00:00:00', 12.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-13 00:00:00', 9.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-14 00:00:00', 12.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-15 00:00:00', 11.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-16 00:00:00', 12.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-17 00:00:00', 10.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-18 00:00:00', 12.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-19 00:00:00', 12.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-20 00:00:00', 13.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-21 00:00:00', 11.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-22 00:00:00', 11.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-23 00:00:00', 14.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-24 00:00:00', 18.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-25 00:00:00', 14.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-26 00:00:00', 9.77900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-27 00:00:00', 12.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-28 00:00:00', 11.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-29 00:00:00', 12.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-30 00:00:00', 9.41199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-03-31 00:00:00', 10.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-01 00:00:00', 13.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-02 00:00:00', 16.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-03 00:00:00', 11.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-04 00:00:00', 11.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-05 00:00:00', 10.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-06 00:00:00', 14.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-07 00:00:00', 18.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-08 00:00:00', 20.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-09 00:00:00', 22.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-10 00:00:00', 24.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-11 00:00:00', 20.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-12 00:00:00', 23.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-13 00:00:00', 24.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-14 00:00:00', 24.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-15 00:00:00', 22.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-16 00:00:00', 20.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-17 00:00:00', 22.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-18 00:00:00', 23.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-19 00:00:00', 26.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-20 00:00:00', 28.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-21 00:00:00', 28.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-22 00:00:00', 29.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-23 00:00:00', 29.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-24 00:00:00', 27.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-25 00:00:00', 26.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-26 00:00:00', 24.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-27 00:00:00', 23.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-28 00:00:00', 26.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-29 00:00:00', 26.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-04-30 00:00:00', 28.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-01 00:00:00', 30.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-02 00:00:00', 30.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-03 00:00:00', 31.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-04 00:00:00', 31.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-05 00:00:00', 31.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-06 00:00:00', 31.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-07 00:00:00', 31.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-08 00:00:00', 31.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-09 00:00:00', 29.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-10 00:00:00', 25.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-11 00:00:00', 24.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-12 00:00:00', 24.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-13 00:00:00', 26.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-14 00:00:00', 26.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-15 00:00:00', 27.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-16 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-17 00:00:00', 30.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-18 00:00:00', 30.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-19 00:00:00', 32.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-20 00:00:00', 34.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-21 00:00:00', 35.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-22 00:00:00', 31.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-23 00:00:00', 32.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-24 00:00:00', 32.1500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-25 00:00:00', 29.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-26 00:00:00', 26.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-27 00:00:00', 29.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-28 00:00:00', 29.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-29 00:00:00', 23.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-30 00:00:00', 27.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-05-31 00:00:00', 29.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-01 00:00:00', 30.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-02 00:00:00', 33.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-03 00:00:00', 32.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-04 00:00:00', 32.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-05 00:00:00', 35.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-06 00:00:00', 36.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-07 00:00:00', 36.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-08 00:00:00', 33.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-09 00:00:00', 37.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-10 00:00:00', 39.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-11 00:00:00', 37.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-12 00:00:00', 37.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-13 00:00:00', 38.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-14 00:00:00', 35.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-15 00:00:00', 33.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-16 00:00:00', 35.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-17 00:00:00', 31.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-18 00:00:00', 31.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-19 00:00:00', 33.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-20 00:00:00', 34.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-21 00:00:00', 34.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-22 00:00:00', 36.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-23 00:00:00', 37.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-24 00:00:00', 37.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-25 00:00:00', 37.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-26 00:00:00', 36.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-27 00:00:00', 36.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-28 00:00:00', 36.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-29 00:00:00', 38.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-06-30 00:00:00', 26.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-01 00:00:00', 28.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-02 00:00:00', 32.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-03 00:00:00', 33.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-04 00:00:00', 35.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-05 00:00:00', 36.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-06 00:00:00', 33.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-07 00:00:00', 34.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-08 00:00:00', 34.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-09 00:00:00', 34.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-10 00:00:00', 36.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-11 00:00:00', 37.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-12 00:00:00', 32.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-13 00:00:00', 35.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-14 00:00:00', 36.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-15 00:00:00', 36.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-16 00:00:00', 38.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-17 00:00:00', 38.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-18 00:00:00', 39.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-19 00:00:00', 40.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-20 00:00:00', 39.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-21 00:00:00', 38.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-22 00:00:00', 38.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-23 00:00:00', 39.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-24 00:00:00', 39.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-25 00:00:00', 38.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-26 00:00:00', 38.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-27 00:00:00', 40.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-28 00:00:00', 40.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-29 00:00:00', 40.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-30 00:00:00', 41.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-07-31 00:00:00', 42.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-01 00:00:00', 43.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-02 00:00:00', 43.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-03 00:00:00', 42.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-04 00:00:00', 41.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-05 00:00:00', 41.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-06 00:00:00', 42.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-07 00:00:00', 42.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-08 00:00:00', 41.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-09 00:00:00', 40.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-10 00:00:00', 40.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-11 00:00:00', 33.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-12 00:00:00', 33.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-13 00:00:00', 34.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-14 00:00:00', 36.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-15 00:00:00', 35.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-16 00:00:00', 32.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-17 00:00:00', 33.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-18 00:00:00', 34.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-19 00:00:00', 35.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-20 00:00:00', 35.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-21 00:00:00', 34.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-22 00:00:00', 33.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-23 00:00:00', 31.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-24 00:00:00', 26.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-25 00:00:00', 26.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-26 00:00:00', 29.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-27 00:00:00', 30.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-28 00:00:00', 32.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-29 00:00:00', 31.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-30 00:00:00', 31.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-08-31 00:00:00', 32.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-01 00:00:00', 33.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-02 00:00:00', 32.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-03 00:00:00', 30.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-04 00:00:00', 31.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-05 00:00:00', 31.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-06 00:00:00', 30.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-07 00:00:00', 30.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-08 00:00:00', 30.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-09 00:00:00', 31.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-10 00:00:00', 31.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-11 00:00:00', 31.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-12 00:00:00', 31.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-13 00:00:00', 32.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-14 00:00:00', 31.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-15 00:00:00', 31.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-16 00:00:00', 30.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-17 00:00:00', 29.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-18 00:00:00', 27.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-19 00:00:00', 28.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-20 00:00:00', 24.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-21 00:00:00', 22.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-22 00:00:00', 23.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-23 00:00:00', 23.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-24 00:00:00', 25.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-25 00:00:00', 25.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-26 00:00:00', 24.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-27 00:00:00', 26.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-28 00:00:00', 25.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-29 00:00:00', 25.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-09-30 00:00:00', 24.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-01 00:00:00', 25.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-02 00:00:00', 28.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-03 00:00:00', 27.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-04 00:00:00', 25.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-05 00:00:00', 26.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-06 00:00:00', 25.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-07 00:00:00', 20.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-08 00:00:00', 19.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-09 00:00:00', 20.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-10 00:00:00', 26.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-11 00:00:00', 20.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-12 00:00:00', 23.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-13 00:00:00', 24.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-14 00:00:00', 26.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-15 00:00:00', 27.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-16 00:00:00', 26.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-17 00:00:00', 24.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-18 00:00:00', 24.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-19 00:00:00', 24.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-20 00:00:00', 23.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-21 00:00:00', 25.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-22 00:00:00', 23.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-23 00:00:00', 20.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-24 00:00:00', 18.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-25 00:00:00', 12.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-26 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-27 00:00:00', 9.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-28 00:00:00', 15.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-29 00:00:00', 19.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-30 00:00:00', 20.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-10-31 00:00:00', 15.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-01 00:00:00', 13.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-02 00:00:00', 12.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-03 00:00:00', 11.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-04 00:00:00', 15.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-05 00:00:00', 15.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-06 00:00:00', 18.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-07 00:00:00', 21.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-08 00:00:00', 18.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-09 00:00:00', 20.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-10 00:00:00', 12.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-11 00:00:00', 9.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-12 00:00:00', 13.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-13 00:00:00', 12.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-14 00:00:00', 8.23499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-15 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-16 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-17 00:00:00', 10.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-18 00:00:00', 6.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-19 00:00:00', 9.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-20 00:00:00', 8.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-21 00:00:00', 8.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-22 00:00:00', 10.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-23 00:00:00', 10.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-24 00:00:00', 6.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-25 00:00:00', 7.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-26 00:00:00', 8.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-27 00:00:00', 10.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-28 00:00:00', 9.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-29 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-11-30 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-01 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-02 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-03 00:00:00', 7.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-04 00:00:00', 10.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-05 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-06 00:00:00', 8.27900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-07 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-08 00:00:00', 4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-09 00:00:00', -2.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-10 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-11 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-12 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-13 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-14 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-15 00:00:00', 7.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-16 00:00:00', 6.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-17 00:00:00', 8.28400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-18 00:00:00', 10.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-19 00:00:00', 9.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-20 00:00:00', 10.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-21 00:00:00', 10.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-22 00:00:00', 9.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-23 00:00:00', 8.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-24 00:00:00', 10.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-25 00:00:00', 10.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-26 00:00:00', 10.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-27 00:00:00', 7.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-28 00:00:00', 6.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-29 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-30 00:00:00', 6.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1982-12-31 00:00:00', 6.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-01 00:00:00', 8.02000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-02 00:00:00', 9.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-03 00:00:00', 8.46100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-04 00:00:00', 9.77700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-05 00:00:00', 5.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-06 00:00:00', 9.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-07 00:00:00', 5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-08 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-09 00:00:00', 0.625999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-10 00:00:00', 6.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-11 00:00:00', 0.595000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-12 00:00:00', 3.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-13 00:00:00', 6.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-14 00:00:00', 2.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-15 00:00:00', 0.922999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-16 00:00:00', 10.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-17 00:00:00', 8.01500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-18 00:00:00', 12.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-19 00:00:00', 12.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-20 00:00:00', 14.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-21 00:00:00', 18.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-22 00:00:00', 10.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-23 00:00:00', 12.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-24 00:00:00', 15.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-25 00:00:00', 13.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-26 00:00:00', 8.51099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-27 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-28 00:00:00', -0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-29 00:00:00', 0.611999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-30 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-01-31 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-01 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-02 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-03 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-04 00:00:00', 5.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-05 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-06 00:00:00', 3.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-07 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-08 00:00:00', 5.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-09 00:00:00', 6.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-10 00:00:00', 4.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-11 00:00:00', 6.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-12 00:00:00', 8.38599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-13 00:00:00', 7.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-14 00:00:00', 8.32400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-15 00:00:00', 11.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-16 00:00:00', 11.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-17 00:00:00', 13.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-18 00:00:00', 13.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-19 00:00:00', 12.1689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-20 00:00:00', 10.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-21 00:00:00', 10.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-22 00:00:00', 10.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-23 00:00:00', 7.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-24 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-25 00:00:00', 6.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-26 00:00:00', 9.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-27 00:00:00', 10.3900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-02-28 00:00:00', 8.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-01 00:00:00', 6.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-02 00:00:00', 8.00300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-03 00:00:00', 8.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-04 00:00:00', 10.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-05 00:00:00', 14.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-06 00:00:00', 14.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-07 00:00:00', 11.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-08 00:00:00', 8.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-09 00:00:00', 4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-10 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-11 00:00:00', 4.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-12 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-13 00:00:00', 5.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-14 00:00:00', 9.30500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-15 00:00:00', 10.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-16 00:00:00', 11.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-17 00:00:00', 8.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-18 00:00:00', 7.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-19 00:00:00', 6.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-20 00:00:00', 6.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-21 00:00:00', 8.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-22 00:00:00', 11.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-23 00:00:00', 12.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-24 00:00:00', 15.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-25 00:00:00', 8.29800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-26 00:00:00', 7.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-27 00:00:00', 9.99400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-28 00:00:00', 10.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-29 00:00:00', 13.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-30 00:00:00', 15.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-03-31 00:00:00', 17.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-01 00:00:00', 18.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-02 00:00:00', 19.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-03 00:00:00', 22.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-04 00:00:00', 19.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-05 00:00:00', 20.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-06 00:00:00', 20.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-07 00:00:00', 17.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-08 00:00:00', 19.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-09 00:00:00', 17.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-10 00:00:00', 17.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-11 00:00:00', 20.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-12 00:00:00', 16.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-13 00:00:00', 17.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-14 00:00:00', 18.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-15 00:00:00', 18.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-16 00:00:00', 16.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-17 00:00:00', 19.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-18 00:00:00', 22.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-19 00:00:00', 23.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-20 00:00:00', 25.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-21 00:00:00', 27.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-22 00:00:00', 23.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-23 00:00:00', 25.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-24 00:00:00', 26.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-25 00:00:00', 27.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-26 00:00:00', 27.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-27 00:00:00', 22.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-28 00:00:00', 24.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-29 00:00:00', 17.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-04-30 00:00:00', 18.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-01 00:00:00', 21.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-02 00:00:00', 25.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-03 00:00:00', 24.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-04 00:00:00', 22.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-05 00:00:00', 27.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-06 00:00:00', 30.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-07 00:00:00', 32.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-08 00:00:00', 25.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-09 00:00:00', 30.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-10 00:00:00', 30.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-11 00:00:00', 27.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-12 00:00:00', 29.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-13 00:00:00', 28.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-14 00:00:00', 30.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-15 00:00:00', 30.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-16 00:00:00', 31.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-17 00:00:00', 31.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-18 00:00:00', 32.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-19 00:00:00', 29.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-20 00:00:00', 30.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-21 00:00:00', 30.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-22 00:00:00', 28.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-23 00:00:00', 30.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-24 00:00:00', 30.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-25 00:00:00', 33.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-26 00:00:00', 33.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-27 00:00:00', 32.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-28 00:00:00', 32.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-29 00:00:00', 31.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-30 00:00:00', 28.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-05-31 00:00:00', 24.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-01 00:00:00', 26.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-02 00:00:00', 27.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-03 00:00:00', 29.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-04 00:00:00', 31.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-05 00:00:00', 31.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-06 00:00:00', 32.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-07 00:00:00', 31.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-08 00:00:00', 32.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-09 00:00:00', 32.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-10 00:00:00', 32.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-11 00:00:00', 33.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-12 00:00:00', 34.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-13 00:00:00', 36.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-14 00:00:00', 35.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-15 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-16 00:00:00', 34.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-17 00:00:00', 33.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-18 00:00:00', 33.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-19 00:00:00', 36.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-20 00:00:00', 36.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-21 00:00:00', 37.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-22 00:00:00', 38.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-23 00:00:00', 38.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-24 00:00:00', 40.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-25 00:00:00', 40.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-26 00:00:00', 41.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-27 00:00:00', 39.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-28 00:00:00', 40.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-29 00:00:00', 40.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-06-30 00:00:00', 40.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-01 00:00:00', 39.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-02 00:00:00', 36.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-03 00:00:00', 34.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-04 00:00:00', 35.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-05 00:00:00', 35.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-06 00:00:00', 35.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-07 00:00:00', 34.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-08 00:00:00', 36.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-09 00:00:00', 37.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-10 00:00:00', 37.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-11 00:00:00', 36.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-12 00:00:00', 37.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-13 00:00:00', 37.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-14 00:00:00', 38.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-15 00:00:00', 39.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-16 00:00:00', 39.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-17 00:00:00', 39.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-18 00:00:00', 40.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-19 00:00:00', 36.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-20 00:00:00', 37.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-21 00:00:00', 39.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-22 00:00:00', 44.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-23 00:00:00', 43.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-24 00:00:00', 43.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-25 00:00:00', 42.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-26 00:00:00', 37.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-27 00:00:00', 37.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-28 00:00:00', 43.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-29 00:00:00', 44.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-30 00:00:00', 44.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-07-31 00:00:00', 44.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-01 00:00:00', 42.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-02 00:00:00', 39.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-03 00:00:00', 40.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-04 00:00:00', 41.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-05 00:00:00', 41.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-06 00:00:00', 41.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-07 00:00:00', 38.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-08 00:00:00', 36.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-09 00:00:00', 34.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-10 00:00:00', 35.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-11 00:00:00', 36.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-12 00:00:00', 36.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-13 00:00:00', 38.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-14 00:00:00', 37.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-15 00:00:00', 39.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-16 00:00:00', 38.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-17 00:00:00', 38.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-18 00:00:00', 38.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-19 00:00:00', 38.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-20 00:00:00', 37.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-21 00:00:00', 37.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-22 00:00:00', 37.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-23 00:00:00', 39.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-24 00:00:00', 39.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-25 00:00:00', 37.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-26 00:00:00', 34.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-27 00:00:00', 32.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-28 00:00:00', 34.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-29 00:00:00', 37.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-30 00:00:00', 39.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-08-31 00:00:00', 39.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-01 00:00:00', 26.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-03 00:00:00', 25.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-05 00:00:00', 26.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-07 00:00:00', 28.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-09 00:00:00', 27.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-11 00:00:00', 30.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-13 00:00:00', 27.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-15 00:00:00', 23.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-17 00:00:00', 22.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-19 00:00:00', 23.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-21 00:00:00', 25.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-23 00:00:00', 25.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-25 00:00:00', 26.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-27 00:00:00', 18.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-29 00:00:00', 19.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-01 00:00:00', 22.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-03 00:00:00', 17.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-05 00:00:00', 18.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-07 00:00:00', 19.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-09 00:00:00', 18.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-11 00:00:00', 16.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-13 00:00:00', 19.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-15 00:00:00', 19.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-17 00:00:00', 19.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-19 00:00:00', 19.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-21 00:00:00', 19.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-23 00:00:00', 18.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-25 00:00:00', 21.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-27 00:00:00', 22.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-29 00:00:00', 19.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-30 00:00:00', 20.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-10-31 00:00:00', 23.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-01 00:00:00', 24.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-02 00:00:00', 21.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-03 00:00:00', 18.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-04 00:00:00', 15.1579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-05 00:00:00', 8.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-06 00:00:00', 12.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-07 00:00:00', 17.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-08 00:00:00', 17.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-09 00:00:00', 15.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-10 00:00:00', 17.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-11 00:00:00', 19.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-12 00:00:00', 20.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-13 00:00:00', 23.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-14 00:00:00', 23.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-15 00:00:00', 22.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-16 00:00:00', 20.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-17 00:00:00', 15.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-18 00:00:00', 18.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-19 00:00:00', 19.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-20 00:00:00', 20.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-21 00:00:00', 19.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-22 00:00:00', 20.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-23 00:00:00', 21.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-24 00:00:00', 20.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-25 00:00:00', 20.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-26 00:00:00', 13.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-27 00:00:00', 12.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-28 00:00:00', 16.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-29 00:00:00', 20.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-11-30 00:00:00', 19.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-01 00:00:00', 18.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-02 00:00:00', 17.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-03 00:00:00', 15.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-04 00:00:00', 9.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-05 00:00:00', 10.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-06 00:00:00', 11.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-07 00:00:00', 13.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-08 00:00:00', 14.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-09 00:00:00', 15.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-10 00:00:00', 12.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-11 00:00:00', 14.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-12 00:00:00', 15.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-13 00:00:00', 16.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-14 00:00:00', 11.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-15 00:00:00', 10.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-16 00:00:00', 3.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-17 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-18 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-19 00:00:00', 2.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-20 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-21 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-22 00:00:00', -0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-23 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-24 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-25 00:00:00', 0.605000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-26 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-27 00:00:00', 7.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-28 00:00:00', 6.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-29 00:00:00', 6.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-30 00:00:00', 7.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1983-12-31 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-01 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-02 00:00:00', 9.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-03 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-04 00:00:00', 6.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-05 00:00:00', 1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-06 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-07 00:00:00', 7.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-08 00:00:00', 7.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-09 00:00:00', 9.54399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-10 00:00:00', 9.78400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-11 00:00:00', 6.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-12 00:00:00', 5.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-13 00:00:00', 6.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-14 00:00:00', 7.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-15 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-16 00:00:00', 2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-17 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-18 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-19 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-20 00:00:00', 1.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-21 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-22 00:00:00', 0.451000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-23 00:00:00', 1.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-24 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-25 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-26 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-27 00:00:00', 2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-28 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-29 00:00:00', 5.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-30 00:00:00', 9.42800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-01-31 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-01 00:00:00', -0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-02 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-03 00:00:00', -1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-04 00:00:00', -3.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-05 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-06 00:00:00', -1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-07 00:00:00', -4.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-08 00:00:00', 0.236000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-09 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-10 00:00:00', 0.919000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-11 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-12 00:00:00', 0.957000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-13 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-14 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-15 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-16 00:00:00', -1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-17 00:00:00', -2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-18 00:00:00', -4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-19 00:00:00', -6.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-20 00:00:00', -6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-21 00:00:00', -5.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-22 00:00:00', -2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-23 00:00:00', -2.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-24 00:00:00', 0.143000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-25 00:00:00', 0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-26 00:00:00', 0.180000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-27 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-28 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-02-29 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-01 00:00:00', 2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-02 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-03 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-04 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-05 00:00:00', 0.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-06 00:00:00', 2.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-07 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-08 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-09 00:00:00', 7.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-10 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-11 00:00:00', 4.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-12 00:00:00', 7.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-13 00:00:00', 11.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-14 00:00:00', 12.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-15 00:00:00', 12.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-16 00:00:00', 14.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-17 00:00:00', 9.96599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-18 00:00:00', 8.32400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-19 00:00:00', 11.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-20 00:00:00', 14.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-21 00:00:00', 15.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-22 00:00:00', 16.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-23 00:00:00', 18.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-24 00:00:00', 20.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-25 00:00:00', 14.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-26 00:00:00', 17.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-27 00:00:00', 14.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-28 00:00:00', 14.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-29 00:00:00', 15.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-30 00:00:00', 17.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-03-31 00:00:00', 15.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-01 00:00:00', 17.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-02 00:00:00', 16.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-03 00:00:00', 16.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-04 00:00:00', 15.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-05 00:00:00', 13.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-06 00:00:00', 16.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-07 00:00:00', 17.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-08 00:00:00', 16.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-09 00:00:00', 20.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-10 00:00:00', 21.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-11 00:00:00', 23.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-12 00:00:00', 25.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-13 00:00:00', 15.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-14 00:00:00', 18.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-15 00:00:00', 20.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-16 00:00:00', 24.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-17 00:00:00', 26.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-18 00:00:00', 27.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-19 00:00:00', 16.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-20 00:00:00', 17.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-21 00:00:00', 21.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-22 00:00:00', 25.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-23 00:00:00', 29.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-24 00:00:00', 30.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-25 00:00:00', 30.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-26 00:00:00', 27.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-27 00:00:00', 21.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-28 00:00:00', 21.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-29 00:00:00', 24.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-04-30 00:00:00', 25.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-01 00:00:00', 26.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-02 00:00:00', 30.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-03 00:00:00', 21.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-04 00:00:00', 25.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-05 00:00:00', 28.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-06 00:00:00', 28.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-07 00:00:00', 24.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-08 00:00:00', 25.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-09 00:00:00', 25.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-10 00:00:00', 28.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-11 00:00:00', 27.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-12 00:00:00', 24.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-13 00:00:00', 23.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-14 00:00:00', 24.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-15 00:00:00', 24.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-16 00:00:00', 24.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-17 00:00:00', 27.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-18 00:00:00', 29.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-19 00:00:00', 27.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-20 00:00:00', 26.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-21 00:00:00', 29.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-22 00:00:00', 32.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-23 00:00:00', 27.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-24 00:00:00', 31.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-25 00:00:00', 31.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-26 00:00:00', 34.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-27 00:00:00', 35.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-28 00:00:00', 33.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-29 00:00:00', 36.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-30 00:00:00', 38.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-05-31 00:00:00', 39.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-01 00:00:00', 35.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-02 00:00:00', 34.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-03 00:00:00', 32.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-04 00:00:00', 35.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-05 00:00:00', 34.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-06 00:00:00', 33.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-07 00:00:00', 34.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-08 00:00:00', 33.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-09 00:00:00', 36.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-10 00:00:00', 36.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-11 00:00:00', 34.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-12 00:00:00', 36.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-13 00:00:00', 37.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-14 00:00:00', 36.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-15 00:00:00', 38.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-16 00:00:00', 35.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-17 00:00:00', 31.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-18 00:00:00', 32.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-19 00:00:00', 32.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-20 00:00:00', 33.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-21 00:00:00', 34.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-22 00:00:00', 37.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-23 00:00:00', 39.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-24 00:00:00', 40.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-25 00:00:00', 40.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-26 00:00:00', 40.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-27 00:00:00', 38.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-28 00:00:00', 36.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-29 00:00:00', 35.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-06-30 00:00:00', 35.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-01 00:00:00', 35.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-02 00:00:00', 38.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-03 00:00:00', 36.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-04 00:00:00', 38.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-05 00:00:00', 39.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-06 00:00:00', 39.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-07 00:00:00', 40.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-08 00:00:00', 36.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-09 00:00:00', 40.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-10 00:00:00', 38.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-11 00:00:00', 40.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-12 00:00:00', 40.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-13 00:00:00', 41.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-14 00:00:00', 40.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-15 00:00:00', 41.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-16 00:00:00', 38.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-17 00:00:00', 39.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-18 00:00:00', 40.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-19 00:00:00', 40.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-20 00:00:00', 39.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-21 00:00:00', 38.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-22 00:00:00', 38.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-23 00:00:00', 40.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-24 00:00:00', 39.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-25 00:00:00', 39.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-26 00:00:00', 39.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-27 00:00:00', 39.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-28 00:00:00', 39.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-29 00:00:00', 39.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-30 00:00:00', 39.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-07-31 00:00:00', 38.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-01 00:00:00', 40.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-02 00:00:00', 41.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-03 00:00:00', 41.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-04 00:00:00', 41.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-05 00:00:00', 40.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-06 00:00:00', 37.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-07 00:00:00', 38.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-08 00:00:00', 39.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-09 00:00:00', 40.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-10 00:00:00', 39.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-11 00:00:00', 40.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-12 00:00:00', 38.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-13 00:00:00', 36.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-14 00:00:00', 38.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-15 00:00:00', 37.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-16 00:00:00', 39.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-17 00:00:00', 39.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-18 00:00:00', 40.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-19 00:00:00', 41.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-20 00:00:00', 42.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-21 00:00:00', 38.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-22 00:00:00', 36.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-23 00:00:00', 38.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-24 00:00:00', 39.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-25 00:00:00', 37.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-26 00:00:00', 37.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-27 00:00:00', 37.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-28 00:00:00', 38.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-29 00:00:00', 40.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-30 00:00:00', 39.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-08-31 00:00:00', 37.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-01 00:00:00', 35.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-02 00:00:00', 33.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-03 00:00:00', 33.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-04 00:00:00', 34.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-05 00:00:00', 32.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-06 00:00:00', 29.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-07 00:00:00', 27.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-08 00:00:00', 29.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-09 00:00:00', 30.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-10 00:00:00', 33.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-11 00:00:00', 32.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-12 00:00:00', 32.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-13 00:00:00', 32.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-14 00:00:00', 30.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-15 00:00:00', 30.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-16 00:00:00', 31.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-17 00:00:00', 31.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-18 00:00:00', 29.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-19 00:00:00', 24.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-20 00:00:00', 24.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-21 00:00:00', 27.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-22 00:00:00', 25.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-23 00:00:00', 25.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-24 00:00:00', 26.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-25 00:00:00', 27.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-26 00:00:00', 27.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-27 00:00:00', 25.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-28 00:00:00', 27.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-29 00:00:00', 28.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-09-30 00:00:00', 26.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-01 00:00:00', 25.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-02 00:00:00', 24.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-03 00:00:00', 25.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-04 00:00:00', 25.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-05 00:00:00', 24.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-06 00:00:00', 24.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-07 00:00:00', 25.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-08 00:00:00', 20.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-09 00:00:00', 14.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-10 00:00:00', 19.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-11 00:00:00', 21.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-12 00:00:00', 18.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-13 00:00:00', 17.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-14 00:00:00', 20.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-15 00:00:00', 21.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-16 00:00:00', 22.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-17 00:00:00', 23.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-18 00:00:00', 25.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-19 00:00:00', 27.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-20 00:00:00', 29.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-21 00:00:00', 17.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-22 00:00:00', 13.1689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-23 00:00:00', 14.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-24 00:00:00', 17.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-25 00:00:00', 16.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-26 00:00:00', 16.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-27 00:00:00', 15.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-28 00:00:00', 16.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-29 00:00:00', 14.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-30 00:00:00', 15.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-10-31 00:00:00', 19.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-01 00:00:00', 19.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-02 00:00:00', 18.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-03 00:00:00', 21.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-04 00:00:00', 16.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-05 00:00:00', 20.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-06 00:00:00', 20.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-07 00:00:00', 18.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-08 00:00:00', 15.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-09 00:00:00', 13.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-10 00:00:00', 17.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-11 00:00:00', 14.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-12 00:00:00', 17.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-13 00:00:00', 16.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-14 00:00:00', 15.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-15 00:00:00', 14.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-16 00:00:00', 12.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-17 00:00:00', 7.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-18 00:00:00', 11.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-19 00:00:00', 10.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-20 00:00:00', 10.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-21 00:00:00', 9.63799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-22 00:00:00', 8.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-23 00:00:00', 8.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-24 00:00:00', 11.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-26 00:00:00', 14.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-27 00:00:00', 11.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-28 00:00:00', 13.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-29 00:00:00', 14.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-11-30 00:00:00', 12.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-01 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-02 00:00:00', -0.499000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-03 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-04 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-05 00:00:00', 1.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-06 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-07 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-08 00:00:00', 3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-09 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-10 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-11 00:00:00', 6.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-12 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-13 00:00:00', 4.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-14 00:00:00', 7.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-15 00:00:00', 6.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-16 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-17 00:00:00', 3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-18 00:00:00', 3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-19 00:00:00', 1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-20 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-21 00:00:00', -3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-22 00:00:00', -2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-23 00:00:00', -1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-24 00:00:00', -1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-25 00:00:00', -1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-26 00:00:00', -2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-27 00:00:00', 0.151999995112419128, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-28 00:00:00', 1.00199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-29 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-30 00:00:00', -2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1984-12-31 00:00:00', -1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-01 00:00:00', -0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-02 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-03 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-04 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-05 00:00:00', 3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-06 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-07 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-08 00:00:00', 5.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-09 00:00:00', 7.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-10 00:00:00', 8.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-11 00:00:00', 8.35499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-12 00:00:00', 9.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-13 00:00:00', 7.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-14 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-15 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-16 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-17 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-18 00:00:00', -1.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-19 00:00:00', 2.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-20 00:00:00', 1.19200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-21 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-22 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-23 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-24 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-25 00:00:00', 1.62300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-26 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-27 00:00:00', 5.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-28 00:00:00', 5.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-29 00:00:00', 6.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-30 00:00:00', 9.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-01-31 00:00:00', 9.84500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-01 00:00:00', 8.00100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-02 00:00:00', 8.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-03 00:00:00', 7.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-04 00:00:00', 9.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-05 00:00:00', 8.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-06 00:00:00', 11.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-07 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-08 00:00:00', 5.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-09 00:00:00', 8.50800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-10 00:00:00', 9.05099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-11 00:00:00', 7.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-12 00:00:00', 12.2440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-13 00:00:00', 14.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-14 00:00:00', 14.3660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-15 00:00:00', 14.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-16 00:00:00', 14.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-17 00:00:00', 17.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-18 00:00:00', 8.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-19 00:00:00', 10.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-20 00:00:00', 9.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-21 00:00:00', 14.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-22 00:00:00', 14.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-23 00:00:00', 10.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-24 00:00:00', 7.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-25 00:00:00', 10.175999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-26 00:00:00', 5.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-27 00:00:00', 6.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-02-28 00:00:00', 2.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-01 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-02 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-03 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-04 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-05 00:00:00', 1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-06 00:00:00', 0.532999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-07 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-08 00:00:00', 1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-09 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-10 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-11 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-12 00:00:00', 1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-13 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-14 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-15 00:00:00', 2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-16 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-17 00:00:00', 3.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-18 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-19 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-20 00:00:00', 8.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-21 00:00:00', 12.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-22 00:00:00', 13.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-23 00:00:00', 11.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-24 00:00:00', 12.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-25 00:00:00', 13.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-26 00:00:00', 10.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-27 00:00:00', 12.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-28 00:00:00', 18.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-29 00:00:00', 13.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-30 00:00:00', 14.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-03-31 00:00:00', 19.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-01 00:00:00', 21.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-02 00:00:00', 16.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-03 00:00:00', 16.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-04 00:00:00', 15.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-05 00:00:00', 16.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-06 00:00:00', 13.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-07 00:00:00', 13.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-08 00:00:00', 16.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-09 00:00:00', 15.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-10 00:00:00', 15.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-11 00:00:00', 19.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-12 00:00:00', 19.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-13 00:00:00', 18.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-14 00:00:00', 20.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-15 00:00:00', 20.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-16 00:00:00', 23.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-17 00:00:00', 14.2100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-18 00:00:00', 15.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-19 00:00:00', 22.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-20 00:00:00', 25.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-21 00:00:00', 27.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-22 00:00:00', 27.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-23 00:00:00', 26.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-24 00:00:00', 27.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-25 00:00:00', 30.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-26 00:00:00', 29.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-27 00:00:00', 29.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-28 00:00:00', 29.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-29 00:00:00', 29.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-04-30 00:00:00', 22.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-01 00:00:00', 20.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-02 00:00:00', 22.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-03 00:00:00', 25.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-04 00:00:00', 26.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-05 00:00:00', 29.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-06 00:00:00', 29.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-07 00:00:00', 24.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-08 00:00:00', 26.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-09 00:00:00', 25.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-10 00:00:00', 25.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-11 00:00:00', 24.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-12 00:00:00', 27.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-13 00:00:00', 24.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-14 00:00:00', 24.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-15 00:00:00', 27.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-16 00:00:00', 29.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-17 00:00:00', 31.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-18 00:00:00', 33.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-19 00:00:00', 35.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-20 00:00:00', 31.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-21 00:00:00', 32.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-22 00:00:00', 34.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-23 00:00:00', 30.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-24 00:00:00', 28.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-25 00:00:00', 25.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-26 00:00:00', 28.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-27 00:00:00', 31.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-28 00:00:00', 33.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-29 00:00:00', 33.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-30 00:00:00', 33.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-05-31 00:00:00', 33.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-01 00:00:00', 35.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-02 00:00:00', 33.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-03 00:00:00', 33.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-04 00:00:00', 37.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-05 00:00:00', 37.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-06 00:00:00', 34.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-07 00:00:00', 34.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-08 00:00:00', 34.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-09 00:00:00', 35.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-10 00:00:00', 33.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-11 00:00:00', 32.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-12 00:00:00', 34.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-13 00:00:00', 35.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-14 00:00:00', 35.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-15 00:00:00', 36.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-16 00:00:00', 37.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-17 00:00:00', 36.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-18 00:00:00', 35.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-19 00:00:00', 36.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-20 00:00:00', 36.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-21 00:00:00', 37.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-22 00:00:00', 38.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-23 00:00:00', 39.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-24 00:00:00', 38.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-25 00:00:00', 38.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-26 00:00:00', 40.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-27 00:00:00', 40.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-28 00:00:00', 38.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-29 00:00:00', 37.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-06-30 00:00:00', 37.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-01 00:00:00', 37.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-02 00:00:00', 37.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-03 00:00:00', 39.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-04 00:00:00', 40.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-05 00:00:00', 40.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-06 00:00:00', 41.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-07 00:00:00', 37.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-08 00:00:00', 37.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-09 00:00:00', 39.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-10 00:00:00', 42.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-11 00:00:00', 40.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-12 00:00:00', 40.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-13 00:00:00', 37.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-14 00:00:00', 37.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-15 00:00:00', 40.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-16 00:00:00', 41.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-17 00:00:00', 40.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-18 00:00:00', 35.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-19 00:00:00', 34.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-20 00:00:00', 37.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-21 00:00:00', 39.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-22 00:00:00', 41.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-23 00:00:00', 40.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-24 00:00:00', 40.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-25 00:00:00', 39.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-26 00:00:00', 38.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-27 00:00:00', 39.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-28 00:00:00', 40.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-29 00:00:00', 40.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-30 00:00:00', 37.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-07-31 00:00:00', 36.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-01 00:00:00', 36.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-02 00:00:00', 34.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-03 00:00:00', 35.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-04 00:00:00', 36.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-05 00:00:00', 35.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-06 00:00:00', 38.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-07 00:00:00', 36.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-08 00:00:00', 36.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-09 00:00:00', 34.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-10 00:00:00', 34.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-11 00:00:00', 34.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-12 00:00:00', 34.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-13 00:00:00', 35.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-14 00:00:00', 36.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-15 00:00:00', 34.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-16 00:00:00', 33.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-17 00:00:00', 34.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-18 00:00:00', 35.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-19 00:00:00', 33.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-20 00:00:00', 34.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-21 00:00:00', 33.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-22 00:00:00', 34.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-23 00:00:00', 34.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-24 00:00:00', 33.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-25 00:00:00', 34.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-26 00:00:00', 33.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-27 00:00:00', 32.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-28 00:00:00', 31.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-29 00:00:00', 30.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-30 00:00:00', 30.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-08-31 00:00:00', 30.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-01 00:00:00', 31.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-02 00:00:00', 33.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-03 00:00:00', 34.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-04 00:00:00', 33.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-05 00:00:00', 30.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-06 00:00:00', 30.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-07 00:00:00', 31.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-08 00:00:00', 30.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-09 00:00:00', 31.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-10 00:00:00', 31.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-11 00:00:00', 32.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-12 00:00:00', 32.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-13 00:00:00', 31.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-14 00:00:00', 32.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-15 00:00:00', 32.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-16 00:00:00', 32.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-17 00:00:00', 31.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-18 00:00:00', 28.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-19 00:00:00', 28.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-20 00:00:00', 31.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-21 00:00:00', 30.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-22 00:00:00', 28.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-23 00:00:00', 28.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-24 00:00:00', 29.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-25 00:00:00', 30.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-26 00:00:00', 30.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-27 00:00:00', 28.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-28 00:00:00', 30.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-29 00:00:00', 29.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-09-30 00:00:00', 31.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-01 00:00:00', 32.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-02 00:00:00', 30.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-03 00:00:00', 23.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-04 00:00:00', 26.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-05 00:00:00', 22.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-06 00:00:00', 22.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-07 00:00:00', 21.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-08 00:00:00', 23.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-09 00:00:00', 20.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-10 00:00:00', 23.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-11 00:00:00', 24.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-12 00:00:00', 17.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-13 00:00:00', 17.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-14 00:00:00', 16.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-15 00:00:00', 18.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-16 00:00:00', 19.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-17 00:00:00', 19.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-18 00:00:00', 22.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-19 00:00:00', 24.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-20 00:00:00', 24.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-21 00:00:00', 26.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-22 00:00:00', 21.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-23 00:00:00', 14.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-24 00:00:00', 18.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-25 00:00:00', 17.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-26 00:00:00', 19.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-27 00:00:00', 21.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-28 00:00:00', 22.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-29 00:00:00', 21.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-30 00:00:00', 22.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-10-31 00:00:00', 16.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-01 00:00:00', 14.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-02 00:00:00', 19.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-03 00:00:00', 20.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-04 00:00:00', 21.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-05 00:00:00', 19.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-06 00:00:00', 18.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-07 00:00:00', 19.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-08 00:00:00', 18.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-09 00:00:00', 17.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-10 00:00:00', 16.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-11 00:00:00', 17.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-12 00:00:00', 17.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-13 00:00:00', 19.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-14 00:00:00', 20.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-15 00:00:00', 18.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-16 00:00:00', 15.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-17 00:00:00', 16.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-18 00:00:00', 15.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-19 00:00:00', 12.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-20 00:00:00', 9.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-21 00:00:00', 9.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-22 00:00:00', 10.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-23 00:00:00', 12.4110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-24 00:00:00', 8.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-25 00:00:00', 9.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-26 00:00:00', 10.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-27 00:00:00', 13.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-28 00:00:00', 13.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-29 00:00:00', 14.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-11-30 00:00:00', 15.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-01 00:00:00', 15.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-02 00:00:00', 17.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-03 00:00:00', 18.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-04 00:00:00', 17.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-05 00:00:00', 15.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-06 00:00:00', 7.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-07 00:00:00', 2.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-08 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-09 00:00:00', 0.395999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-10 00:00:00', 2.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-11 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-12 00:00:00', 7.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-13 00:00:00', 9.10299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-14 00:00:00', 3.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-15 00:00:00', 2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-16 00:00:00', 6.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-17 00:00:00', 10.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-18 00:00:00', 9.56700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-19 00:00:00', 10.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-20 00:00:00', 14.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-21 00:00:00', 14.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-22 00:00:00', 12.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-23 00:00:00', 11.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-24 00:00:00', 9.10499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-25 00:00:00', 6.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-26 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-27 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-28 00:00:00', 7.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-29 00:00:00', 5.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-30 00:00:00', 8.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1985-12-31 00:00:00', 6.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-01 00:00:00', 6.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-02 00:00:00', 7.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-03 00:00:00', 8.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-04 00:00:00', 10.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-05 00:00:00', 10.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-06 00:00:00', 8.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-07 00:00:00', 11.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-08 00:00:00', 11.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-09 00:00:00', 11.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-10 00:00:00', 12.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-11 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-12 00:00:00', 10.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-13 00:00:00', 11.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-14 00:00:00', 11.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-15 00:00:00', 12.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-16 00:00:00', 8.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-17 00:00:00', 8.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-18 00:00:00', 9.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-19 00:00:00', 11.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-20 00:00:00', 11.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-21 00:00:00', 14.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-22 00:00:00', 6.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-23 00:00:00', 7.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-24 00:00:00', 3.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-25 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-26 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-27 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-28 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-29 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-30 00:00:00', 4.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-01-31 00:00:00', 7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-01 00:00:00', 9.36699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-02 00:00:00', 8.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-03 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-04 00:00:00', 7.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-05 00:00:00', 11.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-06 00:00:00', 11.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-07 00:00:00', 14.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-08 00:00:00', 11.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-09 00:00:00', 9.62800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-10 00:00:00', 12.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-11 00:00:00', 14.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-12 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-13 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-14 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-15 00:00:00', 5.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-16 00:00:00', 7.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-17 00:00:00', 5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-18 00:00:00', 4.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-19 00:00:00', 7.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-20 00:00:00', 8.24899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-21 00:00:00', 9.69699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-22 00:00:00', 10.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-23 00:00:00', 10.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-24 00:00:00', 12.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-25 00:00:00', 12.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-26 00:00:00', 14.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-27 00:00:00', 16.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-02-28 00:00:00', 18.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-01 00:00:00', 17.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-02 00:00:00', 18.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-03 00:00:00', 9.73700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-04 00:00:00', 13.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-05 00:00:00', 12.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-06 00:00:00', 15.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-07 00:00:00', 19.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-08 00:00:00', 19.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-09 00:00:00', 22.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-10 00:00:00', 15.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-11 00:00:00', 13.3629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-12 00:00:00', 7.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-13 00:00:00', 7.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-14 00:00:00', 9.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-15 00:00:00', 7.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-16 00:00:00', 5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-17 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-18 00:00:00', 6.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-19 00:00:00', 10.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-20 00:00:00', 11.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-21 00:00:00', 12.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-22 00:00:00', 13.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-23 00:00:00', 8.82699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-24 00:00:00', 11.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-25 00:00:00', 9.09300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-26 00:00:00', 10.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-27 00:00:00', 10.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-28 00:00:00', 9.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-29 00:00:00', 9.67800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-30 00:00:00', 7.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-03-31 00:00:00', 9.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-01 00:00:00', 12.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-02 00:00:00', 16.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-03 00:00:00', 18.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-04 00:00:00', 21.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-05 00:00:00', 21.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-06 00:00:00', 21.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-07 00:00:00', 23.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-08 00:00:00', 23.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-09 00:00:00', 22.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-10 00:00:00', 23.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-11 00:00:00', 26.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-12 00:00:00', 23.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-13 00:00:00', 25.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-14 00:00:00', 23.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-15 00:00:00', 24.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-16 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-17 00:00:00', 27.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-18 00:00:00', 28.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-19 00:00:00', 26.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-20 00:00:00', 26.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-21 00:00:00', 27.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-22 00:00:00', 16.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-23 00:00:00', 18.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-24 00:00:00', 20.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-25 00:00:00', 19.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-26 00:00:00', 21.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-27 00:00:00', 21.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-28 00:00:00', 21.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-29 00:00:00', 23.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-04-30 00:00:00', 23.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-01 00:00:00', 27.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-02 00:00:00', 27.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-03 00:00:00', 29.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-04 00:00:00', 32.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-05 00:00:00', 36.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-06 00:00:00', 35.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-07 00:00:00', 32.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-08 00:00:00', 32.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-09 00:00:00', 31.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-10 00:00:00', 32.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-11 00:00:00', 34.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-12 00:00:00', 30.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-13 00:00:00', 31.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-14 00:00:00', 34.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-15 00:00:00', 31.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-16 00:00:00', 27.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-17 00:00:00', 23.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-18 00:00:00', 22.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-19 00:00:00', 23.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-20 00:00:00', 24.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-21 00:00:00', 25.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-22 00:00:00', 27.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-23 00:00:00', 29.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-24 00:00:00', 34.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-25 00:00:00', 33.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-26 00:00:00', 31.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-27 00:00:00', 30.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-28 00:00:00', 31.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-29 00:00:00', 29.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-30 00:00:00', 19.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-01 00:00:00', 30.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-02 00:00:00', 30.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-03 00:00:00', 31.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-04 00:00:00', 30.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-05 00:00:00', 31.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-06 00:00:00', 33.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-07 00:00:00', 32.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-08 00:00:00', 35.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-09 00:00:00', 35.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-10 00:00:00', 34.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-11 00:00:00', 31.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-12 00:00:00', 33.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-13 00:00:00', 34.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-14 00:00:00', 34.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-15 00:00:00', 33.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-16 00:00:00', 33.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-17 00:00:00', 35.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-18 00:00:00', 38.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-19 00:00:00', 41.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-20 00:00:00', 38.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-21 00:00:00', 38.5789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-22 00:00:00', 37.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-23 00:00:00', 38.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-24 00:00:00', 37.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-25 00:00:00', 37.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-26 00:00:00', 37.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-27 00:00:00', 36.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-28 00:00:00', 36.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-29 00:00:00', 36.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-06-30 00:00:00', 38.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-01 00:00:00', 39.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-02 00:00:00', 40.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-03 00:00:00', 41.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-04 00:00:00', 39.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-05 00:00:00', 38.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-06 00:00:00', 38.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-07 00:00:00', 38.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-08 00:00:00', 36.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-09 00:00:00', 35.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-10 00:00:00', 36.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-11 00:00:00', 36.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-12 00:00:00', 38.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-13 00:00:00', 38.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-14 00:00:00', 40.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-15 00:00:00', 41.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-16 00:00:00', 41.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-17 00:00:00', 40.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-18 00:00:00', 41.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-19 00:00:00', 39.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-20 00:00:00', 37.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-21 00:00:00', 37.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-22 00:00:00', 29.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-23 00:00:00', 32.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-24 00:00:00', 33.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-25 00:00:00', 35.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-26 00:00:00', 37.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-27 00:00:00', 38.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-28 00:00:00', 39.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-29 00:00:00', 39.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-30 00:00:00', 39.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-07-31 00:00:00', 39.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-01 00:00:00', 40.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-02 00:00:00', 40.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-03 00:00:00', 41.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-04 00:00:00', 40.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-05 00:00:00', 35.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-06 00:00:00', 34.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-07 00:00:00', 36.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-08 00:00:00', 32.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-09 00:00:00', 33.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-10 00:00:00', 33.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-11 00:00:00', 34.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-12 00:00:00', 36.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-13 00:00:00', 35.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-14 00:00:00', 36.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-15 00:00:00', 39.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-16 00:00:00', 39.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-17 00:00:00', 37.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-18 00:00:00', 38.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-19 00:00:00', 35.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-20 00:00:00', 33.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-21 00:00:00', 32.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-22 00:00:00', 32.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-23 00:00:00', 33.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-24 00:00:00', 34.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-25 00:00:00', 34.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-26 00:00:00', 34.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-27 00:00:00', 34.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-28 00:00:00', 33.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-29 00:00:00', 33.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-30 00:00:00', 32.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-08-31 00:00:00', 31.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-01 00:00:00', 32.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-02 00:00:00', 34.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-03 00:00:00', 32.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-04 00:00:00', 32.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-05 00:00:00', 32.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-06 00:00:00', 32.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-07 00:00:00', 33.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-08 00:00:00', 32.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-09 00:00:00', 31.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-10 00:00:00', 30.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-11 00:00:00', 31.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-12 00:00:00', 32.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-13 00:00:00', 29.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-14 00:00:00', 29.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-15 00:00:00', 30.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-16 00:00:00', 31.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-17 00:00:00', 31.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-18 00:00:00', 30.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-19 00:00:00', 30.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-20 00:00:00', 28.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-21 00:00:00', 29.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-22 00:00:00', 30.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-23 00:00:00', 30.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-24 00:00:00', 32.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-25 00:00:00', 33.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-26 00:00:00', 32.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-27 00:00:00', 32.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-28 00:00:00', 32.0719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-29 00:00:00', 30.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-09-30 00:00:00', 26.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-01 00:00:00', 25.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-02 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-03 00:00:00', 30.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-04 00:00:00', 27.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-05 00:00:00', 30.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-06 00:00:00', 31.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-07 00:00:00', 31.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-08 00:00:00', 27.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-09 00:00:00', 26.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-10 00:00:00', 27.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-11 00:00:00', 29.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-12 00:00:00', 29.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-13 00:00:00', 25.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-14 00:00:00', 23.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-15 00:00:00', 15.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-16 00:00:00', 14.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-17 00:00:00', 15.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-18 00:00:00', 17.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-19 00:00:00', 18.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-20 00:00:00', 21.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-21 00:00:00', 22.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-22 00:00:00', 23.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-23 00:00:00', 25.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-24 00:00:00', 25.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-25 00:00:00', 26.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-26 00:00:00', 26.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-27 00:00:00', 23.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-28 00:00:00', 22.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-29 00:00:00', 21.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-30 00:00:00', 19.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-10-31 00:00:00', 21.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-01 00:00:00', 21.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-02 00:00:00', 22.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-03 00:00:00', 23.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-04 00:00:00', 23.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-05 00:00:00', 24.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-06 00:00:00', 20.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-07 00:00:00', 21.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-08 00:00:00', 23.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-09 00:00:00', 22.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-10 00:00:00', 21.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-11 00:00:00', 16.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-12 00:00:00', 16.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-13 00:00:00', 11.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-14 00:00:00', 9.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-15 00:00:00', 10.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-16 00:00:00', 9.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-17 00:00:00', 10.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-18 00:00:00', 13.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-19 00:00:00', 11.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-20 00:00:00', 11.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-21 00:00:00', 7.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-22 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-23 00:00:00', 9.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-24 00:00:00', 10.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-25 00:00:00', 6.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-26 00:00:00', 6.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-27 00:00:00', 9.69200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-28 00:00:00', 10.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-29 00:00:00', 10.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-11-30 00:00:00', 13.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-01 00:00:00', 15.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-02 00:00:00', 15.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-03 00:00:00', 15.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-04 00:00:00', 13.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-05 00:00:00', 9.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-06 00:00:00', 9.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-07 00:00:00', 8.16399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-08 00:00:00', 11.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-09 00:00:00', 10.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-10 00:00:00', 5.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-11 00:00:00', -2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-12 00:00:00', -3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-13 00:00:00', -4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-14 00:00:00', 0.935000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-15 00:00:00', -0.388999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-16 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-17 00:00:00', 2.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-18 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-19 00:00:00', 3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-20 00:00:00', 4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-21 00:00:00', 7.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-22 00:00:00', 7.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-23 00:00:00', 5.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-24 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-01 00:00:00', 7.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-02 00:00:00', 9.34099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-03 00:00:00', 11.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-04 00:00:00', 11.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-05 00:00:00', 12.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-06 00:00:00', 12.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-07 00:00:00', 13.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-08 00:00:00', 8.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-09 00:00:00', 11.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-10 00:00:00', 12.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-11 00:00:00', 13.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-12 00:00:00', 9.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-13 00:00:00', 8.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-14 00:00:00', 10.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-15 00:00:00', 8.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-16 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-17 00:00:00', 9.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-18 00:00:00', 8.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-19 00:00:00', 8.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-20 00:00:00', 6.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-21 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-22 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-23 00:00:00', 8.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-24 00:00:00', 13.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-25 00:00:00', 14.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-26 00:00:00', 13.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-27 00:00:00', 16.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-28 00:00:00', 14.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-29 00:00:00', 12.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-30 00:00:00', 14.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-01-31 00:00:00', 14.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-01 00:00:00', 11.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-02 00:00:00', 10.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-03 00:00:00', 12.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-04 00:00:00', 13.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-05 00:00:00', 16.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-06 00:00:00', 9.65900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-07 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-08 00:00:00', 6.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-09 00:00:00', 12.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-10 00:00:00', 15.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-11 00:00:00', 11.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-12 00:00:00', 6.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-13 00:00:00', 10.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-14 00:00:00', 10.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-15 00:00:00', 7.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-16 00:00:00', 6.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-17 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-18 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-19 00:00:00', 11.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-20 00:00:00', 12.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-21 00:00:00', 13.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-22 00:00:00', 8.38799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-23 00:00:00', 8.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-24 00:00:00', 10.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-25 00:00:00', 13.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-26 00:00:00', 16.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-27 00:00:00', 17.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-02-28 00:00:00', 18.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-01 00:00:00', 18.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-02 00:00:00', 16.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-03 00:00:00', 20.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-04 00:00:00', 21.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-05 00:00:00', 14.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-06 00:00:00', 14.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-07 00:00:00', 18.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-08 00:00:00', 17.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-09 00:00:00', 18.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-10 00:00:00', 20.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-11 00:00:00', 19.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-12 00:00:00', 13.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-13 00:00:00', 12.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-14 00:00:00', 19.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-15 00:00:00', 17.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-16 00:00:00', 13.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-17 00:00:00', 17.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-18 00:00:00', 17.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-19 00:00:00', 17.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-20 00:00:00', 17.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-21 00:00:00', 14.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-22 00:00:00', 11.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-23 00:00:00', 12.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-24 00:00:00', 16.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-25 00:00:00', 18.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-26 00:00:00', 20.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-27 00:00:00', 17.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-28 00:00:00', 17.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-29 00:00:00', 19.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-30 00:00:00', 19.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-03-31 00:00:00', 24.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-01 00:00:00', 12.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-02 00:00:00', 14.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-03 00:00:00', 16.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-04 00:00:00', 18.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-05 00:00:00', 19.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-06 00:00:00', 15.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-07 00:00:00', 17.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-08 00:00:00', 13.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-09 00:00:00', 15.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-10 00:00:00', 18.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-11 00:00:00', 18.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-12 00:00:00', 21.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-13 00:00:00', 23.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-14 00:00:00', 21.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-15 00:00:00', 24.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-16 00:00:00', 23.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-17 00:00:00', 24.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-18 00:00:00', 27.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-19 00:00:00', 30.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-20 00:00:00', 28.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-21 00:00:00', 20.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-22 00:00:00', 19.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-23 00:00:00', 21.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-24 00:00:00', 24.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-25 00:00:00', 26.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-26 00:00:00', 28.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-27 00:00:00', 30.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-28 00:00:00', 21.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-29 00:00:00', 26.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-04-30 00:00:00', 22.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-01 00:00:00', 21.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-02 00:00:00', 23.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-03 00:00:00', 26.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-04 00:00:00', 31.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-05 00:00:00', 28.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-06 00:00:00', 27.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-07 00:00:00', 23.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-08 00:00:00', 24.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-09 00:00:00', 26.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-10 00:00:00', 27.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-11 00:00:00', 28.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-12 00:00:00', 31.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-13 00:00:00', 30.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-14 00:00:00', 31.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-15 00:00:00', 32.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-16 00:00:00', 34.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-17 00:00:00', 34.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-18 00:00:00', 29.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-19 00:00:00', 28.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-20 00:00:00', 27.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-21 00:00:00', 30.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-22 00:00:00', 28.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-23 00:00:00', 29.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-24 00:00:00', 32.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-25 00:00:00', 34.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-26 00:00:00', 35.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-27 00:00:00', 32.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-28 00:00:00', 35.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-29 00:00:00', 33.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-30 00:00:00', 31.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-05-31 00:00:00', 32.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-01 00:00:00', 32.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-02 00:00:00', 32.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-03 00:00:00', 33.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-04 00:00:00', 35.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-05 00:00:00', 36.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-06 00:00:00', 37.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-07 00:00:00', 35.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-08 00:00:00', 33.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-09 00:00:00', 28.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-10 00:00:00', 31.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-11 00:00:00', 32.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-12 00:00:00', 30.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-13 00:00:00', 31.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-14 00:00:00', 34.5530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-15 00:00:00', 32.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-16 00:00:00', 33.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-17 00:00:00', 34.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-18 00:00:00', 35.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-19 00:00:00', 36.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-20 00:00:00', 29.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-21 00:00:00', 27.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-22 00:00:00', 33.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-23 00:00:00', 33.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-24 00:00:00', 34.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-25 00:00:00', 36.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-26 00:00:00', 36.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-27 00:00:00', 37.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-28 00:00:00', 37.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-29 00:00:00', 36.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-06-30 00:00:00', 38.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-01 00:00:00', 38.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-02 00:00:00', 38.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-03 00:00:00', 37.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-04 00:00:00', 38.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-05 00:00:00', 32.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-06 00:00:00', 34.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-07 00:00:00', 34.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-08 00:00:00', 37.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-09 00:00:00', 38.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-10 00:00:00', 40.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-11 00:00:00', 31.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-12 00:00:00', 30.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-13 00:00:00', 30.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-14 00:00:00', 27.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-15 00:00:00', 31.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-16 00:00:00', 33.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-17 00:00:00', 35.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-18 00:00:00', 34.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-19 00:00:00', 33.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-20 00:00:00', 35.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-21 00:00:00', 38.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-22 00:00:00', 40.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-23 00:00:00', 41.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-24 00:00:00', 41.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-25 00:00:00', 36.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-26 00:00:00', 33.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-27 00:00:00', 33.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-28 00:00:00', 35.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-29 00:00:00', 35.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-30 00:00:00', 36.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-07-31 00:00:00', 36.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-01 00:00:00', 35.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-02 00:00:00', 36.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-03 00:00:00', 37.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-04 00:00:00', 37.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-05 00:00:00', 37.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-06 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-07 00:00:00', 38.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-08 00:00:00', 38.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-09 00:00:00', 36.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-10 00:00:00', 37.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-11 00:00:00', 37.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-12 00:00:00', 37.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-13 00:00:00', 40.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-14 00:00:00', 39.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-15 00:00:00', 39.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-16 00:00:00', 40.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-17 00:00:00', 39.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-18 00:00:00', 38.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-19 00:00:00', 38.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-20 00:00:00', 38.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-21 00:00:00', 39.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-22 00:00:00', 39.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-23 00:00:00', 39.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-24 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-25 00:00:00', 35.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-26 00:00:00', 36.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-27 00:00:00', 36.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-28 00:00:00', 36.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-29 00:00:00', 36.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-30 00:00:00', 37.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-08-31 00:00:00', 34.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-01 00:00:00', 33.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-02 00:00:00', 32.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-03 00:00:00', 34.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-04 00:00:00', 34.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-05 00:00:00', 36.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-06 00:00:00', 37.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-07 00:00:00', 37.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-08 00:00:00', 30.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-09 00:00:00', 29.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-10 00:00:00', 27.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-11 00:00:00', 28.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-12 00:00:00', 30.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-13 00:00:00', 31.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-14 00:00:00', 34.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-15 00:00:00', 33.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-16 00:00:00', 31.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-17 00:00:00', 33.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-18 00:00:00', 33.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-19 00:00:00', 33.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-20 00:00:00', 27.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-21 00:00:00', 25.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-22 00:00:00', 30.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-23 00:00:00', 31.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-24 00:00:00', 26.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-25 00:00:00', 27.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-26 00:00:00', 28.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-27 00:00:00', 27.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-28 00:00:00', 27.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-29 00:00:00', 29.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-09-30 00:00:00', 30.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-01 00:00:00', 25.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-02 00:00:00', 27.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-03 00:00:00', 28.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-04 00:00:00', 28.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-05 00:00:00', 30.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-06 00:00:00', 26.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-07 00:00:00', 26.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-08 00:00:00', 23.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-09 00:00:00', 23.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-10 00:00:00', 16.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-11 00:00:00', 14.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-12 00:00:00', 14.4980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-13 00:00:00', 13.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-14 00:00:00', 14.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-15 00:00:00', 17.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-16 00:00:00', 17.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-17 00:00:00', 17.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-18 00:00:00', 17.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-19 00:00:00', 16.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-20 00:00:00', 18.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-21 00:00:00', 19.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-22 00:00:00', 20.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-23 00:00:00', 23.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-24 00:00:00', 18.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-25 00:00:00', 22.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-26 00:00:00', 16.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-27 00:00:00', 10.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-28 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-29 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-30 00:00:00', 10.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-10-31 00:00:00', 11.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-01 00:00:00', 15.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-02 00:00:00', 17.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-03 00:00:00', 17.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-04 00:00:00', 17.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-05 00:00:00', 19.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-06 00:00:00', 19.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-07 00:00:00', 22.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-08 00:00:00', 23.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-09 00:00:00', 17.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-10 00:00:00', 18.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-11 00:00:00', 16.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-12 00:00:00', 16.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-13 00:00:00', 16.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-14 00:00:00', 19.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-15 00:00:00', 20.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-16 00:00:00', 15.4420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-17 00:00:00', 16.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-18 00:00:00', 16.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-19 00:00:00', 16.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-20 00:00:00', 17.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-21 00:00:00', 18.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-22 00:00:00', 19.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-23 00:00:00', 19.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-24 00:00:00', 13.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-25 00:00:00', 10.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-26 00:00:00', 8.59799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-27 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-28 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-29 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-11-30 00:00:00', -1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-01 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-02 00:00:00', 0.0199999995529651642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-03 00:00:00', -0.418000012636184692, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-04 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-05 00:00:00', 3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-06 00:00:00', 4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-07 00:00:00', 9.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-08 00:00:00', 10.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-09 00:00:00', 12.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-10 00:00:00', 15.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-11 00:00:00', 14.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-12 00:00:00', 14.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-13 00:00:00', 16.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-14 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-15 00:00:00', 9.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-16 00:00:00', 11.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-17 00:00:00', 13.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-18 00:00:00', 14.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-19 00:00:00', 16.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-20 00:00:00', 17.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-21 00:00:00', 19.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-22 00:00:00', 15.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-23 00:00:00', 16.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-24 00:00:00', 18.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-25 00:00:00', 15.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-26 00:00:00', 15.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-27 00:00:00', 15.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-28 00:00:00', 15.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-29 00:00:00', 7.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-30 00:00:00', 9.40699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1987-12-31 00:00:00', 11.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-01 00:00:00', 9.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-02 00:00:00', 13.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-03 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-04 00:00:00', 10.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-05 00:00:00', 8.60299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-06 00:00:00', 12.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-07 00:00:00', 11.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-08 00:00:00', 8.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-09 00:00:00', 8.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-10 00:00:00', 9.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-11 00:00:00', 9.02700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-12 00:00:00', 5.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-13 00:00:00', 9.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-14 00:00:00', 7.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-15 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-16 00:00:00', 8.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-17 00:00:00', 6.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-18 00:00:00', 8.62199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-19 00:00:00', 9.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-20 00:00:00', 7.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-21 00:00:00', -1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-22 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-23 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-24 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-25 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-26 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-27 00:00:00', 8.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-28 00:00:00', 9.86200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-29 00:00:00', 12.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-30 00:00:00', 7.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-01-31 00:00:00', 7.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-01 00:00:00', 8.47999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-02 00:00:00', 13.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-03 00:00:00', 18.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-04 00:00:00', 8.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-05 00:00:00', 6.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-06 00:00:00', 6.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-07 00:00:00', 0.324999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-08 00:00:00', -0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-09 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-10 00:00:00', 10.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-11 00:00:00', 10.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-12 00:00:00', 8.76500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-13 00:00:00', 9.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-14 00:00:00', 8.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-15 00:00:00', 10.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-16 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-17 00:00:00', 11.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-18 00:00:00', 8.13799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-19 00:00:00', 8.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-20 00:00:00', 12.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-21 00:00:00', 8.10499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-22 00:00:00', 9.43000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-23 00:00:00', 10.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-24 00:00:00', 12.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-25 00:00:00', 15.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-26 00:00:00', 11.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-27 00:00:00', 9.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-28 00:00:00', 9.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-02-29 00:00:00', 11.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-01 00:00:00', 14.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-02 00:00:00', 10.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-03 00:00:00', 16.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-04 00:00:00', 18.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-05 00:00:00', 20.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-06 00:00:00', 13.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-07 00:00:00', 8.97500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-08 00:00:00', 14.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-09 00:00:00', 12.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-10 00:00:00', 11.2130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-11 00:00:00', 13.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-12 00:00:00', 13.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-13 00:00:00', 10.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-14 00:00:00', 13.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-15 00:00:00', 13.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-16 00:00:00', 10.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-17 00:00:00', 13.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-18 00:00:00', 12.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-19 00:00:00', 15.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-20 00:00:00', 17.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-21 00:00:00', 18.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-22 00:00:00', 15.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-23 00:00:00', 12.2100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-24 00:00:00', 11.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-25 00:00:00', 7.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-26 00:00:00', 7.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-27 00:00:00', 12.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-28 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-29 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-30 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-03-31 00:00:00', 13.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-01 00:00:00', 15.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-02 00:00:00', 15.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-03 00:00:00', 12.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-04 00:00:00', 12.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-05 00:00:00', 15.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-06 00:00:00', 17.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-07 00:00:00', 18.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-08 00:00:00', 18.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-09 00:00:00', 15.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-10 00:00:00', 16.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-11 00:00:00', 22.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-12 00:00:00', 24.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-13 00:00:00', 26.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-14 00:00:00', 28.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-15 00:00:00', 29.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-16 00:00:00', 31.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-17 00:00:00', 22.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-18 00:00:00', 24.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-19 00:00:00', 24.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-20 00:00:00', 28.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-21 00:00:00', 28.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-22 00:00:00', 29.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-23 00:00:00', 27.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-24 00:00:00', 30.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-25 00:00:00', 31.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-26 00:00:00', 32.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-27 00:00:00', 31.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-28 00:00:00', 32.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-29 00:00:00', 24.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-04-30 00:00:00', 23.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-01 00:00:00', 24.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-02 00:00:00', 23.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-03 00:00:00', 27.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-04 00:00:00', 21.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-05 00:00:00', 22.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-06 00:00:00', 22.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-07 00:00:00', 24.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-08 00:00:00', 26.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-09 00:00:00', 27.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-10 00:00:00', 29.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-11 00:00:00', 30.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-12 00:00:00', 32.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-13 00:00:00', 30.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-14 00:00:00', 30.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-15 00:00:00', 30.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-16 00:00:00', 26.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-17 00:00:00', 26.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-18 00:00:00', 24.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-19 00:00:00', 28.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-20 00:00:00', 31.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-21 00:00:00', 31.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-22 00:00:00', 30.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-23 00:00:00', 30.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-24 00:00:00', 31.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-25 00:00:00', 32.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-26 00:00:00', 34.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-27 00:00:00', 34.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-28 00:00:00', 33.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-29 00:00:00', 37.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-30 00:00:00', 37.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-05-31 00:00:00', 32.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-01 00:00:00', 30.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-02 00:00:00', 31.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-03 00:00:00', 32.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-04 00:00:00', 32.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-05 00:00:00', 32.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-06 00:00:00', 32.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-07 00:00:00', 33.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-08 00:00:00', 32.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-09 00:00:00', 32.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-10 00:00:00', 31.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-11 00:00:00', 34.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-12 00:00:00', 36.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-13 00:00:00', 37.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-14 00:00:00', 38.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-15 00:00:00', 38.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-16 00:00:00', 39.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-17 00:00:00', 40.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-18 00:00:00', 41.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-19 00:00:00', 40.7739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-20 00:00:00', 42.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-21 00:00:00', 41.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-22 00:00:00', 39.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-23 00:00:00', 40.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-24 00:00:00', 42.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-25 00:00:00', 44.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-26 00:00:00', 41.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-27 00:00:00', 36.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-28 00:00:00', 33.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-29 00:00:00', 33.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-06-30 00:00:00', 35.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-01 00:00:00', 40.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-02 00:00:00', 44.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-03 00:00:00', 41.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-04 00:00:00', 40.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-05 00:00:00', 38.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-06 00:00:00', 38.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-07 00:00:00', 37.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-08 00:00:00', 39.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-09 00:00:00', 39.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-10 00:00:00', 41.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-11 00:00:00', 42.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-12 00:00:00', 42.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-13 00:00:00', 41.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-14 00:00:00', 38.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-15 00:00:00', 38.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-16 00:00:00', 40.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-17 00:00:00', 39.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-18 00:00:00', 39.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-19 00:00:00', 40.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-20 00:00:00', 41.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-21 00:00:00', 39.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-22 00:00:00', 37.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-23 00:00:00', 36.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-24 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-25 00:00:00', 37.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-26 00:00:00', 37.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-27 00:00:00', 39.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-28 00:00:00', 41.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-29 00:00:00', 39.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-30 00:00:00', 39.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-07-31 00:00:00', 39.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-01 00:00:00', 37.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-02 00:00:00', 34.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-03 00:00:00', 34.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-04 00:00:00', 35.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-05 00:00:00', 37.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-06 00:00:00', 39.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-07 00:00:00', 39.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-08 00:00:00', 37.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-09 00:00:00', 37.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-10 00:00:00', 38.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-11 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-12 00:00:00', 37.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-13 00:00:00', 37.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-14 00:00:00', 38.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-15 00:00:00', 35.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-16 00:00:00', 34.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-17 00:00:00', 36.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-18 00:00:00', 36.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-19 00:00:00', 35.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-20 00:00:00', 37.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-21 00:00:00', 36.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-22 00:00:00', 34.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-23 00:00:00', 33.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-24 00:00:00', 31.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-25 00:00:00', 32.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-26 00:00:00', 30.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-27 00:00:00', 30.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-28 00:00:00', 32.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-29 00:00:00', 32.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-30 00:00:00', 34.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-08-31 00:00:00', 34.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-01 00:00:00', 36.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-02 00:00:00', 33.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-03 00:00:00', 34.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-04 00:00:00', 34.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-05 00:00:00', 37.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-06 00:00:00', 39.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-07 00:00:00', 38.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-08 00:00:00', 33.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-09 00:00:00', 32.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-10 00:00:00', 34.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-11 00:00:00', 35.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-12 00:00:00', 35.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-13 00:00:00', 36.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-14 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-15 00:00:00', 31.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-16 00:00:00', 29.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-17 00:00:00', 28.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-18 00:00:00', 30.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-19 00:00:00', 31.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-20 00:00:00', 31.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-21 00:00:00', 32.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-22 00:00:00', 24.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-23 00:00:00', 26.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-24 00:00:00', 26.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-25 00:00:00', 24.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-26 00:00:00', 24.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-27 00:00:00', 24.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-28 00:00:00', 23.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-29 00:00:00', 22.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-09-30 00:00:00', 23.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-01 00:00:00', 23.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-02 00:00:00', 23.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-03 00:00:00', 20.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-04 00:00:00', 20.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-05 00:00:00', 23.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-06 00:00:00', 23.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-07 00:00:00', 22.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-08 00:00:00', 23.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-09 00:00:00', 24.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-10 00:00:00', 25.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-11 00:00:00', 24.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-12 00:00:00', 23.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-13 00:00:00', 22.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-14 00:00:00', 20.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-15 00:00:00', 23.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-16 00:00:00', 19.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-17 00:00:00', 19.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-18 00:00:00', 19.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-19 00:00:00', 19.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-20 00:00:00', 21.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-21 00:00:00', 24.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-22 00:00:00', 25.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-23 00:00:00', 20.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-24 00:00:00', 19.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-25 00:00:00', 20.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-26 00:00:00', 21.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-27 00:00:00', 24.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-28 00:00:00', 24.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-29 00:00:00', 19.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-30 00:00:00', 21.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-10-31 00:00:00', 23.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-01 00:00:00', 22.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-02 00:00:00', 24.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-03 00:00:00', 23.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-04 00:00:00', 23.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-05 00:00:00', 24.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-06 00:00:00', 21.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-07 00:00:00', 21.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-08 00:00:00', 23.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-09 00:00:00', 24.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-10 00:00:00', 25.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-11 00:00:00', 26.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-12 00:00:00', 26.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-13 00:00:00', 25.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-14 00:00:00', 25.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-15 00:00:00', 18.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-16 00:00:00', 15.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-17 00:00:00', 21.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-18 00:00:00', 20.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-19 00:00:00', 20.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-20 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-21 00:00:00', 17.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-22 00:00:00', 13.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-23 00:00:00', 12.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-24 00:00:00', 13.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-25 00:00:00', 13.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-26 00:00:00', 13.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-27 00:00:00', 15.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-28 00:00:00', 17.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-29 00:00:00', 18.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-11-30 00:00:00', 16.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-01 00:00:00', 16.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-02 00:00:00', 17.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-03 00:00:00', 18.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-04 00:00:00', 18.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-05 00:00:00', 16.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-06 00:00:00', 15.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-07 00:00:00', 15.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-08 00:00:00', 17.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-09 00:00:00', 16.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-10 00:00:00', 18.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-11 00:00:00', 17.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-12 00:00:00', 18.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-13 00:00:00', 16.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-14 00:00:00', 12.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-15 00:00:00', 13.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-16 00:00:00', 9.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-17 00:00:00', 11.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-18 00:00:00', 13.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-19 00:00:00', 14.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-20 00:00:00', 13.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-21 00:00:00', 11.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-22 00:00:00', 7.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-23 00:00:00', 7.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-24 00:00:00', 8.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-25 00:00:00', 8.44200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-26 00:00:00', 9.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-27 00:00:00', 11.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-28 00:00:00', 10.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-29 00:00:00', 8.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-30 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1988-12-31 00:00:00', 9.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-01 00:00:00', 6.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-02 00:00:00', 10.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-03 00:00:00', 9.38599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-04 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-05 00:00:00', 1.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-06 00:00:00', -0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-07 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-08 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-09 00:00:00', 6.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-10 00:00:00', 5.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-11 00:00:00', 6.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-12 00:00:00', 8.43999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-13 00:00:00', 4.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-14 00:00:00', 6.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-15 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-16 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-17 00:00:00', 7.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-18 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-19 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-20 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-21 00:00:00', 8.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-22 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-23 00:00:00', 7.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-24 00:00:00', 10.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-25 00:00:00', 3.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-26 00:00:00', 6.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-27 00:00:00', 3.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-28 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-29 00:00:00', 5.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-30 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-01-31 00:00:00', 0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-01 00:00:00', 5.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-02 00:00:00', 7.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-03 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-04 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-05 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-06 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-07 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-08 00:00:00', 4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-09 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-10 00:00:00', 8.43799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-11 00:00:00', 8.97500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-12 00:00:00', 7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-13 00:00:00', 1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-14 00:00:00', 3.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-15 00:00:00', 6.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-16 00:00:00', -0.492000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-17 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-18 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-19 00:00:00', 7.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-20 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-21 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-22 00:00:00', 8.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-23 00:00:00', 10.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-24 00:00:00', 7.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-25 00:00:00', 7.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-26 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-27 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-02-28 00:00:00', 7.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-01 00:00:00', 9.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-02 00:00:00', 10.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-03 00:00:00', 13.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-04 00:00:00', 13.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-05 00:00:00', 15.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-06 00:00:00', 15.8809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-07 00:00:00', 16.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-08 00:00:00', 10.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-09 00:00:00', 11.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-10 00:00:00', 14.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-11 00:00:00', 15.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-12 00:00:00', 18.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-13 00:00:00', 11.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-14 00:00:00', 13.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-15 00:00:00', 18.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-16 00:00:00', 22.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-17 00:00:00', 16.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-18 00:00:00', 17.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-19 00:00:00', 18.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-20 00:00:00', 12.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-21 00:00:00', 17.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-22 00:00:00', 12.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-23 00:00:00', 14.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-24 00:00:00', 16.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-25 00:00:00', 19.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-26 00:00:00', 21.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-27 00:00:00', 22.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-28 00:00:00', 24.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-29 00:00:00', 16.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-30 00:00:00', 20.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-03-31 00:00:00', 12.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-01 00:00:00', 11.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-02 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-03 00:00:00', 13.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-04 00:00:00', 12.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-05 00:00:00', 18.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-06 00:00:00', 20.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-07 00:00:00', 19.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-08 00:00:00', 19.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-09 00:00:00', 16.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-10 00:00:00', 16.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-11 00:00:00', 19.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-12 00:00:00', 18.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-13 00:00:00', 22.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-14 00:00:00', 25.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-15 00:00:00', 26.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-16 00:00:00', 22.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-17 00:00:00', 24.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-18 00:00:00', 21.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-19 00:00:00', 23.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-20 00:00:00', 25.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-21 00:00:00', 25.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-22 00:00:00', 23.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-23 00:00:00', 25.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-24 00:00:00', 25.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-25 00:00:00', 24.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-26 00:00:00', 26.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-27 00:00:00', 26.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-28 00:00:00', 26.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-29 00:00:00', 27.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-04-30 00:00:00', 19.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-01 00:00:00', 13.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-02 00:00:00', 12.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-03 00:00:00', 7.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-04 00:00:00', 13.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-05 00:00:00', 13.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-06 00:00:00', 18.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-07 00:00:00', 25.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-08 00:00:00', 20.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-09 00:00:00', 20.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-10 00:00:00', 24.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-11 00:00:00', 26.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-12 00:00:00', 28.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-13 00:00:00', 29.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-14 00:00:00', 27.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-15 00:00:00', 25.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-16 00:00:00', 27.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-17 00:00:00', 27.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-18 00:00:00', 28.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-19 00:00:00', 31.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-20 00:00:00', 30.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-21 00:00:00', 28.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-22 00:00:00', 28.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-23 00:00:00', 26.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-24 00:00:00', 29.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-25 00:00:00', 30.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-26 00:00:00', 32.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-27 00:00:00', 34.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-28 00:00:00', 36.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-29 00:00:00', 36.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-30 00:00:00', 37.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-05-31 00:00:00', 35.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-01 00:00:00', 37.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-02 00:00:00', 37.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-03 00:00:00', 35.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-04 00:00:00', 36.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-05 00:00:00', 34.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-06 00:00:00', 32.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-07 00:00:00', 31.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-08 00:00:00', 33.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-09 00:00:00', 30.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-10 00:00:00', 32.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-11 00:00:00', 33.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-12 00:00:00', 37.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-13 00:00:00', 35.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-14 00:00:00', 33.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-15 00:00:00', 34.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-16 00:00:00', 33.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-17 00:00:00', 34.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-18 00:00:00', 35.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-19 00:00:00', 31.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-20 00:00:00', 31.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-21 00:00:00', 31.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-22 00:00:00', 33.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-23 00:00:00', 34.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-24 00:00:00', 37.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-25 00:00:00', 38.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-26 00:00:00', 39.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-27 00:00:00', 38.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-28 00:00:00', 37.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-29 00:00:00', 36.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-06-30 00:00:00', 37.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-01 00:00:00', 35.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-02 00:00:00', 34.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-03 00:00:00', 35.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-04 00:00:00', 35.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-05 00:00:00', 35.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-06 00:00:00', 36.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-07 00:00:00', 38.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-08 00:00:00', 39.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-09 00:00:00', 42.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-10 00:00:00', 42.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-11 00:00:00', 42.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-12 00:00:00', 40.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-13 00:00:00', 36.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-14 00:00:00', 36.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-15 00:00:00', 36.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-16 00:00:00', 35.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-17 00:00:00', 36.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-18 00:00:00', 35.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-19 00:00:00', 34.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-20 00:00:00', 35.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-21 00:00:00', 35.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-22 00:00:00', 38.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-23 00:00:00', 33.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-24 00:00:00', 35.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-25 00:00:00', 35.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-26 00:00:00', 35.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-27 00:00:00', 37.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-28 00:00:00', 38.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-29 00:00:00', 39.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-30 00:00:00', 38.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-07-31 00:00:00', 34.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-01 00:00:00', 36.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-02 00:00:00', 37.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-03 00:00:00', 38.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-04 00:00:00', 37.6570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-05 00:00:00', 37.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-06 00:00:00', 37.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-07 00:00:00', 38.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-08 00:00:00', 37.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-09 00:00:00', 38.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-10 00:00:00', 39.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-11 00:00:00', 40.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-12 00:00:00', 40.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-13 00:00:00', 38.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-14 00:00:00', 36.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-15 00:00:00', 35.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-16 00:00:00', 36.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-17 00:00:00', 36.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-18 00:00:00', 37.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-19 00:00:00', 35.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-20 00:00:00', 31.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-21 00:00:00', 33.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-22 00:00:00', 34.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-23 00:00:00', 33.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-24 00:00:00', 34.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-25 00:00:00', 34.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-26 00:00:00', 34.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-27 00:00:00', 32.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-28 00:00:00', 31.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-29 00:00:00', 31.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-30 00:00:00', 33.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-08-31 00:00:00', 32.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-01 00:00:00', 32.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-02 00:00:00', 34.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-03 00:00:00', 35.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-04 00:00:00', 31.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-05 00:00:00', 27.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-06 00:00:00', 28.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-07 00:00:00', 30.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-08 00:00:00', 31.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-09 00:00:00', 32.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-10 00:00:00', 32.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-11 00:00:00', 32.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-12 00:00:00', 32.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-13 00:00:00', 32.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-14 00:00:00', 37.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-15 00:00:00', 38.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-16 00:00:00', 35.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-17 00:00:00', 32.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-18 00:00:00', 34.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-19 00:00:00', 33.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-20 00:00:00', 27.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-21 00:00:00', 24.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-22 00:00:00', 19.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-23 00:00:00', 20.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-24 00:00:00', 23.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-25 00:00:00', 26.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-26 00:00:00', 27.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-27 00:00:00', 27.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-28 00:00:00', 29.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-29 00:00:00', 28.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-09-30 00:00:00', 25.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-01 00:00:00', 28.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-02 00:00:00', 30.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-03 00:00:00', 32.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-04 00:00:00', 30.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-05 00:00:00', 30.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-06 00:00:00', 30.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-07 00:00:00', 31.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-08 00:00:00', 31.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-09 00:00:00', 29.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-10 00:00:00', 26.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-11 00:00:00', 21.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-12 00:00:00', 19.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-13 00:00:00', 21.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-14 00:00:00', 21.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-15 00:00:00', 23.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-16 00:00:00', 23.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-17 00:00:00', 25.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-18 00:00:00', 26.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-19 00:00:00', 24.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-20 00:00:00', 27.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-21 00:00:00', 25.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-22 00:00:00', 23.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-23 00:00:00', 20.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-24 00:00:00', 14.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-25 00:00:00', 19.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-26 00:00:00', 19.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-27 00:00:00', 18.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-28 00:00:00', 20.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-29 00:00:00', 23.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-30 00:00:00', 19.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-10-31 00:00:00', 23.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-01 00:00:00', 16.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-02 00:00:00', 11.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-03 00:00:00', 13.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-04 00:00:00', 14.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-05 00:00:00', 14.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-06 00:00:00', 15.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-07 00:00:00', 14.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-08 00:00:00', 11.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-09 00:00:00', 12.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-10 00:00:00', 10.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-11 00:00:00', 11.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-12 00:00:00', 13.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-13 00:00:00', 16.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-14 00:00:00', 16.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-15 00:00:00', 17.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-16 00:00:00', 19.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-17 00:00:00', 14.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-18 00:00:00', 13.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-19 00:00:00', 16.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-20 00:00:00', 18.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-21 00:00:00', 15.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-22 00:00:00', 12.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-23 00:00:00', 12.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-24 00:00:00', 13.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-25 00:00:00', 14.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-26 00:00:00', 17.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-27 00:00:00', 17.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-28 00:00:00', 18.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-29 00:00:00', 19.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-11-30 00:00:00', 20.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-01 00:00:00', 21.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-02 00:00:00', 19.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-03 00:00:00', 14.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-04 00:00:00', 11.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-05 00:00:00', 17.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-06 00:00:00', 12.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-07 00:00:00', 11.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-08 00:00:00', 10.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-09 00:00:00', 15.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-10 00:00:00', 13.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-11 00:00:00', 13.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-12 00:00:00', 14.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-13 00:00:00', 16.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-14 00:00:00', 14.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-15 00:00:00', 15.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-16 00:00:00', 11.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-17 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-18 00:00:00', 11.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-19 00:00:00', 12.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-20 00:00:00', 9.22299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-21 00:00:00', 10.4280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-22 00:00:00', 7.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-23 00:00:00', 7.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-24 00:00:00', 9.56999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-25 00:00:00', 8.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-26 00:00:00', 9.66100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-27 00:00:00', 10.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-28 00:00:00', 7.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-29 00:00:00', 7.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-30 00:00:00', 9.72099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1989-12-31 00:00:00', 5.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-01 00:00:00', 5.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-02 00:00:00', 7.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-03 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-04 00:00:00', 7.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-05 00:00:00', 10.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-06 00:00:00', 7.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-07 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-08 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-09 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-10 00:00:00', 3.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-11 00:00:00', 0.796000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-12 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-13 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-14 00:00:00', 3.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-15 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-16 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-17 00:00:00', 5.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-18 00:00:00', 10.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-19 00:00:00', 11.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-20 00:00:00', 7.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-21 00:00:00', 10.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-22 00:00:00', 10.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-23 00:00:00', 13.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-24 00:00:00', 15.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-25 00:00:00', 12.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-26 00:00:00', 4.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-27 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-28 00:00:00', 0.781000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-29 00:00:00', 6.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-30 00:00:00', 5.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-01-31 00:00:00', 0.495000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-01 00:00:00', 1.15299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-02 00:00:00', 4.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-03 00:00:00', 7.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-04 00:00:00', 7.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-05 00:00:00', 8.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-06 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-07 00:00:00', 2.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-08 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-09 00:00:00', 6.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-10 00:00:00', 9.19900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-11 00:00:00', 11.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-12 00:00:00', 8.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-13 00:00:00', 6.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-14 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-15 00:00:00', 8.98499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-16 00:00:00', 9.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-17 00:00:00', 8.05099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-18 00:00:00', 11.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-19 00:00:00', 13.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-20 00:00:00', 13.8970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-21 00:00:00', 14.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-22 00:00:00', 9.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-23 00:00:00', 7.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-24 00:00:00', 5.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-25 00:00:00', 7.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-26 00:00:00', 8.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-27 00:00:00', 7.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-02-28 00:00:00', 9.27000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-01 00:00:00', 11.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-02 00:00:00', 13.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-03 00:00:00', 14.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-04 00:00:00', 14.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-05 00:00:00', 14.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-06 00:00:00', 13.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-07 00:00:00', 14.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-08 00:00:00', 16.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-09 00:00:00', 11.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-10 00:00:00', 11.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-11 00:00:00', 15.1689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-12 00:00:00', 16.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-13 00:00:00', 19.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-14 00:00:00', 21.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-15 00:00:00', 18.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-16 00:00:00', 16.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-17 00:00:00', 11.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-18 00:00:00', 8.25800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-19 00:00:00', 11.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-20 00:00:00', 10.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-21 00:00:00', 8.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-22 00:00:00', 6.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-23 00:00:00', 9.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-24 00:00:00', 12.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-25 00:00:00', 17.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-26 00:00:00', 16.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-27 00:00:00', 15.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-28 00:00:00', 18.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-29 00:00:00', 19.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-30 00:00:00', 18.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-03-31 00:00:00', 16.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-01 00:00:00', 19.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-02 00:00:00', 22.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-03 00:00:00', 22.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-04 00:00:00', 18.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-05 00:00:00', 21.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-06 00:00:00', 16.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-07 00:00:00', 20.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-08 00:00:00', 13.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-09 00:00:00', 18.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-10 00:00:00', 21.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-11 00:00:00', 21.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-12 00:00:00', 19.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-13 00:00:00', 20.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-14 00:00:00', 19.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-15 00:00:00', 17.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-16 00:00:00', 20.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-17 00:00:00', 15.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-18 00:00:00', 19.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-19 00:00:00', 21.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-20 00:00:00', 18.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-21 00:00:00', 19.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-22 00:00:00', 25.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-23 00:00:00', 26.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-24 00:00:00', 24.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-25 00:00:00', 24.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-26 00:00:00', 22.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-27 00:00:00', 23.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-28 00:00:00', 27.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-29 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-04-30 00:00:00', 30.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-01 00:00:00', 29.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-02 00:00:00', 27.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-03 00:00:00', 31.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-04 00:00:00', 34.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-05 00:00:00', 32.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-06 00:00:00', 31.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-07 00:00:00', 33.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-08 00:00:00', 31.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-09 00:00:00', 31.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-10 00:00:00', 31.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-11 00:00:00', 34.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-12 00:00:00', 36.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-13 00:00:00', 39.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-14 00:00:00', 35.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-15 00:00:00', 28.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-16 00:00:00', 29.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-17 00:00:00', 30.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-18 00:00:00', 29.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-19 00:00:00', 30.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-20 00:00:00', 34.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-21 00:00:00', 33.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-22 00:00:00', 34.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-23 00:00:00', 35.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-24 00:00:00', 34.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-25 00:00:00', 33.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-26 00:00:00', 32.9410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-27 00:00:00', 36.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-28 00:00:00', 33.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-29 00:00:00', 32.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-30 00:00:00', 30.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-05-31 00:00:00', 30.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-01 00:00:00', 32.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-02 00:00:00', 35.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-03 00:00:00', 34.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-04 00:00:00', 34.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-05 00:00:00', 35.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-06 00:00:00', 34.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-07 00:00:00', 36.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-08 00:00:00', 32.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-09 00:00:00', 30.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-10 00:00:00', 33.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-11 00:00:00', 35.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-12 00:00:00', 35.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-13 00:00:00', 34.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-14 00:00:00', 36.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-15 00:00:00', 37.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-16 00:00:00', 39.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-17 00:00:00', 40.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-18 00:00:00', 41.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-19 00:00:00', 41.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-20 00:00:00', 42.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-21 00:00:00', 42.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-22 00:00:00', 44.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-23 00:00:00', 42.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-24 00:00:00', 39.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-25 00:00:00', 40.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-26 00:00:00', 38.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-27 00:00:00', 38.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-28 00:00:00', 40.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-29 00:00:00', 42.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-06-30 00:00:00', 43.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-01 00:00:00', 39.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-02 00:00:00', 38.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-03 00:00:00', 39.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-04 00:00:00', 36.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-05 00:00:00', 37.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-06 00:00:00', 38.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-07 00:00:00', 38.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-08 00:00:00', 39.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-09 00:00:00', 37.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-10 00:00:00', 35.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-11 00:00:00', 35.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-12 00:00:00', 34.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-13 00:00:00', 33.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-14 00:00:00', 34.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-15 00:00:00', 35.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-16 00:00:00', 35.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-17 00:00:00', 38.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-18 00:00:00', 38.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-19 00:00:00', 38.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-20 00:00:00', 37.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-21 00:00:00', 36.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-22 00:00:00', 34.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-23 00:00:00', 36.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-24 00:00:00', 40.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-25 00:00:00', 41.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-26 00:00:00', 39.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-27 00:00:00', 37.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-28 00:00:00', 38.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-29 00:00:00', 39.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-30 00:00:00', 42.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-07-31 00:00:00', 41.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-01 00:00:00', 40.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-02 00:00:00', 36.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-03 00:00:00', 38.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-04 00:00:00', 38.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-05 00:00:00', 38.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-06 00:00:00', 40.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-07 00:00:00', 41.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-08 00:00:00', 42.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-09 00:00:00', 42.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-10 00:00:00', 41.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-11 00:00:00', 42.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-12 00:00:00', 40.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-13 00:00:00', 37.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-14 00:00:00', 34.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-15 00:00:00', 36.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-16 00:00:00', 37.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-17 00:00:00', 38.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-18 00:00:00', 38.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-19 00:00:00', 36.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-20 00:00:00', 38.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-21 00:00:00', 39.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-22 00:00:00', 38.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-23 00:00:00', 34.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-24 00:00:00', 34.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-25 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-26 00:00:00', 34.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-27 00:00:00', 37.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-28 00:00:00', 39.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-29 00:00:00', 38.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-30 00:00:00', 35.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-08-31 00:00:00', 33.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-01 00:00:00', 34.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-02 00:00:00', 36.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-03 00:00:00', 33.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-04 00:00:00', 31.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-05 00:00:00', 31.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-06 00:00:00', 33.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-07 00:00:00', 33.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-08 00:00:00', 32.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-09 00:00:00', 32.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-10 00:00:00', 32.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-11 00:00:00', 33.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-12 00:00:00', 32.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-13 00:00:00', 34.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-14 00:00:00', 34.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-15 00:00:00', 36.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-16 00:00:00', 35.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-17 00:00:00', 34.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-18 00:00:00', 32.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-19 00:00:00', 32.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-20 00:00:00', 32.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-21 00:00:00', 33.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-22 00:00:00', 33.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-23 00:00:00', 33.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-24 00:00:00', 28.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-25 00:00:00', 30.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-26 00:00:00', 30.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-27 00:00:00', 30.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-28 00:00:00', 29.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-29 00:00:00', 30.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-09-30 00:00:00', 29.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-01 00:00:00', 30.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-02 00:00:00', 30.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-03 00:00:00', 29.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-04 00:00:00', 30.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-05 00:00:00', 30.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-06 00:00:00', 23.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-07 00:00:00', 22.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-08 00:00:00', 24.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-09 00:00:00', 23.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-10 00:00:00', 26.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-11 00:00:00', 26.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-12 00:00:00', 26.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-13 00:00:00', 23.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-14 00:00:00', 24.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-15 00:00:00', 22.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-16 00:00:00', 15.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-17 00:00:00', 14.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-18 00:00:00', 14.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-19 00:00:00', 11.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-20 00:00:00', 17.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-21 00:00:00', 20.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-22 00:00:00', 21.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-23 00:00:00', 20.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-24 00:00:00', 23.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-25 00:00:00', 24.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-26 00:00:00', 25.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-27 00:00:00', 25.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-28 00:00:00', 23.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-29 00:00:00', 22.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-30 00:00:00', 19.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-10-31 00:00:00', 18.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-01 00:00:00', 18.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-02 00:00:00', 19.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-03 00:00:00', 18.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-04 00:00:00', 22.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-05 00:00:00', 22.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-06 00:00:00', 21.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-07 00:00:00', 22.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-08 00:00:00', 22.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-09 00:00:00', 22.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-10 00:00:00', 23.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-11 00:00:00', 23.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-12 00:00:00', 23.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-13 00:00:00', 24.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-14 00:00:00', 14.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-15 00:00:00', 12.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-16 00:00:00', 14.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-17 00:00:00', 10.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-18 00:00:00', 12.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-19 00:00:00', 15.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-20 00:00:00', 18.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-21 00:00:00', 17.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-22 00:00:00', 17.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-23 00:00:00', 13.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-24 00:00:00', 16.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-25 00:00:00', 16.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-26 00:00:00', 16.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-27 00:00:00', 14.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-28 00:00:00', 15.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-29 00:00:00', 16.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-11-30 00:00:00', 16.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-01 00:00:00', 16.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-02 00:00:00', 16.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-03 00:00:00', 18.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-04 00:00:00', 17.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-05 00:00:00', 17.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-06 00:00:00', 18.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-07 00:00:00', 19.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-08 00:00:00', 15.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-09 00:00:00', 13.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-10 00:00:00', 9.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-11 00:00:00', 8.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-12 00:00:00', 8.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-13 00:00:00', 5.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-14 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-15 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-16 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-17 00:00:00', 5.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-18 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-19 00:00:00', 13.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-20 00:00:00', 9.21100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-21 00:00:00', 11.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-22 00:00:00', 10.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-23 00:00:00', 6.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-24 00:00:00', 5.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-25 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-26 00:00:00', 5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-27 00:00:00', 0.0630000010132789612, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-28 00:00:00', -2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-29 00:00:00', -5.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-30 00:00:00', -6.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1990-12-31 00:00:00', -3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-01 00:00:00', -1.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-02 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-03 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-04 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-05 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-06 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-07 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-08 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-09 00:00:00', 7.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-10 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-11 00:00:00', 3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-12 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-13 00:00:00', 4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-14 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-15 00:00:00', 8.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-16 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-17 00:00:00', 4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-18 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-19 00:00:00', 5.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-20 00:00:00', 6.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-21 00:00:00', 5.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-22 00:00:00', 2.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-23 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-24 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-25 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-26 00:00:00', 9.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-27 00:00:00', 6.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-28 00:00:00', 5.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-29 00:00:00', 7.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-30 00:00:00', 9.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-01-31 00:00:00', 9.05099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-01 00:00:00', 10.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-02 00:00:00', 10.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-03 00:00:00', 8.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-04 00:00:00', 7.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-05 00:00:00', 8.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-06 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-07 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-08 00:00:00', 8.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-09 00:00:00', 4.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-10 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-11 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-12 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-13 00:00:00', 2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-14 00:00:00', -1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-15 00:00:00', -1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-16 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-17 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-18 00:00:00', 6.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-19 00:00:00', 9.63300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-20 00:00:00', 11.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-21 00:00:00', 12.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-22 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-23 00:00:00', 8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-24 00:00:00', 5.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-25 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-26 00:00:00', 4.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-27 00:00:00', 7.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-02-28 00:00:00', 11.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-01 00:00:00', 15.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-02 00:00:00', 9.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-03 00:00:00', 11.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-04 00:00:00', 11.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-05 00:00:00', 8.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-06 00:00:00', 11.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-07 00:00:00', 10.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-08 00:00:00', 9.35700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-09 00:00:00', 10.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-10 00:00:00', 12.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-11 00:00:00', 12.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-12 00:00:00', 7.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-13 00:00:00', 11.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-14 00:00:00', 14.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-15 00:00:00', 15.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-16 00:00:00', 14.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-17 00:00:00', 7.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-18 00:00:00', 9.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-19 00:00:00', 14.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-20 00:00:00', 11.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-21 00:00:00', 11.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-22 00:00:00', 11.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-23 00:00:00', 13.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-24 00:00:00', 17.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-25 00:00:00', 17.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-26 00:00:00', 18.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-27 00:00:00', 21.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-28 00:00:00', 24.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-29 00:00:00', 19.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-30 00:00:00', 20.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-03-31 00:00:00', 22.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-01 00:00:00', 25.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-02 00:00:00', 19.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-03 00:00:00', 21.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-04 00:00:00', 24.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-05 00:00:00', 26.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-06 00:00:00', 21.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-07 00:00:00', 20.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-08 00:00:00', 19.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-09 00:00:00', 16.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-10 00:00:00', 19.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-11 00:00:00', 21.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-12 00:00:00', 20.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-13 00:00:00', 20.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-14 00:00:00', 19.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-15 00:00:00', 15.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-16 00:00:00', 16.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-17 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-18 00:00:00', 22.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-19 00:00:00', 26.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-20 00:00:00', 26.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-21 00:00:00', 25.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-22 00:00:00', 25.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-23 00:00:00', 26.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-24 00:00:00', 26.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-25 00:00:00', 26.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-26 00:00:00', 26.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-27 00:00:00', 24.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-28 00:00:00', 27.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-29 00:00:00', 25.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-04-30 00:00:00', 27.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-01 00:00:00', 25.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-02 00:00:00', 22.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-03 00:00:00', 26.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-04 00:00:00', 28.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-05 00:00:00', 22.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-06 00:00:00', 25.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-07 00:00:00', 27.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-08 00:00:00', 26.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-09 00:00:00', 26.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-10 00:00:00', 27.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-11 00:00:00', 29.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-12 00:00:00', 27.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-13 00:00:00', 26.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-14 00:00:00', 27.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-15 00:00:00', 26.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-16 00:00:00', 25.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-17 00:00:00', 28.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-18 00:00:00', 31.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-19 00:00:00', 26.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-20 00:00:00', 28.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-21 00:00:00', 20.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-22 00:00:00', 28.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-23 00:00:00', 30.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-24 00:00:00', 27.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-25 00:00:00', 25.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-26 00:00:00', 25.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-27 00:00:00', 28.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-28 00:00:00', 30.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-29 00:00:00', 30.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-30 00:00:00', 32.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-05-31 00:00:00', 34.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-01 00:00:00', 37.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-02 00:00:00', 36.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-03 00:00:00', 37.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-04 00:00:00', 37.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-05 00:00:00', 38.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-06 00:00:00', 37.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-07 00:00:00', 35.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-08 00:00:00', 36.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-09 00:00:00', 34.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-10 00:00:00', 32.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-11 00:00:00', 31.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-12 00:00:00', 35.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-13 00:00:00', 38.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-14 00:00:00', 38.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-15 00:00:00', 35.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-16 00:00:00', 35.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-17 00:00:00', 35.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-18 00:00:00', 33.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-19 00:00:00', 31.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-20 00:00:00', 33.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-21 00:00:00', 34.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-22 00:00:00', 34.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-23 00:00:00', 30.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-24 00:00:00', 26.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-25 00:00:00', 27.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-26 00:00:00', 29.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-27 00:00:00', 33.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-28 00:00:00', 35.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-29 00:00:00', 37.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-06-30 00:00:00', 36.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-01 00:00:00', 38.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-02 00:00:00', 38.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-03 00:00:00', 37.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-04 00:00:00', 37.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-05 00:00:00', 37.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-06 00:00:00', 37.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-07 00:00:00', 37.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-08 00:00:00', 38.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-09 00:00:00', 41.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-10 00:00:00', 39.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-11 00:00:00', 37.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-12 00:00:00', 34.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-13 00:00:00', 32.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-14 00:00:00', 34.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-15 00:00:00', 35.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-16 00:00:00', 38.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-17 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-18 00:00:00', 36.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-19 00:00:00', 37.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-20 00:00:00', 37.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-21 00:00:00', 37.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-22 00:00:00', 36.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-23 00:00:00', 36.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-24 00:00:00', 36.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-25 00:00:00', 37.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-26 00:00:00', 36.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-27 00:00:00', 37.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-28 00:00:00', 38.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-29 00:00:00', 40.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-30 00:00:00', 40.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-07-31 00:00:00', 39.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-01 00:00:00', 37.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-02 00:00:00', 37.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-03 00:00:00', 38.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-04 00:00:00', 38.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-05 00:00:00', 38.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-06 00:00:00', 37.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-07 00:00:00', 39.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-08 00:00:00', 36.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-09 00:00:00', 33.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-10 00:00:00', 33.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-11 00:00:00', 35.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-12 00:00:00', 37.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-13 00:00:00', 39.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-14 00:00:00', 38.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-15 00:00:00', 38.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-16 00:00:00', 37.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-17 00:00:00', 37.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-18 00:00:00', 38.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-19 00:00:00', 39.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-20 00:00:00', 38.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-21 00:00:00', 33.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-22 00:00:00', 33.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-23 00:00:00', 32.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-24 00:00:00', 33.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-25 00:00:00', 34.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-26 00:00:00', 36.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-27 00:00:00', 36.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-28 00:00:00', 36.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-29 00:00:00', 34.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-30 00:00:00', 34.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-08-31 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-01 00:00:00', 35.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-02 00:00:00', 36.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-03 00:00:00', 37.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-04 00:00:00', 37.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-05 00:00:00', 36.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-06 00:00:00', 32.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-07 00:00:00', 31.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-08 00:00:00', 34.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-09 00:00:00', 35.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-10 00:00:00', 34.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-11 00:00:00', 34.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-12 00:00:00', 32.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-13 00:00:00', 32.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-14 00:00:00', 32.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-15 00:00:00', 32.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-16 00:00:00', 29.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-17 00:00:00', 27.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-18 00:00:00', 25.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-19 00:00:00', 27.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-20 00:00:00', 29.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-21 00:00:00', 31.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-22 00:00:00', 33.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-23 00:00:00', 32.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-24 00:00:00', 32.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-25 00:00:00', 31.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-26 00:00:00', 24.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-27 00:00:00', 17.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-28 00:00:00', 19.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-29 00:00:00', 18.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-09-30 00:00:00', 17.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-01 00:00:00', 20.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-02 00:00:00', 21.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-03 00:00:00', 24.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-04 00:00:00', 25.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-05 00:00:00', 26.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-06 00:00:00', 25.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-07 00:00:00', 23.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-08 00:00:00', 21.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-09 00:00:00', 23.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-10 00:00:00', 24.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-11 00:00:00', 19.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-12 00:00:00', 18.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-13 00:00:00', 18.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-14 00:00:00', 16.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-15 00:00:00', 19.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-16 00:00:00', 21.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-17 00:00:00', 23.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-18 00:00:00', 19.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-19 00:00:00', 22.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-20 00:00:00', 23.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-21 00:00:00', 21.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-22 00:00:00', 22.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-23 00:00:00', 23.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-24 00:00:00', 24.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-25 00:00:00', 24.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-26 00:00:00', 24.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-27 00:00:00', 24.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-28 00:00:00', 23.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-29 00:00:00', 22.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-30 00:00:00', 22.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-10-31 00:00:00', 22.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-01 00:00:00', 21.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-02 00:00:00', 22.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-03 00:00:00', 21.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-04 00:00:00', 19.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-05 00:00:00', 23.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-06 00:00:00', 22.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-07 00:00:00', 21.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-08 00:00:00', 16.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-09 00:00:00', 16.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-10 00:00:00', 16.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-11 00:00:00', 16.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-12 00:00:00', 18.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-13 00:00:00', 12.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-14 00:00:00', 14.2489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-15 00:00:00', 16.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-16 00:00:00', 15.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-17 00:00:00', 12.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-18 00:00:00', 15.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-19 00:00:00', 15.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-20 00:00:00', 13.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-21 00:00:00', 8.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-22 00:00:00', 13.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-23 00:00:00', 8.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-24 00:00:00', 11.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-25 00:00:00', 15.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-26 00:00:00', 15.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-27 00:00:00', 12.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-28 00:00:00', 8.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-29 00:00:00', 6.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-11-30 00:00:00', 9.60499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-01 00:00:00', 10.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-02 00:00:00', 15.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-03 00:00:00', 13.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-04 00:00:00', 12.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-05 00:00:00', 14.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-06 00:00:00', 12.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-07 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-08 00:00:00', 13.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-09 00:00:00', 10.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-10 00:00:00', 10.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-11 00:00:00', 10.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-12 00:00:00', 10.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-13 00:00:00', 10.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-14 00:00:00', 8.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-15 00:00:00', 8.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-16 00:00:00', 8.30799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-17 00:00:00', 8.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-18 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-19 00:00:00', 7.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-20 00:00:00', 5.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-21 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-22 00:00:00', 5.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-23 00:00:00', 9.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-24 00:00:00', 4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-25 00:00:00', 4.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-26 00:00:00', 7.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-27 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-28 00:00:00', 6.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-29 00:00:00', 6.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-30 00:00:00', 5.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1991-12-31 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-01 00:00:00', 5.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-02 00:00:00', 7.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-03 00:00:00', 7.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-04 00:00:00', 7.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-05 00:00:00', 3.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-06 00:00:00', 7.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-07 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-08 00:00:00', 6.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-09 00:00:00', 3.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-10 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-11 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-12 00:00:00', 5.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-13 00:00:00', 8.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-14 00:00:00', 9.02700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-15 00:00:00', 8.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-16 00:00:00', 8.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-17 00:00:00', 11.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-18 00:00:00', 7.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-19 00:00:00', 10.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-20 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-21 00:00:00', 11.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-22 00:00:00', 12.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-23 00:00:00', 8.52900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-24 00:00:00', 8.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-25 00:00:00', 6.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-26 00:00:00', 6.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-27 00:00:00', 3.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-28 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-29 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-30 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-01-31 00:00:00', 6.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-01 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-02 00:00:00', 8.33100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-03 00:00:00', 9.85499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-04 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-05 00:00:00', 10.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-06 00:00:00', 10.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-07 00:00:00', 7.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-08 00:00:00', 8.43000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-09 00:00:00', 10.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-10 00:00:00', 11.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-11 00:00:00', 10.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-12 00:00:00', 7.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-13 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-14 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-15 00:00:00', 8.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-16 00:00:00', 7.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-17 00:00:00', 4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-18 00:00:00', 9.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-19 00:00:00', 8.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-20 00:00:00', 11.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-21 00:00:00', 12.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-22 00:00:00', 11.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-23 00:00:00', 12.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-24 00:00:00', 14.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-25 00:00:00', 15.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-26 00:00:00', 16.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-27 00:00:00', 6.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-28 00:00:00', 5.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-02-29 00:00:00', 5.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-01 00:00:00', 7.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-02 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-03 00:00:00', 6.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-04 00:00:00', 6.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-05 00:00:00', 8.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-06 00:00:00', 11.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-07 00:00:00', 12.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-08 00:00:00', 11.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-09 00:00:00', 10.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-10 00:00:00', 11.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-11 00:00:00', 5.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-12 00:00:00', 4.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-13 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-14 00:00:00', 8.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-15 00:00:00', 13.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-16 00:00:00', 12.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-17 00:00:00', 11.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-18 00:00:00', 14.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-19 00:00:00', 13.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-20 00:00:00', 9.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-21 00:00:00', 14.4980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-22 00:00:00', 15.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-23 00:00:00', 15.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-24 00:00:00', 15.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-25 00:00:00', 18.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-26 00:00:00', 8.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-27 00:00:00', 11.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-28 00:00:00', 15.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-29 00:00:00', 11.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-30 00:00:00', 11.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-03-31 00:00:00', 19.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-01 00:00:00', 21.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-02 00:00:00', 16.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-03 00:00:00', 19.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-04 00:00:00', 19.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-05 00:00:00', 21.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-06 00:00:00', 17.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-07 00:00:00', 17.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-08 00:00:00', 21.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-09 00:00:00', 22.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-10 00:00:00', 19.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-11 00:00:00', 20.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-12 00:00:00', 20.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-13 00:00:00', 24.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-14 00:00:00', 26.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-15 00:00:00', 26.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-16 00:00:00', 23.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-17 00:00:00', 21.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-18 00:00:00', 23.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-19 00:00:00', 26.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-20 00:00:00', 22.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-21 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-22 00:00:00', 23.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-23 00:00:00', 27.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-24 00:00:00', 22.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-25 00:00:00', 27.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-26 00:00:00', 26.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-27 00:00:00', 27.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-28 00:00:00', 26.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-29 00:00:00', 24.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-04-30 00:00:00', 26.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-01 00:00:00', 21.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-02 00:00:00', 13.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-03 00:00:00', 16.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-04 00:00:00', 18.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-05 00:00:00', 20.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-06 00:00:00', 19.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-07 00:00:00', 20.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-08 00:00:00', 21.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-09 00:00:00', 25.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-10 00:00:00', 29.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-11 00:00:00', 29.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-12 00:00:00', 30.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-13 00:00:00', 29.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-14 00:00:00', 29.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-15 00:00:00', 24.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-16 00:00:00', 26.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-17 00:00:00', 25.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-18 00:00:00', 24.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-19 00:00:00', 25.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-20 00:00:00', 25.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-21 00:00:00', 27.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-22 00:00:00', 29.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-23 00:00:00', 29.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-24 00:00:00', 29.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-25 00:00:00', 28.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-26 00:00:00', 26.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-27 00:00:00', 26.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-28 00:00:00', 27.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-29 00:00:00', 27.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-30 00:00:00', 28.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-05-31 00:00:00', 30.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-01 00:00:00', 32.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-02 00:00:00', 30.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-03 00:00:00', 32.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-04 00:00:00', 34.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-05 00:00:00', 35.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-06 00:00:00', 34.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-07 00:00:00', 33.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-08 00:00:00', 32.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-09 00:00:00', 32.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-10 00:00:00', 32.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-11 00:00:00', 33.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-12 00:00:00', 34.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-13 00:00:00', 31.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-14 00:00:00', 28.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-15 00:00:00', 31.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-16 00:00:00', 32.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-17 00:00:00', 32.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-18 00:00:00', 33.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-19 00:00:00', 37.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-20 00:00:00', 38.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-21 00:00:00', 34.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-22 00:00:00', 34.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-23 00:00:00', 34.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-24 00:00:00', 34.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-25 00:00:00', 34.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-26 00:00:00', 35.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-27 00:00:00', 37.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-28 00:00:00', 37.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-29 00:00:00', 36.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-06-30 00:00:00', 36.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-01 00:00:00', 36.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-02 00:00:00', 34.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-03 00:00:00', 32.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-04 00:00:00', 35.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-05 00:00:00', 36.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-06 00:00:00', 39.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-07 00:00:00', 39.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-08 00:00:00', 38.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-09 00:00:00', 36.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-10 00:00:00', 38.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-11 00:00:00', 39.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-12 00:00:00', 38.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-13 00:00:00', 37.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-14 00:00:00', 34.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-15 00:00:00', 35.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-16 00:00:00', 36.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-17 00:00:00', 36.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-18 00:00:00', 37.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-19 00:00:00', 38.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-20 00:00:00', 39.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-21 00:00:00', 39.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-22 00:00:00', 39.7739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-23 00:00:00', 37.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-24 00:00:00', 37.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-25 00:00:00', 38.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-26 00:00:00', 38.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-27 00:00:00', 39.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-28 00:00:00', 40.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-29 00:00:00', 38.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-30 00:00:00', 35.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-07-31 00:00:00', 34.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-01 00:00:00', 38.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-02 00:00:00', 39.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-03 00:00:00', 38.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-04 00:00:00', 38.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-05 00:00:00', 34.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-06 00:00:00', 32.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-07 00:00:00', 32.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-08 00:00:00', 31.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-09 00:00:00', 31.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-10 00:00:00', 32.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-11 00:00:00', 34.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-12 00:00:00', 34.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-13 00:00:00', 33.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-14 00:00:00', 34.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-15 00:00:00', 33.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-16 00:00:00', 31.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-17 00:00:00', 29.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-18 00:00:00', 33.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-19 00:00:00', 33.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-20 00:00:00', 34.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-21 00:00:00', 34.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-22 00:00:00', 34.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-23 00:00:00', 35.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-24 00:00:00', 35.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-25 00:00:00', 38.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-26 00:00:00', 37.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-27 00:00:00', 37.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-28 00:00:00', 32.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-29 00:00:00', 32.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-30 00:00:00', 29.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-08-31 00:00:00', 28.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-01 00:00:00', 30.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-02 00:00:00', 26.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-03 00:00:00', 27.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-04 00:00:00', 30.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-05 00:00:00', 30.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-06 00:00:00', 31.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-07 00:00:00', 31.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-08 00:00:00', 32.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-09 00:00:00', 31.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-10 00:00:00', 26.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-11 00:00:00', 28.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-12 00:00:00', 28.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-13 00:00:00', 28.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-14 00:00:00', 29.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-15 00:00:00', 28.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-16 00:00:00', 28.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-17 00:00:00', 28.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-18 00:00:00', 28.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-19 00:00:00', 30.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-20 00:00:00', 28.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-21 00:00:00', 28.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-22 00:00:00', 29.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-23 00:00:00', 30.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-24 00:00:00', 29.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-25 00:00:00', 30.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-26 00:00:00', 32.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-27 00:00:00', 30.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-28 00:00:00', 31.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-29 00:00:00', 26.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-09-30 00:00:00', 23.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-01 00:00:00', 21.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-02 00:00:00', 21.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-03 00:00:00', 24.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-04 00:00:00', 25.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-05 00:00:00', 23.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-06 00:00:00', 24.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-07 00:00:00', 20.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-08 00:00:00', 20.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-09 00:00:00', 22.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-10 00:00:00', 26.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-11 00:00:00', 28.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-12 00:00:00', 29.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-13 00:00:00', 27.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-14 00:00:00', 27.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-15 00:00:00', 24.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-16 00:00:00', 17.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-17 00:00:00', 14.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-18 00:00:00', 16.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-19 00:00:00', 20.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-20 00:00:00', 22.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-21 00:00:00', 20.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-22 00:00:00', 20.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-23 00:00:00', 21.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-24 00:00:00', 21.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-25 00:00:00', 22.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-26 00:00:00', 24.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-27 00:00:00', 26.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-28 00:00:00', 26.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-29 00:00:00', 26.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-30 00:00:00', 22.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-10-31 00:00:00', 21.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-01 00:00:00', 21.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-02 00:00:00', 20.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-03 00:00:00', 21.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-04 00:00:00', 12.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-05 00:00:00', 12.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-06 00:00:00', 17.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-07 00:00:00', 20.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-08 00:00:00', 23.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-09 00:00:00', 21.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-10 00:00:00', 24.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-11 00:00:00', 23.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-12 00:00:00', 24.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-13 00:00:00', 25.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-14 00:00:00', 23.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-15 00:00:00', 22.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-16 00:00:00', 21.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-17 00:00:00', 19.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-18 00:00:00', 12.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-19 00:00:00', 9.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-20 00:00:00', 12.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-21 00:00:00', 9.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-22 00:00:00', 14.6129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-23 00:00:00', 20.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-24 00:00:00', 21.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-25 00:00:00', 21.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-26 00:00:00', 23.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-27 00:00:00', 10.5780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-28 00:00:00', 14.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-29 00:00:00', 16.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-11-30 00:00:00', 17.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-01 00:00:00', 15.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-02 00:00:00', 13.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-03 00:00:00', 9.52000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-04 00:00:00', 12.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-05 00:00:00', 14.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-06 00:00:00', 12.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-07 00:00:00', 13.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-08 00:00:00', 10.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-09 00:00:00', 13.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-10 00:00:00', 14.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-11 00:00:00', 8.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-12 00:00:00', 7.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-13 00:00:00', 10.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-14 00:00:00', 14.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-15 00:00:00', 15.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-16 00:00:00', 16.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-17 00:00:00', 14.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-18 00:00:00', 14.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-19 00:00:00', 15.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-20 00:00:00', 15.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-21 00:00:00', 15.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-22 00:00:00', 14.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-23 00:00:00', 11.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-24 00:00:00', 7.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-25 00:00:00', 9.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-26 00:00:00', 10.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-27 00:00:00', 10.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-28 00:00:00', 12.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-29 00:00:00', 8.03699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-30 00:00:00', 7.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1992-12-31 00:00:00', 8.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-01 00:00:00', 9.66899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-02 00:00:00', 7.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-03 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-04 00:00:00', 7.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-05 00:00:00', 6.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-06 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-07 00:00:00', -1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-08 00:00:00', -1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-09 00:00:00', 2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-10 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-11 00:00:00', 5.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-12 00:00:00', 4.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-13 00:00:00', 4.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-14 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-15 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-16 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-17 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-18 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-19 00:00:00', 3.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-20 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-21 00:00:00', 3.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-22 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-23 00:00:00', 7.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-24 00:00:00', 7.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-25 00:00:00', 10.2130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-26 00:00:00', 10.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-27 00:00:00', 14.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-28 00:00:00', 13.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-29 00:00:00', 13.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-30 00:00:00', 13.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-01-31 00:00:00', 12.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-01 00:00:00', 13.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-02 00:00:00', 13.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-03 00:00:00', 16.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-04 00:00:00', 11.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-05 00:00:00', 13.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-06 00:00:00', 11.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-07 00:00:00', 15.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-08 00:00:00', 11.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-09 00:00:00', 14.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-10 00:00:00', 10.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-11 00:00:00', 12.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-12 00:00:00', 15.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-13 00:00:00', 11.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-14 00:00:00', 10.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-15 00:00:00', 11.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-16 00:00:00', 8.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-17 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-18 00:00:00', -1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-19 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-20 00:00:00', 6.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-21 00:00:00', 8.59599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-22 00:00:00', 5.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-23 00:00:00', 10.1579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-24 00:00:00', 9.56700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-25 00:00:00', 6.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-26 00:00:00', 8.16100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-27 00:00:00', 8.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-02-28 00:00:00', 11.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-01 00:00:00', 10.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-02 00:00:00', 8.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-03 00:00:00', 7.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-04 00:00:00', 14.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-05 00:00:00', 11.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-06 00:00:00', 16.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-07 00:00:00', 14.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-08 00:00:00', 17.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-09 00:00:00', 18.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-10 00:00:00', 13.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-11 00:00:00', 11.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-12 00:00:00', 12.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-13 00:00:00', 8.13599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-14 00:00:00', 7.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-15 00:00:00', 9.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-16 00:00:00', 9.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-17 00:00:00', 10.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-18 00:00:00', 11.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-19 00:00:00', 14.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-20 00:00:00', 7.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-21 00:00:00', 14.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-22 00:00:00', 12.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-23 00:00:00', 11.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-24 00:00:00', 8.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-25 00:00:00', 8.68500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-26 00:00:00', 12.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-27 00:00:00', 16.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-28 00:00:00', 17.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-29 00:00:00', 18.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-30 00:00:00', 19.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-03-31 00:00:00', 19.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-01 00:00:00', 14.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-02 00:00:00', 15.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-03 00:00:00', 19.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-04 00:00:00', 22.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-05 00:00:00', 20.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-06 00:00:00', 23.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-07 00:00:00', 21.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-08 00:00:00', 21.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-09 00:00:00', 24.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-10 00:00:00', 22.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-11 00:00:00', 23.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-12 00:00:00', 25.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-13 00:00:00', 27.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-14 00:00:00', 23.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-15 00:00:00', 18.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-16 00:00:00', 20.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-17 00:00:00', 23.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-18 00:00:00', 26.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-19 00:00:00', 28.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-20 00:00:00', 29.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-21 00:00:00', 30.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-22 00:00:00', 29.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-23 00:00:00', 31.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-24 00:00:00', 20.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-25 00:00:00', 21.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-26 00:00:00', 25.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-27 00:00:00', 24.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-28 00:00:00', 26.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-29 00:00:00', 21.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-04-30 00:00:00', 25.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-01 00:00:00', 28.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-02 00:00:00', 27.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-03 00:00:00', 27.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-04 00:00:00', 29.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-05 00:00:00', 27.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-06 00:00:00', 28.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-07 00:00:00', 30.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-08 00:00:00', 24.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-09 00:00:00', 16.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-10 00:00:00', 19.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-11 00:00:00', 18.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-12 00:00:00', 22.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-13 00:00:00', 25.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-14 00:00:00', 29.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-15 00:00:00', 27.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-16 00:00:00', 23.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-17 00:00:00', 27.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-18 00:00:00', 27.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-19 00:00:00', 28.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-20 00:00:00', 29.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-21 00:00:00', 26.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-22 00:00:00', 30.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-23 00:00:00', 32.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-24 00:00:00', 29.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-25 00:00:00', 29.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-26 00:00:00', 28.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-27 00:00:00', 31.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-28 00:00:00', 33.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-29 00:00:00', 31.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-30 00:00:00', 26.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-05-31 00:00:00', 26.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-01 00:00:00', 31.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-02 00:00:00', 29.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-03 00:00:00', 31.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-04 00:00:00', 34.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-05 00:00:00', 33.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-06 00:00:00', 31.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-07 00:00:00', 31.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-08 00:00:00', 31.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-09 00:00:00', 34.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-10 00:00:00', 37.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-11 00:00:00', 37.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-12 00:00:00', 37.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-13 00:00:00', 33.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-14 00:00:00', 34.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-15 00:00:00', 33.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-16 00:00:00', 34.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-17 00:00:00', 35.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-18 00:00:00', 35.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-19 00:00:00', 36.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-20 00:00:00', 38.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-21 00:00:00', 38.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-22 00:00:00', 38.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-23 00:00:00', 29.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-24 00:00:00', 32.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-25 00:00:00', 34.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-26 00:00:00', 32.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-27 00:00:00', 34.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-28 00:00:00', 36.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-29 00:00:00', 38.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-06-30 00:00:00', 39.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-01 00:00:00', 38.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-02 00:00:00', 39.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-03 00:00:00', 39.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-04 00:00:00', 41.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-05 00:00:00', 39.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-06 00:00:00', 40.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-07 00:00:00', 40.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-08 00:00:00', 37.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-09 00:00:00', 34.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-10 00:00:00', 34.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-11 00:00:00', 35.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-12 00:00:00', 35.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-13 00:00:00', 37.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-14 00:00:00', 39.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-15 00:00:00', 37.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-16 00:00:00', 38.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-17 00:00:00', 38.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-18 00:00:00', 37.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-19 00:00:00', 38.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-20 00:00:00', 40.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-21 00:00:00', 39.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-22 00:00:00', 35.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-23 00:00:00', 34.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-24 00:00:00', 29.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-25 00:00:00', 32.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-26 00:00:00', 33.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-27 00:00:00', 35.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-28 00:00:00', 36.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-29 00:00:00', 35.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-30 00:00:00', 36.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-07-31 00:00:00', 35.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-01 00:00:00', 35.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-02 00:00:00', 36.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-03 00:00:00', 35.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-04 00:00:00', 34.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-05 00:00:00', 34.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-06 00:00:00', 35.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-07 00:00:00', 35.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-08 00:00:00', 35.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-09 00:00:00', 34.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-10 00:00:00', 33.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-11 00:00:00', 31.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-12 00:00:00', 32.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-13 00:00:00', 34.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-14 00:00:00', 34.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-15 00:00:00', 36.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-16 00:00:00', 36.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-17 00:00:00', 35.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-18 00:00:00', 32.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-19 00:00:00', 31.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-20 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-21 00:00:00', 33.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-22 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-23 00:00:00', 34.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-24 00:00:00', 32.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-25 00:00:00', 30.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-26 00:00:00', 33.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-27 00:00:00', 36.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-28 00:00:00', 36.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-29 00:00:00', 36.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-30 00:00:00', 37.1500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-08-31 00:00:00', 37.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-01 00:00:00', 38.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-02 00:00:00', 36.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-03 00:00:00', 32.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-04 00:00:00', 34.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-05 00:00:00', 34.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-06 00:00:00', 34.4760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-07 00:00:00', 34.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-08 00:00:00', 34.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-09 00:00:00', 33.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-10 00:00:00', 34.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-11 00:00:00', 33.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-12 00:00:00', 30.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-13 00:00:00', 32.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-14 00:00:00', 33.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-15 00:00:00', 35.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-16 00:00:00', 30.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-17 00:00:00', 27.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-18 00:00:00', 31.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-19 00:00:00', 31.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-20 00:00:00', 32.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-21 00:00:00', 31.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-22 00:00:00', 32.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-23 00:00:00', 27.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-24 00:00:00', 26.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-25 00:00:00', 28.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-26 00:00:00', 28.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-27 00:00:00', 27.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-28 00:00:00', 24.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-29 00:00:00', 28.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-09-30 00:00:00', 29.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-01 00:00:00', 29.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-02 00:00:00', 31.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-03 00:00:00', 26.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-04 00:00:00', 25.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-05 00:00:00', 15.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-06 00:00:00', 17.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-07 00:00:00', 14.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-08 00:00:00', 12.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-09 00:00:00', 16.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-10 00:00:00', 16.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-11 00:00:00', 19.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-12 00:00:00', 22.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-13 00:00:00', 21.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-14 00:00:00', 21.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-15 00:00:00', 22.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-16 00:00:00', 19.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-17 00:00:00', 20.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-18 00:00:00', 20.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-19 00:00:00', 20.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-20 00:00:00', 21.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-21 00:00:00', 19.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-22 00:00:00', 16.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-23 00:00:00', 18.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-24 00:00:00', 18.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-25 00:00:00', 16.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-26 00:00:00', 18.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-27 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-28 00:00:00', 22.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-29 00:00:00', 23.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-30 00:00:00', 21.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-10-31 00:00:00', 22.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-01 00:00:00', 24.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-02 00:00:00', 18.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-03 00:00:00', 17.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-04 00:00:00', 11.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-05 00:00:00', 13.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-06 00:00:00', 9.81299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-07 00:00:00', 15.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-08 00:00:00', 9.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-09 00:00:00', 13.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-10 00:00:00', 19.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-11 00:00:00', 18.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-12 00:00:00', 22.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-13 00:00:00', 18.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-14 00:00:00', 21.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-15 00:00:00', 15.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-16 00:00:00', 15.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-17 00:00:00', 9.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-18 00:00:00', 9.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-19 00:00:00', 16.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-20 00:00:00', 15.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-21 00:00:00', 8.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-22 00:00:00', 5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-23 00:00:00', 7.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-24 00:00:00', 12.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-25 00:00:00', 14.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-26 00:00:00', 7.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-27 00:00:00', 8.10299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-28 00:00:00', 9.77900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-29 00:00:00', 12.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-11-30 00:00:00', 7.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-01 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-02 00:00:00', 6.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-03 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-04 00:00:00', 3.06999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-05 00:00:00', 9.71300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-06 00:00:00', 9.99600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-07 00:00:00', 4.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-08 00:00:00', 9.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-09 00:00:00', 6.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-10 00:00:00', 8.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-11 00:00:00', 10.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-12 00:00:00', 10.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-13 00:00:00', 5.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-14 00:00:00', 10.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-15 00:00:00', 12.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-16 00:00:00', 9.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-17 00:00:00', 8.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-18 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-19 00:00:00', 11.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-20 00:00:00', 12.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-21 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-22 00:00:00', 9.27900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-23 00:00:00', 12.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-24 00:00:00', 13.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-25 00:00:00', 13.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-26 00:00:00', 11.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-27 00:00:00', 9.57699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-28 00:00:00', 8.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-29 00:00:00', 9.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-30 00:00:00', 9.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1993-12-31 00:00:00', 8.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-01 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-02 00:00:00', 6.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-03 00:00:00', 7.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-04 00:00:00', 8.67099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-05 00:00:00', 10.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-06 00:00:00', 12.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-07 00:00:00', 6.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-08 00:00:00', 6.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-09 00:00:00', 5.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-10 00:00:00', 1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-11 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-12 00:00:00', 7.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-13 00:00:00', 9.14000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-14 00:00:00', 4.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-15 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-16 00:00:00', 6.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-17 00:00:00', 8.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-18 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-19 00:00:00', 2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-20 00:00:00', 1.59000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-21 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-22 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-23 00:00:00', 9.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-24 00:00:00', 6.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-25 00:00:00', 10.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-26 00:00:00', 7.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-27 00:00:00', 8.00399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-28 00:00:00', 8.40400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-29 00:00:00', 9.01500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-30 00:00:00', 10.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-01-31 00:00:00', 7.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-01 00:00:00', 11.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-02 00:00:00', 10.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-03 00:00:00', 12.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-04 00:00:00', 4.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-05 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-06 00:00:00', 8.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-07 00:00:00', 5.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-08 00:00:00', 3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-09 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-10 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-11 00:00:00', 1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-12 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-13 00:00:00', 4.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-14 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-15 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-16 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-17 00:00:00', 1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-18 00:00:00', 1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-19 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-20 00:00:00', -1.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-21 00:00:00', -1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-22 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-23 00:00:00', 4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-24 00:00:00', 7.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-25 00:00:00', 9.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-26 00:00:00', 6.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-27 00:00:00', 7.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-02-28 00:00:00', 11.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-01 00:00:00', 12.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-02 00:00:00', 12.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-03 00:00:00', 9.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-04 00:00:00', 10.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-05 00:00:00', 12.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-06 00:00:00', 15.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-07 00:00:00', 16.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-08 00:00:00', 18.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-09 00:00:00', 14.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-10 00:00:00', 9.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-11 00:00:00', 14.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-12 00:00:00', 13.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-13 00:00:00', 15.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-14 00:00:00', 12.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-15 00:00:00', 15.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-16 00:00:00', 18.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-17 00:00:00', 15.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-18 00:00:00', 14.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-19 00:00:00', 17.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-20 00:00:00', 17.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-21 00:00:00', 17.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-22 00:00:00', 19.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-23 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-24 00:00:00', 22.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-25 00:00:00', 13.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-26 00:00:00', 18.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-27 00:00:00', 20.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-28 00:00:00', 21.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-29 00:00:00', 21.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-30 00:00:00', 21.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-03-31 00:00:00', 23.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-01 00:00:00', 22.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-02 00:00:00', 23.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-03 00:00:00', 16.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-04 00:00:00', 15.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-05 00:00:00', 9.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-06 00:00:00', 6.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-07 00:00:00', 12.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-08 00:00:00', 14.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-09 00:00:00', 10.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-10 00:00:00', 14.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-11 00:00:00', 19.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-12 00:00:00', 20.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-13 00:00:00', 19.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-14 00:00:00', 20.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-15 00:00:00', 19.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-16 00:00:00', 18.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-17 00:00:00', 20.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-18 00:00:00', 22.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-19 00:00:00', 23.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-20 00:00:00', 21.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-21 00:00:00', 21.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-22 00:00:00', 23.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-23 00:00:00', 23.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-24 00:00:00', 26.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-25 00:00:00', 28.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-26 00:00:00', 30.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-27 00:00:00', 31.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-28 00:00:00', 23.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-29 00:00:00', 25.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-04-30 00:00:00', 20.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-01 00:00:00', 25.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-02 00:00:00', 28.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-03 00:00:00', 28.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-04 00:00:00', 31.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-05 00:00:00', 29.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-06 00:00:00', 31.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-07 00:00:00', 27.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-08 00:00:00', 25.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-09 00:00:00', 22.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-10 00:00:00', 24.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-11 00:00:00', 28.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-12 00:00:00', 30.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-13 00:00:00', 29.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-14 00:00:00', 31.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-15 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-16 00:00:00', 33.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-17 00:00:00', 33.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-18 00:00:00', 31.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-19 00:00:00', 26.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-20 00:00:00', 29.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-21 00:00:00', 31.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-22 00:00:00', 32.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-23 00:00:00', 29.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-24 00:00:00', 26.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-25 00:00:00', 30.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-26 00:00:00', 32.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-27 00:00:00', 32.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-28 00:00:00', 34.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-29 00:00:00', 36.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-30 00:00:00', 35.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-05-31 00:00:00', 32.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-01 00:00:00', 32.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-02 00:00:00', 34.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-03 00:00:00', 33.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-04 00:00:00', 35.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-05 00:00:00', 35.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-06 00:00:00', 37.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-07 00:00:00', 35.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-08 00:00:00', 33.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-09 00:00:00', 31.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-10 00:00:00', 33.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-11 00:00:00', 30.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-12 00:00:00', 31.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-13 00:00:00', 33.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-14 00:00:00', 32.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-15 00:00:00', 35.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-16 00:00:00', 34.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-17 00:00:00', 37.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-18 00:00:00', 40.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-19 00:00:00', 38.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-20 00:00:00', 38.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-21 00:00:00', 39.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-22 00:00:00', 39.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-23 00:00:00', 40.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-24 00:00:00', 38.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-25 00:00:00', 37.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-26 00:00:00', 36.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-27 00:00:00', 36.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-28 00:00:00', 38.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-29 00:00:00', 40.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-06-30 00:00:00', 42.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-01 00:00:00', 42.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-02 00:00:00', 38.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-03 00:00:00', 37.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-04 00:00:00', 38.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-05 00:00:00', 39.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-06 00:00:00', 41.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-07 00:00:00', 41.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-08 00:00:00', 42.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-09 00:00:00', 43.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-10 00:00:00', 42.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-11 00:00:00', 37.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-12 00:00:00', 35.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-13 00:00:00', 34.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-14 00:00:00', 33.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-15 00:00:00', 36.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-16 00:00:00', 37.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-17 00:00:00', 39.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-18 00:00:00', 40.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-19 00:00:00', 39.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-20 00:00:00', 38.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-21 00:00:00', 39.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-22 00:00:00', 40.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-23 00:00:00', 40.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-24 00:00:00', 37.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-25 00:00:00', 38.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-26 00:00:00', 39.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-27 00:00:00', 39.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-28 00:00:00', 38.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-29 00:00:00', 37.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-30 00:00:00', 37.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-07-31 00:00:00', 39.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-01 00:00:00', 41.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-02 00:00:00', 42.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-03 00:00:00', 43.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-04 00:00:00', 42.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-05 00:00:00', 41.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-06 00:00:00', 41.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-07 00:00:00', 40.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-08 00:00:00', 35.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-09 00:00:00', 33.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-10 00:00:00', 32.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-11 00:00:00', 36.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-12 00:00:00', 37.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-13 00:00:00', 40.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-14 00:00:00', 40.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-15 00:00:00', 36.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-16 00:00:00', 36.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-17 00:00:00', 34.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-18 00:00:00', 36.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-19 00:00:00', 37.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-20 00:00:00', 39.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-21 00:00:00', 39.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-22 00:00:00', 38.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-23 00:00:00', 38.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-24 00:00:00', 39.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-25 00:00:00', 39.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-26 00:00:00', 37.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-27 00:00:00', 37.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-28 00:00:00', 35.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-29 00:00:00', 34.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-30 00:00:00', 36.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-08-31 00:00:00', 34.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-01 00:00:00', 34.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-02 00:00:00', 33.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-03 00:00:00', 34.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-04 00:00:00', 31.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-05 00:00:00', 27.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-06 00:00:00', 26.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-07 00:00:00', 27.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-08 00:00:00', 28.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-09 00:00:00', 29.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-10 00:00:00', 28.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-11 00:00:00', 29.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-12 00:00:00', 28.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-13 00:00:00', 28.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-14 00:00:00', 26.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-15 00:00:00', 23.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-16 00:00:00', 25.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-17 00:00:00', 24.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-18 00:00:00', 20.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-19 00:00:00', 19.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-20 00:00:00', 19.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-21 00:00:00', 20.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-22 00:00:00', 23.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-23 00:00:00', 23.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-24 00:00:00', 25.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-25 00:00:00', 26.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-26 00:00:00', 26.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-27 00:00:00', 28.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-28 00:00:00', 29.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-29 00:00:00', 28.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-09-30 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-01 00:00:00', 28.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-02 00:00:00', 27.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-03 00:00:00', 25.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-04 00:00:00', 26.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-05 00:00:00', 23.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-06 00:00:00', 22.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-07 00:00:00', 25.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-08 00:00:00', 24.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-09 00:00:00', 23.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-10 00:00:00', 22.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-11 00:00:00', 21.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-12 00:00:00', 19.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-13 00:00:00', 20.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-14 00:00:00', 21.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-15 00:00:00', 22.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-16 00:00:00', 23.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-17 00:00:00', 19.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-18 00:00:00', 24.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-19 00:00:00', 26.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-20 00:00:00', 27.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-21 00:00:00', 26.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-22 00:00:00', 25.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-23 00:00:00', 21.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-24 00:00:00', 14.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-25 00:00:00', 12.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-26 00:00:00', 8.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-27 00:00:00', 16.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-28 00:00:00', 17.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-29 00:00:00', 18.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-30 00:00:00', 18.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-10-31 00:00:00', 19.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-01 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-02 00:00:00', 17.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-03 00:00:00', 18.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-04 00:00:00', 21.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-05 00:00:00', 22.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-06 00:00:00', 23.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-07 00:00:00', 18.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-08 00:00:00', 22.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-09 00:00:00', 24.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-10 00:00:00', 16.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-11 00:00:00', 14.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-12 00:00:00', 17.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-13 00:00:00', 17.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-14 00:00:00', 17.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-15 00:00:00', 19.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-16 00:00:00', 18.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-17 00:00:00', 18.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-18 00:00:00', 18.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-19 00:00:00', 16.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-20 00:00:00', 17.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-21 00:00:00', 18.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-22 00:00:00', 18.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-23 00:00:00', 19.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-24 00:00:00', 18.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-25 00:00:00', 13.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-26 00:00:00', 17.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-27 00:00:00', 14.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-28 00:00:00', 17.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-29 00:00:00', 16.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-11-30 00:00:00', 17.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-01 00:00:00', 18.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-02 00:00:00', 13.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-03 00:00:00', 15.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-04 00:00:00', 16.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-05 00:00:00', 14.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-06 00:00:00', 9.64999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-07 00:00:00', 5.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-08 00:00:00', -0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-09 00:00:00', 1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-10 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-11 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-12 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-13 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-14 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-15 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-16 00:00:00', 5.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-17 00:00:00', 7.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-18 00:00:00', 10.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-19 00:00:00', 12.9469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-20 00:00:00', 9.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-21 00:00:00', 9.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-22 00:00:00', 6.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-23 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-24 00:00:00', 1.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-25 00:00:00', 4.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-26 00:00:00', 2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-27 00:00:00', 3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-28 00:00:00', 2.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-29 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-30 00:00:00', 6.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1994-12-31 00:00:00', 9.06200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-01 00:00:00', 10.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-02 00:00:00', 10.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-03 00:00:00', 9.03699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-04 00:00:00', 10.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-05 00:00:00', 10.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-06 00:00:00', 8.61400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-07 00:00:00', 4.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-08 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-09 00:00:00', 2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-10 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-11 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-12 00:00:00', 8.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-13 00:00:00', 6.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-14 00:00:00', 6.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-15 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-16 00:00:00', 3.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-17 00:00:00', 6.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-18 00:00:00', 6.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-19 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-20 00:00:00', 6.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-21 00:00:00', 6.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-22 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-23 00:00:00', 5.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-24 00:00:00', 6.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-25 00:00:00', 3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-26 00:00:00', 7.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-27 00:00:00', 9.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-28 00:00:00', 8.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-29 00:00:00', 10.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-30 00:00:00', 13.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-01-31 00:00:00', 13.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-01 00:00:00', 13.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-02 00:00:00', 14.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-03 00:00:00', 14.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-04 00:00:00', 13.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-05 00:00:00', 12.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-06 00:00:00', 10.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-07 00:00:00', 8.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-08 00:00:00', 11.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-09 00:00:00', 9.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-10 00:00:00', 11.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-11 00:00:00', 7.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-12 00:00:00', 8.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-13 00:00:00', 9.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-14 00:00:00', 9.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-15 00:00:00', 8.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-16 00:00:00', 10.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-17 00:00:00', 8.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-18 00:00:00', 1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-19 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-20 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-21 00:00:00', 8.45199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-22 00:00:00', 8.36400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-23 00:00:00', 10.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-24 00:00:00', 13.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-25 00:00:00', 7.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-26 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-27 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-02-28 00:00:00', 4.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-01 00:00:00', 7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-02 00:00:00', 8.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-03 00:00:00', 8.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-04 00:00:00', 5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-05 00:00:00', 8.44900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-06 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-07 00:00:00', 8.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-08 00:00:00', 8.57900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-09 00:00:00', 6.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-10 00:00:00', 8.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-11 00:00:00', 12.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-12 00:00:00', 13.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-13 00:00:00', 14.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-14 00:00:00', 15.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-15 00:00:00', 15.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-16 00:00:00', 18.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-17 00:00:00', 20.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-18 00:00:00', 20.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-19 00:00:00', 13.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-20 00:00:00', 14.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-21 00:00:00', 13.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-22 00:00:00', 13.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-23 00:00:00', 14.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-24 00:00:00', 17.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-25 00:00:00', 17.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-26 00:00:00', 20.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-27 00:00:00', 15.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-28 00:00:00', 17.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-29 00:00:00', 14.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-30 00:00:00', 16.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-03-31 00:00:00', 18.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-01 00:00:00', 10.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-02 00:00:00', 14.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-03 00:00:00', 20.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-04 00:00:00', 21.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-05 00:00:00', 23.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-06 00:00:00', 24.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-07 00:00:00', 17.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-08 00:00:00', 16.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-09 00:00:00', 19.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-10 00:00:00', 21.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-11 00:00:00', 23.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-12 00:00:00', 24.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-13 00:00:00', 26.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-14 00:00:00', 24.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-15 00:00:00', 24.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-16 00:00:00', 26.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-17 00:00:00', 24.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-18 00:00:00', 23.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-19 00:00:00', 22.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-20 00:00:00', 23.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-21 00:00:00', 24.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-22 00:00:00', 24.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-23 00:00:00', 24.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-24 00:00:00', 25.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-25 00:00:00', 27.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-26 00:00:00', 26.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-27 00:00:00', 23.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-28 00:00:00', 25.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-29 00:00:00', 28.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-04-30 00:00:00', 27.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-01 00:00:00', 28.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-02 00:00:00', 29.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-03 00:00:00', 31.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-04 00:00:00', 32.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-05 00:00:00', 32.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-06 00:00:00', 34.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-07 00:00:00', 35.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-08 00:00:00', 36.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-09 00:00:00', 36.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-10 00:00:00', 31.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-11 00:00:00', 31.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-12 00:00:00', 32.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-13 00:00:00', 31.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-14 00:00:00', 32.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-15 00:00:00', 34.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-16 00:00:00', 32.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-17 00:00:00', 29.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-18 00:00:00', 29.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-19 00:00:00', 28.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-20 00:00:00', 28.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-21 00:00:00', 28.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-22 00:00:00', 28.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-23 00:00:00', 28.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-24 00:00:00', 26.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-25 00:00:00', 25.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-26 00:00:00', 25.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-27 00:00:00', 24.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-28 00:00:00', 27.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-29 00:00:00', 25.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-30 00:00:00', 27.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-05-31 00:00:00', 29.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-01 00:00:00', 31.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-02 00:00:00', 31.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-03 00:00:00', 30.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-04 00:00:00', 32.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-05 00:00:00', 35.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-06 00:00:00', 36.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-07 00:00:00', 37.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-08 00:00:00', 36.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-09 00:00:00', 35.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-10 00:00:00', 30.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-11 00:00:00', 33.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-12 00:00:00', 35.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-13 00:00:00', 34.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-14 00:00:00', 36.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-15 00:00:00', 40.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-16 00:00:00', 41.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-17 00:00:00', 38.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-18 00:00:00', 37.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-19 00:00:00', 37.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-20 00:00:00', 34.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-21 00:00:00', 34.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-22 00:00:00', 33.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-23 00:00:00', 35.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-24 00:00:00', 31.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-25 00:00:00', 33.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-26 00:00:00', 34.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-27 00:00:00', 34.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-28 00:00:00', 34.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-29 00:00:00', 35.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-06-30 00:00:00', 36.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-01 00:00:00', 39.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-02 00:00:00', 40.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-03 00:00:00', 39.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-04 00:00:00', 39.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-05 00:00:00', 38.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-06 00:00:00', 37.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-07 00:00:00', 37.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-08 00:00:00', 36.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-09 00:00:00', 36.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-10 00:00:00', 38.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-11 00:00:00', 37.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-12 00:00:00', 37.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-13 00:00:00', 39.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-14 00:00:00', 39.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-15 00:00:00', 41.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-16 00:00:00', 41.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-17 00:00:00', 43.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-18 00:00:00', 44.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-19 00:00:00', 40.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-20 00:00:00', 37.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-21 00:00:00', 38.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-22 00:00:00', 40.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-23 00:00:00', 40.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-24 00:00:00', 37.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-25 00:00:00', 33.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-26 00:00:00', 35.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-27 00:00:00', 37.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-28 00:00:00', 37.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-29 00:00:00', 37.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-30 00:00:00', 38.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-07-31 00:00:00', 40.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-01 00:00:00', 40.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-02 00:00:00', 39.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-03 00:00:00', 39.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-04 00:00:00', 39.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-05 00:00:00', 38.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-06 00:00:00', 35.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-07 00:00:00', 34.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-08 00:00:00', 36.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-09 00:00:00', 37.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-10 00:00:00', 40.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-11 00:00:00', 39.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-12 00:00:00', 40.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-13 00:00:00', 39.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-14 00:00:00', 39.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-15 00:00:00', 38.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-16 00:00:00', 37.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-17 00:00:00', 36.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-18 00:00:00', 36.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-19 00:00:00', 38.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-20 00:00:00', 38.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-21 00:00:00', 35.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-22 00:00:00', 35.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-23 00:00:00', 37.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-24 00:00:00', 40.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-25 00:00:00', 34.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-26 00:00:00', 35.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-27 00:00:00', 35.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-28 00:00:00', 35.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-29 00:00:00', 30.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-30 00:00:00', 29.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-08-31 00:00:00', 27.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-01 00:00:00', 31.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-02 00:00:00', 29.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-03 00:00:00', 28.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-04 00:00:00', 27.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-05 00:00:00', 27.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-06 00:00:00', 30.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-07 00:00:00', 30.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-08 00:00:00', 31.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-09 00:00:00', 32.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-10 00:00:00', 33.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-11 00:00:00', 31.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-12 00:00:00', 32.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-13 00:00:00', 29.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-14 00:00:00', 31.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-15 00:00:00', 31.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-16 00:00:00', 31.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-17 00:00:00', 32.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-18 00:00:00', 33.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-19 00:00:00', 33.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-20 00:00:00', 35.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-21 00:00:00', 36.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-22 00:00:00', 27.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-23 00:00:00', 24.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-24 00:00:00', 29.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-25 00:00:00', 31.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-26 00:00:00', 32.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-27 00:00:00', 32.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-28 00:00:00', 21.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-29 00:00:00', 25.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-09-30 00:00:00', 28.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-01 00:00:00', 27.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-02 00:00:00', 25.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-03 00:00:00', 23.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-04 00:00:00', 22.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-05 00:00:00', 28.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-06 00:00:00', 29.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-07 00:00:00', 29.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-08 00:00:00', 29.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-09 00:00:00', 27.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-10 00:00:00', 26.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-11 00:00:00', 24.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-12 00:00:00', 24.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-13 00:00:00', 20.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-14 00:00:00', 15.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-15 00:00:00', 20.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-16 00:00:00', 20.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-17 00:00:00', 20.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-18 00:00:00', 8.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-19 00:00:00', 10.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-20 00:00:00', 7.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-21 00:00:00', 16.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-22 00:00:00', 18.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-23 00:00:00', 19.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-24 00:00:00', 17.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-25 00:00:00', 16.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-26 00:00:00', 16.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-27 00:00:00', 14.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-28 00:00:00', 10.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-29 00:00:00', 15.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-30 00:00:00', 16.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-10-31 00:00:00', 17.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-01 00:00:00', 20.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-02 00:00:00', 17.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-03 00:00:00', 20.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-04 00:00:00', 22.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-05 00:00:00', 22.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-06 00:00:00', 22.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-07 00:00:00', 21.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-08 00:00:00', 23.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-09 00:00:00', 22.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-10 00:00:00', 23.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-11 00:00:00', 22.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-12 00:00:00', 22.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-13 00:00:00', 15.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-14 00:00:00', 17.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-15 00:00:00', 15.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-16 00:00:00', 9.59500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-17 00:00:00', 11.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-18 00:00:00', 12.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-19 00:00:00', 12.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-20 00:00:00', 16.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-21 00:00:00', 15.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-22 00:00:00', 14.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-23 00:00:00', 14.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-24 00:00:00', 15.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-25 00:00:00', 17.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-26 00:00:00', 17.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-27 00:00:00', 8.39000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-28 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-29 00:00:00', 0.808000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-11-30 00:00:00', 5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-01 00:00:00', 6.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-02 00:00:00', 7.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-03 00:00:00', 8.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-04 00:00:00', 8.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-05 00:00:00', 9.28699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-06 00:00:00', 8.84599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-07 00:00:00', 7.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-08 00:00:00', 7.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-09 00:00:00', 6.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-10 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-11 00:00:00', 2.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-12 00:00:00', 4.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-13 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-14 00:00:00', 1.98899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-15 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-16 00:00:00', 5.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-17 00:00:00', 8.15400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-18 00:00:00', 7.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-19 00:00:00', 5.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-20 00:00:00', 1.87000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-21 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-22 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-23 00:00:00', 4.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-24 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-25 00:00:00', 2.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-26 00:00:00', 2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-27 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-28 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-29 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-30 00:00:00', 8.55500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1995-12-31 00:00:00', 5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-01 00:00:00', 10.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-02 00:00:00', 7.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-03 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-04 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-05 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-06 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-07 00:00:00', 9.88300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-08 00:00:00', 5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-09 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-10 00:00:00', -1.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-11 00:00:00', -3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-12 00:00:00', -0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-13 00:00:00', -2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-14 00:00:00', -4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-15 00:00:00', -5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-16 00:00:00', -4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-17 00:00:00', 0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-18 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-19 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-20 00:00:00', 1.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-21 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-22 00:00:00', 0.515999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-23 00:00:00', 1.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-24 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-25 00:00:00', 0.300999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-26 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-27 00:00:00', 1.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-28 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-29 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-30 00:00:00', 2.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-01-31 00:00:00', 2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-01 00:00:00', 2.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-02 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-03 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-04 00:00:00', 0.714999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-05 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-06 00:00:00', 7.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-07 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-08 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-09 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-10 00:00:00', 8.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-11 00:00:00', 12.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-12 00:00:00', 7.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-13 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-14 00:00:00', -0.144999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-15 00:00:00', -0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-16 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-17 00:00:00', 7.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-18 00:00:00', 11.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-19 00:00:00', 13.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-20 00:00:00', 13.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-21 00:00:00', 9.64999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-22 00:00:00', 9.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-23 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-24 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-25 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-26 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-27 00:00:00', 0.950999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-28 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-02-29 00:00:00', 6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-01 00:00:00', 5.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-02 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-03 00:00:00', 11.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-04 00:00:00', 13.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-05 00:00:00', 14.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-06 00:00:00', 10.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-07 00:00:00', 11.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-08 00:00:00', 14.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-09 00:00:00', 14.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-10 00:00:00', 15.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-11 00:00:00', 15.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-12 00:00:00', 14.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-13 00:00:00', 17.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-14 00:00:00', 18.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-15 00:00:00', 10.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-16 00:00:00', 9.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-17 00:00:00', 10.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-18 00:00:00', 8.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-19 00:00:00', 8.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-20 00:00:00', 7.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-21 00:00:00', 8.97000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-22 00:00:00', 13.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-23 00:00:00', 17.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-24 00:00:00', 12.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-25 00:00:00', 15.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-26 00:00:00', 19.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-27 00:00:00', 12.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-28 00:00:00', 11.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-29 00:00:00', 12.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-30 00:00:00', 10.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-03-31 00:00:00', 11.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-01 00:00:00', 16.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-02 00:00:00', 14.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-03 00:00:00', 14.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-04 00:00:00', 9.15400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-05 00:00:00', 10.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-06 00:00:00', 12.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-07 00:00:00', 13.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-08 00:00:00', 17.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-09 00:00:00', 18.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-10 00:00:00', 18.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-11 00:00:00', 19.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-12 00:00:00', 18.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-13 00:00:00', 22.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-14 00:00:00', 26.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-15 00:00:00', 28.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-16 00:00:00', 22.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-17 00:00:00', 16.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-18 00:00:00', 20.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-19 00:00:00', 26.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-20 00:00:00', 25.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-21 00:00:00', 27.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-22 00:00:00', 24.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-23 00:00:00', 26.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-24 00:00:00', 26.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-25 00:00:00', 26.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-26 00:00:00', 24.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-27 00:00:00', 21.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-28 00:00:00', 25.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-29 00:00:00', 20.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-04-30 00:00:00', 21.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-01 00:00:00', 22.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-02 00:00:00', 21.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-03 00:00:00', 21.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-04 00:00:00', 21.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-05 00:00:00', 21.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-06 00:00:00', 23.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-07 00:00:00', 25.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-08 00:00:00', 25.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-09 00:00:00', 24.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-10 00:00:00', 24.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-11 00:00:00', 25.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-12 00:00:00', 24.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-13 00:00:00', 27.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-14 00:00:00', 28.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-15 00:00:00', 28.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-16 00:00:00', 28.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-17 00:00:00', 30.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-18 00:00:00', 30.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-19 00:00:00', 29.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-20 00:00:00', 27.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-21 00:00:00', 29.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-22 00:00:00', 30.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-23 00:00:00', 28.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-24 00:00:00', 30.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-25 00:00:00', 33.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-26 00:00:00', 34.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-27 00:00:00', 29.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-28 00:00:00', 27.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-29 00:00:00', 28.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-30 00:00:00', 31.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-05-31 00:00:00', 33.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-01 00:00:00', 33.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-02 00:00:00', 35.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-03 00:00:00', 36.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-04 00:00:00', 35.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-05 00:00:00', 34.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-06 00:00:00', 36.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-07 00:00:00', 39.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-08 00:00:00', 37.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-09 00:00:00', 37.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-10 00:00:00', 39.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-11 00:00:00', 38.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-12 00:00:00', 33.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-13 00:00:00', 34.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-14 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-15 00:00:00', 31.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-16 00:00:00', 27.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-17 00:00:00', 28.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-18 00:00:00', 29.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-19 00:00:00', 32.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-20 00:00:00', 32.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-21 00:00:00', 34.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-22 00:00:00', 36.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-23 00:00:00', 37.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-24 00:00:00', 36.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-25 00:00:00', 36.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-26 00:00:00', 36.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-27 00:00:00', 35.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-28 00:00:00', 34.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-29 00:00:00', 31.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-06-30 00:00:00', 33.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-01 00:00:00', 36.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-02 00:00:00', 37.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-03 00:00:00', 35.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-04 00:00:00', 33.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-05 00:00:00', 34.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-06 00:00:00', 36.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-07 00:00:00', 38.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-08 00:00:00', 39.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-09 00:00:00', 39.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-10 00:00:00', 36.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-11 00:00:00', 35.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-12 00:00:00', 35.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-13 00:00:00', 33.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-14 00:00:00', 30.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-15 00:00:00', 31.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-16 00:00:00', 31.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-17 00:00:00', 32.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-18 00:00:00', 35.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-19 00:00:00', 35.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-20 00:00:00', 34.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-21 00:00:00', 35.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-22 00:00:00', 36.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-23 00:00:00', 35.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-24 00:00:00', 38.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-25 00:00:00', 39.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-26 00:00:00', 39.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-27 00:00:00', 40.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-28 00:00:00', 40.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-29 00:00:00', 40.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-30 00:00:00', 39.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-07-31 00:00:00', 39.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-01 00:00:00', 39.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-02 00:00:00', 34.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-03 00:00:00', 37.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-04 00:00:00', 38.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-05 00:00:00', 39.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-06 00:00:00', 38.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-07 00:00:00', 38.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-08 00:00:00', 37.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-09 00:00:00', 39.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-10 00:00:00', 39.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-11 00:00:00', 40.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-12 00:00:00', 41.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-13 00:00:00', 39.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-14 00:00:00', 38.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-15 00:00:00', 36.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-16 00:00:00', 31.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-17 00:00:00', 30.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-18 00:00:00', 31.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-19 00:00:00', 31.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-20 00:00:00', 32.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-21 00:00:00', 32.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-22 00:00:00', 33.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-23 00:00:00', 32.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-24 00:00:00', 33.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-25 00:00:00', 33.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-26 00:00:00', 35.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-27 00:00:00', 35.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-28 00:00:00', 37.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-29 00:00:00', 35.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-30 00:00:00', 26.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-08-31 00:00:00', 29.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-01 00:00:00', 31.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-02 00:00:00', 30.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-03 00:00:00', 30.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-04 00:00:00', 29.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-05 00:00:00', 31.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-06 00:00:00', 33.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-07 00:00:00', 33.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-08 00:00:00', 33.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-09 00:00:00', 35.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-10 00:00:00', 37.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-11 00:00:00', 37.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-12 00:00:00', 37.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-13 00:00:00', 36.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-14 00:00:00', 36.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-15 00:00:00', 32.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-16 00:00:00', 31.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-17 00:00:00', 30.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-18 00:00:00', 31.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-19 00:00:00', 32.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-20 00:00:00', 32.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-21 00:00:00', 32.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-22 00:00:00', 35.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-23 00:00:00', 34.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-24 00:00:00', 31.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-25 00:00:00', 26.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-26 00:00:00', 27.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-27 00:00:00', 28.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-28 00:00:00', 28.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-29 00:00:00', 31.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-09-30 00:00:00', 32.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-01 00:00:00', 29.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-02 00:00:00', 18.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-03 00:00:00', 19.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-04 00:00:00', 21.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-05 00:00:00', 22.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-06 00:00:00', 23.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-07 00:00:00', 24.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-08 00:00:00', 22.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-09 00:00:00', 22.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-10 00:00:00', 24.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-11 00:00:00', 23.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-12 00:00:00', 23.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-13 00:00:00', 25.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-14 00:00:00', 27.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-15 00:00:00', 25.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-16 00:00:00', 19.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-17 00:00:00', 19.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-18 00:00:00', 19.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-19 00:00:00', 15.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-20 00:00:00', 16.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-21 00:00:00', 18.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-22 00:00:00', 20.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-23 00:00:00', 22.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-24 00:00:00', 24.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-25 00:00:00', 24.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-26 00:00:00', 24.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-27 00:00:00', 24.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-28 00:00:00', 25.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-29 00:00:00', 21.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-30 00:00:00', 21.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-10-31 00:00:00', 23.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-01 00:00:00', 14.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-02 00:00:00', 20.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-03 00:00:00', 19.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-04 00:00:00', 17.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-05 00:00:00', 18.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-06 00:00:00', 16.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-07 00:00:00', 19.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-08 00:00:00', 21.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-09 00:00:00', 21.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-10 00:00:00', 19.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-11 00:00:00', 15.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-12 00:00:00', 13.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-13 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-14 00:00:00', 4.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-15 00:00:00', 8.78400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-16 00:00:00', 10.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-17 00:00:00', 9.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-18 00:00:00', 8.09500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-19 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-20 00:00:00', 5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-21 00:00:00', 8.09099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-22 00:00:00', 8.93999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-23 00:00:00', 10.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-24 00:00:00', 10.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-25 00:00:00', 9.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-26 00:00:00', 9.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-27 00:00:00', 10.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-28 00:00:00', 11.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-29 00:00:00', 12.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-11-30 00:00:00', 11.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-01 00:00:00', 10.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-02 00:00:00', 6.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-03 00:00:00', 6.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-04 00:00:00', 5.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-05 00:00:00', 6.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-06 00:00:00', 5.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-07 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-08 00:00:00', 6.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-09 00:00:00', 6.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-10 00:00:00', 10.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-11 00:00:00', 12.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-12 00:00:00', 10.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-13 00:00:00', 11.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-14 00:00:00', 13.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-15 00:00:00', 14.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-16 00:00:00', 13.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-17 00:00:00', 13.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-18 00:00:00', 12.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-19 00:00:00', 13.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-20 00:00:00', 13.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-21 00:00:00', 13.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-22 00:00:00', 14.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-23 00:00:00', 15.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-24 00:00:00', 10.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-25 00:00:00', 13.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-26 00:00:00', 13.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-27 00:00:00', 13.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-28 00:00:00', 14.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-29 00:00:00', 16.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-30 00:00:00', 19.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1996-12-31 00:00:00', 15.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-01 00:00:00', 15.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-02 00:00:00', 18.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-03 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-04 00:00:00', 9.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-05 00:00:00', 10.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-06 00:00:00', 11.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-07 00:00:00', 12.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-08 00:00:00', 11.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-09 00:00:00', 13.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-10 00:00:00', 14.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-11 00:00:00', 14.1920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-12 00:00:00', 10.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-13 00:00:00', 9.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-14 00:00:00', 6.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-15 00:00:00', 8.24600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-16 00:00:00', 11.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-17 00:00:00', 12.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-18 00:00:00', 7.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-19 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-20 00:00:00', 2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-21 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-22 00:00:00', 6.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-23 00:00:00', 4.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-24 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-25 00:00:00', 6.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-26 00:00:00', 10.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-27 00:00:00', 8.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-28 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-29 00:00:00', 7.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-30 00:00:00', 8.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-01-31 00:00:00', 7.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-01 00:00:00', 6.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-02 00:00:00', 1.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-03 00:00:00', 6.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-04 00:00:00', 7.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-05 00:00:00', 8.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-06 00:00:00', 10.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-07 00:00:00', 7.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-08 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-09 00:00:00', 4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-10 00:00:00', 4.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-11 00:00:00', 6.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-12 00:00:00', 9, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-13 00:00:00', 10.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-14 00:00:00', 10.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-15 00:00:00', 11.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-16 00:00:00', 12.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-17 00:00:00', 12.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-18 00:00:00', 11.9709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-19 00:00:00', 14.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-20 00:00:00', 11.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-21 00:00:00', 12.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-22 00:00:00', 10.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-23 00:00:00', 12.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-24 00:00:00', 10.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-25 00:00:00', 9.98200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-26 00:00:00', 12.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-27 00:00:00', 16.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-02-28 00:00:00', 14.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-01 00:00:00', 10.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-02 00:00:00', 7.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-03 00:00:00', 11.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-04 00:00:00', 15.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-05 00:00:00', 14.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-06 00:00:00', 15.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-07 00:00:00', 11.255000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-08 00:00:00', 19.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-09 00:00:00', 11.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-10 00:00:00', 8.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-11 00:00:00', 9.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-12 00:00:00', 11.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-13 00:00:00', 14.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-14 00:00:00', 10.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-15 00:00:00', 11.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-16 00:00:00', 13.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-17 00:00:00', 14.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-18 00:00:00', 17.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-19 00:00:00', 15.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-20 00:00:00', 17.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-21 00:00:00', 16.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-22 00:00:00', 14.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-23 00:00:00', 16.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-24 00:00:00', 21.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-25 00:00:00', 24.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-26 00:00:00', 23.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-27 00:00:00', 15.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-28 00:00:00', 16.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-29 00:00:00', 19.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-30 00:00:00', 23.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-03-31 00:00:00', 21.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-01 00:00:00', 14.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-02 00:00:00', 16.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-03 00:00:00', 16.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-04 00:00:00', 18.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-05 00:00:00', 21.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-06 00:00:00', 18.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-07 00:00:00', 21.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-08 00:00:00', 23.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-09 00:00:00', 23.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-10 00:00:00', 26.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-11 00:00:00', 26.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-12 00:00:00', 18.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-13 00:00:00', 17.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-14 00:00:00', 17.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-15 00:00:00', 15.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-16 00:00:00', 21.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-17 00:00:00', 24.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-18 00:00:00', 25.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-19 00:00:00', 26.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-20 00:00:00', 23.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-21 00:00:00', 23.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-22 00:00:00', 27.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-23 00:00:00', 29.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-24 00:00:00', 29.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-25 00:00:00', 30.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-26 00:00:00', 31.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-27 00:00:00', 29.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-28 00:00:00', 28.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-29 00:00:00', 30.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-04-30 00:00:00', 26.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-01 00:00:00', 26.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-02 00:00:00', 27.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-03 00:00:00', 28.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-04 00:00:00', 28.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-05 00:00:00', 32.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-06 00:00:00', 24.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-07 00:00:00', 20.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-08 00:00:00', 19.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-09 00:00:00', 22.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-10 00:00:00', 24.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-11 00:00:00', 24.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-12 00:00:00', 21.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-13 00:00:00', 22.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-14 00:00:00', 26.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-15 00:00:00', 26.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-16 00:00:00', 20.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-17 00:00:00', 21.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-18 00:00:00', 25.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-19 00:00:00', 29.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-20 00:00:00', 29.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-21 00:00:00', 30.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-22 00:00:00', 31.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-23 00:00:00', 32.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-24 00:00:00', 33.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-25 00:00:00', 33.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-26 00:00:00', 32.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-27 00:00:00', 32.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-28 00:00:00', 32.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-29 00:00:00', 32.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-30 00:00:00', 34.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-05-31 00:00:00', 33.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-01 00:00:00', 34.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-02 00:00:00', 34.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-03 00:00:00', 34.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-04 00:00:00', 30.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-05 00:00:00', 33.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-06 00:00:00', 34.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-07 00:00:00', 34.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-08 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-09 00:00:00', 35.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-10 00:00:00', 35.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-11 00:00:00', 33.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-12 00:00:00', 32.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-13 00:00:00', 33.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-14 00:00:00', 35.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-15 00:00:00', 36.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-16 00:00:00', 38.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-17 00:00:00', 37.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-18 00:00:00', 37.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-19 00:00:00', 30.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-20 00:00:00', 35.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-21 00:00:00', 35.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-22 00:00:00', 34.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-23 00:00:00', 36.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-24 00:00:00', 38.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-25 00:00:00', 38.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-26 00:00:00', 39.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-27 00:00:00', 38.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-28 00:00:00', 36.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-29 00:00:00', 34.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-06-30 00:00:00', 33.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-01 00:00:00', 35.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-02 00:00:00', 37.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-03 00:00:00', 38.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-04 00:00:00', 38.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-05 00:00:00', 39.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-06 00:00:00', 38.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-07 00:00:00', 40.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-08 00:00:00', 39.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-09 00:00:00', 37.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-10 00:00:00', 35.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-11 00:00:00', 37.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-12 00:00:00', 38.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-13 00:00:00', 39.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-14 00:00:00', 39.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-15 00:00:00', 40.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-16 00:00:00', 43.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-17 00:00:00', 42.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-18 00:00:00', 44.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-19 00:00:00', 45.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-20 00:00:00', 42.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-21 00:00:00', 40.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-22 00:00:00', 35.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-23 00:00:00', 37.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-24 00:00:00', 38.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-25 00:00:00', 39.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-26 00:00:00', 41.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-27 00:00:00', 41.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-28 00:00:00', 42.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-29 00:00:00', 39.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-30 00:00:00', 38.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-07-31 00:00:00', 38.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-01 00:00:00', 35.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-02 00:00:00', 32.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-03 00:00:00', 31.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-04 00:00:00', 33.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-05 00:00:00', 34.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-06 00:00:00', 37.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-07 00:00:00', 40.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-08 00:00:00', 41.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-09 00:00:00', 40.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-10 00:00:00', 39.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-11 00:00:00', 37.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-12 00:00:00', 34.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-13 00:00:00', 35.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-14 00:00:00', 38.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-15 00:00:00', 39.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-16 00:00:00', 40.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-17 00:00:00', 40.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-18 00:00:00', 40.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-19 00:00:00', 41.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-20 00:00:00', 40.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-21 00:00:00', 40.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-22 00:00:00', 40.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-23 00:00:00', 39.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-24 00:00:00', 36.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-25 00:00:00', 31.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-26 00:00:00', 31.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-27 00:00:00', 32.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-28 00:00:00', 32.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-29 00:00:00', 33.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-30 00:00:00', 33.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-08-31 00:00:00', 35.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-01 00:00:00', 36.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-02 00:00:00', 37.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-03 00:00:00', 38.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-04 00:00:00', 37.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-05 00:00:00', 36.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-06 00:00:00', 32.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-07 00:00:00', 29.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-08 00:00:00', 28.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-09 00:00:00', 28.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-10 00:00:00', 31.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-11 00:00:00', 33.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-12 00:00:00', 32.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-13 00:00:00', 32.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-14 00:00:00', 33.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-15 00:00:00', 31.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-16 00:00:00', 28.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-17 00:00:00', 30.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-18 00:00:00', 30.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-19 00:00:00', 28.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-20 00:00:00', 29.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-21 00:00:00', 27.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-22 00:00:00', 28.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-23 00:00:00', 29.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-24 00:00:00', 31.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-25 00:00:00', 31.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-26 00:00:00', 31.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-27 00:00:00', 30.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-28 00:00:00', 29.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-29 00:00:00', 29.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-09-30 00:00:00', 30.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-01 00:00:00', 29.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-02 00:00:00', 30.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-03 00:00:00', 30.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-04 00:00:00', 31.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-05 00:00:00', 29.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-06 00:00:00', 27.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-07 00:00:00', 28.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-08 00:00:00', 24.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-09 00:00:00', 24.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-10 00:00:00', 23.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-11 00:00:00', 24.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-12 00:00:00', 25.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-13 00:00:00', 25.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-14 00:00:00', 25.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-15 00:00:00', 25.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-16 00:00:00', 25.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-17 00:00:00', 24.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-18 00:00:00', 22.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-19 00:00:00', 24.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-20 00:00:00', 24.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-21 00:00:00', 23.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-22 00:00:00', 21.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-23 00:00:00', 23.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-24 00:00:00', 24.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-25 00:00:00', 21.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-26 00:00:00', 19.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-27 00:00:00', 21.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-28 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-29 00:00:00', 21.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-30 00:00:00', 21.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-10-31 00:00:00', 22.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-01 00:00:00', 22.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-02 00:00:00', 12.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-03 00:00:00', 18.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-04 00:00:00', 21.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-05 00:00:00', 24.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-06 00:00:00', 16.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-07 00:00:00', 15.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-08 00:00:00', 11.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-09 00:00:00', 9.65400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-10 00:00:00', 12.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-11 00:00:00', 16.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-12 00:00:00', 17.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-13 00:00:00', 19.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-14 00:00:00', 16.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-15 00:00:00', 12.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-16 00:00:00', 13.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-17 00:00:00', 14.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-18 00:00:00', 15.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-19 00:00:00', 15.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-20 00:00:00', 16.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-21 00:00:00', 17.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-22 00:00:00', 16.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-23 00:00:00', 14.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-24 00:00:00', 10.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-25 00:00:00', 8.16100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-26 00:00:00', 7.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-27 00:00:00', 9.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-28 00:00:00', 11.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-29 00:00:00', 11.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-11-30 00:00:00', 11.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-01 00:00:00', 13.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-02 00:00:00', 9.48200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-03 00:00:00', 9.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-04 00:00:00', 10.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-05 00:00:00', 12.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-06 00:00:00', 12.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-07 00:00:00', 14.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-08 00:00:00', 13.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-09 00:00:00', 13.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-10 00:00:00', 12.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-11 00:00:00', 16.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-12 00:00:00', 9.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-13 00:00:00', 9.55300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-14 00:00:00', 11.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-15 00:00:00', 12.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-16 00:00:00', 11.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-17 00:00:00', 12.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-18 00:00:00', 7.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-19 00:00:00', 6.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-20 00:00:00', 7.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-21 00:00:00', 9.30500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-22 00:00:00', 5.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-23 00:00:00', 7.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-24 00:00:00', 8.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-25 00:00:00', 7.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-26 00:00:00', 9.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-27 00:00:00', 7.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-28 00:00:00', 5.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-29 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-30 00:00:00', 7.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1997-12-31 00:00:00', 8.52499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-01 00:00:00', 10.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-02 00:00:00', 10.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-03 00:00:00', 10.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-04 00:00:00', 7.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-05 00:00:00', 7.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-06 00:00:00', 8.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-07 00:00:00', 6.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-08 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-09 00:00:00', 6.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-10 00:00:00', 9.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-11 00:00:00', 7.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-12 00:00:00', 6.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-13 00:00:00', 7.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-14 00:00:00', 6.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-15 00:00:00', 0.842000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-16 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-17 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-18 00:00:00', 2.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-19 00:00:00', 4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-20 00:00:00', 4.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-21 00:00:00', 5.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-22 00:00:00', 3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-23 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-24 00:00:00', 4.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-25 00:00:00', 6.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-26 00:00:00', 8.66899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-27 00:00:00', 10.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-28 00:00:00', 5.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-29 00:00:00', 8.48700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-30 00:00:00', 8.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-01-31 00:00:00', 10.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-01 00:00:00', 9.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-02 00:00:00', 7.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-03 00:00:00', 8.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-04 00:00:00', 9.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-05 00:00:00', 7.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-06 00:00:00', 10.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-07 00:00:00', 12.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-08 00:00:00', 8.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-09 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-10 00:00:00', 10.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-11 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-12 00:00:00', 11.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-13 00:00:00', 10.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-14 00:00:00', 8.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-15 00:00:00', 8.85999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-16 00:00:00', 6.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-17 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-18 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-19 00:00:00', 9.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-20 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-21 00:00:00', 6.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-22 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-23 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-24 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-25 00:00:00', 6.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-26 00:00:00', 11.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-27 00:00:00', 8.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-02-28 00:00:00', 12.2309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-01 00:00:00', 6.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-02 00:00:00', 9.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-03 00:00:00', 5.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-04 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-05 00:00:00', 6.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-06 00:00:00', 3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-07 00:00:00', 5.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-08 00:00:00', 8.11900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-09 00:00:00', 11.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-10 00:00:00', 13.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-11 00:00:00', 13.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-12 00:00:00', 12.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-13 00:00:00', 12.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-14 00:00:00', 13.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-15 00:00:00', 15.7589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-16 00:00:00', 17.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-17 00:00:00', 14.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-18 00:00:00', 17.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-19 00:00:00', 13.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-20 00:00:00', 16.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-21 00:00:00', 16.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-22 00:00:00', 12.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-23 00:00:00', 14.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-24 00:00:00', 16.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-25 00:00:00', 19.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-26 00:00:00', 15.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-27 00:00:00', 16.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-28 00:00:00', 18.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-29 00:00:00', 18.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-30 00:00:00', 23.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-03-31 00:00:00', 24.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-01 00:00:00', 23.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-02 00:00:00', 19.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-03 00:00:00', 19.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-04 00:00:00', 22.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-05 00:00:00', 25.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-06 00:00:00', 23.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-07 00:00:00', 23.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-08 00:00:00', 13.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-09 00:00:00', 18.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-10 00:00:00', 22.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-11 00:00:00', 23.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-12 00:00:00', 24.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-13 00:00:00', 23.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-14 00:00:00', 27.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-15 00:00:00', 28.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-16 00:00:00', 29.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-17 00:00:00', 30.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-18 00:00:00', 30.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-19 00:00:00', 31.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-20 00:00:00', 27.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-21 00:00:00', 26.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-22 00:00:00', 28.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-23 00:00:00', 30.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-24 00:00:00', 25.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-25 00:00:00', 17.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-26 00:00:00', 20.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-27 00:00:00', 22.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-28 00:00:00', 25.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-29 00:00:00', 27.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-04-30 00:00:00', 27.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-01 00:00:00', 26.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-02 00:00:00', 21.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-03 00:00:00', 20.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-04 00:00:00', 22.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-05 00:00:00', 21.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-06 00:00:00', 20.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-07 00:00:00', 23.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-08 00:00:00', 26.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-09 00:00:00', 26.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-10 00:00:00', 27.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-11 00:00:00', 26.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-12 00:00:00', 28.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-13 00:00:00', 26.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-14 00:00:00', 32.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-15 00:00:00', 34.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-16 00:00:00', 30.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-17 00:00:00', 31.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-18 00:00:00', 29.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-19 00:00:00', 28.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-20 00:00:00', 30.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-21 00:00:00', 31.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-22 00:00:00', 34.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-23 00:00:00', 34.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-24 00:00:00', 34.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-25 00:00:00', 34.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-26 00:00:00', 32.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-27 00:00:00', 29.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-28 00:00:00', 26.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-29 00:00:00', 27.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-30 00:00:00', 30.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-05-31 00:00:00', 30.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-01 00:00:00', 30.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-02 00:00:00', 32.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-03 00:00:00', 30.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-04 00:00:00', 31.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-05 00:00:00', 32.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-06 00:00:00', 30.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-07 00:00:00', 30.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-08 00:00:00', 32.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-09 00:00:00', 33.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-10 00:00:00', 30.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-11 00:00:00', 28.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-12 00:00:00', 28.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-13 00:00:00', 28.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-14 00:00:00', 27.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-15 00:00:00', 32.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-16 00:00:00', 34.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-17 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-18 00:00:00', 32.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-19 00:00:00', 34.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-20 00:00:00', 36.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-21 00:00:00', 34.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-22 00:00:00', 32.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-23 00:00:00', 32.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-24 00:00:00', 36.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-25 00:00:00', 36.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-26 00:00:00', 37.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-27 00:00:00', 38.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-28 00:00:00', 37.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-29 00:00:00', 39.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-06-30 00:00:00', 37.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-01 00:00:00', 33.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-02 00:00:00', 34.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-03 00:00:00', 36.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-04 00:00:00', 37.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-05 00:00:00', 37.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-06 00:00:00', 39.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-07 00:00:00', 42.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-08 00:00:00', 42.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-09 00:00:00', 42.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-10 00:00:00', 43.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-11 00:00:00', 41.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-12 00:00:00', 36.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-13 00:00:00', 38.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-14 00:00:00', 39.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-15 00:00:00', 38.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-16 00:00:00', 37.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-17 00:00:00', 36.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-18 00:00:00', 38.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-19 00:00:00', 36.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-20 00:00:00', 36.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-21 00:00:00', 36.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-22 00:00:00', 37.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-23 00:00:00', 34.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-24 00:00:00', 36.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-25 00:00:00', 35.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-26 00:00:00', 29.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-27 00:00:00', 34.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-28 00:00:00', 36.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-29 00:00:00', 36.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-30 00:00:00', 36.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-07-31 00:00:00', 38.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-01 00:00:00', 38.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-02 00:00:00', 37.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-03 00:00:00', 37.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-04 00:00:00', 37.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-05 00:00:00', 33.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-06 00:00:00', 33.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-07 00:00:00', 34.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-08 00:00:00', 33.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-09 00:00:00', 34.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-10 00:00:00', 37.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-11 00:00:00', 38.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-12 00:00:00', 38.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-13 00:00:00', 38.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-14 00:00:00', 38.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-15 00:00:00', 37.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-16 00:00:00', 34.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-17 00:00:00', 35.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-18 00:00:00', 36.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-19 00:00:00', 37.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-20 00:00:00', 35.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-21 00:00:00', 33.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-22 00:00:00', 33.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-23 00:00:00', 35.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-24 00:00:00', 34.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-25 00:00:00', 34.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-26 00:00:00', 35.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-27 00:00:00', 36.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-28 00:00:00', 36.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-29 00:00:00', 35.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-30 00:00:00', 35.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-08-31 00:00:00', 35.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-01 00:00:00', 35.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-02 00:00:00', 37.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-03 00:00:00', 37.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-04 00:00:00', 38.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-05 00:00:00', 37.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-06 00:00:00', 37.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-07 00:00:00', 38.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-08 00:00:00', 35.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-09 00:00:00', 32.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-10 00:00:00', 32.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-11 00:00:00', 31.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-12 00:00:00', 28.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-13 00:00:00', 23.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-14 00:00:00', 24.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-15 00:00:00', 27.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-16 00:00:00', 30.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-17 00:00:00', 31.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-18 00:00:00', 31.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-19 00:00:00', 29.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-20 00:00:00', 29.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-21 00:00:00', 29.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-22 00:00:00', 29.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-23 00:00:00', 30.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-24 00:00:00', 31.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-25 00:00:00', 32.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-26 00:00:00', 33.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-27 00:00:00', 33.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-28 00:00:00', 29.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-29 00:00:00', 28.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-09-30 00:00:00', 28.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-01 00:00:00', 30.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-02 00:00:00', 30.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-03 00:00:00', 27.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-04 00:00:00', 28.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-05 00:00:00', 28.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-06 00:00:00', 28.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-07 00:00:00', 28.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-08 00:00:00', 29.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-09 00:00:00', 21.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-10 00:00:00', 14.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-11 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-12 00:00:00', 24.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-13 00:00:00', 23.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-14 00:00:00', 20.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-15 00:00:00', 23.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-16 00:00:00', 24.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-17 00:00:00', 25.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-18 00:00:00', 26.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-19 00:00:00', 23.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-20 00:00:00', 25.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-21 00:00:00', 22.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-22 00:00:00', 21.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-23 00:00:00', 21.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-24 00:00:00', 20.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-25 00:00:00', 15.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-26 00:00:00', 16.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-27 00:00:00', 17.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-28 00:00:00', 18.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-29 00:00:00', 17.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-30 00:00:00', 20.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-10-31 00:00:00', 23.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-01 00:00:00', 25.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-02 00:00:00', 24.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-03 00:00:00', 24.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-04 00:00:00', 24.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-05 00:00:00', 21.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-06 00:00:00', 22.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-07 00:00:00', 21.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-08 00:00:00', 20.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-09 00:00:00', 21.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-10 00:00:00', 22.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-11 00:00:00', 23.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-12 00:00:00', 22.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-13 00:00:00', 16.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-14 00:00:00', 16.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-15 00:00:00', 20.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-16 00:00:00', 20.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-17 00:00:00', 18.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-18 00:00:00', 19.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-19 00:00:00', 19.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-20 00:00:00', 20.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-21 00:00:00', 16.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-22 00:00:00', 16.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-23 00:00:00', 14.9530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-24 00:00:00', 14.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-25 00:00:00', 14.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-26 00:00:00', 15.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-27 00:00:00', 14.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-28 00:00:00', 10.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-29 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-11-30 00:00:00', 6.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-01 00:00:00', 11.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-02 00:00:00', 9.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-03 00:00:00', 9.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-04 00:00:00', 11.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-05 00:00:00', 14.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-06 00:00:00', 8.61699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-07 00:00:00', 12.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-08 00:00:00', 14.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-09 00:00:00', 16.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-10 00:00:00', 15.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-11 00:00:00', 17.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-12 00:00:00', 19.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-13 00:00:00', 19.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-14 00:00:00', 18.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-15 00:00:00', 13.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-16 00:00:00', 15.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-17 00:00:00', 16.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-18 00:00:00', 18.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-19 00:00:00', 17.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-20 00:00:00', 10.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-21 00:00:00', 13.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-22 00:00:00', 11.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-23 00:00:00', 12.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-24 00:00:00', 13.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-25 00:00:00', 11.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-26 00:00:00', 11.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-27 00:00:00', 14.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-28 00:00:00', 13.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-29 00:00:00', 10.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-30 00:00:00', 7.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1998-12-31 00:00:00', 13.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-02 00:00:00', 7.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-04 00:00:00', 8.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-06 00:00:00', 10.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-08 00:00:00', 10.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-10 00:00:00', 9.50800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-12 00:00:00', 8.83800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-14 00:00:00', 8.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-16 00:00:00', 11.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-18 00:00:00', 8.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-20 00:00:00', 14.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-22 00:00:00', 15.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-24 00:00:00', 12.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-26 00:00:00', 13.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-28 00:00:00', 15.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-30 00:00:00', 14.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-01 00:00:00', 14.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-03 00:00:00', 14.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-05 00:00:00', 15.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-07 00:00:00', 15.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-09 00:00:00', 16.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-11 00:00:00', 12.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-13 00:00:00', 13.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-15 00:00:00', 12.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-17 00:00:00', 13.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-19 00:00:00', 13.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-21 00:00:00', 15.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-23 00:00:00', 15.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-25 00:00:00', 16.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-27 00:00:00', 13.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-01 00:00:00', 13.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-03 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-04 00:00:00', 12.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-05 00:00:00', 9.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-06 00:00:00', 12.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-07 00:00:00', 7.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-08 00:00:00', 11.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-09 00:00:00', 13.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-10 00:00:00', 15.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-11 00:00:00', 17.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-12 00:00:00', 16.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-13 00:00:00', 17.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-14 00:00:00', 12.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-15 00:00:00', 15.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-16 00:00:00', 11.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-17 00:00:00', 12.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-18 00:00:00', 13.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-19 00:00:00', 6.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-20 00:00:00', 9.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-21 00:00:00', 14.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-22 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-23 00:00:00', 19.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-24 00:00:00', 17.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-25 00:00:00', 18.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-26 00:00:00', 19.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-27 00:00:00', 19.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-28 00:00:00', 20.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-29 00:00:00', 18.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-30 00:00:00', 19.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-03-31 00:00:00', 19.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-01 00:00:00', 17.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-02 00:00:00', 19.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-03 00:00:00', 23.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-04 00:00:00', 23.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-05 00:00:00', 24.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-06 00:00:00', 23.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-07 00:00:00', 17.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-08 00:00:00', 19.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-09 00:00:00', 21.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-10 00:00:00', 17.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-11 00:00:00', 18.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-12 00:00:00', 18.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-13 00:00:00', 20.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-14 00:00:00', 20.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-15 00:00:00', 25.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-16 00:00:00', 28.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-17 00:00:00', 27.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-18 00:00:00', 26.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-19 00:00:00', 24.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-20 00:00:00', 25.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-21 00:00:00', 26.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-22 00:00:00', 21.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-23 00:00:00', 19.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-24 00:00:00', 21.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-25 00:00:00', 23.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-26 00:00:00', 26.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-27 00:00:00', 27.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-28 00:00:00', 28.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-29 00:00:00', 29.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-04-30 00:00:00', 29.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-01 00:00:00', 27.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-02 00:00:00', 29.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-03 00:00:00', 28.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-04 00:00:00', 31.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-05 00:00:00', 30.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-06 00:00:00', 29.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-07 00:00:00', 31.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-08 00:00:00', 32.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-09 00:00:00', 32.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-10 00:00:00', 30.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-11 00:00:00', 31.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-12 00:00:00', 25.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-13 00:00:00', 26.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-14 00:00:00', 30.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-15 00:00:00', 34.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-16 00:00:00', 31.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-17 00:00:00', 34.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-18 00:00:00', 35.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-19 00:00:00', 36.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-20 00:00:00', 35.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-21 00:00:00', 38.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-22 00:00:00', 29.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-23 00:00:00', 25.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-24 00:00:00', 26.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-25 00:00:00', 27.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-26 00:00:00', 26.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-27 00:00:00', 29.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-28 00:00:00', 31.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-29 00:00:00', 30.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-30 00:00:00', 31.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-05-31 00:00:00', 33.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-01 00:00:00', 32.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-02 00:00:00', 31.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-03 00:00:00', 32.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-04 00:00:00', 33.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-05 00:00:00', 33.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-06 00:00:00', 35.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-07 00:00:00', 35.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-08 00:00:00', 36.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-09 00:00:00', 33.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-10 00:00:00', 31.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-11 00:00:00', 32.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-12 00:00:00', 33.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-13 00:00:00', 33.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-14 00:00:00', 36.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-15 00:00:00', 38.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-16 00:00:00', 36.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-17 00:00:00', 33.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-18 00:00:00', 34.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-19 00:00:00', 34.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-20 00:00:00', 34.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-21 00:00:00', 34.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-22 00:00:00', 35.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-23 00:00:00', 34.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-24 00:00:00', 31.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-25 00:00:00', 36.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-26 00:00:00', 40.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-27 00:00:00', 42.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-28 00:00:00', 41.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-29 00:00:00', 39.0719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-06-30 00:00:00', 39.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-01 00:00:00', 40.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-02 00:00:00', 36.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-03 00:00:00', 36.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-04 00:00:00', 37.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-05 00:00:00', 38.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-06 00:00:00', 37.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-07 00:00:00', 37.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-08 00:00:00', 37.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-09 00:00:00', 41.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-10 00:00:00', 38.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-11 00:00:00', 34.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-12 00:00:00', 32.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-13 00:00:00', 31.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-14 00:00:00', 33.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-15 00:00:00', 36.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-16 00:00:00', 38.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-17 00:00:00', 40.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-18 00:00:00', 39.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-19 00:00:00', 36.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-20 00:00:00', 36.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-21 00:00:00', 34.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-22 00:00:00', 35.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-23 00:00:00', 35.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-24 00:00:00', 35.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-25 00:00:00', 34.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-26 00:00:00', 34.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-27 00:00:00', 34.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-28 00:00:00', 34.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-29 00:00:00', 35.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-30 00:00:00', 36.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-07-31 00:00:00', 37.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-01 00:00:00', 38.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-02 00:00:00', 37.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-03 00:00:00', 37.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-04 00:00:00', 39.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-05 00:00:00', 41.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-06 00:00:00', 40.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-07 00:00:00', 39.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-08 00:00:00', 39.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-09 00:00:00', 40.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-10 00:00:00', 38.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-11 00:00:00', 36.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-12 00:00:00', 34.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-13 00:00:00', 32.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-14 00:00:00', 32.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-15 00:00:00', 35.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-16 00:00:00', 35.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-17 00:00:00', 37.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-18 00:00:00', 38.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-19 00:00:00', 39.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-20 00:00:00', 39.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-21 00:00:00', 38.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-22 00:00:00', 37.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-23 00:00:00', 38.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-24 00:00:00', 39.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-25 00:00:00', 38.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-26 00:00:00', 37.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-27 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-28 00:00:00', 39.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-29 00:00:00', 39.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-30 00:00:00', 38.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-08-31 00:00:00', 37.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-01 00:00:00', 35.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-02 00:00:00', 32.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-03 00:00:00', 32.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-04 00:00:00', 34.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-05 00:00:00', 33.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-06 00:00:00', 29.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-07 00:00:00', 32.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-08 00:00:00', 31.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-09 00:00:00', 31.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-10 00:00:00', 32.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-11 00:00:00', 33.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-12 00:00:00', 34.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-13 00:00:00', 35.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-14 00:00:00', 37.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-15 00:00:00', 36.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-16 00:00:00', 35.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-17 00:00:00', 36.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-18 00:00:00', 34.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-19 00:00:00', 32.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-20 00:00:00', 32.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-21 00:00:00', 32.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-22 00:00:00', 33.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-23 00:00:00', 34.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-24 00:00:00', 26.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-25 00:00:00', 26.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-26 00:00:00', 26.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-27 00:00:00', 29.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-28 00:00:00', 30.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-29 00:00:00', 19.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-09-30 00:00:00', 24.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-01 00:00:00', 25.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-02 00:00:00', 27.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-03 00:00:00', 27.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-04 00:00:00', 27.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-05 00:00:00', 27.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-06 00:00:00', 26.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-07 00:00:00', 25.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-08 00:00:00', 23.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-09 00:00:00', 24.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-10 00:00:00', 25.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-11 00:00:00', 25.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-12 00:00:00', 25.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-13 00:00:00', 26.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-14 00:00:00', 21.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-15 00:00:00', 25.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-16 00:00:00', 28.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-17 00:00:00', 28.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-18 00:00:00', 26.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-19 00:00:00', 27.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-20 00:00:00', 26.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-21 00:00:00', 25.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-22 00:00:00', 24.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-23 00:00:00', 25.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-24 00:00:00', 27.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-25 00:00:00', 27.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-26 00:00:00', 17.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-27 00:00:00', 17.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-28 00:00:00', 17.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-29 00:00:00', 21.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-30 00:00:00', 23.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-10-31 00:00:00', 21.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-01 00:00:00', 22.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-02 00:00:00', 20.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-03 00:00:00', 14.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-04 00:00:00', 14.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-05 00:00:00', 11.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-06 00:00:00', 14.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-07 00:00:00', 14.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-08 00:00:00', 16.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-09 00:00:00', 11.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-10 00:00:00', 12.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-11 00:00:00', 9.85999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-12 00:00:00', 11.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-13 00:00:00', 9.62600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-14 00:00:00', 12.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-15 00:00:00', 14.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-16 00:00:00', 15.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-17 00:00:00', 16.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-18 00:00:00', 14.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-19 00:00:00', 12.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-20 00:00:00', 12.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-21 00:00:00', 10.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-22 00:00:00', 8.12399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-23 00:00:00', 12.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-24 00:00:00', 10.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-25 00:00:00', 12.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-26 00:00:00', 12.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-27 00:00:00', 13.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-28 00:00:00', 16.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-29 00:00:00', 11.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-11-30 00:00:00', 7.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-01 00:00:00', 6.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-02 00:00:00', 10.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-03 00:00:00', 14.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-04 00:00:00', 13.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-05 00:00:00', 13.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-06 00:00:00', 8.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-07 00:00:00', 11.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-08 00:00:00', 12.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-09 00:00:00', 12.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-10 00:00:00', 12.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-11 00:00:00', 7.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-12 00:00:00', 10.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-13 00:00:00', 12.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-14 00:00:00', 11.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-15 00:00:00', 14.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-16 00:00:00', 16.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-17 00:00:00', 13.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-18 00:00:00', 7.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-19 00:00:00', 8.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-20 00:00:00', 11.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-21 00:00:00', 12.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-22 00:00:00', 14.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-23 00:00:00', 13.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-24 00:00:00', 13.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-25 00:00:00', 7.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-26 00:00:00', 8.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-27 00:00:00', 13.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-28 00:00:00', 15.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-29 00:00:00', 13.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-30 00:00:00', 15.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '1999-12-31 00:00:00', 15.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-01 00:00:00', 15.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-02 00:00:00', 16.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-03 00:00:00', 16.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-04 00:00:00', 16.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-05 00:00:00', 15.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-06 00:00:00', 16.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-07 00:00:00', 14.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-08 00:00:00', 9.60499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-09 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-10 00:00:00', 6.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-11 00:00:00', 5.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-12 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-13 00:00:00', -0.246000006794929504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-14 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-15 00:00:00', 1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-16 00:00:00', 5.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-17 00:00:00', 10.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-18 00:00:00', 7.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-19 00:00:00', 8.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-20 00:00:00', 10.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-21 00:00:00', 12.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-22 00:00:00', 10.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-23 00:00:00', 12.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-24 00:00:00', 10.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-25 00:00:00', 7.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-26 00:00:00', 8.62600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-27 00:00:00', 10.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-28 00:00:00', 13.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-29 00:00:00', 15.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-30 00:00:00', 13.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-01-31 00:00:00', 6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-01 00:00:00', 7.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-02 00:00:00', 9.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-03 00:00:00', 6.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-04 00:00:00', 8.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-05 00:00:00', 10.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-06 00:00:00', 10.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-07 00:00:00', 13.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-08 00:00:00', 13.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-09 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-10 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-11 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-12 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-13 00:00:00', 9.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-14 00:00:00', 12.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-15 00:00:00', 8.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-16 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-17 00:00:00', 8.29800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-18 00:00:00', 9.82400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-19 00:00:00', 10.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-20 00:00:00', 9.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-21 00:00:00', 11.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-22 00:00:00', 11.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-23 00:00:00', 12.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-24 00:00:00', 13.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-25 00:00:00', 14.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-26 00:00:00', 13.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-27 00:00:00', 9.72299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-28 00:00:00', 12.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-02-29 00:00:00', 12.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-01 00:00:00', 10.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-02 00:00:00', 10.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-03 00:00:00', 13.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-04 00:00:00', 8.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-05 00:00:00', 9.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-06 00:00:00', 11.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-07 00:00:00', 13.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-08 00:00:00', 16.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-09 00:00:00', 17.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-10 00:00:00', 15.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-11 00:00:00', 14.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-12 00:00:00', 16.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-13 00:00:00', 17.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-14 00:00:00', 19.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-15 00:00:00', 19.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-16 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-17 00:00:00', 11.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-18 00:00:00', 14.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-19 00:00:00', 18.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-20 00:00:00', 20.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-21 00:00:00', 20.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-22 00:00:00', 19.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-23 00:00:00', 21.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-24 00:00:00', 23.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-25 00:00:00', 28.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-26 00:00:00', 27.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-27 00:00:00', 15.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-28 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-29 00:00:00', 13.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-30 00:00:00', 18.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-03-31 00:00:00', 21.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-01 00:00:00', 22.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-02 00:00:00', 21.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-03 00:00:00', 19.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-04 00:00:00', 18.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-05 00:00:00', 21.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-06 00:00:00', 23.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-07 00:00:00', 25.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-08 00:00:00', 27.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-09 00:00:00', 29.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-10 00:00:00', 30.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-11 00:00:00', 33.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-12 00:00:00', 32.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-13 00:00:00', 28.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-14 00:00:00', 24.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-15 00:00:00', 26.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-16 00:00:00', 27.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-17 00:00:00', 30.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-18 00:00:00', 29.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-19 00:00:00', 30.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-20 00:00:00', 30.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-21 00:00:00', 30.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-22 00:00:00', 32.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-23 00:00:00', 32.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-24 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-25 00:00:00', 30.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-26 00:00:00', 27.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-27 00:00:00', 28.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-28 00:00:00', 26.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-29 00:00:00', 26.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-04-30 00:00:00', 29.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-01 00:00:00', 33.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-02 00:00:00', 32.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-03 00:00:00', 32.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-04 00:00:00', 32.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-05 00:00:00', 34.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-06 00:00:00', 32.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-07 00:00:00', 35.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-08 00:00:00', 37.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-09 00:00:00', 39.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-10 00:00:00', 37.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-11 00:00:00', 31.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-12 00:00:00', 31.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-13 00:00:00', 33.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-14 00:00:00', 33.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-15 00:00:00', 32.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-16 00:00:00', 34.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-17 00:00:00', 35.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-18 00:00:00', 35.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-19 00:00:00', 36.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-20 00:00:00', 36.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-21 00:00:00', 36.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-22 00:00:00', 32.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-23 00:00:00', 31.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-24 00:00:00', 31.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-25 00:00:00', 32.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-26 00:00:00', 32.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-27 00:00:00', 34.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-28 00:00:00', 38.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-29 00:00:00', 36.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-30 00:00:00', 33.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-05-31 00:00:00', 34.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-01 00:00:00', 34.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-02 00:00:00', 31.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-03 00:00:00', 31.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-04 00:00:00', 31.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-05 00:00:00', 33.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-06 00:00:00', 35.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-07 00:00:00', 34.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-08 00:00:00', 36.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-09 00:00:00', 36.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-10 00:00:00', 35.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-11 00:00:00', 34.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-12 00:00:00', 35.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-13 00:00:00', 35.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-14 00:00:00', 28.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-15 00:00:00', 33.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-16 00:00:00', 32.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-17 00:00:00', 34.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-18 00:00:00', 35.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-19 00:00:00', 36.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-20 00:00:00', 36.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-21 00:00:00', 37.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-22 00:00:00', 37.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-23 00:00:00', 37.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-24 00:00:00', 39.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-25 00:00:00', 41.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-26 00:00:00', 39.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-27 00:00:00', 39.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-28 00:00:00', 38.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-29 00:00:00', 37.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-06-30 00:00:00', 37.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-01 00:00:00', 38.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-02 00:00:00', 37.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-03 00:00:00', 37.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-04 00:00:00', 36.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-05 00:00:00', 36.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-06 00:00:00', 38.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-07 00:00:00', 38.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-08 00:00:00', 38.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-09 00:00:00', 39.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-10 00:00:00', 40.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-11 00:00:00', 38.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-12 00:00:00', 38.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-13 00:00:00', 37.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-14 00:00:00', 37.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-15 00:00:00', 36.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-16 00:00:00', 34.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-17 00:00:00', 31.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-18 00:00:00', 32.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-19 00:00:00', 34.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-20 00:00:00', 34.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-21 00:00:00', 36.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-22 00:00:00', 36.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-23 00:00:00', 36.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-24 00:00:00', 36.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-25 00:00:00', 33.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-26 00:00:00', 35.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-27 00:00:00', 36.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-28 00:00:00', 38.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-29 00:00:00', 39.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-30 00:00:00', 40.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-07-31 00:00:00', 40.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-01 00:00:00', 39.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-02 00:00:00', 37.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-03 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-04 00:00:00', 37.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-05 00:00:00', 37.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-06 00:00:00', 38.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-07 00:00:00', 39.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-08 00:00:00', 39.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-09 00:00:00', 37.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-10 00:00:00', 37.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-11 00:00:00', 38.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-12 00:00:00', 36.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-13 00:00:00', 36.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-14 00:00:00', 36.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-15 00:00:00', 37.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-16 00:00:00', 36.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-17 00:00:00', 35.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-18 00:00:00', 32.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-19 00:00:00', 34.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-20 00:00:00', 33.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-21 00:00:00', 34.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-22 00:00:00', 35.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-23 00:00:00', 35.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-24 00:00:00', 37.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-25 00:00:00', 36.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-26 00:00:00', 38.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-27 00:00:00', 38.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-28 00:00:00', 39.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-29 00:00:00', 40.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-30 00:00:00', 38.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-08-31 00:00:00', 37.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-01 00:00:00', 35.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-02 00:00:00', 35.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-03 00:00:00', 35.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-04 00:00:00', 36.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-05 00:00:00', 35.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-06 00:00:00', 34.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-07 00:00:00', 32.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-08 00:00:00', 33.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-09 00:00:00', 32.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-10 00:00:00', 31.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-11 00:00:00', 32.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-12 00:00:00', 31.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-13 00:00:00', 33.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-14 00:00:00', 34.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-15 00:00:00', 34.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-16 00:00:00', 36.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-17 00:00:00', 36.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-18 00:00:00', 35.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-19 00:00:00', 34.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-20 00:00:00', 29.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-21 00:00:00', 27.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-22 00:00:00', 27.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-23 00:00:00', 28.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-24 00:00:00', 29.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-25 00:00:00', 27.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-26 00:00:00', 22.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-27 00:00:00', 26.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-28 00:00:00', 28.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-29 00:00:00', 30.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-09-30 00:00:00', 26.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-01 00:00:00', 27.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-02 00:00:00', 24.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-03 00:00:00', 27.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-04 00:00:00', 23.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-05 00:00:00', 19.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-06 00:00:00', 22.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-07 00:00:00', 21.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-08 00:00:00', 21.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-09 00:00:00', 20.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-10 00:00:00', 21.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-11 00:00:00', 23.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-12 00:00:00', 25.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-13 00:00:00', 26.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-14 00:00:00', 25.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-15 00:00:00', 19.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-16 00:00:00', 15.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-17 00:00:00', 21.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-18 00:00:00', 24.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-19 00:00:00', 22.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-20 00:00:00', 23.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-21 00:00:00', 23.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-22 00:00:00', 22.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-23 00:00:00', 20.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-24 00:00:00', 23.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-25 00:00:00', 22.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-26 00:00:00', 23.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-27 00:00:00', 26.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-28 00:00:00', 27.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-29 00:00:00', 26.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-30 00:00:00', 23.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-10-31 00:00:00', 23.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-01 00:00:00', 20.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-02 00:00:00', 21.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-03 00:00:00', 23.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-04 00:00:00', 24.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-05 00:00:00', 20.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-06 00:00:00', 19.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-07 00:00:00', 17.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-08 00:00:00', 10.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-09 00:00:00', 15.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-10 00:00:00', 17.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-11 00:00:00', 11.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-12 00:00:00', 8.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-13 00:00:00', 9.54800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-14 00:00:00', 13.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-15 00:00:00', 14.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-16 00:00:00', 9.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-17 00:00:00', 8.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-18 00:00:00', 7.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-19 00:00:00', 13.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-20 00:00:00', 14.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-21 00:00:00', 13.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-22 00:00:00', 13.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-23 00:00:00', 13.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-24 00:00:00', 14.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-25 00:00:00', 14.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-26 00:00:00', 13.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-27 00:00:00', 12.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-28 00:00:00', 11.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-29 00:00:00', 9.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-11-30 00:00:00', 8.13599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-01 00:00:00', 11.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-02 00:00:00', 8.17300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-03 00:00:00', 7.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-04 00:00:00', 11.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-05 00:00:00', 9.97099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-06 00:00:00', 11.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-07 00:00:00', 10.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-08 00:00:00', 11.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-09 00:00:00', 11.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-10 00:00:00', 7.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-11 00:00:00', 10.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-12 00:00:00', 11.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-13 00:00:00', 12.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-14 00:00:00', 12.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-15 00:00:00', 13.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-16 00:00:00', 10.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-17 00:00:00', 7.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-18 00:00:00', 8.84099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-19 00:00:00', 10.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-20 00:00:00', 13.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-21 00:00:00', 14.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-22 00:00:00', 15.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-23 00:00:00', 13.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-24 00:00:00', 11.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-25 00:00:00', 10.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-26 00:00:00', 14.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-27 00:00:00', 11.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-28 00:00:00', 7.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-29 00:00:00', 10.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-30 00:00:00', 10.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2000-12-31 00:00:00', 10.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-01 00:00:00', 11.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-02 00:00:00', 8.92300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-03 00:00:00', 8.14299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-04 00:00:00', 9.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-05 00:00:00', 12.9189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-06 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-07 00:00:00', 9.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-08 00:00:00', 8.86900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-09 00:00:00', 8.94699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-10 00:00:00', 9.26299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-11 00:00:00', 11.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-12 00:00:00', 10.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-13 00:00:00', 11.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-14 00:00:00', 11.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-15 00:00:00', 10.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-16 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-17 00:00:00', 6.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-18 00:00:00', 7.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-19 00:00:00', 11.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-20 00:00:00', 10.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-21 00:00:00', 4.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-22 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-23 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-24 00:00:00', 4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-25 00:00:00', 1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-26 00:00:00', 2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-27 00:00:00', 3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-28 00:00:00', 5.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-29 00:00:00', -1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-30 00:00:00', -0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-01-31 00:00:00', 1.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-01 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-02 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-03 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-04 00:00:00', 5.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-05 00:00:00', 6.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-06 00:00:00', 5.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-07 00:00:00', 6.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-08 00:00:00', 8.43000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-09 00:00:00', 7.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-10 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-11 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-12 00:00:00', 8.45199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-13 00:00:00', 9.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-14 00:00:00', 10.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-15 00:00:00', 15.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-16 00:00:00', 11.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-17 00:00:00', 11.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-18 00:00:00', 12.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-19 00:00:00', 16.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-20 00:00:00', 10.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-21 00:00:00', 14.8809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-22 00:00:00', 10.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-23 00:00:00', 12.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-24 00:00:00', 14.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-25 00:00:00', 13.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-26 00:00:00', 15.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-27 00:00:00', 14.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-02-28 00:00:00', 15.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-01 00:00:00', 14.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-02 00:00:00', 17.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-03 00:00:00', 17.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-04 00:00:00', 19.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-05 00:00:00', 18.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-06 00:00:00', 16.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-07 00:00:00', 18.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-08 00:00:00', 20.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-09 00:00:00', 21.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-10 00:00:00', 21.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-11 00:00:00', 12.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-12 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-13 00:00:00', 8.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-14 00:00:00', 11.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-15 00:00:00', 14.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-16 00:00:00', 18.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-17 00:00:00', 16.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-18 00:00:00', 19.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-19 00:00:00', 14.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-20 00:00:00', 17.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-21 00:00:00', 19.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-22 00:00:00', 20.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-23 00:00:00', 22.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-24 00:00:00', 25.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-25 00:00:00', 24.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-26 00:00:00', 25.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-27 00:00:00', 17.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-28 00:00:00', 16.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-29 00:00:00', 16.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-30 00:00:00', 21.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-03-31 00:00:00', 22.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-01 00:00:00', 23.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-02 00:00:00', 20.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-03 00:00:00', 20.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-04 00:00:00', 25.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-05 00:00:00', 25.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-06 00:00:00', 26.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-07 00:00:00', 30.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-08 00:00:00', 32.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-09 00:00:00', 31.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-10 00:00:00', 30.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-11 00:00:00', 30.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-12 00:00:00', 30.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-13 00:00:00', 30.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-14 00:00:00', 28.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-15 00:00:00', 29.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-16 00:00:00', 28.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-17 00:00:00', 26.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-18 00:00:00', 26.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-19 00:00:00', 20.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-20 00:00:00', 24.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-21 00:00:00', 27.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-22 00:00:00', 30.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-23 00:00:00', 28.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-24 00:00:00', 29.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-25 00:00:00', 29.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-26 00:00:00', 29.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-27 00:00:00', 31.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-28 00:00:00', 31.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-29 00:00:00', 30.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-04-30 00:00:00', 31.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-01 00:00:00', 29.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-02 00:00:00', 29.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-03 00:00:00', 32.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-04 00:00:00', 34.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-05 00:00:00', 35.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-06 00:00:00', 35.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-07 00:00:00', 32.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-08 00:00:00', 33.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-09 00:00:00', 35.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-10 00:00:00', 37.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-11 00:00:00', 37.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-12 00:00:00', 38.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-13 00:00:00', 37.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-14 00:00:00', 36.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-15 00:00:00', 36.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-16 00:00:00', 37.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-17 00:00:00', 38.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-18 00:00:00', 37.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-19 00:00:00', 34.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-20 00:00:00', 31.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-21 00:00:00', 30.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-22 00:00:00', 32.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-23 00:00:00', 34.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-24 00:00:00', 32.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-25 00:00:00', 32.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-26 00:00:00', 36.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-27 00:00:00', 37.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-28 00:00:00', 33.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-29 00:00:00', 34.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-30 00:00:00', 37.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-05-31 00:00:00', 39.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-01 00:00:00', 39.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-02 00:00:00', 37.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-03 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-04 00:00:00', 34.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-05 00:00:00', 35.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-06 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-07 00:00:00', 36.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-08 00:00:00', 36.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-09 00:00:00', 38.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-10 00:00:00', 40.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-11 00:00:00', 38.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-12 00:00:00', 36.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-13 00:00:00', 37.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-14 00:00:00', 33.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-15 00:00:00', 36.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-16 00:00:00', 35.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-17 00:00:00', 35.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-18 00:00:00', 36.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-19 00:00:00', 38.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-20 00:00:00', 40.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-21 00:00:00', 38.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-22 00:00:00', 34.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-23 00:00:00', 37.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-24 00:00:00', 37.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-25 00:00:00', 39.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-26 00:00:00', 40.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-27 00:00:00', 42.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-28 00:00:00', 43.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-29 00:00:00', 44.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-06-30 00:00:00', 42.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-01 00:00:00', 41.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-02 00:00:00', 38.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-03 00:00:00', 37.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-04 00:00:00', 37.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-05 00:00:00', 34.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-06 00:00:00', 35.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-07 00:00:00', 35.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-08 00:00:00', 38.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-09 00:00:00', 38.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-10 00:00:00', 40.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-11 00:00:00', 42.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-12 00:00:00', 43.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-13 00:00:00', 42.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-14 00:00:00', 41.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-15 00:00:00', 37.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-16 00:00:00', 33.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-17 00:00:00', 34.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-18 00:00:00', 36.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-19 00:00:00', 40.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-20 00:00:00', 39.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-21 00:00:00', 37.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-22 00:00:00', 36.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-23 00:00:00', 36.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-24 00:00:00', 35.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-25 00:00:00', 37.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-26 00:00:00', 38.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-27 00:00:00', 39.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-28 00:00:00', 36.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-29 00:00:00', 33.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-30 00:00:00', 31.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-07-31 00:00:00', 33.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-01 00:00:00', 35.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-02 00:00:00', 37.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-03 00:00:00', 37.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-04 00:00:00', 37.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-05 00:00:00', 39.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-06 00:00:00', 37.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-07 00:00:00', 38.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-08 00:00:00', 35.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-09 00:00:00', 36.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-10 00:00:00', 36.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-11 00:00:00', 36.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-12 00:00:00', 35.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-13 00:00:00', 35.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-14 00:00:00', 32.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-15 00:00:00', 32.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-16 00:00:00', 33.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-17 00:00:00', 35.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-18 00:00:00', 36.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-19 00:00:00', 34.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-20 00:00:00', 35.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-21 00:00:00', 35.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-22 00:00:00', 35.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-23 00:00:00', 35.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-24 00:00:00', 35.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-25 00:00:00', 36.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-26 00:00:00', 31.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-27 00:00:00', 34.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-28 00:00:00', 30.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-29 00:00:00', 32.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-30 00:00:00', 32.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-08-31 00:00:00', 34.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-01 00:00:00', 38.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-02 00:00:00', 37.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-03 00:00:00', 34.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-04 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-05 00:00:00', 34.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-06 00:00:00', 33.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-07 00:00:00', 34.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-08 00:00:00', 36.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-09 00:00:00', 37.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-10 00:00:00', 32.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-11 00:00:00', 31.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-12 00:00:00', 29.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-13 00:00:00', 27.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-14 00:00:00', 26.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-15 00:00:00', 28.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-16 00:00:00', 28.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-17 00:00:00', 29.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-18 00:00:00', 29.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-19 00:00:00', 25.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-20 00:00:00', 21.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-21 00:00:00', 24.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-22 00:00:00', 24.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-23 00:00:00', 24.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-24 00:00:00', 26.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-25 00:00:00', 26.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-26 00:00:00', 27.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-27 00:00:00', 30.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-28 00:00:00', 31.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-29 00:00:00', 30.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-09-30 00:00:00', 32.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-01 00:00:00', 31.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-02 00:00:00', 31.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-03 00:00:00', 23.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-04 00:00:00', 24.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-05 00:00:00', 23.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-06 00:00:00', 25.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-07 00:00:00', 29.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-08 00:00:00', 29.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-09 00:00:00', 25.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-10 00:00:00', 20.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-11 00:00:00', 16.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-12 00:00:00', 22.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-13 00:00:00', 23.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-14 00:00:00', 25.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-15 00:00:00', 25.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-16 00:00:00', 25.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-17 00:00:00', 26.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-18 00:00:00', 21.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-19 00:00:00', 22.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-20 00:00:00', 27.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-21 00:00:00', 24.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-22 00:00:00', 26.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-23 00:00:00', 19.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-24 00:00:00', 23.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-25 00:00:00', 26.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-26 00:00:00', 28.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-27 00:00:00', 18.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-28 00:00:00', 17.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-29 00:00:00', 19.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-30 00:00:00', 20.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-10-31 00:00:00', 21.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-01 00:00:00', 20.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-02 00:00:00', 16.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-03 00:00:00', 12.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-04 00:00:00', 17.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-05 00:00:00', 16.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-06 00:00:00', 17.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-07 00:00:00', 18.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-08 00:00:00', 21.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-09 00:00:00', 17.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-10 00:00:00', 17.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-11 00:00:00', 17.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-12 00:00:00', 20.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-13 00:00:00', 24.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-14 00:00:00', 23.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-15 00:00:00', 19.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-16 00:00:00', 21.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-17 00:00:00', 23.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-18 00:00:00', 23.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-19 00:00:00', 23.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-20 00:00:00', 15.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-21 00:00:00', 17.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-22 00:00:00', 19.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-23 00:00:00', 22.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-24 00:00:00', 16.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-25 00:00:00', 15.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-26 00:00:00', 15.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-27 00:00:00', 15.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-28 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-29 00:00:00', 10.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-11-30 00:00:00', 10.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-01 00:00:00', 10.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-02 00:00:00', 9.06499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-03 00:00:00', 5.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-04 00:00:00', 8.37899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-05 00:00:00', 11.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-06 00:00:00', 12.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-07 00:00:00', 12.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-08 00:00:00', 11.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-09 00:00:00', 12.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-10 00:00:00', 7.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-11 00:00:00', 8.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-12 00:00:00', 10.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-13 00:00:00', 8.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-14 00:00:00', 12.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-15 00:00:00', 12.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-16 00:00:00', 10.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-17 00:00:00', 9.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-18 00:00:00', 8.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-19 00:00:00', 10.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-20 00:00:00', 13.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-21 00:00:00', 14.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-22 00:00:00', 9.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-23 00:00:00', 8.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-24 00:00:00', 11.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-25 00:00:00', 12.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-26 00:00:00', 13.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-27 00:00:00', 14.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-28 00:00:00', 14.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-29 00:00:00', 14.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-30 00:00:00', 15.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2001-12-31 00:00:00', 14.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-01 00:00:00', 14.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-02 00:00:00', 17.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-03 00:00:00', 18.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-04 00:00:00', 16.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-05 00:00:00', 15.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-06 00:00:00', 14.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-07 00:00:00', 15.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-08 00:00:00', 17.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-09 00:00:00', 12.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-10 00:00:00', 10.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-11 00:00:00', 11.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-12 00:00:00', 8.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-13 00:00:00', 6.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-14 00:00:00', 3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-15 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-16 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-17 00:00:00', 4.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-18 00:00:00', 4.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-19 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-20 00:00:00', 6.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-21 00:00:00', 8.06700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-22 00:00:00', 9.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-23 00:00:00', 8.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-24 00:00:00', 8.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-25 00:00:00', 6.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-26 00:00:00', 5.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-27 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-28 00:00:00', 7.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-29 00:00:00', 10.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-30 00:00:00', 11.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-01-31 00:00:00', 10.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-01 00:00:00', 8.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-02 00:00:00', 4.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-03 00:00:00', 6.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-04 00:00:00', 7.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-05 00:00:00', 3.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-06 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-07 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-08 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-09 00:00:00', 8.55500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-10 00:00:00', 10.7559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-11 00:00:00', 10.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-12 00:00:00', 8.08100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-13 00:00:00', 12.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-14 00:00:00', 14.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-15 00:00:00', 12.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-16 00:00:00', 13.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-17 00:00:00', 10.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-18 00:00:00', 11.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-19 00:00:00', 10.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-20 00:00:00', 13.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-21 00:00:00', 14.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-22 00:00:00', 12.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-23 00:00:00', 11.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-24 00:00:00', 12.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-25 00:00:00', 13.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-26 00:00:00', 12.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-27 00:00:00', 14.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-02-28 00:00:00', 16.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-01 00:00:00', 11.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-02 00:00:00', 11.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-03 00:00:00', 14.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-04 00:00:00', 16.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-05 00:00:00', 19.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-06 00:00:00', 20.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-07 00:00:00', 8.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-08 00:00:00', 11.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-09 00:00:00', 15.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-10 00:00:00', 15.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-11 00:00:00', 7.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-12 00:00:00', 11.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-13 00:00:00', 15.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-14 00:00:00', 17.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-15 00:00:00', 20.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-16 00:00:00', 22.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-17 00:00:00', 24.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-18 00:00:00', 24.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-19 00:00:00', 27.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-20 00:00:00', 23.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-21 00:00:00', 21.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-22 00:00:00', 22.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-23 00:00:00', 18.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-24 00:00:00', 13.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-25 00:00:00', 17.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-26 00:00:00', 21.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-27 00:00:00', 24.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-28 00:00:00', 26.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-29 00:00:00', 26.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-30 00:00:00', 20.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-03-31 00:00:00', 19.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-01 00:00:00', 16.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-02 00:00:00', 19.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-03 00:00:00', 21.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-04 00:00:00', 20.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-05 00:00:00', 20.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-06 00:00:00', 22.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-07 00:00:00', 22.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-08 00:00:00', 25.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-09 00:00:00', 28.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-10 00:00:00', 28.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-11 00:00:00', 29.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-12 00:00:00', 24.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-13 00:00:00', 28.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-14 00:00:00', 25.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-15 00:00:00', 19.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-16 00:00:00', 25.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-17 00:00:00', 25.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-18 00:00:00', 28.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-19 00:00:00', 31.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-20 00:00:00', 33.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-21 00:00:00', 33.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-22 00:00:00', 25.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-23 00:00:00', 20.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-24 00:00:00', 21.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-25 00:00:00', 21.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-26 00:00:00', 19.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-27 00:00:00', 18.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-28 00:00:00', 20.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-29 00:00:00', 21.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-04-30 00:00:00', 21.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-01 00:00:00', 24.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-02 00:00:00', 23.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-03 00:00:00', 26.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-04 00:00:00', 27.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-05 00:00:00', 28.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-06 00:00:00', 26.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-07 00:00:00', 29.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-08 00:00:00', 31.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-09 00:00:00', 32.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-10 00:00:00', 31.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-11 00:00:00', 33.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-12 00:00:00', 33.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-13 00:00:00', 26.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-14 00:00:00', 22.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-15 00:00:00', 26.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-16 00:00:00', 29.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-17 00:00:00', 30.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-18 00:00:00', 26.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-19 00:00:00', 25.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-20 00:00:00', 26.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-21 00:00:00', 29.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-22 00:00:00', 31.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-23 00:00:00', 32.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-24 00:00:00', 33.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-25 00:00:00', 34.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-26 00:00:00', 35.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-27 00:00:00', 31.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-28 00:00:00', 31.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-29 00:00:00', 31.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-30 00:00:00', 34.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-05-31 00:00:00', 36.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-01 00:00:00', 37.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-02 00:00:00', 38.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-03 00:00:00', 38.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-04 00:00:00', 37.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-05 00:00:00', 34.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-06 00:00:00', 32.9410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-07 00:00:00', 37.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-08 00:00:00', 33.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-09 00:00:00', 33.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-10 00:00:00', 33.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-11 00:00:00', 34.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-12 00:00:00', 36.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-13 00:00:00', 37.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-14 00:00:00', 39.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-15 00:00:00', 35.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-16 00:00:00', 33.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-17 00:00:00', 32.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-18 00:00:00', 34.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-19 00:00:00', 34.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-20 00:00:00', 35.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-21 00:00:00', 39.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-22 00:00:00', 38.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-23 00:00:00', 33.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-24 00:00:00', 32.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-25 00:00:00', 34.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-26 00:00:00', 36.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-27 00:00:00', 40.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-28 00:00:00', 39.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-29 00:00:00', 37.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-06-30 00:00:00', 37.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-01 00:00:00', 37.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-02 00:00:00', 36.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-03 00:00:00', 35.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-04 00:00:00', 36.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-05 00:00:00', 34.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-06 00:00:00', 32.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-07 00:00:00', 35.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-08 00:00:00', 34.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-09 00:00:00', 34.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-10 00:00:00', 35.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-11 00:00:00', 35.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-12 00:00:00', 36.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-13 00:00:00', 37.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-14 00:00:00', 37.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-15 00:00:00', 37.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-16 00:00:00', 39.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-17 00:00:00', 39.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-18 00:00:00', 39.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-19 00:00:00', 40.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-20 00:00:00', 41.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-21 00:00:00', 35.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-22 00:00:00', 32.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-23 00:00:00', 35.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-24 00:00:00', 37.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-25 00:00:00', 38.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-26 00:00:00', 39.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-27 00:00:00', 37.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-28 00:00:00', 37.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-29 00:00:00', 36.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-30 00:00:00', 36.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-07-31 00:00:00', 35.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-01 00:00:00', 37.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-02 00:00:00', 37.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-03 00:00:00', 38.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-04 00:00:00', 38.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-05 00:00:00', 39.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-06 00:00:00', 39.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-07 00:00:00', 40.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-08 00:00:00', 40.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-09 00:00:00', 41.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-10 00:00:00', 42.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-11 00:00:00', 43.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-12 00:00:00', 40.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-13 00:00:00', 35.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-14 00:00:00', 31.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-15 00:00:00', 33.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-16 00:00:00', 35.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-17 00:00:00', 37.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-18 00:00:00', 37.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-19 00:00:00', 38.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-20 00:00:00', 40.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-21 00:00:00', 36.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-22 00:00:00', 36.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-23 00:00:00', 38.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-24 00:00:00', 38.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-25 00:00:00', 39.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-26 00:00:00', 38.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-27 00:00:00', 38.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-28 00:00:00', 38.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-29 00:00:00', 38.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-30 00:00:00', 38.1500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-08-31 00:00:00', 36.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-01 00:00:00', 33.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-02 00:00:00', 31.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-03 00:00:00', 29.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-04 00:00:00', 29.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-05 00:00:00', 30.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-06 00:00:00', 31.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-07 00:00:00', 29.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-08 00:00:00', 32.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-09 00:00:00', 31.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-10 00:00:00', 32.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-11 00:00:00', 33.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-12 00:00:00', 34.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-13 00:00:00', 36.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-14 00:00:00', 36.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-15 00:00:00', 36.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-16 00:00:00', 36.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-17 00:00:00', 30.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-18 00:00:00', 31.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-19 00:00:00', 31.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-20 00:00:00', 33.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-21 00:00:00', 33.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-22 00:00:00', 32.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-23 00:00:00', 30.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-24 00:00:00', 28.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-25 00:00:00', 28.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-26 00:00:00', 29.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-27 00:00:00', 29.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-28 00:00:00', 29.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-29 00:00:00', 30.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-09-30 00:00:00', 29.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-01 00:00:00', 30.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-02 00:00:00', 30.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-03 00:00:00', 30.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-04 00:00:00', 33.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-05 00:00:00', 32.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-06 00:00:00', 31.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-07 00:00:00', 31.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-08 00:00:00', 29.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-09 00:00:00', 30.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-10 00:00:00', 29.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-11 00:00:00', 29.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-12 00:00:00', 28.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-13 00:00:00', 28.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-14 00:00:00', 28.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-15 00:00:00', 26.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-16 00:00:00', 25.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-17 00:00:00', 25.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-18 00:00:00', 25.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-19 00:00:00', 24.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-20 00:00:00', 24.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-21 00:00:00', 24.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-22 00:00:00', 25.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-23 00:00:00', 22.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-24 00:00:00', 20.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-25 00:00:00', 22.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-26 00:00:00', 23.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-27 00:00:00', 24.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-28 00:00:00', 24.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-29 00:00:00', 24.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-30 00:00:00', 24.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-10-31 00:00:00', 26.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-01 00:00:00', 23.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-02 00:00:00', 25.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-03 00:00:00', 23.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-04 00:00:00', 21.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-05 00:00:00', 19.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-06 00:00:00', 19.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-07 00:00:00', 22.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-08 00:00:00', 20.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-09 00:00:00', 18.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-10 00:00:00', 18.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-11 00:00:00', 19.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-12 00:00:00', 20.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-13 00:00:00', 21.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-14 00:00:00', 19.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-15 00:00:00', 17.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-16 00:00:00', 12.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-17 00:00:00', 15.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-18 00:00:00', 12.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-19 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-20 00:00:00', 17.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-21 00:00:00', 15.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-22 00:00:00', 16.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-23 00:00:00', 15.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-24 00:00:00', 18.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-25 00:00:00', 19.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-26 00:00:00', 17.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-27 00:00:00', 12.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-28 00:00:00', 12.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-29 00:00:00', 13.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-11-30 00:00:00', 10.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-01 00:00:00', 12.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-02 00:00:00', 8.93500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-03 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-04 00:00:00', -4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-05 00:00:00', -2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-06 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-07 00:00:00', 2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-08 00:00:00', 3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-09 00:00:00', 8.13099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-10 00:00:00', 11.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-11 00:00:00', 9.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-12 00:00:00', 8.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-13 00:00:00', 10.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-14 00:00:00', 9.88599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-15 00:00:00', 6.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-16 00:00:00', 8.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-17 00:00:00', 6.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-18 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-19 00:00:00', 3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-20 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-21 00:00:00', 8.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-22 00:00:00', 13.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-23 00:00:00', 8.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-24 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-25 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-26 00:00:00', 7.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-27 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-28 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-29 00:00:00', 7.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-30 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2002-12-31 00:00:00', 7.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-01 00:00:00', 10.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-02 00:00:00', 10.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-03 00:00:00', 10.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-04 00:00:00', 11.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-05 00:00:00', 12.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-06 00:00:00', 11.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-07 00:00:00', 9.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-08 00:00:00', 7.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-09 00:00:00', 8.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-10 00:00:00', 11.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-11 00:00:00', 9.63599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-12 00:00:00', 8.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-13 00:00:00', 10.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-14 00:00:00', 12.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-15 00:00:00', 13.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-16 00:00:00', 13.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-17 00:00:00', 14.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-18 00:00:00', 14.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-19 00:00:00', 8.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-20 00:00:00', 13.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-21 00:00:00', 10.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-22 00:00:00', 9.37199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-23 00:00:00', 9.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-24 00:00:00', 9.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-25 00:00:00', 8.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-26 00:00:00', 8.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-27 00:00:00', 8.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-28 00:00:00', 9.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-29 00:00:00', 6.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-30 00:00:00', 7.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-01-31 00:00:00', 8.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-01 00:00:00', 9.14299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-02 00:00:00', 11.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-03 00:00:00', 14.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-04 00:00:00', 15.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-05 00:00:00', 17.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-06 00:00:00', 12.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-07 00:00:00', 7.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-08 00:00:00', 10.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-09 00:00:00', 11.7860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-10 00:00:00', 14.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-11 00:00:00', 15.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-12 00:00:00', 12.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-13 00:00:00', 6.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-14 00:00:00', 10.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-15 00:00:00', 12.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-16 00:00:00', 10.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-17 00:00:00', 7.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-18 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-19 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-20 00:00:00', 6.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-21 00:00:00', 10.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-22 00:00:00', 11.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-23 00:00:00', 11.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-24 00:00:00', 10.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-25 00:00:00', 11.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-26 00:00:00', 9.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-27 00:00:00', 9.82900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-02-28 00:00:00', 9.19900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-01 00:00:00', 7.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-02 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-03 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-04 00:00:00', 3.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-05 00:00:00', 8.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-06 00:00:00', 10.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-07 00:00:00', 10.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-08 00:00:00', 14.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-09 00:00:00', 10.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-10 00:00:00', 10.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-11 00:00:00', 14.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-12 00:00:00', 16.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-13 00:00:00', 17.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-14 00:00:00', 17.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-15 00:00:00', 10.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-16 00:00:00', 12.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-17 00:00:00', 16.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-18 00:00:00', 17.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-19 00:00:00', 16.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-20 00:00:00', 18.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-21 00:00:00', 24.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-22 00:00:00', 19.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-23 00:00:00', 21.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-24 00:00:00', 17.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-25 00:00:00', 21.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-26 00:00:00', 24.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-27 00:00:00', 17.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-28 00:00:00', 16.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-29 00:00:00', 17.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-30 00:00:00', 20.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-03-31 00:00:00', 13.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-01 00:00:00', 14.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-02 00:00:00', 16.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-03 00:00:00', 16.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-04 00:00:00', 16.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-05 00:00:00', 18.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-06 00:00:00', 23.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-07 00:00:00', 28.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-08 00:00:00', 30.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-09 00:00:00', 29.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-10 00:00:00', 31.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-11 00:00:00', 29.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-12 00:00:00', 30.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-13 00:00:00', 29.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-14 00:00:00', 27.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-15 00:00:00', 15.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-16 00:00:00', 14.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-17 00:00:00', 21.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-18 00:00:00', 15.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-19 00:00:00', 7.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-20 00:00:00', 14.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-21 00:00:00', 22.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-22 00:00:00', 26.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-23 00:00:00', 29.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-24 00:00:00', 24.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-25 00:00:00', 24.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-26 00:00:00', 26.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-27 00:00:00', 29.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-28 00:00:00', 31.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-29 00:00:00', 29.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-04-30 00:00:00', 23.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-01 00:00:00', 20.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-02 00:00:00', 16.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-03 00:00:00', 18.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-04 00:00:00', 21.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-05 00:00:00', 22.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-06 00:00:00', 25.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-07 00:00:00', 29.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-08 00:00:00', 30.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-09 00:00:00', 30.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-10 00:00:00', 23.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-11 00:00:00', 25.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-12 00:00:00', 24.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-13 00:00:00', 26.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-14 00:00:00', 26.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-15 00:00:00', 26.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-16 00:00:00', 28.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-17 00:00:00', 30.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-18 00:00:00', 30.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-19 00:00:00', 31.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-20 00:00:00', 32.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-21 00:00:00', 32.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-22 00:00:00', 32.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-23 00:00:00', 31.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-24 00:00:00', 32.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-25 00:00:00', 31.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-26 00:00:00', 26.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-27 00:00:00', 22.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-28 00:00:00', 26.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-29 00:00:00', 30.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-30 00:00:00', 33.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-05-31 00:00:00', 35.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-01 00:00:00', 33.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-02 00:00:00', 36.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-03 00:00:00', 35.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-04 00:00:00', 34.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-05 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-06 00:00:00', 36.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-07 00:00:00', 30.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-08 00:00:00', 30.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-09 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-10 00:00:00', 33.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-11 00:00:00', 31.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-12 00:00:00', 27.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-13 00:00:00', 32.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-14 00:00:00', 34.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-15 00:00:00', 35.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-16 00:00:00', 35.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-17 00:00:00', 36.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-18 00:00:00', 37.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-19 00:00:00', 37.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-20 00:00:00', 36.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-21 00:00:00', 34.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-22 00:00:00', 34.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-23 00:00:00', 35.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-24 00:00:00', 36.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-25 00:00:00', 39.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-26 00:00:00', 34.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-27 00:00:00', 35.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-28 00:00:00', 36.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-29 00:00:00', 34.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-06-30 00:00:00', 36.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-01 00:00:00', 37.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-02 00:00:00', 39.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-03 00:00:00', 43.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-04 00:00:00', 40.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-05 00:00:00', 36.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-06 00:00:00', 36.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-07 00:00:00', 37.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-08 00:00:00', 38.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-09 00:00:00', 36.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-10 00:00:00', 38.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-11 00:00:00', 39.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-12 00:00:00', 38.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-13 00:00:00', 35.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-14 00:00:00', 37.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-15 00:00:00', 38.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-16 00:00:00', 38.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-17 00:00:00', 38.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-18 00:00:00', 41.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-19 00:00:00', 43.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-20 00:00:00', 43.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-21 00:00:00', 43.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-22 00:00:00', 42.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-23 00:00:00', 38.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-24 00:00:00', 35.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-25 00:00:00', 37.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-26 00:00:00', 37.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-27 00:00:00', 38.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-28 00:00:00', 39.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-29 00:00:00', 37.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-30 00:00:00', 37.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-07-31 00:00:00', 39.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-01 00:00:00', 40.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-02 00:00:00', 40.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-03 00:00:00', 36.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-04 00:00:00', 34.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-05 00:00:00', 32.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-06 00:00:00', 33.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-07 00:00:00', 33.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-08 00:00:00', 34.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-09 00:00:00', 35.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-10 00:00:00', 35.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-11 00:00:00', 35.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-12 00:00:00', 35.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-13 00:00:00', 35.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-14 00:00:00', 38.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-15 00:00:00', 40.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-16 00:00:00', 41.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-17 00:00:00', 40.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-18 00:00:00', 40.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-19 00:00:00', 38.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-20 00:00:00', 35.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-21 00:00:00', 33.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-22 00:00:00', 34.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-23 00:00:00', 34.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-24 00:00:00', 35.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-25 00:00:00', 35.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-26 00:00:00', 34.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-27 00:00:00', 35.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-28 00:00:00', 36.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-29 00:00:00', 35.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-30 00:00:00', 33.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-08-31 00:00:00', 35.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-01 00:00:00', 35.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-02 00:00:00', 35.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-03 00:00:00', 35.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-04 00:00:00', 35.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-05 00:00:00', 33.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-06 00:00:00', 33.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-07 00:00:00', 35.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-08 00:00:00', 36.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-09 00:00:00', 36.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-10 00:00:00', 36.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-11 00:00:00', 35.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-12 00:00:00', 34.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-13 00:00:00', 32.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-14 00:00:00', 33.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-15 00:00:00', 31.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-16 00:00:00', 28.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-17 00:00:00', 29.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-18 00:00:00', 32.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-19 00:00:00', 34.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-20 00:00:00', 35.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-21 00:00:00', 33.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-22 00:00:00', 31.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-23 00:00:00', 28.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-24 00:00:00', 24.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-25 00:00:00', 25.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-26 00:00:00', 23.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-27 00:00:00', 22.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-28 00:00:00', 23.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-29 00:00:00', 24.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-09-30 00:00:00', 25.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-01 00:00:00', 26.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-02 00:00:00', 27.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-03 00:00:00', 29.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-04 00:00:00', 31.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-05 00:00:00', 31.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-06 00:00:00', 25.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-07 00:00:00', 24.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-08 00:00:00', 24.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-09 00:00:00', 21.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-10 00:00:00', 23.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-11 00:00:00', 23.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-12 00:00:00', 22.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-13 00:00:00', 23.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-14 00:00:00', 23.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-15 00:00:00', 23.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-16 00:00:00', 21.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-17 00:00:00', 24.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-18 00:00:00', 25.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-19 00:00:00', 26.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-20 00:00:00', 26.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-21 00:00:00', 24.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-22 00:00:00', 25.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-23 00:00:00', 26.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-24 00:00:00', 24.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-25 00:00:00', 26.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-26 00:00:00', 26.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-27 00:00:00', 27.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-28 00:00:00', 28.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-29 00:00:00', 29.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-30 00:00:00', 29.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-10-31 00:00:00', 28.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-01 00:00:00', 27.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-02 00:00:00', 26.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-03 00:00:00', 27.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-04 00:00:00', 18.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-05 00:00:00', 11.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-06 00:00:00', 13.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-07 00:00:00', 12.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-08 00:00:00', 9.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-09 00:00:00', 15.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-10 00:00:00', 19.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-11 00:00:00', 20.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-12 00:00:00', 19.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-13 00:00:00', 16.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-14 00:00:00', 17.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-15 00:00:00', 16.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-16 00:00:00', 8.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-17 00:00:00', 7.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-18 00:00:00', 8.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-19 00:00:00', 10.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-20 00:00:00', 13.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-21 00:00:00', 14.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-22 00:00:00', 14.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-23 00:00:00', 9.26299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-24 00:00:00', 9.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-25 00:00:00', 13.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-26 00:00:00', 13.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-27 00:00:00', 13.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-28 00:00:00', 15.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-29 00:00:00', 14.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-11-30 00:00:00', 13.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-01 00:00:00', 12.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-02 00:00:00', 12.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-03 00:00:00', 12.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-04 00:00:00', 12.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-05 00:00:00', 10.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-06 00:00:00', 13.8809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-07 00:00:00', 12.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-08 00:00:00', 13.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-09 00:00:00', 11.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-10 00:00:00', 12.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-11 00:00:00', 12.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-12 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-13 00:00:00', -2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-14 00:00:00', -0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-15 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-16 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-17 00:00:00', 6.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-18 00:00:00', 9.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-19 00:00:00', 11.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-20 00:00:00', 12.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-21 00:00:00', 13.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-22 00:00:00', 6.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-23 00:00:00', 1.44299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-24 00:00:00', 4.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-25 00:00:00', 6.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-26 00:00:00', 4.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-27 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-28 00:00:00', 8.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-29 00:00:00', 7.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-30 00:00:00', 6.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2003-12-31 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-01 00:00:00', 2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-02 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-03 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-04 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-05 00:00:00', 6.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-06 00:00:00', 6.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-07 00:00:00', 6.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-08 00:00:00', 6.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-09 00:00:00', 12.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-10 00:00:00', 11.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-11 00:00:00', 12.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-12 00:00:00', 10.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-13 00:00:00', 9.74899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-14 00:00:00', 12.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-15 00:00:00', 13.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-16 00:00:00', 11.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-17 00:00:00', 9.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-18 00:00:00', 11.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-19 00:00:00', 12.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-20 00:00:00', 10.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-21 00:00:00', 8.51099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-22 00:00:00', 8.09099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-23 00:00:00', 8.93799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-24 00:00:00', 10.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-25 00:00:00', 11.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-26 00:00:00', 10.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-27 00:00:00', 11.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-28 00:00:00', 7.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-29 00:00:00', 7.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-30 00:00:00', 5.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-01-31 00:00:00', 5.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-01 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-02 00:00:00', 8.26799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-03 00:00:00', 11.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-04 00:00:00', 8.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-05 00:00:00', 10.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-06 00:00:00', 10.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-07 00:00:00', 9.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-08 00:00:00', 11.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-09 00:00:00', 9.22500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-10 00:00:00', 13.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-11 00:00:00', 16.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-12 00:00:00', 18.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-13 00:00:00', 16.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-14 00:00:00', 17.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-15 00:00:00', 19.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-16 00:00:00', 21.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-17 00:00:00', 13.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-18 00:00:00', 12.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-19 00:00:00', 12.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-20 00:00:00', 15.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-21 00:00:00', 13.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-22 00:00:00', 17.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-23 00:00:00', 17.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-24 00:00:00', 18.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-25 00:00:00', 16.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-26 00:00:00', 15.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-27 00:00:00', 15.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-28 00:00:00', 16.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-02-29 00:00:00', 16.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-01 00:00:00', 14.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-02 00:00:00', 17.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-03 00:00:00', 17.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-04 00:00:00', 17.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-05 00:00:00', 19.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-06 00:00:00', 23.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-07 00:00:00', 27.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-08 00:00:00', 24.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-09 00:00:00', 17.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-10 00:00:00', 16.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-11 00:00:00', 20.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-12 00:00:00', 23.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-13 00:00:00', 22.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-14 00:00:00', 18.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-15 00:00:00', 20.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-16 00:00:00', 22.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-17 00:00:00', 8.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-18 00:00:00', 15.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-19 00:00:00', 18.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-20 00:00:00', 17.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-21 00:00:00', 12.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-22 00:00:00', 14.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-23 00:00:00', 15.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-24 00:00:00', 18.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-25 00:00:00', 19.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-26 00:00:00', 22.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-27 00:00:00', 23.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-28 00:00:00', 23.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-29 00:00:00', 25.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-30 00:00:00', 27.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-03-31 00:00:00', 28.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-01 00:00:00', 26.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-02 00:00:00', 26.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-03 00:00:00', 21.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-04 00:00:00', 28.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-05 00:00:00', 30.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-06 00:00:00', 21.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-07 00:00:00', 17.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-08 00:00:00', 20.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-09 00:00:00', 20.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-10 00:00:00', 21.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-11 00:00:00', 23.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-12 00:00:00', 23.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-13 00:00:00', 24.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-14 00:00:00', 26.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-15 00:00:00', 28.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-16 00:00:00', 26.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-17 00:00:00', 27.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-18 00:00:00', 26.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-19 00:00:00', 22.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-20 00:00:00', 28.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-21 00:00:00', 29.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-22 00:00:00', 23.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-23 00:00:00', 25.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-24 00:00:00', 31.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-25 00:00:00', 32.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-26 00:00:00', 31.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-27 00:00:00', 27.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-28 00:00:00', 25.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-29 00:00:00', 20.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-04-30 00:00:00', 21.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-01 00:00:00', 22.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-02 00:00:00', 26.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-03 00:00:00', 29.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-04 00:00:00', 29.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-05 00:00:00', 32.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-06 00:00:00', 32.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-07 00:00:00', 23.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-08 00:00:00', 27.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-09 00:00:00', 28.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-10 00:00:00', 32.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-11 00:00:00', 33.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-12 00:00:00', 34.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-13 00:00:00', 36.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-14 00:00:00', 38.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-15 00:00:00', 39.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-16 00:00:00', 37.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-17 00:00:00', 37.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-18 00:00:00', 37.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-19 00:00:00', 33.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-20 00:00:00', 31.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-21 00:00:00', 32.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-22 00:00:00', 28.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-23 00:00:00', 27.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-24 00:00:00', 30.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-25 00:00:00', 32.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-26 00:00:00', 31.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-27 00:00:00', 31.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-28 00:00:00', 30.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-29 00:00:00', 32.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-30 00:00:00', 32.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-05-31 00:00:00', 33.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-01 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-02 00:00:00', 33.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-03 00:00:00', 35.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-04 00:00:00', 37.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-05 00:00:00', 38.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-06 00:00:00', 34.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-07 00:00:00', 31.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-08 00:00:00', 32.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-09 00:00:00', 33.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-10 00:00:00', 36.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-11 00:00:00', 37.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-12 00:00:00', 38.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-13 00:00:00', 38.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-14 00:00:00', 33.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-15 00:00:00', 35.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-16 00:00:00', 37.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-17 00:00:00', 38.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-18 00:00:00', 38.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-19 00:00:00', 38.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-20 00:00:00', 39.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-21 00:00:00', 39.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-22 00:00:00', 38.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-23 00:00:00', 38.6570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-24 00:00:00', 36.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-25 00:00:00', 36.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-26 00:00:00', 36.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-27 00:00:00', 34.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-28 00:00:00', 36.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-29 00:00:00', 37.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-06-30 00:00:00', 39.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-01 00:00:00', 38.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-02 00:00:00', 39.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-03 00:00:00', 40.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-04 00:00:00', 40.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-05 00:00:00', 37.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-06 00:00:00', 33.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-07 00:00:00', 36.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-08 00:00:00', 35.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-09 00:00:00', 35.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-10 00:00:00', 36.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-11 00:00:00', 38.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-12 00:00:00', 36.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-13 00:00:00', 34.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-14 00:00:00', 35.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-15 00:00:00', 34.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-16 00:00:00', 33.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-17 00:00:00', 31.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-18 00:00:00', 31.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-19 00:00:00', 27.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-20 00:00:00', 32.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-21 00:00:00', 33.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-22 00:00:00', 34.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-23 00:00:00', 36.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-24 00:00:00', 39.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-25 00:00:00', 39.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-26 00:00:00', 39.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-27 00:00:00', 39.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-28 00:00:00', 39.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-29 00:00:00', 40.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-30 00:00:00', 37.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-07-31 00:00:00', 36.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-01 00:00:00', 34.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-02 00:00:00', 34.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-03 00:00:00', 33.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-04 00:00:00', 36.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-05 00:00:00', 39.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-06 00:00:00', 39.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-07 00:00:00', 34.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-08 00:00:00', 33.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-09 00:00:00', 33.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-10 00:00:00', 34.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-11 00:00:00', 34.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-12 00:00:00', 36.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-13 00:00:00', 39.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-14 00:00:00', 41.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-15 00:00:00', 40.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-16 00:00:00', 40.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-17 00:00:00', 36.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-18 00:00:00', 37.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-19 00:00:00', 36.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-20 00:00:00', 35.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-21 00:00:00', 35.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-22 00:00:00', 37.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-23 00:00:00', 38.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-24 00:00:00', 37.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-25 00:00:00', 35.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-26 00:00:00', 34.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-27 00:00:00', 35.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-28 00:00:00', 35.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-29 00:00:00', 34.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-30 00:00:00', 33.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-08-31 00:00:00', 32.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-01 00:00:00', 31.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-02 00:00:00', 31.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-03 00:00:00', 31.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-04 00:00:00', 31.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-05 00:00:00', 33.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-06 00:00:00', 35.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-07 00:00:00', 38.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-08 00:00:00', 37.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-09 00:00:00', 34.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-10 00:00:00', 35.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-11 00:00:00', 37.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-12 00:00:00', 35.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-13 00:00:00', 35.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-14 00:00:00', 32.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-15 00:00:00', 28.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-16 00:00:00', 27.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-17 00:00:00', 27.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-18 00:00:00', 30.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-19 00:00:00', 31.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-20 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-21 00:00:00', 27.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-22 00:00:00', 25.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-23 00:00:00', 29.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-24 00:00:00', 29.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-25 00:00:00', 30.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-26 00:00:00', 29.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-27 00:00:00', 30.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-28 00:00:00', 28.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-29 00:00:00', 28.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-09-30 00:00:00', 29.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-01 00:00:00', 28.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-02 00:00:00', 27.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-03 00:00:00', 28.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-04 00:00:00', 30.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-05 00:00:00', 29.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-06 00:00:00', 27.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-07 00:00:00', 22.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-08 00:00:00', 18.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-09 00:00:00', 16.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-10 00:00:00', 18.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-11 00:00:00', 21.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-12 00:00:00', 23.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-13 00:00:00', 23.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-14 00:00:00', 24.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-15 00:00:00', 19.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-16 00:00:00', 18.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-17 00:00:00', 19.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-18 00:00:00', 18.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-19 00:00:00', 18.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-20 00:00:00', 19.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-21 00:00:00', 22.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-22 00:00:00', 25.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-23 00:00:00', 26.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-24 00:00:00', 20.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-25 00:00:00', 19.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-26 00:00:00', 20.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-27 00:00:00', 17.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-28 00:00:00', 17.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-29 00:00:00', 21.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-30 00:00:00', 21.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-10-31 00:00:00', 21.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-01 00:00:00', 19.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-02 00:00:00', 20.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-03 00:00:00', 22.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-04 00:00:00', 24.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-05 00:00:00', 21.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-06 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-07 00:00:00', 20.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-08 00:00:00', 21.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-09 00:00:00', 19.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-10 00:00:00', 17.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-11 00:00:00', 18.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-12 00:00:00', 17.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-13 00:00:00', 17.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-14 00:00:00', 19.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-15 00:00:00', 19.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-16 00:00:00', 17.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-17 00:00:00', 18.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-18 00:00:00', 19.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-19 00:00:00', 15.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-20 00:00:00', 15.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-21 00:00:00', 16.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-22 00:00:00', 16.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-23 00:00:00', 18.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-24 00:00:00', 20.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-25 00:00:00', 14.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-26 00:00:00', 15.0679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-27 00:00:00', 18.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-28 00:00:00', 18.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-29 00:00:00', 11.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-11-30 00:00:00', 10.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-01 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-02 00:00:00', 14.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-03 00:00:00', 9.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-04 00:00:00', 7.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-05 00:00:00', 12.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-06 00:00:00', 12.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-07 00:00:00', 10.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-08 00:00:00', 14.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-09 00:00:00', 15.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-10 00:00:00', 15.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-11 00:00:00', 16.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-12 00:00:00', 14.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-13 00:00:00', 17.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-14 00:00:00', 12.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-15 00:00:00', 13.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-16 00:00:00', 13.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-17 00:00:00', 18.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-18 00:00:00', 9.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-19 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-20 00:00:00', 6.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-21 00:00:00', 8.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-22 00:00:00', 7.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-23 00:00:00', 5.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-24 00:00:00', 7.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-25 00:00:00', 8.33899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-26 00:00:00', 10.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-27 00:00:00', 8.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-28 00:00:00', 4.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-29 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-30 00:00:00', 3.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2004-12-31 00:00:00', 8.61400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-01 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-02 00:00:00', 7.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-03 00:00:00', 8.06200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-04 00:00:00', 13.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-05 00:00:00', 8.31299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-06 00:00:00', 10.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-07 00:00:00', 8.34099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-08 00:00:00', 5.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-09 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-10 00:00:00', 6.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-11 00:00:00', 10.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-12 00:00:00', 7.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-13 00:00:00', 6.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-14 00:00:00', 5.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-15 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-16 00:00:00', 7.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-17 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-18 00:00:00', 6.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-19 00:00:00', 7.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-20 00:00:00', 11.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-21 00:00:00', 7.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-22 00:00:00', 5.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-23 00:00:00', 7.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-24 00:00:00', 8.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-25 00:00:00', 10.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-26 00:00:00', 7.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-27 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-28 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-29 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-30 00:00:00', 3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-01-31 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-01 00:00:00', 7.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-02 00:00:00', 7.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-03 00:00:00', 7.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-04 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-05 00:00:00', 7.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-06 00:00:00', 4.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-07 00:00:00', 6.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-08 00:00:00', 6.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-09 00:00:00', 10.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-10 00:00:00', 10.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-11 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-12 00:00:00', 4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-13 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-14 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-15 00:00:00', 4, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-16 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-17 00:00:00', 2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-18 00:00:00', 2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-19 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-20 00:00:00', 8.65499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-21 00:00:00', 12.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-22 00:00:00', 13.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-23 00:00:00', 8.08899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-24 00:00:00', 7.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-25 00:00:00', 9.39299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-26 00:00:00', 12.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-27 00:00:00', 14.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-02-28 00:00:00', 15.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-01 00:00:00', 18.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-02 00:00:00', 20.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-03 00:00:00', 20.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-04 00:00:00', 20.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-05 00:00:00', 21.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-06 00:00:00', 22.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-07 00:00:00', 20.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-08 00:00:00', 20.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-09 00:00:00', 19.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-10 00:00:00', 20.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-11 00:00:00', 22.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-12 00:00:00', 26.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-13 00:00:00', 26.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-14 00:00:00', 19.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-15 00:00:00', 20.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-16 00:00:00', 15.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-17 00:00:00', 14.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-18 00:00:00', 16.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-19 00:00:00', 14.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-20 00:00:00', 18.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-21 00:00:00', 18.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-22 00:00:00', 20.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-23 00:00:00', 20.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-24 00:00:00', 21.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-25 00:00:00', 16.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-26 00:00:00', 17.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-27 00:00:00', 8.32199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-28 00:00:00', 14.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-29 00:00:00', 18.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-30 00:00:00', 19.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-03-31 00:00:00', 23.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-01 00:00:00', 25.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-02 00:00:00', 26.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-03 00:00:00', 27.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-04 00:00:00', 24.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-05 00:00:00', 17.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-06 00:00:00', 12.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-07 00:00:00', 12.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-08 00:00:00', 12.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-09 00:00:00', 13.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-10 00:00:00', 15.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-11 00:00:00', 19.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-12 00:00:00', 18.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-13 00:00:00', 22.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-14 00:00:00', 21.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-15 00:00:00', 24.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-16 00:00:00', 26.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-17 00:00:00', 29.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-18 00:00:00', 31.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-19 00:00:00', 31.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-20 00:00:00', 30.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-21 00:00:00', 31.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-22 00:00:00', 31.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-23 00:00:00', 31.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-24 00:00:00', 29.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-25 00:00:00', 26.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-26 00:00:00', 27.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-27 00:00:00', 26.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-28 00:00:00', 30.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-29 00:00:00', 30.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-04-30 00:00:00', 31.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-01 00:00:00', 32.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-02 00:00:00', 32.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-03 00:00:00', 31.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-04 00:00:00', 31.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-05 00:00:00', 31.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-06 00:00:00', 31.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-07 00:00:00', 28.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-08 00:00:00', 21.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-09 00:00:00', 24.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-10 00:00:00', 28.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-11 00:00:00', 29.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-12 00:00:00', 27.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-13 00:00:00', 25.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-14 00:00:00', 25.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-15 00:00:00', 28.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-16 00:00:00', 28.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-17 00:00:00', 29.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-18 00:00:00', 29.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-19 00:00:00', 24.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-20 00:00:00', 21.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-21 00:00:00', 26.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-22 00:00:00', 27.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-23 00:00:00', 27.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-24 00:00:00', 25.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-25 00:00:00', 27.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-26 00:00:00', 27.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-27 00:00:00', 29.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-28 00:00:00', 29.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-29 00:00:00', 31.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-30 00:00:00', 32.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-05-31 00:00:00', 32.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-01 00:00:00', 33.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-02 00:00:00', 34.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-03 00:00:00', 35.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-04 00:00:00', 36.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-05 00:00:00', 35.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-06 00:00:00', 35.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-07 00:00:00', 35.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-08 00:00:00', 35.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-09 00:00:00', 32.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-10 00:00:00', 25.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-11 00:00:00', 27.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-12 00:00:00', 31.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-13 00:00:00', 32.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-14 00:00:00', 34.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-15 00:00:00', 37.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-16 00:00:00', 38.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-17 00:00:00', 39.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-18 00:00:00', 39.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-19 00:00:00', 38.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-20 00:00:00', 39.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-21 00:00:00', 40.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-22 00:00:00', 43.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-23 00:00:00', 44.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-24 00:00:00', 40.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-25 00:00:00', 36.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-26 00:00:00', 36.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-27 00:00:00', 38.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-28 00:00:00', 38.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-29 00:00:00', 36.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-06-30 00:00:00', 37.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-01 00:00:00', 37.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-02 00:00:00', 37.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-03 00:00:00', 37.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-04 00:00:00', 37.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-05 00:00:00', 37.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-06 00:00:00', 39.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-07 00:00:00', 40.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-08 00:00:00', 42.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-09 00:00:00', 43.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-10 00:00:00', 40.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-11 00:00:00', 40.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-12 00:00:00', 39.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-13 00:00:00', 39.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-14 00:00:00', 38.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-15 00:00:00', 37.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-16 00:00:00', 35.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-17 00:00:00', 35.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-18 00:00:00', 36.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-19 00:00:00', 37.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-20 00:00:00', 38.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-21 00:00:00', 39.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-22 00:00:00', 38.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-23 00:00:00', 36.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-24 00:00:00', 37.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-25 00:00:00', 38.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-26 00:00:00', 37.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-27 00:00:00', 37.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-28 00:00:00', 37.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-29 00:00:00', 36.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-30 00:00:00', 36.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-07-31 00:00:00', 37.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-01 00:00:00', 35.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-02 00:00:00', 34.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-03 00:00:00', 35.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-04 00:00:00', 35.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-05 00:00:00', 36.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-06 00:00:00', 38.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-07 00:00:00', 37.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-08 00:00:00', 35.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-09 00:00:00', 38.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-10 00:00:00', 36.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-11 00:00:00', 35.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-12 00:00:00', 33.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-13 00:00:00', 34.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-14 00:00:00', 36.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-15 00:00:00', 36.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-16 00:00:00', 35.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-17 00:00:00', 35.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-18 00:00:00', 34.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-19 00:00:00', 35.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-20 00:00:00', 35.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-21 00:00:00', 35.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-22 00:00:00', 37.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-23 00:00:00', 35.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-24 00:00:00', 34.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-25 00:00:00', 31.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-26 00:00:00', 32.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-27 00:00:00', 27.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-28 00:00:00', 27.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-29 00:00:00', 28.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-30 00:00:00', 28.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-08-31 00:00:00', 31.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-01 00:00:00', 33.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-02 00:00:00', 34.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-03 00:00:00', 34.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-04 00:00:00', 36.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-05 00:00:00', 38.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-06 00:00:00', 38.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-07 00:00:00', 37.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-08 00:00:00', 34.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-09 00:00:00', 32.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-10 00:00:00', 28.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-11 00:00:00', 31.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-12 00:00:00', 32.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-13 00:00:00', 33.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-14 00:00:00', 33.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-15 00:00:00', 34.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-16 00:00:00', 35.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-17 00:00:00', 34.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-18 00:00:00', 31.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-19 00:00:00', 30.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-20 00:00:00', 31.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-21 00:00:00', 31.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-22 00:00:00', 31.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-23 00:00:00', 29.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-24 00:00:00', 29.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-25 00:00:00', 30.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-26 00:00:00', 28.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-27 00:00:00', 27.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-28 00:00:00', 27.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-29 00:00:00', 28.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-09-30 00:00:00', 29.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-01 00:00:00', 31.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-02 00:00:00', 30.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-03 00:00:00', 27.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-04 00:00:00', 26.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-05 00:00:00', 26.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-06 00:00:00', 31.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-07 00:00:00', 32.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-08 00:00:00', 30.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-09 00:00:00', 29.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-10 00:00:00', 27.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-11 00:00:00', 24.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-12 00:00:00', 21.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-13 00:00:00', 19.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-14 00:00:00', 19.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-15 00:00:00', 19.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-16 00:00:00', 18.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-17 00:00:00', 21.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-18 00:00:00', 23.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-19 00:00:00', 25.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-20 00:00:00', 27.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-21 00:00:00', 27.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-22 00:00:00', 27.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-23 00:00:00', 22.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-24 00:00:00', 15.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-25 00:00:00', 16.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-26 00:00:00', 21.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-27 00:00:00', 18.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-28 00:00:00', 22.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-29 00:00:00', 24.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-30 00:00:00', 24.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-10-31 00:00:00', 20.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-01 00:00:00', 17.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-02 00:00:00', 18.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-03 00:00:00', 19.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-04 00:00:00', 20.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-05 00:00:00', 20.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-06 00:00:00', 20.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-07 00:00:00', 15.8730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-08 00:00:00', 18.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-09 00:00:00', 22.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-10 00:00:00', 13.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-11 00:00:00', 12.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-12 00:00:00', 14.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-13 00:00:00', 15.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-14 00:00:00', 13.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-15 00:00:00', 13.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-16 00:00:00', 12.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-17 00:00:00', 15.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-18 00:00:00', 18.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-19 00:00:00', 20.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-20 00:00:00', 22.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-21 00:00:00', 19.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-22 00:00:00', 18.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-23 00:00:00', 18.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-24 00:00:00', 13.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-25 00:00:00', 12.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-26 00:00:00', 10.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-27 00:00:00', 9.60499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-28 00:00:00', 9.58899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-29 00:00:00', 10.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-11-30 00:00:00', 11.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-01 00:00:00', 13.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-02 00:00:00', 13.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-03 00:00:00', 11.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-04 00:00:00', 12.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-05 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-06 00:00:00', 15.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-07 00:00:00', 15.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-08 00:00:00', 10.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-09 00:00:00', 10.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-10 00:00:00', 11.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-11 00:00:00', 12.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-12 00:00:00', 9.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-13 00:00:00', 11.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-14 00:00:00', 9.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-15 00:00:00', 12.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-16 00:00:00', 13.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-17 00:00:00', 15.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-18 00:00:00', 17.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-19 00:00:00', 13.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-20 00:00:00', 14.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-21 00:00:00', 14.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-22 00:00:00', 13.1689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-23 00:00:00', 13.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-24 00:00:00', 14.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-25 00:00:00', 13.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-26 00:00:00', 15.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-27 00:00:00', 12.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-28 00:00:00', 6.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-29 00:00:00', 5.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-30 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2005-12-31 00:00:00', 2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-01 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-02 00:00:00', -2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-03 00:00:00', -4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-04 00:00:00', -1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-05 00:00:00', -0.720000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-06 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-07 00:00:00', 7.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-08 00:00:00', 9.55500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-09 00:00:00', 10.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-10 00:00:00', 5.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-11 00:00:00', 6.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-12 00:00:00', 6.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-13 00:00:00', 6.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-14 00:00:00', 6.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-15 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-16 00:00:00', 4.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-17 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-18 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-19 00:00:00', 6.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-20 00:00:00', 5.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-21 00:00:00', 6.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-22 00:00:00', 9.76799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-23 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-24 00:00:00', 7.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-25 00:00:00', 9.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-26 00:00:00', 8.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-27 00:00:00', 8.36900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-28 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-29 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-30 00:00:00', 7.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-01-31 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-01 00:00:00', 5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-02 00:00:00', 8.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-03 00:00:00', 12.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-04 00:00:00', 18.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-05 00:00:00', 17.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-06 00:00:00', 15.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-07 00:00:00', 17.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-08 00:00:00', 18.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-09 00:00:00', 18.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-10 00:00:00', 15.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-11 00:00:00', 15.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-12 00:00:00', 17.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-13 00:00:00', 16.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-14 00:00:00', 18.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-15 00:00:00', 16.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-16 00:00:00', 15.3900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-17 00:00:00', 11.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-18 00:00:00', 15.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-19 00:00:00', 10.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-20 00:00:00', 13.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-21 00:00:00', 12.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-22 00:00:00', 13.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-23 00:00:00', 10.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-24 00:00:00', 8.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-25 00:00:00', 7.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-26 00:00:00', 12.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-27 00:00:00', 15.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-02-28 00:00:00', 17.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-01 00:00:00', 17.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-02 00:00:00', 17.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-03 00:00:00', 19.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-04 00:00:00', 18.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-05 00:00:00', 19.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-06 00:00:00', 15.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-07 00:00:00', 15.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-08 00:00:00', 18.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-09 00:00:00', 21.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-10 00:00:00', 23.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-11 00:00:00', 24.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-12 00:00:00', 21.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-13 00:00:00', 11.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-14 00:00:00', 12.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-15 00:00:00', 12.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-16 00:00:00', 14.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-17 00:00:00', 19.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-18 00:00:00', 19.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-19 00:00:00', 18.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-20 00:00:00', 21.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-21 00:00:00', 20.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-22 00:00:00', 17.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-23 00:00:00', 20.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-24 00:00:00', 21.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-25 00:00:00', 21.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-26 00:00:00', 15.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-27 00:00:00', 18.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-28 00:00:00', 23.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-29 00:00:00', 25.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-30 00:00:00', 25.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-03-31 00:00:00', 17.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-01 00:00:00', 16.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-02 00:00:00', 20.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-03 00:00:00', 22.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-04 00:00:00', 26.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-05 00:00:00', 26.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-06 00:00:00', 25.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-07 00:00:00', 27.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-08 00:00:00', 25.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-09 00:00:00', 16.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-10 00:00:00', 13.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-11 00:00:00', 17.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-12 00:00:00', 19.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-13 00:00:00', 21.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-14 00:00:00', 21.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-15 00:00:00', 22.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-16 00:00:00', 24.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-17 00:00:00', 25.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-18 00:00:00', 26.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-19 00:00:00', 28.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-20 00:00:00', 27.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-21 00:00:00', 23.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-22 00:00:00', 26.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-23 00:00:00', 28.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-24 00:00:00', 32.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-25 00:00:00', 34.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-26 00:00:00', 34.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-27 00:00:00', 35.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-28 00:00:00', 33.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-29 00:00:00', 30.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-04-30 00:00:00', 29.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-01 00:00:00', 28.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-02 00:00:00', 30.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-03 00:00:00', 30.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-04 00:00:00', 30.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-05 00:00:00', 31.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-06 00:00:00', 30.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-07 00:00:00', 30.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-08 00:00:00', 31.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-09 00:00:00', 33.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-10 00:00:00', 35.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-11 00:00:00', 35.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-12 00:00:00', 36.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-13 00:00:00', 37.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-14 00:00:00', 37.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-15 00:00:00', 39.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-16 00:00:00', 39.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-17 00:00:00', 35.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-18 00:00:00', 34.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-19 00:00:00', 35.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-20 00:00:00', 36.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-21 00:00:00', 34.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-22 00:00:00', 34.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-23 00:00:00', 34.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-24 00:00:00', 34.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-25 00:00:00', 33.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-26 00:00:00', 33.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-27 00:00:00', 33.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-28 00:00:00', 34.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-29 00:00:00', 33.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-30 00:00:00', 34.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-05-31 00:00:00', 30.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-01 00:00:00', 30.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-02 00:00:00', 33.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-03 00:00:00', 33.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-04 00:00:00', 33.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-05 00:00:00', 34.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-06 00:00:00', 34.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-07 00:00:00', 31.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-08 00:00:00', 31.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-09 00:00:00', 32.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-10 00:00:00', 32.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-11 00:00:00', 30.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-12 00:00:00', 33.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-13 00:00:00', 36.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-14 00:00:00', 38.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-15 00:00:00', 36.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-16 00:00:00', 35.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-17 00:00:00', 36.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-18 00:00:00', 37.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-19 00:00:00', 39.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-20 00:00:00', 39.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-21 00:00:00', 39.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-22 00:00:00', 39.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-23 00:00:00', 38.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-24 00:00:00', 39.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-25 00:00:00', 39.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-26 00:00:00', 39.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-27 00:00:00', 39.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-28 00:00:00', 38.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-29 00:00:00', 37.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-06-30 00:00:00', 38.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-01 00:00:00', 33.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-02 00:00:00', 34.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-03 00:00:00', 36.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-04 00:00:00', 37.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-05 00:00:00', 38.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-06 00:00:00', 40.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-07 00:00:00', 39.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-08 00:00:00', 40.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-09 00:00:00', 42.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-10 00:00:00', 40.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-11 00:00:00', 38.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-12 00:00:00', 33.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-13 00:00:00', 29.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-14 00:00:00', 30.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-15 00:00:00', 32.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-16 00:00:00', 34.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-17 00:00:00', 36.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-18 00:00:00', 35.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-19 00:00:00', 36.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-20 00:00:00', 38.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-21 00:00:00', 40.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-22 00:00:00', 42.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-23 00:00:00', 42.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-24 00:00:00', 40.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-25 00:00:00', 40.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-26 00:00:00', 39.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-27 00:00:00', 40.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-28 00:00:00', 37.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-29 00:00:00', 39.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-30 00:00:00', 42.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-07-31 00:00:00', 42.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-01 00:00:00', 41.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-02 00:00:00', 41.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-03 00:00:00', 40.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-04 00:00:00', 39.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-05 00:00:00', 38.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-06 00:00:00', 37.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-07 00:00:00', 38.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-08 00:00:00', 37.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-09 00:00:00', 39.5789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-10 00:00:00', 40.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-11 00:00:00', 39.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-12 00:00:00', 39.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-13 00:00:00', 40.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-14 00:00:00', 41.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-15 00:00:00', 35.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-16 00:00:00', 34.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-17 00:00:00', 34.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-18 00:00:00', 35.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-19 00:00:00', 36.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-20 00:00:00', 38.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-21 00:00:00', 35.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-22 00:00:00', 36.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-23 00:00:00', 37.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-24 00:00:00', 38.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-25 00:00:00', 38.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-26 00:00:00', 37.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-27 00:00:00', 35.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-28 00:00:00', 34.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-29 00:00:00', 34.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-30 00:00:00', 36.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-08-31 00:00:00', 35.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-01 00:00:00', 33.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-02 00:00:00', 31.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-03 00:00:00', 30.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-04 00:00:00', 28.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-05 00:00:00', 30.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-06 00:00:00', 32.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-07 00:00:00', 34.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-08 00:00:00', 34.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-09 00:00:00', 34.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-10 00:00:00', 33.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-11 00:00:00', 31.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-12 00:00:00', 31.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-13 00:00:00', 31.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-14 00:00:00', 31.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-15 00:00:00', 31.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-16 00:00:00', 33.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-17 00:00:00', 34.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-18 00:00:00', 29.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-19 00:00:00', 24.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-20 00:00:00', 25.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-21 00:00:00', 27.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-22 00:00:00', 27.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-23 00:00:00', 29.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-24 00:00:00', 27.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-25 00:00:00', 26.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-26 00:00:00', 28.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-27 00:00:00', 30.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-28 00:00:00', 32.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-29 00:00:00', 27.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-09-30 00:00:00', 28.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-01 00:00:00', 29.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-02 00:00:00', 29.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-03 00:00:00', 30.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-04 00:00:00', 31.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-05 00:00:00', 30.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-06 00:00:00', 27.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-07 00:00:00', 29.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-08 00:00:00', 28.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-09 00:00:00', 30.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-10 00:00:00', 31.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-11 00:00:00', 30.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-12 00:00:00', 28.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-13 00:00:00', 28.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-14 00:00:00', 26.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-15 00:00:00', 25.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-16 00:00:00', 28.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-17 00:00:00', 28.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-18 00:00:00', 27.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-19 00:00:00', 26.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-20 00:00:00', 25.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-21 00:00:00', 22.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-22 00:00:00', 24.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-23 00:00:00', 25.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-24 00:00:00', 22.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-25 00:00:00', 20.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-26 00:00:00', 22.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-27 00:00:00', 22.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-28 00:00:00', 24.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-29 00:00:00', 24.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-30 00:00:00', 25.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-10-31 00:00:00', 27.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-01 00:00:00', 26.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-02 00:00:00', 25.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-03 00:00:00', 26.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-04 00:00:00', 26.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-05 00:00:00', 27.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-06 00:00:00', 26.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-07 00:00:00', 26.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-08 00:00:00', 26.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-09 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-10 00:00:00', 14.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-11 00:00:00', 18.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-12 00:00:00', 18.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-13 00:00:00', 19.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-14 00:00:00', 17.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-15 00:00:00', 18.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-16 00:00:00', 13.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-17 00:00:00', 12.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-18 00:00:00', 16.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-19 00:00:00', 18.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-20 00:00:00', 13.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-21 00:00:00', 7.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-22 00:00:00', 4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-23 00:00:00', 6.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-24 00:00:00', 8.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-25 00:00:00', 7.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-26 00:00:00', 7.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-27 00:00:00', 7.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-28 00:00:00', 9.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-29 00:00:00', 9.70600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-11-30 00:00:00', 9.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-01 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-02 00:00:00', 6.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-03 00:00:00', 9.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-04 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-05 00:00:00', 3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-06 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-07 00:00:00', 6.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-08 00:00:00', 7.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-09 00:00:00', 7.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-10 00:00:00', 5.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-11 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-12 00:00:00', 4.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-13 00:00:00', 8.45400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-14 00:00:00', 9.51799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-15 00:00:00', 10.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-16 00:00:00', 9.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-17 00:00:00', 9.81499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-18 00:00:00', 12.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-19 00:00:00', 11.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-20 00:00:00', 9.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-21 00:00:00', 13.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-22 00:00:00', 13.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-23 00:00:00', 12.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-24 00:00:00', 7.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-25 00:00:00', 5.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-26 00:00:00', 8.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-27 00:00:00', 11.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-28 00:00:00', 13.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-29 00:00:00', 13.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-30 00:00:00', 5.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2006-12-31 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-01 00:00:00', 0.0970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-02 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-03 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-04 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-05 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-06 00:00:00', 6.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-07 00:00:00', 8.99400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-08 00:00:00', 10.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-09 00:00:00', 6.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-10 00:00:00', 7.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-11 00:00:00', 5.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-12 00:00:00', 3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-13 00:00:00', 4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-14 00:00:00', 3.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-15 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-16 00:00:00', 6.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-17 00:00:00', 8.55300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-18 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-19 00:00:00', 3.8900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-20 00:00:00', 7.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-21 00:00:00', 8.52000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-22 00:00:00', 10.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-23 00:00:00', 12.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-24 00:00:00', 7.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-25 00:00:00', 11.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-26 00:00:00', 12.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-27 00:00:00', 13.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-28 00:00:00', 14.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-29 00:00:00', 15.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-30 00:00:00', 15.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-01-31 00:00:00', 16.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-01 00:00:00', 14.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-02 00:00:00', 11.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-03 00:00:00', 12.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-04 00:00:00', 10.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-05 00:00:00', 10.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-06 00:00:00', 11.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-07 00:00:00', 13.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-08 00:00:00', 16.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-09 00:00:00', 10.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-10 00:00:00', 9.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-11 00:00:00', 9.08600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-12 00:00:00', 8.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-13 00:00:00', 9.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-14 00:00:00', 11.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-15 00:00:00', 12.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-16 00:00:00', 12.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-17 00:00:00', 12.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-18 00:00:00', 10.6029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-19 00:00:00', 7.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-20 00:00:00', 12.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-21 00:00:00', 8.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-22 00:00:00', 9.70600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-23 00:00:00', 13.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-24 00:00:00', 13.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-25 00:00:00', 10.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-26 00:00:00', 7.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-27 00:00:00', 1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-02-28 00:00:00', 5.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-01 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-02 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-03 00:00:00', 10.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-04 00:00:00', 9.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-05 00:00:00', 13.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-06 00:00:00', 15.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-07 00:00:00', 17.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-08 00:00:00', 18.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-09 00:00:00', 7.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-10 00:00:00', 13.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-11 00:00:00', 11.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-12 00:00:00', 9.36699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-13 00:00:00', 11.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-14 00:00:00', 13.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-15 00:00:00', 16.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-16 00:00:00', 16.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-17 00:00:00', 15.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-18 00:00:00', 13.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-19 00:00:00', 13.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-20 00:00:00', 17.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-21 00:00:00', 18.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-22 00:00:00', 19.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-23 00:00:00', 20.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-24 00:00:00', 18.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-25 00:00:00', 20.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-26 00:00:00', 15.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-27 00:00:00', 23.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-28 00:00:00', 21.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-29 00:00:00', 14.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-30 00:00:00', 11.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-03-31 00:00:00', 9.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-01 00:00:00', 11.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-02 00:00:00', 15.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-03 00:00:00', 19.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-04 00:00:00', 21.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-05 00:00:00', 22.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-06 00:00:00', 20.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-07 00:00:00', 22.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-08 00:00:00', 25.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-09 00:00:00', 27.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-10 00:00:00', 30.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-11 00:00:00', 29.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-12 00:00:00', 32.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-13 00:00:00', 34.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-14 00:00:00', 30.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-15 00:00:00', 33.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-16 00:00:00', 31.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-17 00:00:00', 29.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-18 00:00:00', 29.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-19 00:00:00', 30.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-20 00:00:00', 32.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-21 00:00:00', 32.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-22 00:00:00', 28.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-23 00:00:00', 28.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-24 00:00:00', 29.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-25 00:00:00', 30.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-26 00:00:00', 33.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-27 00:00:00', 29.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-28 00:00:00', 31.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-29 00:00:00', 32.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-04-30 00:00:00', 32.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-01 00:00:00', 34.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-02 00:00:00', 33.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-03 00:00:00', 33.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-04 00:00:00', 33.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-05 00:00:00', 33.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-06 00:00:00', 33.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-07 00:00:00', 23.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-08 00:00:00', 25.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-09 00:00:00', 29.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-10 00:00:00', 32.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-11 00:00:00', 33.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-12 00:00:00', 34.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-13 00:00:00', 33.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-14 00:00:00', 36.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-15 00:00:00', 37.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-16 00:00:00', 28.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-17 00:00:00', 22.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-18 00:00:00', 26.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-19 00:00:00', 24.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-20 00:00:00', 25.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-21 00:00:00', 28.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-22 00:00:00', 30.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-23 00:00:00', 30.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-24 00:00:00', 32.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-25 00:00:00', 31.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-26 00:00:00', 31.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-27 00:00:00', 33.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-28 00:00:00', 33.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-29 00:00:00', 35.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-30 00:00:00', 35.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-05-31 00:00:00', 35.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-01 00:00:00', 34.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-02 00:00:00', 36.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-03 00:00:00', 35.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-04 00:00:00', 34.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-05 00:00:00', 30.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-06 00:00:00', 31.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-07 00:00:00', 34.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-08 00:00:00', 36.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-09 00:00:00', 38.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-10 00:00:00', 38.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-11 00:00:00', 39.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-12 00:00:00', 39.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-13 00:00:00', 38.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-14 00:00:00', 38.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-15 00:00:00', 37.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-16 00:00:00', 33.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-17 00:00:00', 35.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-18 00:00:00', 35.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-19 00:00:00', 37.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-20 00:00:00', 38.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-21 00:00:00', 40.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-22 00:00:00', 41.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-23 00:00:00', 43.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-24 00:00:00', 41.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-25 00:00:00', 40.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-26 00:00:00', 40.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-27 00:00:00', 39.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-28 00:00:00', 39.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-29 00:00:00', 37.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-06-30 00:00:00', 38.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-01 00:00:00', 38.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-02 00:00:00', 36.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-03 00:00:00', 38.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-04 00:00:00', 39.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-05 00:00:00', 38.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-06 00:00:00', 39.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-07 00:00:00', 37.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-08 00:00:00', 36.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-09 00:00:00', 38.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-10 00:00:00', 40.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-11 00:00:00', 39.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-12 00:00:00', 38.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-13 00:00:00', 38.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-14 00:00:00', 37.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-15 00:00:00', 36.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-16 00:00:00', 36.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-17 00:00:00', 36.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-18 00:00:00', 39.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-19 00:00:00', 41.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-20 00:00:00', 40.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-21 00:00:00', 33.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-22 00:00:00', 35.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-23 00:00:00', 36.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-24 00:00:00', 38.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-25 00:00:00', 38.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-26 00:00:00', 36.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-27 00:00:00', 35.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-28 00:00:00', 36.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-29 00:00:00', 37.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-30 00:00:00', 38.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-07-31 00:00:00', 37.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-01 00:00:00', 38.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-02 00:00:00', 37.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-03 00:00:00', 36.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-04 00:00:00', 35.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-05 00:00:00', 36.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-06 00:00:00', 36.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-07 00:00:00', 36.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-08 00:00:00', 37.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-09 00:00:00', 39.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-10 00:00:00', 40.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-11 00:00:00', 39.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-12 00:00:00', 33.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-13 00:00:00', 35.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-14 00:00:00', 35.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-15 00:00:00', 34.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-16 00:00:00', 34.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-17 00:00:00', 34.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-18 00:00:00', 35.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-19 00:00:00', 35.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-20 00:00:00', 36.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-21 00:00:00', 36.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-22 00:00:00', 35.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-23 00:00:00', 36, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-24 00:00:00', 36.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-25 00:00:00', 36.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-26 00:00:00', 35.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-27 00:00:00', 35.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-28 00:00:00', 34.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-29 00:00:00', 35.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-30 00:00:00', 35.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-08-31 00:00:00', 35.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-01 00:00:00', 36.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-02 00:00:00', 36.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-03 00:00:00', 36.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-04 00:00:00', 35.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-05 00:00:00', 32.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-06 00:00:00', 34.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-07 00:00:00', 33.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-08 00:00:00', 32.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-09 00:00:00', 33.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-10 00:00:00', 35.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-11 00:00:00', 35.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-12 00:00:00', 35.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-13 00:00:00', 34.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-14 00:00:00', 35.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-15 00:00:00', 34.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-16 00:00:00', 32.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-17 00:00:00', 33.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-18 00:00:00', 34.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-19 00:00:00', 32.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-20 00:00:00', 30.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-21 00:00:00', 27.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-22 00:00:00', 25.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-23 00:00:00', 25.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-24 00:00:00', 26.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-25 00:00:00', 27.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-26 00:00:00', 25.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-27 00:00:00', 24.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-28 00:00:00', 21.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-29 00:00:00', 23.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-09-30 00:00:00', 25.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-01 00:00:00', 24.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-02 00:00:00', 23.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-03 00:00:00', 22.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-04 00:00:00', 20.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-05 00:00:00', 20.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-06 00:00:00', 20.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-07 00:00:00', 21.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-08 00:00:00', 22.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-09 00:00:00', 21.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-10 00:00:00', 21.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-11 00:00:00', 21.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-12 00:00:00', 23.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-13 00:00:00', 24.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-14 00:00:00', 25.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-15 00:00:00', 26.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-16 00:00:00', 25.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-17 00:00:00', 25.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-18 00:00:00', 27.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-19 00:00:00', 21.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-20 00:00:00', 19.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-21 00:00:00', 22.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-22 00:00:00', 23.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-23 00:00:00', 22.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-24 00:00:00', 21.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-25 00:00:00', 19.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-26 00:00:00', 19.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-27 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-28 00:00:00', 21.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-29 00:00:00', 17.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-30 00:00:00', 20.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-10-31 00:00:00', 23.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-01 00:00:00', 25.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-02 00:00:00', 24.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-03 00:00:00', 23.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-04 00:00:00', 26.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-05 00:00:00', 21.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-06 00:00:00', 26.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-07 00:00:00', 24.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-08 00:00:00', 23.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-09 00:00:00', 19.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-10 00:00:00', 22.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-11 00:00:00', 21.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-12 00:00:00', 23.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-13 00:00:00', 20.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-14 00:00:00', 17.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-15 00:00:00', 18.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-16 00:00:00', 18.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-17 00:00:00', 19.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-18 00:00:00', 19.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-19 00:00:00', 20.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-20 00:00:00', 17.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-21 00:00:00', 19.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-22 00:00:00', 21.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-23 00:00:00', 19.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-24 00:00:00', 14.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-25 00:00:00', 18.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-26 00:00:00', 18.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-27 00:00:00', 15.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-28 00:00:00', 14.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-29 00:00:00', 16.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-11-30 00:00:00', 13.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-01 00:00:00', 6.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-02 00:00:00', 10.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-03 00:00:00', 12.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-04 00:00:00', 14.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-05 00:00:00', 13.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-06 00:00:00', 12.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-07 00:00:00', 11.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-08 00:00:00', 11.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-09 00:00:00', 8.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-10 00:00:00', 6.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-11 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-12 00:00:00', 6.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-13 00:00:00', 6.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-14 00:00:00', 6.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-15 00:00:00', 9.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-16 00:00:00', 8.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-17 00:00:00', 9.83600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-18 00:00:00', 7.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-19 00:00:00', 6.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-20 00:00:00', 7.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-21 00:00:00', 8.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-22 00:00:00', 8.97500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-23 00:00:00', 6.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-24 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-25 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-26 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-27 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-28 00:00:00', 1.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-29 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-30 00:00:00', 3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2007-12-31 00:00:00', 6.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-01 00:00:00', 6.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-02 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-03 00:00:00', 6.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-04 00:00:00', 5.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-05 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-06 00:00:00', 5.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-07 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-08 00:00:00', -3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-09 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-10 00:00:00', -0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-11 00:00:00', 1.21899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-12 00:00:00', 2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-13 00:00:00', -1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-14 00:00:00', -1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-15 00:00:00', 0.922999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-16 00:00:00', -2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-17 00:00:00', -3.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-18 00:00:00', -2.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-19 00:00:00', -5.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-20 00:00:00', -5.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-21 00:00:00', -3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-22 00:00:00', -4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-23 00:00:00', -3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-24 00:00:00', -3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-25 00:00:00', -3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-26 00:00:00', -1.70599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-27 00:00:00', 2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-28 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-29 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-30 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-01-31 00:00:00', 8.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-01 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-02 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-03 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-04 00:00:00', -0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-05 00:00:00', -2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-06 00:00:00', -2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-07 00:00:00', -1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-08 00:00:00', 0.684000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-09 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-10 00:00:00', -1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-11 00:00:00', -0.381999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-12 00:00:00', 3.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-13 00:00:00', 6.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-14 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-15 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-16 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-17 00:00:00', 6.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-18 00:00:00', 8.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-19 00:00:00', 11.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-20 00:00:00', 13.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-21 00:00:00', 7.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-22 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-23 00:00:00', 7.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-24 00:00:00', 9.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-25 00:00:00', 11.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-26 00:00:00', 14.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-27 00:00:00', 19.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-28 00:00:00', 16.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-02-29 00:00:00', 18.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-01 00:00:00', 14.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-02 00:00:00', 17.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-03 00:00:00', 18.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-04 00:00:00', 19.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-05 00:00:00', 17.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-06 00:00:00', 11.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-07 00:00:00', 14.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-08 00:00:00', 19.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-09 00:00:00', 16.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-10 00:00:00', 18.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-11 00:00:00', 20.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-12 00:00:00', 18.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-13 00:00:00', 22.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-14 00:00:00', 23.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-15 00:00:00', 25.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-16 00:00:00', 24.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-17 00:00:00', 21.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-18 00:00:00', 19.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-19 00:00:00', 21.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-20 00:00:00', 23.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-21 00:00:00', 24.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-22 00:00:00', 26.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-23 00:00:00', 27.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-24 00:00:00', 27.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-25 00:00:00', 27.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-26 00:00:00', 25.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-27 00:00:00', 27.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-28 00:00:00', 28.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-29 00:00:00', 27.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-30 00:00:00', 28.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-03-31 00:00:00', 24.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-01 00:00:00', 25.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-02 00:00:00', 27.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-03 00:00:00', 29.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-04 00:00:00', 19.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-05 00:00:00', 22.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-06 00:00:00', 23.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-07 00:00:00', 17.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-08 00:00:00', 22.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-09 00:00:00', 25.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-10 00:00:00', 23.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-11 00:00:00', 23.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-12 00:00:00', 24.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-13 00:00:00', 23.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-14 00:00:00', 21.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-15 00:00:00', 19.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-16 00:00:00', 22.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-17 00:00:00', 24.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-18 00:00:00', 25.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-19 00:00:00', 25.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-20 00:00:00', 29.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-21 00:00:00', 29.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-22 00:00:00', 26.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-23 00:00:00', 26.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-24 00:00:00', 28.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-25 00:00:00', 29.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-26 00:00:00', 31.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-27 00:00:00', 32.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-28 00:00:00', 33.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-29 00:00:00', 34.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-04-30 00:00:00', 34.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-01 00:00:00', 34.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-02 00:00:00', 34.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-03 00:00:00', 35.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-04 00:00:00', 28.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-05 00:00:00', 27.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-06 00:00:00', 29.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-07 00:00:00', 33.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-08 00:00:00', 35.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-09 00:00:00', 30.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-10 00:00:00', 32.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-11 00:00:00', 36.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-12 00:00:00', 36.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-13 00:00:00', 34.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-14 00:00:00', 36.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-15 00:00:00', 35.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-16 00:00:00', 31.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-17 00:00:00', 34.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-18 00:00:00', 34.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-19 00:00:00', 34.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-20 00:00:00', 35.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-21 00:00:00', 37.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-22 00:00:00', 34.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-23 00:00:00', 32.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-24 00:00:00', 31.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-25 00:00:00', 29.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-26 00:00:00', 29.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-27 00:00:00', 30.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-28 00:00:00', 33.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-29 00:00:00', 35.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-30 00:00:00', 38.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-05-31 00:00:00', 35.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-01 00:00:00', 36.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-02 00:00:00', 37.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-03 00:00:00', 36.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-04 00:00:00', 38.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-05 00:00:00', 39.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-06 00:00:00', 39.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-07 00:00:00', 38.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-08 00:00:00', 38.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-09 00:00:00', 40.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-10 00:00:00', 40.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-11 00:00:00', 38.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-12 00:00:00', 41.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-13 00:00:00', 42.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-14 00:00:00', 42.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-15 00:00:00', 38.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-16 00:00:00', 37.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-17 00:00:00', 36.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-18 00:00:00', 37.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-19 00:00:00', 38.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-20 00:00:00', 39.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-21 00:00:00', 39.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-22 00:00:00', 39.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-23 00:00:00', 38.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-24 00:00:00', 38.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-25 00:00:00', 39.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-26 00:00:00', 39.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-27 00:00:00', 37.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-28 00:00:00', 36.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-29 00:00:00', 34.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-06-30 00:00:00', 34.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-01 00:00:00', 36.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-02 00:00:00', 37.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-03 00:00:00', 39.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-04 00:00:00', 39.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-05 00:00:00', 40.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-06 00:00:00', 40.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-07 00:00:00', 40.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-08 00:00:00', 37.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-09 00:00:00', 37.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-10 00:00:00', 38.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-11 00:00:00', 39.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-12 00:00:00', 40.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-13 00:00:00', 40.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-14 00:00:00', 40.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-15 00:00:00', 40.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-16 00:00:00', 37.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-17 00:00:00', 38.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-18 00:00:00', 38.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-19 00:00:00', 39.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-20 00:00:00', 36.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-21 00:00:00', 37.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-22 00:00:00', 36.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-23 00:00:00', 36.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-24 00:00:00', 36.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-25 00:00:00', 35.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-26 00:00:00', 35.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-27 00:00:00', 36.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-28 00:00:00', 38.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-29 00:00:00', 40.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-30 00:00:00', 42.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-07-31 00:00:00', 43.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-01 00:00:00', 43.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-02 00:00:00', 43.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-03 00:00:00', 43.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-04 00:00:00', 40.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-05 00:00:00', 37.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-06 00:00:00', 40.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-07 00:00:00', 40.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-08 00:00:00', 41.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-09 00:00:00', 42.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-10 00:00:00', 38.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-11 00:00:00', 35.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-12 00:00:00', 35.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-13 00:00:00', 36.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-14 00:00:00', 37.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-15 00:00:00', 36.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-16 00:00:00', 33.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-17 00:00:00', 32.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-18 00:00:00', 35.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-19 00:00:00', 36.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-20 00:00:00', 36.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-21 00:00:00', 35.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-22 00:00:00', 36.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-23 00:00:00', 37.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-24 00:00:00', 37.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-25 00:00:00', 36.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-26 00:00:00', 37.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-27 00:00:00', 36.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-28 00:00:00', 35.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-29 00:00:00', 35.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-30 00:00:00', 34.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-08-31 00:00:00', 33.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-01 00:00:00', 34.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-02 00:00:00', 36.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-03 00:00:00', 35.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-04 00:00:00', 33.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-05 00:00:00', 29.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-06 00:00:00', 29.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-07 00:00:00', 29.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-08 00:00:00', 30.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-09 00:00:00', 31.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-10 00:00:00', 31.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-11 00:00:00', 33.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-12 00:00:00', 36.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-13 00:00:00', 36.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-14 00:00:00', 35.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-15 00:00:00', 33.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-16 00:00:00', 32.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-17 00:00:00', 32.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-18 00:00:00', 30.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-19 00:00:00', 29.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-20 00:00:00', 27.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-21 00:00:00', 27.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-22 00:00:00', 26.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-23 00:00:00', 26.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-24 00:00:00', 27.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-25 00:00:00', 30.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-26 00:00:00', 32.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-27 00:00:00', 31.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-28 00:00:00', 31.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-29 00:00:00', 32.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-09-30 00:00:00', 26.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-01 00:00:00', 27.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-02 00:00:00', 33.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-03 00:00:00', 31.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-04 00:00:00', 27.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-05 00:00:00', 26.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-06 00:00:00', 27.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-07 00:00:00', 26.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-08 00:00:00', 26.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-09 00:00:00', 26.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-10 00:00:00', 29.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-11 00:00:00', 25.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-12 00:00:00', 26.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-13 00:00:00', 23.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-14 00:00:00', 22.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-15 00:00:00', 23.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-16 00:00:00', 23.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-17 00:00:00', 27.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-18 00:00:00', 27.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-19 00:00:00', 24.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-20 00:00:00', 22.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-21 00:00:00', 23.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-22 00:00:00', 22.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-23 00:00:00', 24.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-24 00:00:00', 19.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-25 00:00:00', 18.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-26 00:00:00', 22.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-27 00:00:00', 23.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-28 00:00:00', 13.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-29 00:00:00', 12.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-30 00:00:00', 13.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-10-31 00:00:00', 14.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-01 00:00:00', 13.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-02 00:00:00', 14.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-03 00:00:00', 17.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-04 00:00:00', 21.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-05 00:00:00', 22.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-06 00:00:00', 20.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-07 00:00:00', 21.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-08 00:00:00', 17.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-09 00:00:00', 14.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-10 00:00:00', 13.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-11 00:00:00', 10.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-12 00:00:00', 7.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-13 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-14 00:00:00', 7.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-15 00:00:00', 9.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-16 00:00:00', 11.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-17 00:00:00', 9.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-18 00:00:00', 14.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-19 00:00:00', 11.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-20 00:00:00', 13.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-21 00:00:00', 14.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-22 00:00:00', 15.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-23 00:00:00', 19.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-24 00:00:00', 18.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-25 00:00:00', 19.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-26 00:00:00', 19.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-27 00:00:00', 20.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-28 00:00:00', 21.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-29 00:00:00', 20.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-11-30 00:00:00', 20.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-01 00:00:00', 19.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-02 00:00:00', 19.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-03 00:00:00', 16.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-04 00:00:00', 14.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-05 00:00:00', 12.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-06 00:00:00', 12.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-07 00:00:00', 14.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-08 00:00:00', 7.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-09 00:00:00', 12.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-10 00:00:00', 13.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-11 00:00:00', 13.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-12 00:00:00', 15.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-13 00:00:00', 15.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-14 00:00:00', 11.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-15 00:00:00', 16.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-16 00:00:00', 10.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-17 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-18 00:00:00', 1.40299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-19 00:00:00', 1.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-20 00:00:00', 0.39500001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-21 00:00:00', 1.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-22 00:00:00', 3.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-23 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-24 00:00:00', 10.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-25 00:00:00', 14.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-26 00:00:00', 15.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-27 00:00:00', 9.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-28 00:00:00', 9.00300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-29 00:00:00', 7.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-30 00:00:00', 10.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2008-12-31 00:00:00', 11.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-01 00:00:00', 12.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-02 00:00:00', 9.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-03 00:00:00', 6.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-04 00:00:00', 4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-05 00:00:00', 8.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-06 00:00:00', 8.98700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-07 00:00:00', 9.43799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-08 00:00:00', 12.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-09 00:00:00', 12.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-10 00:00:00', 11.0679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-11 00:00:00', 8.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-12 00:00:00', 11.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-13 00:00:00', 6.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-14 00:00:00', 7.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-15 00:00:00', 8.90699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-16 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-17 00:00:00', 7.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-18 00:00:00', 9.95199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-19 00:00:00', 10.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-20 00:00:00', 14.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-21 00:00:00', 13.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-22 00:00:00', 14.5780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-23 00:00:00', 12.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-24 00:00:00', 12.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-25 00:00:00', 10.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-26 00:00:00', 11.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-27 00:00:00', 10.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-28 00:00:00', 13.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-29 00:00:00', 9.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-30 00:00:00', 10.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-01-31 00:00:00', 14.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-01 00:00:00', 14.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-02 00:00:00', 13.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-03 00:00:00', 8.71599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-04 00:00:00', 7.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-05 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-06 00:00:00', 7.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-07 00:00:00', 13.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-08 00:00:00', 16.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-09 00:00:00', 13.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-10 00:00:00', 10.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-11 00:00:00', 9.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-12 00:00:00', 13.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-13 00:00:00', 11.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-14 00:00:00', 10.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-15 00:00:00', 12.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-16 00:00:00', 15.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-17 00:00:00', 13.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-18 00:00:00', 15.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-19 00:00:00', 13.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-20 00:00:00', 7.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-21 00:00:00', 13.3629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-22 00:00:00', 12.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-23 00:00:00', 9.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-24 00:00:00', 11.4110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-25 00:00:00', 10.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-26 00:00:00', 13.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-27 00:00:00', 14.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-02-28 00:00:00', 16.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-01 00:00:00', 16.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-02 00:00:00', 18.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-03 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-04 00:00:00', 14.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-05 00:00:00', 15.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-06 00:00:00', 13.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-07 00:00:00', 12.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-08 00:00:00', 15.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-09 00:00:00', 17.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-10 00:00:00', 19.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-11 00:00:00', 24.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-12 00:00:00', 23.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-13 00:00:00', 23.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-14 00:00:00', 25.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-15 00:00:00', 26.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-16 00:00:00', 25.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-17 00:00:00', 24.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-18 00:00:00', 17.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-19 00:00:00', 16.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-20 00:00:00', 20.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-21 00:00:00', 22.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-22 00:00:00', 21.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-23 00:00:00', 20.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-24 00:00:00', 20.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-25 00:00:00', 23.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-26 00:00:00', 20.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-27 00:00:00', 18.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-28 00:00:00', 22.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-29 00:00:00', 21.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-30 00:00:00', 23.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-03-31 00:00:00', 23.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-01 00:00:00', 24.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-02 00:00:00', 15.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-03 00:00:00', 18.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-04 00:00:00', 23.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-05 00:00:00', 18.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-06 00:00:00', 16.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-07 00:00:00', 16.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-08 00:00:00', 18.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-09 00:00:00', 22.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-10 00:00:00', 21.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-11 00:00:00', 18.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-12 00:00:00', 23.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-13 00:00:00', 23.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-14 00:00:00', 21.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-15 00:00:00', 12.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-16 00:00:00', 17.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-17 00:00:00', 22.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-18 00:00:00', 26.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-19 00:00:00', 28.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-20 00:00:00', 25.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-21 00:00:00', 19.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-22 00:00:00', 19.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-23 00:00:00', 22.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-24 00:00:00', 26.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-25 00:00:00', 26.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-26 00:00:00', 20.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-27 00:00:00', 17.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-28 00:00:00', 20.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-29 00:00:00', 24.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-04-30 00:00:00', 28.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-01 00:00:00', 30.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-02 00:00:00', 29.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-03 00:00:00', 27.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-04 00:00:00', 26.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-05 00:00:00', 24.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-06 00:00:00', 25.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-07 00:00:00', 29.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-08 00:00:00', 24.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-09 00:00:00', 26.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-10 00:00:00', 25.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-11 00:00:00', 27.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-12 00:00:00', 29.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-13 00:00:00', 29.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-14 00:00:00', 31.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-15 00:00:00', 28.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-16 00:00:00', 29.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-17 00:00:00', 33.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-18 00:00:00', 34.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-19 00:00:00', 29.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-20 00:00:00', 29.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-21 00:00:00', 31.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-22 00:00:00', 30.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-23 00:00:00', 32.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-24 00:00:00', 31.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-25 00:00:00', 30.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-26 00:00:00', 33.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-27 00:00:00', 33.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-28 00:00:00', 34.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-29 00:00:00', 36.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-30 00:00:00', 37.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-05-31 00:00:00', 34.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-01 00:00:00', 29.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-02 00:00:00', 29.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-03 00:00:00', 29.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-04 00:00:00', 29.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-05 00:00:00', 29.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-06 00:00:00', 29.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-07 00:00:00', 29.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-08 00:00:00', 30.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-09 00:00:00', 31.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-10 00:00:00', 34.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-11 00:00:00', 34.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-12 00:00:00', 34.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-13 00:00:00', 32.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-14 00:00:00', 34.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-15 00:00:00', 34.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-16 00:00:00', 34.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-17 00:00:00', 34.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-18 00:00:00', 32.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-19 00:00:00', 35.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-20 00:00:00', 35.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-21 00:00:00', 36.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-22 00:00:00', 37.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-23 00:00:00', 35.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-24 00:00:00', 34.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-25 00:00:00', 36.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-26 00:00:00', 37.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-27 00:00:00', 37.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-28 00:00:00', 38.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-29 00:00:00', 36.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-06-30 00:00:00', 32.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-01 00:00:00', 34.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-02 00:00:00', 34.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-03 00:00:00', 32.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-04 00:00:00', 31.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-05 00:00:00', 34.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-06 00:00:00', 36.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-07 00:00:00', 39.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-08 00:00:00', 38.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-09 00:00:00', 38.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-10 00:00:00', 38.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-11 00:00:00', 38.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-12 00:00:00', 37.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-13 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-14 00:00:00', 35.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-15 00:00:00', 37.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-16 00:00:00', 38.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-17 00:00:00', 37.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-18 00:00:00', 38.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-19 00:00:00', 38.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-20 00:00:00', 38.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-21 00:00:00', 39.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-22 00:00:00', 39.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-23 00:00:00', 38.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-24 00:00:00', 39.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-25 00:00:00', 41.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-26 00:00:00', 42.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-27 00:00:00', 42.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-28 00:00:00', 41.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-29 00:00:00', 40.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-30 00:00:00', 36.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-07-31 00:00:00', 38.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-01 00:00:00', 39.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-02 00:00:00', 39.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-03 00:00:00', 39.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-04 00:00:00', 37.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-05 00:00:00', 36.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-06 00:00:00', 36.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-07 00:00:00', 36.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-08 00:00:00', 37.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-09 00:00:00', 37.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-10 00:00:00', 40.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-11 00:00:00', 40.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-12 00:00:00', 40.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-13 00:00:00', 43.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-14 00:00:00', 42.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-15 00:00:00', 39.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-16 00:00:00', 37.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-17 00:00:00', 36.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-18 00:00:00', 35.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-19 00:00:00', 34.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-20 00:00:00', 33.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-21 00:00:00', 32.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-22 00:00:00', 33.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-23 00:00:00', 34.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-24 00:00:00', 36.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-25 00:00:00', 32.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-26 00:00:00', 32.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-27 00:00:00', 34.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-28 00:00:00', 37.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-29 00:00:00', 37.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-30 00:00:00', 33.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-08-31 00:00:00', 34.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-01 00:00:00', 33.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-02 00:00:00', 30.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-03 00:00:00', 29.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-04 00:00:00', 29.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-05 00:00:00', 28.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-06 00:00:00', 28.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-07 00:00:00', 28.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-08 00:00:00', 28.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-09 00:00:00', 25.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-10 00:00:00', 28.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-11 00:00:00', 30.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-12 00:00:00', 30.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-13 00:00:00', 33.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-14 00:00:00', 34.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-15 00:00:00', 34.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-16 00:00:00', 31.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-17 00:00:00', 30.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-18 00:00:00', 34.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-19 00:00:00', 35.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-20 00:00:00', 35.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-21 00:00:00', 34.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-22 00:00:00', 33.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-23 00:00:00', 32.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-24 00:00:00', 33.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-25 00:00:00', 34.8170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-26 00:00:00', 27.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-27 00:00:00', 28.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-28 00:00:00', 30.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-29 00:00:00', 31.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-09-30 00:00:00', 34.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-01 00:00:00', 34.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-02 00:00:00', 30.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-03 00:00:00', 25.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-04 00:00:00', 26.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-05 00:00:00', 26.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-06 00:00:00', 26.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-07 00:00:00', 25.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-08 00:00:00', 24.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-09 00:00:00', 21.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-10 00:00:00', 21.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-11 00:00:00', 23.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-12 00:00:00', 25.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-13 00:00:00', 24.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-14 00:00:00', 25.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-15 00:00:00', 25.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-16 00:00:00', 25.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-17 00:00:00', 23.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-18 00:00:00', 22.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-19 00:00:00', 23.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-20 00:00:00', 23.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-21 00:00:00', 21.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-22 00:00:00', 21.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-23 00:00:00', 21.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-24 00:00:00', 19.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-25 00:00:00', 22.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-26 00:00:00', 21.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-27 00:00:00', 22.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-28 00:00:00', 16.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-29 00:00:00', 21.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-30 00:00:00', 21.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-10-31 00:00:00', 24.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-01 00:00:00', 25.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-02 00:00:00', 20.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-03 00:00:00', 25.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-04 00:00:00', 25.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-05 00:00:00', 24.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-06 00:00:00', 24.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-07 00:00:00', 17.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-08 00:00:00', 14.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-09 00:00:00', 10.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-10 00:00:00', 10.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-11 00:00:00', 17.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-12 00:00:00', 17.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-13 00:00:00', 18.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-14 00:00:00', 14.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-15 00:00:00', 11.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-16 00:00:00', 12.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-17 00:00:00', 12.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-18 00:00:00', 14.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-19 00:00:00', 17.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-20 00:00:00', 18.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-21 00:00:00', 17.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-22 00:00:00', 19.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-23 00:00:00', 9.92599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-24 00:00:00', 15.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-25 00:00:00', 11.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-26 00:00:00', 11.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-27 00:00:00', 12.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-28 00:00:00', 11.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-29 00:00:00', 12.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-11-30 00:00:00', 14.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-01 00:00:00', 11.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-02 00:00:00', 13.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-03 00:00:00', 12.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-04 00:00:00', 6.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-05 00:00:00', 7.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-06 00:00:00', 9.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-07 00:00:00', 10.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-08 00:00:00', 12.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-09 00:00:00', 8.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-10 00:00:00', 5.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-11 00:00:00', 8.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-12 00:00:00', 6.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-13 00:00:00', 9.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-14 00:00:00', 12.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-15 00:00:00', 12.6059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-16 00:00:00', 9.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-17 00:00:00', 10.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-18 00:00:00', 12.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-19 00:00:00', 16.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-20 00:00:00', 10.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-21 00:00:00', 9.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-22 00:00:00', 12.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-23 00:00:00', 12.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-24 00:00:00', 12.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-25 00:00:00', 13.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-26 00:00:00', 12.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-27 00:00:00', 11.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-28 00:00:00', 10.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-29 00:00:00', 11.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-30 00:00:00', 13.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2009-12-31 00:00:00', 15.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-01 00:00:00', 17.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-02 00:00:00', 16.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-03 00:00:00', 14.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-04 00:00:00', 15.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-05 00:00:00', 15.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-06 00:00:00', 13.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-07 00:00:00', 6.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-08 00:00:00', 7.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-09 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-10 00:00:00', 6.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-11 00:00:00', 8.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-12 00:00:00', 12.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-13 00:00:00', 12.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-14 00:00:00', 14.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-15 00:00:00', 12.7860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-16 00:00:00', 15.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-17 00:00:00', 13.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-18 00:00:00', 10.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-19 00:00:00', 10.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-20 00:00:00', 16.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-21 00:00:00', 15.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-22 00:00:00', 12.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-23 00:00:00', 11.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-24 00:00:00', 12.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-25 00:00:00', 14.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-26 00:00:00', 17.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-27 00:00:00', 11.4329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-28 00:00:00', 8.28899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-29 00:00:00', 7.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-30 00:00:00', 13.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-01-31 00:00:00', 9.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-01 00:00:00', 12.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-02 00:00:00', 12.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-03 00:00:00', 12.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-04 00:00:00', 13.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-05 00:00:00', 9.32900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-06 00:00:00', 11.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-07 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-08 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-09 00:00:00', -0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-10 00:00:00', 6.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-11 00:00:00', 7.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-12 00:00:00', 5.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-13 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-14 00:00:00', -0.185000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-15 00:00:00', 1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-16 00:00:00', 6.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-17 00:00:00', 11.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-18 00:00:00', 9.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-19 00:00:00', 11.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-20 00:00:00', 15.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-21 00:00:00', 20.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-22 00:00:00', 16.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-23 00:00:00', 17.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-24 00:00:00', 12.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-25 00:00:00', 16.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-26 00:00:00', 12.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-27 00:00:00', 11.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-02-28 00:00:00', 9.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-01 00:00:00', 15.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-02 00:00:00', 16.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-03 00:00:00', 19.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-04 00:00:00', 13.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-05 00:00:00', 17.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-06 00:00:00', 15.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-07 00:00:00', 17.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-08 00:00:00', 20.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-09 00:00:00', 19.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-10 00:00:00', 22.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-11 00:00:00', 23.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-12 00:00:00', 15.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-13 00:00:00', 20.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-14 00:00:00', 24.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-15 00:00:00', 26.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-16 00:00:00', 28.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-17 00:00:00', 29.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-18 00:00:00', 26.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-19 00:00:00', 31.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-20 00:00:00', 18.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-21 00:00:00', 14.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-22 00:00:00', 12.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-23 00:00:00', 15.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-24 00:00:00', 18.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-25 00:00:00', 21.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-26 00:00:00', 21.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-27 00:00:00', 19.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-28 00:00:00', 21.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-29 00:00:00', 23.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-30 00:00:00', 17.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-03-31 00:00:00', 21.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-01 00:00:00', 23.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-02 00:00:00', 24.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-03 00:00:00', 17.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-04 00:00:00', 21.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-05 00:00:00', 23.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-06 00:00:00', 24.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-07 00:00:00', 22.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-08 00:00:00', 27.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-09 00:00:00', 28.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-10 00:00:00', 26.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-11 00:00:00', 25.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-12 00:00:00', 21.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-13 00:00:00', 25.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-14 00:00:00', 31.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-15 00:00:00', 25.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-16 00:00:00', 27.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-17 00:00:00', 26.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-18 00:00:00', 27.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-19 00:00:00', 28.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-20 00:00:00', 26.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-21 00:00:00', 20.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-22 00:00:00', 24.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-23 00:00:00', 27.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-24 00:00:00', 29.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-25 00:00:00', 28.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-26 00:00:00', 29.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-27 00:00:00', 27.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-28 00:00:00', 30.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-29 00:00:00', 28.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-04-30 00:00:00', 31.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-01 00:00:00', 27.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-02 00:00:00', 28.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-03 00:00:00', 31.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-04 00:00:00', 28.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-05 00:00:00', 24.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-06 00:00:00', 27.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-07 00:00:00', 27.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-08 00:00:00', 29.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-09 00:00:00', 30.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-10 00:00:00', 28.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-11 00:00:00', 26.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-12 00:00:00', 28.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-13 00:00:00', 28.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-14 00:00:00', 30.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-15 00:00:00', 30.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-16 00:00:00', 23.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-17 00:00:00', 26.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-18 00:00:00', 28.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-19 00:00:00', 31.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-20 00:00:00', 32.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-21 00:00:00', 25.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-22 00:00:00', 31.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-23 00:00:00', 31.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-24 00:00:00', 30.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-25 00:00:00', 34.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-26 00:00:00', 32.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-27 00:00:00', 30.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-28 00:00:00', 30.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-29 00:00:00', 31.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-30 00:00:00', 34.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-05-31 00:00:00', 35.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-01 00:00:00', 35.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-02 00:00:00', 28.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-03 00:00:00', 29.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-04 00:00:00', 27.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-05 00:00:00', 29.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-06 00:00:00', 29.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-07 00:00:00', 32.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-08 00:00:00', 32.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-09 00:00:00', 33.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-10 00:00:00', 35.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-11 00:00:00', 37.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-12 00:00:00', 36.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-13 00:00:00', 37.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-14 00:00:00', 34.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-15 00:00:00', 34.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-16 00:00:00', 36.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-17 00:00:00', 35.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-18 00:00:00', 36.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-19 00:00:00', 37.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-20 00:00:00', 38.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-21 00:00:00', 39.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-22 00:00:00', 38.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-23 00:00:00', 39.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-24 00:00:00', 34.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-25 00:00:00', 32.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-26 00:00:00', 35.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-27 00:00:00', 38.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-28 00:00:00', 36.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-29 00:00:00', 37.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-06-30 00:00:00', 35.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-01 00:00:00', 36.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-02 00:00:00', 36.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-03 00:00:00', 38.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-04 00:00:00', 38.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-05 00:00:00', 37.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-06 00:00:00', 35.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-07 00:00:00', 38.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-08 00:00:00', 39.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-09 00:00:00', 39.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-10 00:00:00', 41.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-11 00:00:00', 38.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-12 00:00:00', 35.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-13 00:00:00', 35.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-14 00:00:00', 37.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-15 00:00:00', 40.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-16 00:00:00', 43.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-17 00:00:00', 42.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-18 00:00:00', 41.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-19 00:00:00', 38.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-20 00:00:00', 37.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-21 00:00:00', 34.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-22 00:00:00', 31.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-23 00:00:00', 35.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-24 00:00:00', 36.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-25 00:00:00', 35.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-26 00:00:00', 36.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-27 00:00:00', 35.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-28 00:00:00', 36.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-29 00:00:00', 35.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-30 00:00:00', 37.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-07-31 00:00:00', 35.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-01 00:00:00', 36.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-02 00:00:00', 36.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-03 00:00:00', 31.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-04 00:00:00', 30.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-05 00:00:00', 36.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-06 00:00:00', 36.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-07 00:00:00', 37.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-08 00:00:00', 39.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-09 00:00:00', 39.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-10 00:00:00', 36.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-11 00:00:00', 37.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-12 00:00:00', 37.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-13 00:00:00', 37.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-14 00:00:00', 36.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-15 00:00:00', 36.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-16 00:00:00', 37.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-17 00:00:00', 37.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-18 00:00:00', 37.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-19 00:00:00', 37.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-20 00:00:00', 38.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-21 00:00:00', 40.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-22 00:00:00', 40.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-23 00:00:00', 36.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-24 00:00:00', 29.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-25 00:00:00', 31.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-26 00:00:00', 32.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-27 00:00:00', 33.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-28 00:00:00', 35.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-29 00:00:00', 35.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-30 00:00:00', 35.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-08-31 00:00:00', 36.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-01 00:00:00', 37.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-02 00:00:00', 37.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-03 00:00:00', 36.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-04 00:00:00', 35.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-05 00:00:00', 35.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-06 00:00:00', 34.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-07 00:00:00', 34.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-08 00:00:00', 34.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-09 00:00:00', 34.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-10 00:00:00', 33.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-11 00:00:00', 34.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-12 00:00:00', 28.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-13 00:00:00', 25.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-14 00:00:00', 29.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-15 00:00:00', 30.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-16 00:00:00', 21.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-17 00:00:00', 20.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-18 00:00:00', 23.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-19 00:00:00', 25.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-20 00:00:00', 27.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-21 00:00:00', 28.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-22 00:00:00', 27.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-23 00:00:00', 27.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-24 00:00:00', 28.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-25 00:00:00', 28.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-26 00:00:00', 28.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-27 00:00:00', 26.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-28 00:00:00', 24.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-29 00:00:00', 27.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-09-30 00:00:00', 26.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-01 00:00:00', 29.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-02 00:00:00', 31.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-03 00:00:00', 31.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-04 00:00:00', 32.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-05 00:00:00', 32.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-06 00:00:00', 32.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-07 00:00:00', 32.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-08 00:00:00', 28.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-09 00:00:00', 25.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-10 00:00:00', 24.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-11 00:00:00', 26.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-12 00:00:00', 29.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-13 00:00:00', 25.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-14 00:00:00', 26.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-15 00:00:00', 28.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-16 00:00:00', 31.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-17 00:00:00', 30.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-18 00:00:00', 30.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-19 00:00:00', 29.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-20 00:00:00', 27.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-21 00:00:00', 23.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-22 00:00:00', 16.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-23 00:00:00', 18.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-24 00:00:00', 20.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-25 00:00:00', 20.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-26 00:00:00', 20.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-27 00:00:00', 21.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-28 00:00:00', 19.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-29 00:00:00', 20.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-30 00:00:00', 20.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-10-31 00:00:00', 23.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-01 00:00:00', 24.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-02 00:00:00', 21.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-03 00:00:00', 13.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-04 00:00:00', 16.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-05 00:00:00', 10.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-06 00:00:00', 15.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-07 00:00:00', 20.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-08 00:00:00', 23.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-09 00:00:00', 23.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-10 00:00:00', 24.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-11 00:00:00', 20.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-12 00:00:00', 18.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-13 00:00:00', 18.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-14 00:00:00', 18.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-15 00:00:00', 18.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-16 00:00:00', 16.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-17 00:00:00', 16.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-18 00:00:00', 16.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-19 00:00:00', 16.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-20 00:00:00', 15.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-21 00:00:00', 14.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-22 00:00:00', 15.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-23 00:00:00', 17.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-24 00:00:00', 18.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-25 00:00:00', 15.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-26 00:00:00', 15.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-27 00:00:00', 16.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-28 00:00:00', 18.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-29 00:00:00', 18.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-11-30 00:00:00', 15.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-01 00:00:00', 15.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-02 00:00:00', 16.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-03 00:00:00', 18.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-04 00:00:00', 9.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-05 00:00:00', 8.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-06 00:00:00', 6.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-07 00:00:00', 10.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-08 00:00:00', 11.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-09 00:00:00', 13.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-10 00:00:00', 14.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-11 00:00:00', 15.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-12 00:00:00', 18.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-13 00:00:00', 18.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-14 00:00:00', 20.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-15 00:00:00', 12.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-16 00:00:00', 10.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-17 00:00:00', 12.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-18 00:00:00', 13.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-19 00:00:00', 15.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-20 00:00:00', 16.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-21 00:00:00', 12.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-22 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-23 00:00:00', 6.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-24 00:00:00', 10.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-25 00:00:00', 9.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-26 00:00:00', 7.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-27 00:00:00', 8.00800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-28 00:00:00', 8.47299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-29 00:00:00', 9.17099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-30 00:00:00', 7.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2010-12-31 00:00:00', 9.08100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-01 00:00:00', 15.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-02 00:00:00', 15.3559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-03 00:00:00', 11.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-04 00:00:00', 8.62899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-05 00:00:00', 11.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-06 00:00:00', 12.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-07 00:00:00', 9.21100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-08 00:00:00', 7.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-09 00:00:00', 10.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-10 00:00:00', 11.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-11 00:00:00', 5.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-12 00:00:00', 8.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-13 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-14 00:00:00', -0.925999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-15 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-16 00:00:00', 5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-17 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-18 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-19 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-20 00:00:00', 10.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-21 00:00:00', 7.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-22 00:00:00', 8.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-23 00:00:00', 7.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-24 00:00:00', 10.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-25 00:00:00', 10.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-26 00:00:00', 11.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-27 00:00:00', 14.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-28 00:00:00', 13.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-29 00:00:00', 13.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-30 00:00:00', 11.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-01-31 00:00:00', 13.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-01 00:00:00', 14.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-02 00:00:00', 17.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-03 00:00:00', 14.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-04 00:00:00', 10.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-05 00:00:00', 9.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-06 00:00:00', 7.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-07 00:00:00', 7.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-08 00:00:00', 6.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-09 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-10 00:00:00', 10.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-11 00:00:00', 13.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-12 00:00:00', 8.77900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-13 00:00:00', 7.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-14 00:00:00', 11.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-15 00:00:00', 12.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-16 00:00:00', 12.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-17 00:00:00', 12.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-18 00:00:00', 10.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-19 00:00:00', 5.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-20 00:00:00', 8.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-21 00:00:00', 13.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-22 00:00:00', 13.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-23 00:00:00', 9.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-24 00:00:00', 4.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-25 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-26 00:00:00', 0.331999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-27 00:00:00', 6.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-02-28 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-01 00:00:00', 7.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-02 00:00:00', 7.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-03 00:00:00', 8.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-04 00:00:00', 3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-05 00:00:00', 8.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-06 00:00:00', 12.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-07 00:00:00', 10.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-08 00:00:00', 15.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-09 00:00:00', 18.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-10 00:00:00', 20.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-11 00:00:00', 22.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-12 00:00:00', 22.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-13 00:00:00', 24.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-14 00:00:00', 26.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-15 00:00:00', 14.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-16 00:00:00', 15.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-17 00:00:00', 10.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-18 00:00:00', 17.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-19 00:00:00', 14.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-20 00:00:00', 16.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-21 00:00:00', 19.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-22 00:00:00', 21.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-23 00:00:00', 24.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-24 00:00:00', 25.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-25 00:00:00', 21.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-26 00:00:00', 21.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-27 00:00:00', 16.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-28 00:00:00', 17.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-29 00:00:00', 19.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-30 00:00:00', 18.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-03-31 00:00:00', 19.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-01 00:00:00', 20.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-02 00:00:00', 20.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-03 00:00:00', 16.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-04 00:00:00', 14.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-05 00:00:00', 18.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-06 00:00:00', 21.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-07 00:00:00', 25.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-08 00:00:00', 21.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-09 00:00:00', 20.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-10 00:00:00', 23.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-11 00:00:00', 25.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-12 00:00:00', 28.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-13 00:00:00', 29.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-14 00:00:00', 27.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-15 00:00:00', 21.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-16 00:00:00', 24.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-17 00:00:00', 26.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-18 00:00:00', 26.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-19 00:00:00', 26.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-20 00:00:00', 27.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-21 00:00:00', 30.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-22 00:00:00', 33.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-23 00:00:00', 34.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-24 00:00:00', 35.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-25 00:00:00', 34.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-26 00:00:00', 34.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-27 00:00:00', 34.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-28 00:00:00', 30.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-29 00:00:00', 27.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-04-30 00:00:00', 30.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-01 00:00:00', 33.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-02 00:00:00', 36.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-03 00:00:00', 36.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-04 00:00:00', 36.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-05 00:00:00', 29.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-06 00:00:00', 24.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-07 00:00:00', 29.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-08 00:00:00', 27.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-09 00:00:00', 30.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-10 00:00:00', 28.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-11 00:00:00', 26.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-12 00:00:00', 29.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-13 00:00:00', 31.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-14 00:00:00', 35.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-15 00:00:00', 38.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-16 00:00:00', 41.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-17 00:00:00', 38.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-18 00:00:00', 34.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-19 00:00:00', 32.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-20 00:00:00', 30.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-21 00:00:00', 31.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-22 00:00:00', 32.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-23 00:00:00', 35.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-24 00:00:00', 36.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-25 00:00:00', 33.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-26 00:00:00', 35.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-27 00:00:00', 34.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-28 00:00:00', 34.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-29 00:00:00', 34.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-30 00:00:00', 34.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-05-31 00:00:00', 33.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-01 00:00:00', 29.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-02 00:00:00', 32.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-03 00:00:00', 33.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-04 00:00:00', 33.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-05 00:00:00', 34.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-06 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-07 00:00:00', 38.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-08 00:00:00', 40.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-09 00:00:00', 38.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-10 00:00:00', 39.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-11 00:00:00', 37.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-12 00:00:00', 35.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-13 00:00:00', 35.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-14 00:00:00', 38.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-15 00:00:00', 40.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-16 00:00:00', 40.0719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-17 00:00:00', 35.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-18 00:00:00', 36.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-19 00:00:00', 36.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-20 00:00:00', 37.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-21 00:00:00', 39.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-22 00:00:00', 40.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-23 00:00:00', 37.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-24 00:00:00', 39.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-25 00:00:00', 37.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-26 00:00:00', 35.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-27 00:00:00', 37.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-28 00:00:00', 37.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-29 00:00:00', 37.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-06-30 00:00:00', 36.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-01 00:00:00', 36.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-02 00:00:00', 35.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-03 00:00:00', 36.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-04 00:00:00', 39.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-05 00:00:00', 39.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-06 00:00:00', 38.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-07 00:00:00', 38.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-08 00:00:00', 38.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-09 00:00:00', 38.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-10 00:00:00', 37.5530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-11 00:00:00', 39.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-12 00:00:00', 40.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-13 00:00:00', 43.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-14 00:00:00', 38.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-15 00:00:00', 35.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-16 00:00:00', 35.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-17 00:00:00', 36.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-18 00:00:00', 38.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-19 00:00:00', 35.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-20 00:00:00', 35.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-21 00:00:00', 37.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-22 00:00:00', 37.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-23 00:00:00', 37.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-24 00:00:00', 39.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-25 00:00:00', 37.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-26 00:00:00', 37.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-27 00:00:00', 36.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-28 00:00:00', 37.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-29 00:00:00', 38.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-30 00:00:00', 38.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-07-31 00:00:00', 38.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-01 00:00:00', 38.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-02 00:00:00', 40.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-03 00:00:00', 42.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-04 00:00:00', 42.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-05 00:00:00', 41.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-06 00:00:00', 42.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-07 00:00:00', 43.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-08 00:00:00', 41.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-09 00:00:00', 35.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-10 00:00:00', 35.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-11 00:00:00', 36.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-12 00:00:00', 37.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-13 00:00:00', 37.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-14 00:00:00', 38.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-15 00:00:00', 38.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-16 00:00:00', 38.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-17 00:00:00', 38.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-18 00:00:00', 37.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-19 00:00:00', 37.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-20 00:00:00', 39.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-21 00:00:00', 40.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-22 00:00:00', 39.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-23 00:00:00', 40.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-24 00:00:00', 40.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-25 00:00:00', 38.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-26 00:00:00', 35.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-27 00:00:00', 33.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-28 00:00:00', 31.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-29 00:00:00', 29.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-30 00:00:00', 29.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-08-31 00:00:00', 32.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-01 00:00:00', 33.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-02 00:00:00', 34.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-03 00:00:00', 34.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-04 00:00:00', 35.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-05 00:00:00', 36.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-06 00:00:00', 35.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-07 00:00:00', 34.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-08 00:00:00', 33.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-09 00:00:00', 34.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-10 00:00:00', 33.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-11 00:00:00', 34.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-12 00:00:00', 35.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-13 00:00:00', 36.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-14 00:00:00', 33.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-15 00:00:00', 32.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-16 00:00:00', 27.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-17 00:00:00', 31.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-18 00:00:00', 28.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-19 00:00:00', 28.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-20 00:00:00', 29.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-21 00:00:00', 28.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-22 00:00:00', 29.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-23 00:00:00', 25.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-24 00:00:00', 30.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-25 00:00:00', 29.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-26 00:00:00', 30.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-27 00:00:00', 30.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-28 00:00:00', 28.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-29 00:00:00', 26.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-09-30 00:00:00', 27.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-01 00:00:00', 30.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-02 00:00:00', 32.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-03 00:00:00', 32.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-04 00:00:00', 31.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-05 00:00:00', 23.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-06 00:00:00', 24.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-07 00:00:00', 23.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-08 00:00:00', 25.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-09 00:00:00', 25.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-10 00:00:00', 26.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-11 00:00:00', 25.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-12 00:00:00', 23.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-13 00:00:00', 24.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-14 00:00:00', 25.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-15 00:00:00', 28.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-16 00:00:00', 28.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-17 00:00:00', 27.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-18 00:00:00', 26.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-19 00:00:00', 25.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-20 00:00:00', 27.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-21 00:00:00', 26.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-22 00:00:00', 23.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-23 00:00:00', 15.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-24 00:00:00', 19.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-25 00:00:00', 20.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-26 00:00:00', 23.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-27 00:00:00', 24.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-28 00:00:00', 15.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-29 00:00:00', 13.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-30 00:00:00', 14.1549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-10-31 00:00:00', 16.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-01 00:00:00', 12.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-02 00:00:00', 15.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-03 00:00:00', 15.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-04 00:00:00', 14.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-05 00:00:00', 18.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-06 00:00:00', 18.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-07 00:00:00', 22.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-08 00:00:00', 10.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-09 00:00:00', 2.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-10 00:00:00', 12.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-11 00:00:00', 17.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-12 00:00:00', 17.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-13 00:00:00', 18.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-14 00:00:00', 12.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-15 00:00:00', 11.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-16 00:00:00', 16.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-17 00:00:00', 14.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-18 00:00:00', 14.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-19 00:00:00', 14.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-20 00:00:00', 16.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-21 00:00:00', 21.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-22 00:00:00', 14.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-23 00:00:00', 17.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-24 00:00:00', 12.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-25 00:00:00', 14.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-26 00:00:00', 8.91199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-27 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-28 00:00:00', 8.84799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-29 00:00:00', 12.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-11-30 00:00:00', 16.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-01 00:00:00', 7.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-02 00:00:00', 10.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-03 00:00:00', 10.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-04 00:00:00', 8.62800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-05 00:00:00', 5.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-06 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-07 00:00:00', 6.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-08 00:00:00', 9.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-09 00:00:00', 10.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-10 00:00:00', 11.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-11 00:00:00', 13.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-12 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-13 00:00:00', 9.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-14 00:00:00', 10.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-15 00:00:00', 7.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-16 00:00:00', 9.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-17 00:00:00', 12.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-18 00:00:00', 10.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-19 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-20 00:00:00', -3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-21 00:00:00', -2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-22 00:00:00', -0.428000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-23 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-24 00:00:00', 8.47000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-25 00:00:00', 12.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-26 00:00:00', 12.508000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-27 00:00:00', 4.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-28 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-29 00:00:00', 6.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-30 00:00:00', 6.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2011-12-31 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-01 00:00:00', 9.81000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-02 00:00:00', 9.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-03 00:00:00', 9.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-04 00:00:00', 6.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-05 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-06 00:00:00', -0.546999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-07 00:00:00', 0.583000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-08 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-09 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-10 00:00:00', 4.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-11 00:00:00', 9.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-12 00:00:00', 9.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-13 00:00:00', 6.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-14 00:00:00', 8.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-15 00:00:00', 6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-16 00:00:00', 5.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-17 00:00:00', 8.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-18 00:00:00', 7.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-19 00:00:00', 5.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-20 00:00:00', 4.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-21 00:00:00', 8.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-22 00:00:00', 1.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-23 00:00:00', 3.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-24 00:00:00', 9.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-25 00:00:00', 7.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-26 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-27 00:00:00', 9.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-28 00:00:00', 9.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-29 00:00:00', 11.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-30 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-01-31 00:00:00', 5.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-01 00:00:00', 9.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-02 00:00:00', 11.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-03 00:00:00', 7.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-04 00:00:00', 0.639999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-05 00:00:00', -3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-06 00:00:00', -1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-07 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-08 00:00:00', 4.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-09 00:00:00', 6.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-10 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-11 00:00:00', 9.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-12 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-13 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-14 00:00:00', -0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-15 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-16 00:00:00', 2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-17 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-18 00:00:00', 6.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-19 00:00:00', 8.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-20 00:00:00', 8.22799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-21 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-22 00:00:00', 1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-23 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-24 00:00:00', 5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-25 00:00:00', 9.17599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-26 00:00:00', 11.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-27 00:00:00', 10.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-28 00:00:00', 11.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-02-29 00:00:00', 13.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-01 00:00:00', 14.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-02 00:00:00', 16.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-03 00:00:00', 16.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-04 00:00:00', 11.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-05 00:00:00', 9.89299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-06 00:00:00', 7.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-07 00:00:00', 8.30799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-08 00:00:00', 11.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-09 00:00:00', 10.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-10 00:00:00', 9.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-11 00:00:00', 6.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-12 00:00:00', 5.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-13 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-14 00:00:00', 12.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-15 00:00:00', 15.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-16 00:00:00', 14.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-17 00:00:00', 16.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-18 00:00:00', 15.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-19 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-20 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-21 00:00:00', 10.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-22 00:00:00', 13.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-23 00:00:00', 18.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-24 00:00:00', 18.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-25 00:00:00', 18.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-26 00:00:00', 18.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-27 00:00:00', 20.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-28 00:00:00', 24.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-29 00:00:00', 20.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-30 00:00:00', 25.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-03-31 00:00:00', 25.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-01 00:00:00', 21.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-02 00:00:00', 25.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-03 00:00:00', 27.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-04 00:00:00', 28.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-05 00:00:00', 26.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-06 00:00:00', 25.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-07 00:00:00', 26.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-08 00:00:00', 27.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-09 00:00:00', 24.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-10 00:00:00', 27.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-11 00:00:00', 25.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-12 00:00:00', 24.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-13 00:00:00', 25.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-14 00:00:00', 27.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-15 00:00:00', 27.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-16 00:00:00', 28.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-17 00:00:00', 28.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-18 00:00:00', 30.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-19 00:00:00', 31.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-20 00:00:00', 30.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-21 00:00:00', 22.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-22 00:00:00', 22.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-23 00:00:00', 24.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-24 00:00:00', 26.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-25 00:00:00', 24.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-26 00:00:00', 25.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-27 00:00:00', 24.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-28 00:00:00', 25.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-29 00:00:00', 23.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-04-30 00:00:00', 24.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-01 00:00:00', 23.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-02 00:00:00', 23.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-03 00:00:00', 26.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-04 00:00:00', 27.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-05 00:00:00', 28.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-06 00:00:00', 28.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-07 00:00:00', 26.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-08 00:00:00', 26.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-09 00:00:00', 32.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-10 00:00:00', 28.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-11 00:00:00', 28.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-12 00:00:00', 25.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-13 00:00:00', 27.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-14 00:00:00', 29.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-15 00:00:00', 30.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-16 00:00:00', 29.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-17 00:00:00', 28.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-18 00:00:00', 26.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-19 00:00:00', 29.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-20 00:00:00', 28.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-21 00:00:00', 29.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-22 00:00:00', 29.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-23 00:00:00', 30.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-24 00:00:00', 33.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-25 00:00:00', 27.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-26 00:00:00', 29.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-27 00:00:00', 31.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-28 00:00:00', 34.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-29 00:00:00', 35.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-30 00:00:00', 35.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-05-31 00:00:00', 33.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-01 00:00:00', 33.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-02 00:00:00', 34.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-03 00:00:00', 36.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-04 00:00:00', 35.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-05 00:00:00', 32.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-06 00:00:00', 33.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-07 00:00:00', 33.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-08 00:00:00', 35.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-09 00:00:00', 35.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-10 00:00:00', 34.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-11 00:00:00', 35.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-12 00:00:00', 35.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-13 00:00:00', 33.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-14 00:00:00', 34.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-15 00:00:00', 36.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-16 00:00:00', 36.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-17 00:00:00', 37.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-18 00:00:00', 37.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-19 00:00:00', 37.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-20 00:00:00', 36.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-21 00:00:00', 36.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-22 00:00:00', 34.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-23 00:00:00', 34.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-24 00:00:00', 34.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-25 00:00:00', 34.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-26 00:00:00', 34.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-27 00:00:00', 34.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-28 00:00:00', 36.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-29 00:00:00', 37.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-06-30 00:00:00', 38.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-01 00:00:00', 38.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-02 00:00:00', 40.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-03 00:00:00', 39.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-04 00:00:00', 39.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-05 00:00:00', 39.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-06 00:00:00', 39.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-07 00:00:00', 38.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-08 00:00:00', 39.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-09 00:00:00', 39.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-10 00:00:00', 40.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-11 00:00:00', 42.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-12 00:00:00', 39.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-13 00:00:00', 37.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-14 00:00:00', 36.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-15 00:00:00', 36.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-16 00:00:00', 36.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-17 00:00:00', 38.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-18 00:00:00', 39.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-19 00:00:00', 38.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-20 00:00:00', 38.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-21 00:00:00', 38.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-22 00:00:00', 38.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-23 00:00:00', 38.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-24 00:00:00', 37.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-25 00:00:00', 37.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-26 00:00:00', 37.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-27 00:00:00', 33.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-28 00:00:00', 33.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-29 00:00:00', 35.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-30 00:00:00', 37.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-07-31 00:00:00', 38.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-01 00:00:00', 38.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-02 00:00:00', 36.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-03 00:00:00', 34.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-04 00:00:00', 35.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-05 00:00:00', 36.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-06 00:00:00', 37.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-07 00:00:00', 38.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-08 00:00:00', 37.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-09 00:00:00', 37.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-10 00:00:00', 37.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-11 00:00:00', 37.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-12 00:00:00', 37.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-13 00:00:00', 37.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-14 00:00:00', 37.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-15 00:00:00', 37.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-16 00:00:00', 38.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-17 00:00:00', 38.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-18 00:00:00', 40.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-19 00:00:00', 40.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-20 00:00:00', 39.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-21 00:00:00', 40.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-22 00:00:00', 39.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-23 00:00:00', 38.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-24 00:00:00', 37.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-25 00:00:00', 34.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-26 00:00:00', 34.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-27 00:00:00', 33.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-28 00:00:00', 35.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-29 00:00:00', 37.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-30 00:00:00', 37.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-08-31 00:00:00', 37.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-01 00:00:00', 36.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-02 00:00:00', 36.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-03 00:00:00', 35.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-04 00:00:00', 32.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-05 00:00:00', 30.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-06 00:00:00', 32.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-07 00:00:00', 30.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-08 00:00:00', 32.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-09 00:00:00', 33.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-10 00:00:00', 35.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-11 00:00:00', 35.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-12 00:00:00', 34.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-13 00:00:00', 32.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-14 00:00:00', 29.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-15 00:00:00', 29.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-16 00:00:00', 29.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-17 00:00:00', 28.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-18 00:00:00', 29.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-19 00:00:00', 29.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-20 00:00:00', 29.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-21 00:00:00', 28.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-22 00:00:00', 28.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-23 00:00:00', 29.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-24 00:00:00', 29.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-25 00:00:00', 29.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-26 00:00:00', 28.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-27 00:00:00', 31.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-28 00:00:00', 29.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-29 00:00:00', 28.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-09-30 00:00:00', 24.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-01 00:00:00', 27.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-02 00:00:00', 25.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-03 00:00:00', 25.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-04 00:00:00', 24.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-05 00:00:00', 25.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-06 00:00:00', 26.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-07 00:00:00', 28.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-08 00:00:00', 27.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-09 00:00:00', 27.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-10 00:00:00', 27.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-11 00:00:00', 28.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-12 00:00:00', 27.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-13 00:00:00', 28.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-14 00:00:00', 22.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-15 00:00:00', 21.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-16 00:00:00', 22.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-17 00:00:00', 21.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-18 00:00:00', 21.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-19 00:00:00', 19.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-20 00:00:00', 17.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-21 00:00:00', 18.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-22 00:00:00', 21.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-23 00:00:00', 20.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-24 00:00:00', 22.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-25 00:00:00', 22.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-26 00:00:00', 23.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-27 00:00:00', 24.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-28 00:00:00', 25.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-29 00:00:00', 26.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-30 00:00:00', 28.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-10-31 00:00:00', 23.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-01 00:00:00', 21.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-02 00:00:00', 20.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-03 00:00:00', 22.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-04 00:00:00', 18.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-05 00:00:00', 17.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-06 00:00:00', 20.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-07 00:00:00', 21.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-08 00:00:00', 22.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-09 00:00:00', 22.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-10 00:00:00', 22.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-11 00:00:00', 23.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-12 00:00:00', 18.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-13 00:00:00', 15.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-14 00:00:00', 19.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-15 00:00:00', 22.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-16 00:00:00', 15.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-17 00:00:00', 14.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-18 00:00:00', 14.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-19 00:00:00', 13.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-20 00:00:00', 12.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-21 00:00:00', 12.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-22 00:00:00', 12.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-23 00:00:00', 10.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-24 00:00:00', 10.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-25 00:00:00', 14.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-26 00:00:00', 12.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-27 00:00:00', 15.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-28 00:00:00', 11.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-29 00:00:00', 8.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-11-30 00:00:00', 12.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-01 00:00:00', 15.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-02 00:00:00', 15.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-03 00:00:00', 16.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-04 00:00:00', 18.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-05 00:00:00', 20.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-06 00:00:00', 19.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-07 00:00:00', 18.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-08 00:00:00', 14.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-09 00:00:00', 17.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-10 00:00:00', 13.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-11 00:00:00', 12.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-12 00:00:00', 12.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-13 00:00:00', 6.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-14 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-15 00:00:00', 6.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-16 00:00:00', 5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-17 00:00:00', 8.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-18 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-19 00:00:00', 5.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-20 00:00:00', 10.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-21 00:00:00', 15.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-22 00:00:00', 18.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-23 00:00:00', 12.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-24 00:00:00', 11.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-25 00:00:00', 13.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-26 00:00:00', 8.25100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-27 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-28 00:00:00', -5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-29 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-30 00:00:00', 3.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2012-12-31 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-01 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-02 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-03 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-04 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-05 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-06 00:00:00', 5.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-07 00:00:00', 7.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-08 00:00:00', 8.63599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-09 00:00:00', 8.31200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-10 00:00:00', 10.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-11 00:00:00', 13.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-12 00:00:00', 6.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-13 00:00:00', 6.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-14 00:00:00', 9.84300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-15 00:00:00', 7.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-16 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-17 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-18 00:00:00', 7.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-19 00:00:00', 8.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-20 00:00:00', 9.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-21 00:00:00', 11.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-22 00:00:00', 8.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-23 00:00:00', 9.23700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-24 00:00:00', 13.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-25 00:00:00', 14.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-26 00:00:00', 14.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-27 00:00:00', 13.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-28 00:00:00', 14.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-29 00:00:00', 14.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-30 00:00:00', 16.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-01-31 00:00:00', 13.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-01 00:00:00', 15.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-02 00:00:00', 11.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-03 00:00:00', 13.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-04 00:00:00', 8.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-05 00:00:00', 7.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-06 00:00:00', 10.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-07 00:00:00', 14.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-08 00:00:00', 16.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-09 00:00:00', 11.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-10 00:00:00', 12.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-11 00:00:00', 12.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-12 00:00:00', 13.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-13 00:00:00', 13.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-14 00:00:00', 15.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-15 00:00:00', 11.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-16 00:00:00', 12.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-17 00:00:00', 16.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-18 00:00:00', 11.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-19 00:00:00', 11.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-20 00:00:00', 15.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-21 00:00:00', 11.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-22 00:00:00', 14.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-23 00:00:00', 12.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-24 00:00:00', 15.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-25 00:00:00', 16.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-26 00:00:00', 8.52999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-27 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-02-28 00:00:00', 9.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-01 00:00:00', 17.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-02 00:00:00', 21.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-03 00:00:00', 19.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-04 00:00:00', 18.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-05 00:00:00', 23.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-06 00:00:00', 26.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-07 00:00:00', 16.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-08 00:00:00', 8.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-09 00:00:00', 7.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-10 00:00:00', 13.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-11 00:00:00', 17.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-12 00:00:00', 18.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-13 00:00:00', 16.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-14 00:00:00', 20.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-15 00:00:00', 20.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-16 00:00:00', 16.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-17 00:00:00', 15.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-18 00:00:00', 19.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-19 00:00:00', 24.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-20 00:00:00', 21.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-21 00:00:00', 17.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-22 00:00:00', 19.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-23 00:00:00', 14.6129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-24 00:00:00', 18.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-25 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-26 00:00:00', 15.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-27 00:00:00', 21.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-28 00:00:00', 24.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-29 00:00:00', 24.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-30 00:00:00', 25.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-03-31 00:00:00', 17.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-01 00:00:00', 15.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-02 00:00:00', 18.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-03 00:00:00', 20.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-04 00:00:00', 22.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-05 00:00:00', 18.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-06 00:00:00', 20.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-07 00:00:00', 23.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-08 00:00:00', 26.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-09 00:00:00', 27.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-10 00:00:00', 28.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-11 00:00:00', 30.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-12 00:00:00', 30.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-13 00:00:00', 28.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-14 00:00:00', 27.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-15 00:00:00', 20.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-16 00:00:00', 19.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-17 00:00:00', 21.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-18 00:00:00', 25.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-19 00:00:00', 25.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-20 00:00:00', 25.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-21 00:00:00', 26.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-22 00:00:00', 30.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-23 00:00:00', 27.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-24 00:00:00', 23.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-25 00:00:00', 22.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-26 00:00:00', 17.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-27 00:00:00', 23.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-28 00:00:00', 20.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-29 00:00:00', 16.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-04-30 00:00:00', 18.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-01 00:00:00', 22.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-02 00:00:00', 25.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-03 00:00:00', 25.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-04 00:00:00', 26.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-05 00:00:00', 28.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-06 00:00:00', 30.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-07 00:00:00', 30.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-08 00:00:00', 31.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-09 00:00:00', 31.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-10 00:00:00', 30.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-11 00:00:00', 29.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-12 00:00:00', 28.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-13 00:00:00', 27.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-14 00:00:00', 30.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-15 00:00:00', 32.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-16 00:00:00', 34.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-17 00:00:00', 35.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-18 00:00:00', 37.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-19 00:00:00', 29.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-20 00:00:00', 32.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-21 00:00:00', 30.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-22 00:00:00', 31.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-23 00:00:00', 34.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-24 00:00:00', 32.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-25 00:00:00', 30.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-26 00:00:00', 29.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-27 00:00:00', 27.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-28 00:00:00', 30.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-29 00:00:00', 33.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-30 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-05-31 00:00:00', 38.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-01 00:00:00', 39.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-02 00:00:00', 35.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-03 00:00:00', 34.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-04 00:00:00', 34.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-05 00:00:00', 37.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-06 00:00:00', 37.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-07 00:00:00', 36.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-08 00:00:00', 39.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-09 00:00:00', 39.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-10 00:00:00', 38.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-11 00:00:00', 38.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-12 00:00:00', 38.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-13 00:00:00', 38.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-14 00:00:00', 35.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-15 00:00:00', 32.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-16 00:00:00', 34.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-17 00:00:00', 32.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-18 00:00:00', 35.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-19 00:00:00', 38.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-20 00:00:00', 39.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-21 00:00:00', 41.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-22 00:00:00', 42.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-23 00:00:00', 40.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-24 00:00:00', 40.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-25 00:00:00', 41.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-26 00:00:00', 41.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-27 00:00:00', 38.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-28 00:00:00', 34.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-29 00:00:00', 34.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-06-30 00:00:00', 36.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-01 00:00:00', 34.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-02 00:00:00', 36.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-03 00:00:00', 38.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-04 00:00:00', 40.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-05 00:00:00', 38.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-06 00:00:00', 35.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-07 00:00:00', 35.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-08 00:00:00', 34.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-09 00:00:00', 33.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-10 00:00:00', 36.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-11 00:00:00', 34.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-12 00:00:00', 36.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-13 00:00:00', 39.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-14 00:00:00', 38.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-15 00:00:00', 37.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-16 00:00:00', 38.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-17 00:00:00', 37.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-18 00:00:00', 39.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-19 00:00:00', 40.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-20 00:00:00', 41.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-21 00:00:00', 41.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-22 00:00:00', 35.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-23 00:00:00', 37.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-24 00:00:00', 38.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-25 00:00:00', 37.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-26 00:00:00', 39.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-27 00:00:00', 42.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-28 00:00:00', 43.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-29 00:00:00', 44.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-30 00:00:00', 42.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-07-31 00:00:00', 42.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-01 00:00:00', 40.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-02 00:00:00', 40.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-03 00:00:00', 40.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-04 00:00:00', 40.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-05 00:00:00', 38.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-06 00:00:00', 41.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-07 00:00:00', 38.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-08 00:00:00', 34.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-09 00:00:00', 35.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-10 00:00:00', 37.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-11 00:00:00', 35.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-12 00:00:00', 35.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-13 00:00:00', 34.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-14 00:00:00', 34.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-15 00:00:00', 35.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-16 00:00:00', 34.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-17 00:00:00', 35.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-18 00:00:00', 36.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-19 00:00:00', 36.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-20 00:00:00', 37.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-21 00:00:00', 36.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-22 00:00:00', 37.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-23 00:00:00', 37.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-24 00:00:00', 36.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-25 00:00:00', 35.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-26 00:00:00', 37.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-27 00:00:00', 36.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-28 00:00:00', 37.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-29 00:00:00', 37.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-30 00:00:00', 32.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-08-31 00:00:00', 33.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-01 00:00:00', 33.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-02 00:00:00', 34.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-03 00:00:00', 34.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-04 00:00:00', 34.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-05 00:00:00', 35.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-06 00:00:00', 38.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-07 00:00:00', 36.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-08 00:00:00', 36.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-09 00:00:00', 37.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-10 00:00:00', 37.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-11 00:00:00', 36.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-12 00:00:00', 33.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-13 00:00:00', 33.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-14 00:00:00', 32.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-15 00:00:00', 30.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-16 00:00:00', 27.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-17 00:00:00', 30.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-18 00:00:00', 31.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-19 00:00:00', 34.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-20 00:00:00', 36.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-21 00:00:00', 37.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-22 00:00:00', 35.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-23 00:00:00', 34.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-24 00:00:00', 34.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-25 00:00:00', 36.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-26 00:00:00', 38.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-27 00:00:00', 31.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-28 00:00:00', 32.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-29 00:00:00', 32.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-09-30 00:00:00', 31.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-01 00:00:00', 32.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-02 00:00:00', 32.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-03 00:00:00', 33.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-04 00:00:00', 35.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-05 00:00:00', 35.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-06 00:00:00', 35.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-07 00:00:00', 33.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-08 00:00:00', 30.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-09 00:00:00', 26.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-10 00:00:00', 23.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-11 00:00:00', 23.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-12 00:00:00', 25.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-13 00:00:00', 25.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-14 00:00:00', 26.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-15 00:00:00', 24.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-16 00:00:00', 23.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-17 00:00:00', 23.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-18 00:00:00', 26.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-19 00:00:00', 27.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-20 00:00:00', 28.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-21 00:00:00', 29.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-22 00:00:00', 21.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-23 00:00:00', 17.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-24 00:00:00', 23.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-25 00:00:00', 20.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-26 00:00:00', 13.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-27 00:00:00', 15.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-28 00:00:00', 20.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-29 00:00:00', 22.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-30 00:00:00', 14.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-10-31 00:00:00', 15.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-01 00:00:00', 14.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-02 00:00:00', 17.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-03 00:00:00', 20.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-04 00:00:00', 18.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-05 00:00:00', 18.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-06 00:00:00', 16.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-07 00:00:00', 16.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-08 00:00:00', 18.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-09 00:00:00', 19.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-10 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-11 00:00:00', 17.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-12 00:00:00', 15.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-13 00:00:00', 16.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-14 00:00:00', 19.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-15 00:00:00', 22.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-16 00:00:00', 16.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-17 00:00:00', 19.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-18 00:00:00', 20.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-19 00:00:00', 18.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-20 00:00:00', 13.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-21 00:00:00', 12.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-22 00:00:00', 16.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-23 00:00:00', 15.1190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-24 00:00:00', 14.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-25 00:00:00', 17.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-26 00:00:00', 17.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-27 00:00:00', 17.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-28 00:00:00', 17.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-29 00:00:00', 18.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-11-30 00:00:00', 20.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-01 00:00:00', 20.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-02 00:00:00', 10.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-03 00:00:00', 15.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-04 00:00:00', 17.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-05 00:00:00', 12.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-06 00:00:00', 13.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-07 00:00:00', 13.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-08 00:00:00', 14.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-09 00:00:00', 14.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-10 00:00:00', 15.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-11 00:00:00', 10.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-12 00:00:00', 14.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-13 00:00:00', 16.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-14 00:00:00', 19.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-15 00:00:00', 19.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-16 00:00:00', 9.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-17 00:00:00', 7.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-18 00:00:00', 4.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-19 00:00:00', 5.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-20 00:00:00', 10.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-21 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-22 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-23 00:00:00', 6.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-24 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-25 00:00:00', 6.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-26 00:00:00', 7.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-27 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-28 00:00:00', -0.638000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-29 00:00:00', -0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-30 00:00:00', -0.998000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2013-12-31 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-01 00:00:00', 4.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-02 00:00:00', 8.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-03 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-04 00:00:00', 6.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-05 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-06 00:00:00', 6.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-07 00:00:00', 7.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-08 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-09 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-10 00:00:00', 4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-11 00:00:00', 7.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-12 00:00:00', 11.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-13 00:00:00', 8.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-14 00:00:00', 10.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-15 00:00:00', 9.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-16 00:00:00', 10.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-17 00:00:00', 10.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-18 00:00:00', 13.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-19 00:00:00', 14.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-20 00:00:00', 15.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-21 00:00:00', 10.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-22 00:00:00', 8.64500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-23 00:00:00', 7.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-24 00:00:00', 9.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-25 00:00:00', 8.46399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-26 00:00:00', 11.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-27 00:00:00', 13.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-28 00:00:00', 16.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-29 00:00:00', 16.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-30 00:00:00', 12.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-01-31 00:00:00', 8.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-01 00:00:00', 5.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-02 00:00:00', -5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-03 00:00:00', -6.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-04 00:00:00', -3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-05 00:00:00', -2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-06 00:00:00', -1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-07 00:00:00', -1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-08 00:00:00', 0.919000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-09 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-10 00:00:00', 1.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-11 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-12 00:00:00', 3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-13 00:00:00', 3.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-14 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-15 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-16 00:00:00', 7.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-17 00:00:00', 11.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-18 00:00:00', 11.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-19 00:00:00', 8.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-20 00:00:00', 10.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-21 00:00:00', 11.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-22 00:00:00', 13.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-23 00:00:00', 7.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-24 00:00:00', 7.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-25 00:00:00', 11.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-26 00:00:00', 9.34599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-27 00:00:00', 11.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-02-28 00:00:00', 13.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-01 00:00:00', 15.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-02 00:00:00', 17.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-03 00:00:00', 13.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-04 00:00:00', 14.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-05 00:00:00', 16.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-06 00:00:00', 12.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-07 00:00:00', 10.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-08 00:00:00', 15.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-09 00:00:00', 9.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-10 00:00:00', 10.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-11 00:00:00', 11.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-12 00:00:00', 17.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-13 00:00:00', 17.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-14 00:00:00', 13.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-15 00:00:00', 10.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-16 00:00:00', 18.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-17 00:00:00', 13.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-18 00:00:00', 17.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-19 00:00:00', 19.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-20 00:00:00', 18.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-21 00:00:00', 17.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-22 00:00:00', 20.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-23 00:00:00', 12.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-24 00:00:00', 8.64000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-25 00:00:00', 12.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-26 00:00:00', 16.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-27 00:00:00', 15.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-28 00:00:00', 17.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-29 00:00:00', 20.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-30 00:00:00', 23.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-03-31 00:00:00', 25.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-01 00:00:00', 25.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-02 00:00:00', 20.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-03 00:00:00', 21.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-04 00:00:00', 15.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-05 00:00:00', 15.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-06 00:00:00', 18.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-07 00:00:00', 18.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-08 00:00:00', 19.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-09 00:00:00', 22.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-10 00:00:00', 23.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-11 00:00:00', 19.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-12 00:00:00', 20.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-13 00:00:00', 18.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-14 00:00:00', 22.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-15 00:00:00', 25.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-16 00:00:00', 23.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-17 00:00:00', 23.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-18 00:00:00', 22.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-19 00:00:00', 24.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-20 00:00:00', 25.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-21 00:00:00', 26.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-22 00:00:00', 28.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-23 00:00:00', 28.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-24 00:00:00', 23.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-25 00:00:00', 24.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-26 00:00:00', 23.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-27 00:00:00', 28.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-28 00:00:00', 29.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-29 00:00:00', 25.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-04-30 00:00:00', 29.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-01 00:00:00', 30.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-02 00:00:00', 32.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-03 00:00:00', 32.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-04 00:00:00', 31.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-05 00:00:00', 31.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-06 00:00:00', 29.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-07 00:00:00', 31.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-08 00:00:00', 28.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-09 00:00:00', 27.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-10 00:00:00', 30.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-11 00:00:00', 30.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-12 00:00:00', 28.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-13 00:00:00', 26.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-14 00:00:00', 29.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-15 00:00:00', 32.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-16 00:00:00', 33.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-17 00:00:00', 33.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-18 00:00:00', 25.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-19 00:00:00', 30.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-20 00:00:00', 31.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-21 00:00:00', 31.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-22 00:00:00', 28.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-23 00:00:00', 30.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-24 00:00:00', 31.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-25 00:00:00', 33.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-26 00:00:00', 32.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-27 00:00:00', 35.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-28 00:00:00', 35.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-29 00:00:00', 33.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-30 00:00:00', 26.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-05-31 00:00:00', 29.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-01 00:00:00', 31.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-02 00:00:00', 32.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-03 00:00:00', 31.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-04 00:00:00', 32.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-05 00:00:00', 35.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-06 00:00:00', 34.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-07 00:00:00', 34.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-08 00:00:00', 32.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-09 00:00:00', 34.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-10 00:00:00', 34.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-11 00:00:00', 35.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-12 00:00:00', 36.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-13 00:00:00', 39.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-14 00:00:00', 38.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-15 00:00:00', 35.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-16 00:00:00', 35.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-17 00:00:00', 34.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-18 00:00:00', 34.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-19 00:00:00', 36.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-20 00:00:00', 36.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-21 00:00:00', 37.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-22 00:00:00', 38.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-23 00:00:00', 38.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-24 00:00:00', 37.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-25 00:00:00', 38.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-26 00:00:00', 38.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-27 00:00:00', 40.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-28 00:00:00', 42.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-29 00:00:00', 40.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-06-30 00:00:00', 40.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-01 00:00:00', 39.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-02 00:00:00', 37.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-03 00:00:00', 34.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-04 00:00:00', 34.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-05 00:00:00', 35.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-06 00:00:00', 35.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-07 00:00:00', 38.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-08 00:00:00', 38.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-09 00:00:00', 39.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-10 00:00:00', 39.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-11 00:00:00', 40.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-12 00:00:00', 41.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-13 00:00:00', 38.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-14 00:00:00', 37.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-15 00:00:00', 38.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-16 00:00:00', 36.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-17 00:00:00', 35.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-18 00:00:00', 34.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-19 00:00:00', 35.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-20 00:00:00', 37.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-21 00:00:00', 40.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-22 00:00:00', 42.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-23 00:00:00', 43.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-24 00:00:00', 38.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-25 00:00:00', 38.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-26 00:00:00', 38.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-27 00:00:00', 40.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-28 00:00:00', 43.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-29 00:00:00', 39.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-30 00:00:00', 36.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (37, '2014-07-31 00:00:00', 34.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-01 00:00:00', 8.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-02 00:00:00', 9.09599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-03 00:00:00', 13.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-04 00:00:00', 13.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-05 00:00:00', 16.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-06 00:00:00', 14.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-07 00:00:00', 12.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-08 00:00:00', 10.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-09 00:00:00', 5.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-10 00:00:00', 7.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-11 00:00:00', 10.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-12 00:00:00', 13.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-13 00:00:00', 3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-14 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-15 00:00:00', 5.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-16 00:00:00', 5.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-17 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-18 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-19 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-20 00:00:00', 1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-21 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-22 00:00:00', 8.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-23 00:00:00', 6.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-24 00:00:00', 10.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-25 00:00:00', 7.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-26 00:00:00', -0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-27 00:00:00', -2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-28 00:00:00', -1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-29 00:00:00', -4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-30 00:00:00', -0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-01-31 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-01 00:00:00', 7.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-02 00:00:00', 8.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-03 00:00:00', 10.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-04 00:00:00', 10.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-05 00:00:00', 10.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-06 00:00:00', 6.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-07 00:00:00', 12.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-08 00:00:00', 11.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-09 00:00:00', 14.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-10 00:00:00', 10.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-11 00:00:00', 10.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-12 00:00:00', 8.59099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-13 00:00:00', 10.2489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-14 00:00:00', 9.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-15 00:00:00', 14.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-16 00:00:00', 14.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-17 00:00:00', 11.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-18 00:00:00', 8.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-19 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-20 00:00:00', -1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-21 00:00:00', 4.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-22 00:00:00', 3.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-23 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-24 00:00:00', 7.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-25 00:00:00', 7.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-26 00:00:00', 8.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-27 00:00:00', 6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-02-28 00:00:00', 5.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-01 00:00:00', 5.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-02 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-03 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-04 00:00:00', 2.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-05 00:00:00', 0.879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-06 00:00:00', -0.587999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-07 00:00:00', -0.204999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-08 00:00:00', 0.574000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-09 00:00:00', 7.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-10 00:00:00', 8.90499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-11 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-12 00:00:00', 12.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-13 00:00:00', 11.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-14 00:00:00', 12.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-15 00:00:00', 14.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-16 00:00:00', 12.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-17 00:00:00', 15.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-18 00:00:00', 16.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-19 00:00:00', 17.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-20 00:00:00', 19.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-21 00:00:00', 19.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-22 00:00:00', 19.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-23 00:00:00', 19.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-24 00:00:00', 21.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-25 00:00:00', 18.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-26 00:00:00', 18.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-27 00:00:00', 20.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-28 00:00:00', 19.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-29 00:00:00', 16.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-30 00:00:00', 11.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-03-31 00:00:00', 13.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-01 00:00:00', 18.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-02 00:00:00', 13.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-03 00:00:00', 16.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-04 00:00:00', 14.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-05 00:00:00', 18.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-06 00:00:00', 20.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-07 00:00:00', 20.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-08 00:00:00', 21.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-09 00:00:00', 23.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-10 00:00:00', 27.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-11 00:00:00', 25.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-12 00:00:00', 22.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-13 00:00:00', 25.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-14 00:00:00', 19.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-15 00:00:00', 21.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-16 00:00:00', 17.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-17 00:00:00', 21.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-18 00:00:00', 13.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-19 00:00:00', 12.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-20 00:00:00', 16.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-21 00:00:00', 17.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-22 00:00:00', 17.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-23 00:00:00', 21.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-24 00:00:00', 26.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-25 00:00:00', 21.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-26 00:00:00', 21.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-27 00:00:00', 18.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-28 00:00:00', 14.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-29 00:00:00', 20.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-04-30 00:00:00', 12.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-01 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-02 00:00:00', 17.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-03 00:00:00', 21.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-04 00:00:00', 22.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-05 00:00:00', 22.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-06 00:00:00', 24.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-07 00:00:00', 19.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-08 00:00:00', 19.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-09 00:00:00', 9.21300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-10 00:00:00', 11.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-11 00:00:00', 12.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-12 00:00:00', 8.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-13 00:00:00', 9.01500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-14 00:00:00', 14.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-15 00:00:00', 15.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-16 00:00:00', 16.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-17 00:00:00', 20.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-18 00:00:00', 17.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-19 00:00:00', 17.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-20 00:00:00', 21.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-21 00:00:00', 20.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-22 00:00:00', 25.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-23 00:00:00', 25.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-24 00:00:00', 23.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-25 00:00:00', 16.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-26 00:00:00', 21.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-27 00:00:00', 20.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-28 00:00:00', 19.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-29 00:00:00', 23.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-30 00:00:00', 25.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-05-31 00:00:00', 27.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-01 00:00:00', 28.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-02 00:00:00', 27.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-03 00:00:00', 30.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-04 00:00:00', 30.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-05 00:00:00', 29.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-06 00:00:00', 31.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-07 00:00:00', 33.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-08 00:00:00', 33.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-09 00:00:00', 32.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-10 00:00:00', 36.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-11 00:00:00', 29.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-12 00:00:00', 30.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-13 00:00:00', 30.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-14 00:00:00', 32.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-15 00:00:00', 33.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-16 00:00:00', 34.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-17 00:00:00', 35.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-18 00:00:00', 33.9490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-19 00:00:00', 33.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-20 00:00:00', 34.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-21 00:00:00', 35.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-22 00:00:00', 36.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-23 00:00:00', 38.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-24 00:00:00', 39.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-25 00:00:00', 39.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-26 00:00:00', 39.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-27 00:00:00', 36.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-28 00:00:00', 34.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-29 00:00:00', 34.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-06-30 00:00:00', 35.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-01 00:00:00', 35.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-02 00:00:00', 34.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-03 00:00:00', 35.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-04 00:00:00', 35.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-05 00:00:00', 36.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-06 00:00:00', 38.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-07 00:00:00', 39.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-08 00:00:00', 40.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-09 00:00:00', 42.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-10 00:00:00', 43.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-11 00:00:00', 40.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-12 00:00:00', 38.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-13 00:00:00', 37.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-14 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-15 00:00:00', 39.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-16 00:00:00', 40.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-17 00:00:00', 41.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-18 00:00:00', 41.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-19 00:00:00', 41.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-20 00:00:00', 40.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-21 00:00:00', 35.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-22 00:00:00', 37.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-23 00:00:00', 34.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-24 00:00:00', 36.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-25 00:00:00', 37.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-26 00:00:00', 38.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-27 00:00:00', 37.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-28 00:00:00', 38.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-29 00:00:00', 39.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-30 00:00:00', 40.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-07-31 00:00:00', 43.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-01 00:00:00', 42.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-02 00:00:00', 41.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-03 00:00:00', 38.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-04 00:00:00', 37.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-05 00:00:00', 34.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-06 00:00:00', 35.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-07 00:00:00', 28.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-08 00:00:00', 35.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-09 00:00:00', 34.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-10 00:00:00', 36.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-11 00:00:00', 37.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-12 00:00:00', 38.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-13 00:00:00', 37.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-14 00:00:00', 37.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-15 00:00:00', 37.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-16 00:00:00', 37.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-17 00:00:00', 38.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-18 00:00:00', 40.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-19 00:00:00', 39.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-20 00:00:00', 32.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-21 00:00:00', 31.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-22 00:00:00', 29.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-23 00:00:00', 31.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-24 00:00:00', 32.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-25 00:00:00', 33.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-26 00:00:00', 33.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-27 00:00:00', 32.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-28 00:00:00', 28.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-29 00:00:00', 31.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-30 00:00:00', 31.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-08-31 00:00:00', 32.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-01 00:00:00', 33.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-02 00:00:00', 31.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-03 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-04 00:00:00', 33.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-05 00:00:00', 34.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-06 00:00:00', 35.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-07 00:00:00', 35.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-08 00:00:00', 37.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-09 00:00:00', 35.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-10 00:00:00', 34.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-11 00:00:00', 35.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-12 00:00:00', 35.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-13 00:00:00', 33.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-14 00:00:00', 33.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-15 00:00:00', 31.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-16 00:00:00', 30.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-17 00:00:00', 29.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-18 00:00:00', 30.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-19 00:00:00', 30.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-20 00:00:00', 31.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-21 00:00:00', 30.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-22 00:00:00', 28.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-23 00:00:00', 26.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-24 00:00:00', 25.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-25 00:00:00', 26.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-26 00:00:00', 27.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-27 00:00:00', 27.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-28 00:00:00', 27.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-29 00:00:00', 27.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-09-30 00:00:00', 28.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-01 00:00:00', 27.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-02 00:00:00', 28.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-03 00:00:00', 28.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-04 00:00:00', 29.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-05 00:00:00', 30.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-06 00:00:00', 30.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-07 00:00:00', 31.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-08 00:00:00', 28.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-09 00:00:00', 25.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-10 00:00:00', 22.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-11 00:00:00', 23.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-12 00:00:00', 23.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-13 00:00:00', 24.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-14 00:00:00', 26.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-15 00:00:00', 26.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-16 00:00:00', 26.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-17 00:00:00', 26.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-18 00:00:00', 26.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-19 00:00:00', 26.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-20 00:00:00', 20.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-21 00:00:00', 25.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-22 00:00:00', 26.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-23 00:00:00', 28.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-24 00:00:00', 29.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-25 00:00:00', 30.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-26 00:00:00', 29.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-27 00:00:00', 29.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-28 00:00:00', 24.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-29 00:00:00', 26.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-30 00:00:00', 20.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-10-31 00:00:00', 21.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-01 00:00:00', 20.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-02 00:00:00', 25.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-03 00:00:00', 25.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-04 00:00:00', 26.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-05 00:00:00', 18.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-06 00:00:00', 8.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-07 00:00:00', 7.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-08 00:00:00', 8.36900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-09 00:00:00', 15.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-10 00:00:00', 16.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-11 00:00:00', 11.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-12 00:00:00', 11.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-13 00:00:00', 5.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-14 00:00:00', 8.63799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-15 00:00:00', 12.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-16 00:00:00', 14.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-17 00:00:00', 14.9189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-18 00:00:00', 13.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-19 00:00:00', 11.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-20 00:00:00', 8.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-21 00:00:00', 8.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-22 00:00:00', 9.17599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-23 00:00:00', 11.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-24 00:00:00', 12.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-25 00:00:00', 13.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-26 00:00:00', 15.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-27 00:00:00', 17.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-28 00:00:00', 17.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-29 00:00:00', 19.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-11-30 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-01 00:00:00', 20.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-02 00:00:00', 15.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-03 00:00:00', 9.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-04 00:00:00', 9.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-05 00:00:00', 9.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-06 00:00:00', 13.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-07 00:00:00', 15.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-08 00:00:00', 14.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-09 00:00:00', 13.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-10 00:00:00', 10.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-11 00:00:00', 10.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-12 00:00:00', 11.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-13 00:00:00', 11.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-14 00:00:00', 9.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-15 00:00:00', 9.64700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-16 00:00:00', 15.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-17 00:00:00', 8.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-18 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-19 00:00:00', 7.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-20 00:00:00', 9.10700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-21 00:00:00', 10.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-22 00:00:00', 5.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-23 00:00:00', -0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-24 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-25 00:00:00', 6.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-26 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-27 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-28 00:00:00', 8.41100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-29 00:00:00', 6.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-30 00:00:00', 5.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1979-12-31 00:00:00', 5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-01 00:00:00', 5.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-02 00:00:00', 5.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-03 00:00:00', 7.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-04 00:00:00', 8.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-05 00:00:00', 7.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-06 00:00:00', 11.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-07 00:00:00', 13.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-08 00:00:00', 8.63099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-09 00:00:00', 6.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-10 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-11 00:00:00', 6.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-12 00:00:00', 7.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-13 00:00:00', 7.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-14 00:00:00', 10.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-15 00:00:00', 4.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-16 00:00:00', -0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-17 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-18 00:00:00', 6.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-19 00:00:00', 6.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-20 00:00:00', 5.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-21 00:00:00', 5.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-22 00:00:00', 5.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-23 00:00:00', 3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-24 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-25 00:00:00', 0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-26 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-27 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-28 00:00:00', -0.240999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-29 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-30 00:00:00', 5.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-01-31 00:00:00', 2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-01 00:00:00', -2.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-02 00:00:00', -5.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-03 00:00:00', -6.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-04 00:00:00', -7.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-05 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-06 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-07 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-08 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-09 00:00:00', 5.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-10 00:00:00', 5.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-11 00:00:00', 7.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-12 00:00:00', 11.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-13 00:00:00', 8.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-14 00:00:00', 6.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-15 00:00:00', 11.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-16 00:00:00', 12.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-17 00:00:00', 9.79599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-18 00:00:00', 9.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-19 00:00:00', 8.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-20 00:00:00', 5.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-21 00:00:00', 5.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-22 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-23 00:00:00', 5.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-24 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-25 00:00:00', 4.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-26 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-27 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-28 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-02-29 00:00:00', 4.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-01 00:00:00', 7.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-02 00:00:00', 7.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-03 00:00:00', 8.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-04 00:00:00', 8.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-05 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-06 00:00:00', 5.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-07 00:00:00', 9.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-08 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-09 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-10 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-11 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-12 00:00:00', 9.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-13 00:00:00', 12.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-14 00:00:00', 8.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-15 00:00:00', 7.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-16 00:00:00', 10.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-17 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-18 00:00:00', 11.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-19 00:00:00', 15.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-20 00:00:00', 11.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-21 00:00:00', 10.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-22 00:00:00', 13.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-23 00:00:00', 15.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-24 00:00:00', 14.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-25 00:00:00', 15.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-26 00:00:00', 17.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-27 00:00:00', 12.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-28 00:00:00', 7.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-29 00:00:00', 9.02999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-30 00:00:00', 20.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-03-31 00:00:00', 13.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-01 00:00:00', 10.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-02 00:00:00', 12.175999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-03 00:00:00', 14.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-04 00:00:00', 17.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-05 00:00:00', 14.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-06 00:00:00', 17.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-07 00:00:00', 20.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-08 00:00:00', 23.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-09 00:00:00', 24.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-10 00:00:00', 25.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-11 00:00:00', 24.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-12 00:00:00', 23.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-13 00:00:00', 23.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-14 00:00:00', 25.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-15 00:00:00', 24.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-16 00:00:00', 26.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-17 00:00:00', 28.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-18 00:00:00', 13.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-19 00:00:00', 19.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-20 00:00:00', 18.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-21 00:00:00', 17.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-22 00:00:00', 18.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-23 00:00:00', 23.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-24 00:00:00', 26.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-25 00:00:00', 22.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-26 00:00:00', 26.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-27 00:00:00', 25.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-28 00:00:00', 21.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-29 00:00:00', 26.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-04-30 00:00:00', 28.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-01 00:00:00', 30.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-02 00:00:00', 29.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-03 00:00:00', 28.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-04 00:00:00', 30.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-05 00:00:00', 30.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-06 00:00:00', 32.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-07 00:00:00', 31.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-08 00:00:00', 21.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-09 00:00:00', 26.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-10 00:00:00', 27.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-11 00:00:00', 21.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-12 00:00:00', 21.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-13 00:00:00', 25.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-14 00:00:00', 27.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-15 00:00:00', 27.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-16 00:00:00', 27.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-17 00:00:00', 24.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-18 00:00:00', 27.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-19 00:00:00', 29.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-20 00:00:00', 29.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-21 00:00:00', 29.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-22 00:00:00', 30.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-23 00:00:00', 31.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-24 00:00:00', 32.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-25 00:00:00', 35.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-26 00:00:00', 34.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-27 00:00:00', 33.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-28 00:00:00', 33.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-29 00:00:00', 34.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-30 00:00:00', 34.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-05-31 00:00:00', 34.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-01 00:00:00', 29.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-02 00:00:00', 30.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-03 00:00:00', 31.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-04 00:00:00', 33.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-05 00:00:00', 34.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-06 00:00:00', 35.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-07 00:00:00', 36.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-08 00:00:00', 37.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-09 00:00:00', 39.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-10 00:00:00', 41.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-11 00:00:00', 39.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-12 00:00:00', 32.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-13 00:00:00', 30.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-14 00:00:00', 32.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-15 00:00:00', 33.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-16 00:00:00', 35.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-17 00:00:00', 37.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-18 00:00:00', 40.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-19 00:00:00', 38.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-20 00:00:00', 37.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-21 00:00:00', 37.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-22 00:00:00', 39.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-23 00:00:00', 39.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-24 00:00:00', 35.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-25 00:00:00', 34.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-26 00:00:00', 34.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-27 00:00:00', 34.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-28 00:00:00', 35.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-29 00:00:00', 36.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-06-30 00:00:00', 36.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-01 00:00:00', 37.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-02 00:00:00', 40.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-03 00:00:00', 40.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-04 00:00:00', 39.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-05 00:00:00', 39.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-06 00:00:00', 39.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-07 00:00:00', 39.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-08 00:00:00', 40.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-09 00:00:00', 41.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-10 00:00:00', 42.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-11 00:00:00', 40.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-12 00:00:00', 37.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-13 00:00:00', 38.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-14 00:00:00', 38.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-15 00:00:00', 40.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-16 00:00:00', 40.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-17 00:00:00', 41.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-18 00:00:00', 39.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-19 00:00:00', 34.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-20 00:00:00', 35.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-21 00:00:00', 37.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-22 00:00:00', 37.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-23 00:00:00', 37.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-24 00:00:00', 39.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-25 00:00:00', 39.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-26 00:00:00', 39.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-27 00:00:00', 39.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-28 00:00:00', 39.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-29 00:00:00', 38.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-30 00:00:00', 38.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-07-31 00:00:00', 38.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-01 00:00:00', 40.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-02 00:00:00', 40.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-03 00:00:00', 36.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-04 00:00:00', 36.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-05 00:00:00', 39.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-06 00:00:00', 39.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-07 00:00:00', 37.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-08 00:00:00', 34.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-09 00:00:00', 35.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-10 00:00:00', 34.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-11 00:00:00', 35.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-12 00:00:00', 35.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-13 00:00:00', 35.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-14 00:00:00', 35.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-15 00:00:00', 35.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-16 00:00:00', 35.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-17 00:00:00', 35.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-18 00:00:00', 36.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-19 00:00:00', 37.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-20 00:00:00', 39.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-21 00:00:00', 40.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-22 00:00:00', 39.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-23 00:00:00', 35.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-24 00:00:00', 35.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-25 00:00:00', 35.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-26 00:00:00', 35.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-27 00:00:00', 36.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-28 00:00:00', 36.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-29 00:00:00', 36.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-30 00:00:00', 35.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-08-31 00:00:00', 29.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-01 00:00:00', 31.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-02 00:00:00', 31.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-03 00:00:00', 33.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-04 00:00:00', 32.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-05 00:00:00', 32.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-06 00:00:00', 33.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-07 00:00:00', 34.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-08 00:00:00', 35.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-09 00:00:00', 33.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-10 00:00:00', 28.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-11 00:00:00', 29.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-12 00:00:00', 28.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-13 00:00:00', 29.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-14 00:00:00', 30.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-15 00:00:00', 29.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-16 00:00:00', 32.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-17 00:00:00', 33.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-18 00:00:00', 32.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-19 00:00:00', 33.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-20 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-21 00:00:00', 33.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-22 00:00:00', 36.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-23 00:00:00', 33.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-24 00:00:00', 31.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-25 00:00:00', 29.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-26 00:00:00', 29.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-27 00:00:00', 27.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-28 00:00:00', 27.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-29 00:00:00', 29.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-09-30 00:00:00', 30.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-01 00:00:00', 30.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-02 00:00:00', 30.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-03 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-04 00:00:00', 31.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-05 00:00:00', 31.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-06 00:00:00', 30.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-07 00:00:00', 25.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-08 00:00:00', 24.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-09 00:00:00', 25.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-10 00:00:00', 19.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-11 00:00:00', 16.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-12 00:00:00', 21.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-13 00:00:00', 24.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-14 00:00:00', 25.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-15 00:00:00', 16.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-16 00:00:00', 15.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-17 00:00:00', 18.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-18 00:00:00', 18.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-19 00:00:00', 18.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-20 00:00:00', 24.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-21 00:00:00', 23.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-22 00:00:00', 12.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-23 00:00:00', 12.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-24 00:00:00', 17.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-25 00:00:00', 20.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-26 00:00:00', 22.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-27 00:00:00', 23.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-28 00:00:00', 18.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-29 00:00:00', 20.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-30 00:00:00', 20.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-10-31 00:00:00', 20.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-01 00:00:00', 20.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-02 00:00:00', 18.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-03 00:00:00', 15.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-04 00:00:00', 11.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-05 00:00:00', 14.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-06 00:00:00', 14.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-07 00:00:00', 20.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-08 00:00:00', 18.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-09 00:00:00', 23.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-10 00:00:00', 24.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-11 00:00:00', 22.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-12 00:00:00', 23.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-13 00:00:00', 23.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-14 00:00:00', 22.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-15 00:00:00', 20.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-16 00:00:00', 18.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-17 00:00:00', 23.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-18 00:00:00', 20.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-19 00:00:00', 13.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-20 00:00:00', 16.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-21 00:00:00', 18.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-22 00:00:00', 19.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-23 00:00:00', 20.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-24 00:00:00', 14.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-25 00:00:00', 8.82900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-26 00:00:00', 9.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-27 00:00:00', 11.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-28 00:00:00', 14.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-29 00:00:00', 16.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-11-30 00:00:00', 18.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-01 00:00:00', 15.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-02 00:00:00', 14.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-03 00:00:00', 12.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-04 00:00:00', 14.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-05 00:00:00', 6.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-06 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-07 00:00:00', 17.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-08 00:00:00', 10.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-09 00:00:00', 13.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-10 00:00:00', 15.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-11 00:00:00', 11.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-12 00:00:00', 11.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-13 00:00:00', 10.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-14 00:00:00', 6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-15 00:00:00', 6.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-16 00:00:00', 7.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-17 00:00:00', 8.27999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-18 00:00:00', 7.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-19 00:00:00', 9.65499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-20 00:00:00', 5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-21 00:00:00', 4.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-22 00:00:00', 10.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-23 00:00:00', 13.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-24 00:00:00', 11.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-25 00:00:00', 11.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-26 00:00:00', 7.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-27 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-28 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-29 00:00:00', 8.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-30 00:00:00', 7.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1980-12-31 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-01 00:00:00', 2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-02 00:00:00', 4.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-03 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-04 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-05 00:00:00', 3.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-06 00:00:00', 6.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-07 00:00:00', 8.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-08 00:00:00', 9.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-09 00:00:00', 6.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-10 00:00:00', 7.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-11 00:00:00', 9.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-12 00:00:00', 12.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-13 00:00:00', 9.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-14 00:00:00', 5.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-15 00:00:00', 2.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-16 00:00:00', 1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-17 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-18 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-19 00:00:00', 6.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-20 00:00:00', 6.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-21 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-22 00:00:00', 8.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-23 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-24 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-25 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-26 00:00:00', 6.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-27 00:00:00', 8.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-28 00:00:00', 5.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-29 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-30 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-01-31 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-01 00:00:00', 7.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-02 00:00:00', 5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-03 00:00:00', 7.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-04 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-05 00:00:00', 6.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-06 00:00:00', 10.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-07 00:00:00', 11.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-08 00:00:00', 11.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-09 00:00:00', 13.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-10 00:00:00', 12.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-11 00:00:00', 8.06499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-12 00:00:00', 7.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-13 00:00:00', 5.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-14 00:00:00', 7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-15 00:00:00', 9.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-16 00:00:00', 9.82699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-17 00:00:00', 9.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-18 00:00:00', 10.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-19 00:00:00', 9.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-20 00:00:00', 10.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-21 00:00:00', 13.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-22 00:00:00', 13.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-23 00:00:00', 8.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-24 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-25 00:00:00', 9.42099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-26 00:00:00', 5.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-27 00:00:00', 8.98499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-02-28 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-01 00:00:00', 5.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-02 00:00:00', 11.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-03 00:00:00', 14.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-04 00:00:00', 13.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-05 00:00:00', 9.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-06 00:00:00', 10.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-07 00:00:00', 12.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-08 00:00:00', 13.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-09 00:00:00', 8.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-10 00:00:00', 11.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-11 00:00:00', 13.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-12 00:00:00', 15.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-13 00:00:00', 15.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-14 00:00:00', 16.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-15 00:00:00', 13.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-16 00:00:00', 11.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-17 00:00:00', 9.87899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-18 00:00:00', 7.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-19 00:00:00', 13.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-20 00:00:00', 8.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-21 00:00:00', 6.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-22 00:00:00', 10.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-23 00:00:00', 11.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-24 00:00:00', 10.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-25 00:00:00', 12.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-26 00:00:00', 15.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-27 00:00:00', 8.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-28 00:00:00', 15.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-29 00:00:00', 9.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-30 00:00:00', 9.66399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-03-31 00:00:00', 11.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-01 00:00:00', 13.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-02 00:00:00', 8.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-03 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-04 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-05 00:00:00', 8.47999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-06 00:00:00', 9.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-07 00:00:00', 9.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-08 00:00:00', 10.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-09 00:00:00', 13.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-10 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-11 00:00:00', 11.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-12 00:00:00', 5.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-13 00:00:00', 4.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-14 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-15 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-16 00:00:00', 20.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-17 00:00:00', 24.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-18 00:00:00', 27.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-19 00:00:00', 17.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-20 00:00:00', 13.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-21 00:00:00', 16.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-22 00:00:00', 20.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-23 00:00:00', 22.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-24 00:00:00', 26.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-25 00:00:00', 27.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-26 00:00:00', 28.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-27 00:00:00', 29.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-28 00:00:00', 25.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-29 00:00:00', 28.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-04-30 00:00:00', 23.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-01 00:00:00', 28.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-02 00:00:00', 29.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-03 00:00:00', 30.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-04 00:00:00', 21.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-05 00:00:00', 23.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-06 00:00:00', 26.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-07 00:00:00', 27.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-08 00:00:00', 21.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-09 00:00:00', 26.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-10 00:00:00', 24.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-11 00:00:00', 26.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-12 00:00:00', 29.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-13 00:00:00', 28.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-14 00:00:00', 25.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-15 00:00:00', 28.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-16 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-17 00:00:00', 33.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-18 00:00:00', 29.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-19 00:00:00', 18.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-20 00:00:00', 24.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-21 00:00:00', 27.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-22 00:00:00', 28.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-23 00:00:00', 29.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-24 00:00:00', 34.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-25 00:00:00', 32.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-26 00:00:00', 32.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-27 00:00:00', 32.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-28 00:00:00', 33.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-29 00:00:00', 34.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-30 00:00:00', 25.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-05-31 00:00:00', 23.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-01 00:00:00', 25.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-02 00:00:00', 25.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-03 00:00:00', 28.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-04 00:00:00', 29.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-05 00:00:00', 33.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-06 00:00:00', 34.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-07 00:00:00', 28.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-08 00:00:00', 27.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-09 00:00:00', 29.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-10 00:00:00', 29.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-11 00:00:00', 29.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-12 00:00:00', 30.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-13 00:00:00', 32.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-14 00:00:00', 30.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-15 00:00:00', 33.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-16 00:00:00', 36.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-17 00:00:00', 38.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-18 00:00:00', 36.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-19 00:00:00', 37.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-20 00:00:00', 37.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-21 00:00:00', 36.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-22 00:00:00', 37.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-23 00:00:00', 36.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-24 00:00:00', 37.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-25 00:00:00', 38.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-26 00:00:00', 36.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-27 00:00:00', 37.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-28 00:00:00', 38.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-29 00:00:00', 38.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-06-30 00:00:00', 36.0719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-01 00:00:00', 34.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-02 00:00:00', 35.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-03 00:00:00', 36.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-04 00:00:00', 37.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-05 00:00:00', 36.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-06 00:00:00', 38.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-07 00:00:00', 40.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-08 00:00:00', 34.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-09 00:00:00', 36.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-10 00:00:00', 37.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-11 00:00:00', 39.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-12 00:00:00', 40.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-13 00:00:00', 43.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-14 00:00:00', 43.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-15 00:00:00', 42.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-16 00:00:00', 36.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-17 00:00:00', 36.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-18 00:00:00', 36.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-19 00:00:00', 36.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-20 00:00:00', 38.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-21 00:00:00', 39.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-22 00:00:00', 36.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-23 00:00:00', 29.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-24 00:00:00', 29.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-25 00:00:00', 33.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-26 00:00:00', 35.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-27 00:00:00', 36.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-28 00:00:00', 36.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-29 00:00:00', 35.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-30 00:00:00', 33.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-07-31 00:00:00', 34.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-01 00:00:00', 33.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-02 00:00:00', 33.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-03 00:00:00', 33.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-04 00:00:00', 35.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-05 00:00:00', 34.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-06 00:00:00', 36.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-07 00:00:00', 37.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-08 00:00:00', 38.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-09 00:00:00', 37.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-10 00:00:00', 38.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-11 00:00:00', 37.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-12 00:00:00', 35.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-13 00:00:00', 35.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-14 00:00:00', 35.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-15 00:00:00', 36.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-16 00:00:00', 36.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-17 00:00:00', 38.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-18 00:00:00', 37.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-19 00:00:00', 33.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-20 00:00:00', 32.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-21 00:00:00', 32.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-22 00:00:00', 31.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-23 00:00:00', 32.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-24 00:00:00', 32.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-25 00:00:00', 34.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-26 00:00:00', 33.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-27 00:00:00', 33.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-28 00:00:00', 32.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-29 00:00:00', 33.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-30 00:00:00', 33.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-08-31 00:00:00', 34.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-01 00:00:00', 33.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-02 00:00:00', 31.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-03 00:00:00', 30.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-04 00:00:00', 31.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-05 00:00:00', 30.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-06 00:00:00', 31.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-07 00:00:00', 31.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-08 00:00:00', 32.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-09 00:00:00', 31.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-10 00:00:00', 31.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-11 00:00:00', 30.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-12 00:00:00', 32.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-13 00:00:00', 34.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-14 00:00:00', 36.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-15 00:00:00', 37.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-16 00:00:00', 36.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-17 00:00:00', 36.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-18 00:00:00', 36.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-19 00:00:00', 35.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-20 00:00:00', 35.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-21 00:00:00', 33.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-22 00:00:00', 31.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-23 00:00:00', 21.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-24 00:00:00', 20.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-25 00:00:00', 25.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-26 00:00:00', 28.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-27 00:00:00', 27.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-28 00:00:00', 27.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-29 00:00:00', 25.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-09-30 00:00:00', 25.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-01 00:00:00', 23.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-02 00:00:00', 21.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-03 00:00:00', 21.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-04 00:00:00', 22.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-05 00:00:00', 23.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-06 00:00:00', 22.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-07 00:00:00', 22.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-08 00:00:00', 23.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-09 00:00:00', 25.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-10 00:00:00', 21.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-11 00:00:00', 21.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-12 00:00:00', 23.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-13 00:00:00', 25.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-14 00:00:00', 17.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-15 00:00:00', 20.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-16 00:00:00', 18.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-17 00:00:00', 23.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-18 00:00:00', 24.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-19 00:00:00', 15.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-20 00:00:00', 12.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-21 00:00:00', 18.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-22 00:00:00', 19.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-23 00:00:00', 18.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-24 00:00:00', 17.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-25 00:00:00', 19.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-26 00:00:00', 17.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-27 00:00:00', 17.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-28 00:00:00', 15.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-29 00:00:00', 16.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-30 00:00:00', 16.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-10-31 00:00:00', 16.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-01 00:00:00', 18.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-02 00:00:00', 20.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-03 00:00:00', 19.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-04 00:00:00', 20.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-05 00:00:00', 23.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-06 00:00:00', 25.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-07 00:00:00', 19.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-08 00:00:00', 16.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-09 00:00:00', 17.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-10 00:00:00', 16.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-11 00:00:00', 17.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-12 00:00:00', 19.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-13 00:00:00', 22.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-14 00:00:00', 23.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-15 00:00:00', 21.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-16 00:00:00', 15.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-17 00:00:00', 15.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-18 00:00:00', 17.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-19 00:00:00', 18.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-20 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-21 00:00:00', 17.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-22 00:00:00', 16.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-23 00:00:00', 12.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-24 00:00:00', 7.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-25 00:00:00', 9.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-26 00:00:00', 11.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-27 00:00:00', 11.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-28 00:00:00', 13.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-29 00:00:00', 13.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-11-30 00:00:00', 13.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-01 00:00:00', 13.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-02 00:00:00', 7.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-03 00:00:00', 7.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-04 00:00:00', 8.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-05 00:00:00', 11.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-06 00:00:00', 8.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-07 00:00:00', 10.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-08 00:00:00', 7.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-09 00:00:00', 12.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-10 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-11 00:00:00', 11.4329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-12 00:00:00', 13.1190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-13 00:00:00', 12.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-14 00:00:00', 13.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-15 00:00:00', 12.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-16 00:00:00', 9.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-17 00:00:00', 14.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-18 00:00:00', 13.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-19 00:00:00', 14.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-20 00:00:00', 9.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-21 00:00:00', 7.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-22 00:00:00', 10.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-23 00:00:00', 12.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-24 00:00:00', 14.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-25 00:00:00', 9.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-26 00:00:00', 12.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-27 00:00:00', 6.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-28 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-29 00:00:00', 5.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-30 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1981-12-31 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-01 00:00:00', 6.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-02 00:00:00', 8.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-03 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-04 00:00:00', 8.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-05 00:00:00', 10.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-06 00:00:00', 13.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-07 00:00:00', 15.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-08 00:00:00', 15.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-09 00:00:00', 14.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-10 00:00:00', 14.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-11 00:00:00', 13.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-12 00:00:00', 6.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-13 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-14 00:00:00', 4.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-15 00:00:00', 5.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-16 00:00:00', 6.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-17 00:00:00', 8.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-18 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-19 00:00:00', -0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-20 00:00:00', -0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-21 00:00:00', -2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-22 00:00:00', -3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-23 00:00:00', -3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-24 00:00:00', 0.180999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-25 00:00:00', 1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-26 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-27 00:00:00', 5.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-28 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-29 00:00:00', 5.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-30 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-01-31 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-01 00:00:00', 9.09599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-02 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-03 00:00:00', 6.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-04 00:00:00', 10.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-05 00:00:00', 12.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-06 00:00:00', 6.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-07 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-08 00:00:00', 6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-09 00:00:00', 9.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-10 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-11 00:00:00', 1.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-12 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-13 00:00:00', 7.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-14 00:00:00', 11.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-15 00:00:00', 5.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-16 00:00:00', 5.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-17 00:00:00', 9.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-18 00:00:00', 11.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-19 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-20 00:00:00', -0.352999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-21 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-22 00:00:00', 6.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-23 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-24 00:00:00', 8.73499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-25 00:00:00', 12.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-26 00:00:00', 6.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-27 00:00:00', 8.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-02-28 00:00:00', 10.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-01 00:00:00', 8.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-02 00:00:00', 11.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-03 00:00:00', 12.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-04 00:00:00', 6.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-05 00:00:00', 6.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-06 00:00:00', 5.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-07 00:00:00', 9.41399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-08 00:00:00', 8.96300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-09 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-10 00:00:00', 12.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-11 00:00:00', 14.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-12 00:00:00', 17.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-13 00:00:00', 12.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-14 00:00:00', 11.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-15 00:00:00', 16.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-16 00:00:00', 12.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-17 00:00:00', 12.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-18 00:00:00', 15.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-19 00:00:00', 16.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-20 00:00:00', 13.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-21 00:00:00', 9.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-22 00:00:00', 13.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-23 00:00:00', 16.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-24 00:00:00', 17.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-25 00:00:00', 18.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-26 00:00:00', 12.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-27 00:00:00', 14.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-28 00:00:00', 15.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-29 00:00:00', 12.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-30 00:00:00', 9.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-03-31 00:00:00', 12.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-01 00:00:00', 16.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-02 00:00:00', 20.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-03 00:00:00', 13.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-04 00:00:00', 13.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-05 00:00:00', 13.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-06 00:00:00', 18.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-07 00:00:00', 21.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-08 00:00:00', 23.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-09 00:00:00', 25.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-10 00:00:00', 26.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-11 00:00:00', 20.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-12 00:00:00', 24.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-13 00:00:00', 25.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-14 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-15 00:00:00', 18.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-16 00:00:00', 18.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-17 00:00:00', 21.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-18 00:00:00', 25.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-19 00:00:00', 27.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-20 00:00:00', 28.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-21 00:00:00', 28.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-22 00:00:00', 29.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-23 00:00:00', 30.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-24 00:00:00', 23.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-25 00:00:00', 23.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-26 00:00:00', 23.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-27 00:00:00', 22.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-28 00:00:00', 25.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-29 00:00:00', 25.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-04-30 00:00:00', 28.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-01 00:00:00', 29.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-02 00:00:00', 30.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-03 00:00:00', 31.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-04 00:00:00', 31.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-05 00:00:00', 30.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-06 00:00:00', 31.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-07 00:00:00', 31.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-08 00:00:00', 31.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-09 00:00:00', 30.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-10 00:00:00', 27.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-11 00:00:00', 24.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-12 00:00:00', 24.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-13 00:00:00', 26.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-14 00:00:00', 26.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-15 00:00:00', 27.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-16 00:00:00', 30.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-17 00:00:00', 31.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-18 00:00:00', 30.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-19 00:00:00', 32.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-20 00:00:00', 33.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-21 00:00:00', 35.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-22 00:00:00', 33.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-23 00:00:00', 31.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-24 00:00:00', 31.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-25 00:00:00', 27.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-26 00:00:00', 25.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-27 00:00:00', 28.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-28 00:00:00', 28.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-29 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-30 00:00:00', 27.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-05-31 00:00:00', 28.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-01 00:00:00', 30.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-02 00:00:00', 33.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-03 00:00:00', 31.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-04 00:00:00', 31.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-05 00:00:00', 35.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-06 00:00:00', 36.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-07 00:00:00', 36.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-08 00:00:00', 34.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-09 00:00:00', 36.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-10 00:00:00', 38.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-11 00:00:00', 37.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-12 00:00:00', 36.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-13 00:00:00', 37.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-14 00:00:00', 36.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-15 00:00:00', 33.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-16 00:00:00', 35.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-17 00:00:00', 32.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-18 00:00:00', 32.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-19 00:00:00', 33.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-20 00:00:00', 35.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-21 00:00:00', 34.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-22 00:00:00', 36.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-23 00:00:00', 36.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-24 00:00:00', 37.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-25 00:00:00', 37.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-26 00:00:00', 37.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-27 00:00:00', 37.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-28 00:00:00', 38.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-29 00:00:00', 38.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-06-30 00:00:00', 29.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-01 00:00:00', 27.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-02 00:00:00', 32.1500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-03 00:00:00', 33.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-04 00:00:00', 35.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-05 00:00:00', 35.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-06 00:00:00', 34.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-07 00:00:00', 34.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-08 00:00:00', 34.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-09 00:00:00', 35.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-10 00:00:00', 36.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-11 00:00:00', 37.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-12 00:00:00', 33.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-13 00:00:00', 34.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-14 00:00:00', 36.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-15 00:00:00', 38.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-16 00:00:00', 39.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-17 00:00:00', 38.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-18 00:00:00', 39.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-19 00:00:00', 41.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-20 00:00:00', 39.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-21 00:00:00', 38.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-22 00:00:00', 39.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-23 00:00:00', 39.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-24 00:00:00', 39.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-25 00:00:00', 37.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-26 00:00:00', 39.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-27 00:00:00', 41.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-28 00:00:00', 41.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-29 00:00:00', 40.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-30 00:00:00', 41.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-07-31 00:00:00', 41.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-01 00:00:00', 43.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-02 00:00:00', 42.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-03 00:00:00', 41.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-04 00:00:00', 40.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-05 00:00:00', 42, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-06 00:00:00', 42.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-07 00:00:00', 42.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-08 00:00:00', 41.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-09 00:00:00', 40.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-10 00:00:00', 40.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-11 00:00:00', 32.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-12 00:00:00', 33.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-13 00:00:00', 36.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-14 00:00:00', 36.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-15 00:00:00', 35.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-16 00:00:00', 33.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-17 00:00:00', 33.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-18 00:00:00', 35.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-19 00:00:00', 36.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-20 00:00:00', 36.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-21 00:00:00', 35.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-22 00:00:00', 34.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-23 00:00:00', 33.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-24 00:00:00', 28.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-25 00:00:00', 27.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-26 00:00:00', 29.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-27 00:00:00', 31.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-28 00:00:00', 33.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-29 00:00:00', 32.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-30 00:00:00', 32.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-08-31 00:00:00', 32.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-01 00:00:00', 33.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-02 00:00:00', 33.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-03 00:00:00', 31.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-04 00:00:00', 32.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-05 00:00:00', 33.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-06 00:00:00', 32.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-07 00:00:00', 31.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-08 00:00:00', 31.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-09 00:00:00', 31.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-10 00:00:00', 33.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-11 00:00:00', 33.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-12 00:00:00', 32.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-13 00:00:00', 33.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-14 00:00:00', 32.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-15 00:00:00', 32.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-16 00:00:00', 32.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-17 00:00:00', 28.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-18 00:00:00', 28.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-19 00:00:00', 29.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-20 00:00:00', 25.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-21 00:00:00', 22.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-22 00:00:00', 23.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-23 00:00:00', 23.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-24 00:00:00', 26.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-25 00:00:00', 26.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-26 00:00:00', 25.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-27 00:00:00', 26.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-28 00:00:00', 26.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-29 00:00:00', 26.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-09-30 00:00:00', 25.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-01 00:00:00', 26.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-02 00:00:00', 29.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-03 00:00:00', 28.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-04 00:00:00', 22.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-05 00:00:00', 26.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-06 00:00:00', 26.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-07 00:00:00', 17.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-08 00:00:00', 16.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-09 00:00:00', 20.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-10 00:00:00', 26.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-11 00:00:00', 22.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-12 00:00:00', 23.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-13 00:00:00', 24.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-14 00:00:00', 26.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-15 00:00:00', 28.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-16 00:00:00', 26.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-17 00:00:00', 22.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-18 00:00:00', 21.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-19 00:00:00', 23.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-20 00:00:00', 23.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-21 00:00:00', 25.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-22 00:00:00', 22.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-23 00:00:00', 18.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-24 00:00:00', 17.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-25 00:00:00', 11.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-26 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-27 00:00:00', 8.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-28 00:00:00', 14.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-29 00:00:00', 19.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-30 00:00:00', 19.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-10-31 00:00:00', 14.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-01 00:00:00', 11.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-02 00:00:00', 11.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-03 00:00:00', 8.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-04 00:00:00', 15.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-05 00:00:00', 15.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-06 00:00:00', 18.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-07 00:00:00', 20.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-08 00:00:00', 15.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-09 00:00:00', 20.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-10 00:00:00', 12.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-11 00:00:00', 8.31499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-12 00:00:00', 12.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-13 00:00:00', 11.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-14 00:00:00', 7.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-15 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-16 00:00:00', 8.17800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-17 00:00:00', 9.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-18 00:00:00', 6.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-19 00:00:00', 9.93500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-20 00:00:00', 7.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-21 00:00:00', 8.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-22 00:00:00', 11.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-23 00:00:00', 10.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-24 00:00:00', 6.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-25 00:00:00', 7.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-26 00:00:00', 8.02499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-27 00:00:00', 10.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-28 00:00:00', 9.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-29 00:00:00', 3.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-11-30 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-01 00:00:00', 0.873000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-02 00:00:00', 3.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-03 00:00:00', 7.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-04 00:00:00', 9.62199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-05 00:00:00', 9.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-06 00:00:00', 8.43500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-07 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-08 00:00:00', 4.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-09 00:00:00', -4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-10 00:00:00', 0.351000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-11 00:00:00', 0.643000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-12 00:00:00', 1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-13 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-14 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-15 00:00:00', 4.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-16 00:00:00', 4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-17 00:00:00', 6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-18 00:00:00', 8.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-19 00:00:00', 7.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-20 00:00:00', 6.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-21 00:00:00', 7.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-22 00:00:00', 6.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-23 00:00:00', 7.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-24 00:00:00', 7.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-25 00:00:00', 7.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-26 00:00:00', 7.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-27 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-28 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-29 00:00:00', 3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-30 00:00:00', 7.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1982-12-31 00:00:00', 6.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-01 00:00:00', 9.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-02 00:00:00', 8.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-03 00:00:00', 7.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-04 00:00:00', 9.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-05 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-06 00:00:00', 10.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-07 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-08 00:00:00', 1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-09 00:00:00', 0.405999988317489624, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-10 00:00:00', 6.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-11 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-12 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-13 00:00:00', 6.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-14 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-15 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-16 00:00:00', 7.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-17 00:00:00', 8.61699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-18 00:00:00', 11.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-19 00:00:00', 12.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-20 00:00:00', 14.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-21 00:00:00', 17.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-22 00:00:00', 10.3900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-23 00:00:00', 13.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-24 00:00:00', 16.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-25 00:00:00', 12.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-26 00:00:00', 7.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-27 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-28 00:00:00', -1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-29 00:00:00', -0.412999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-30 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-01-31 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-01 00:00:00', 4.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-02 00:00:00', 6.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-03 00:00:00', 8.32699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-04 00:00:00', 5.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-05 00:00:00', 5.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-06 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-07 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-08 00:00:00', 6.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-09 00:00:00', 5.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-10 00:00:00', 3.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-11 00:00:00', 5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-12 00:00:00', 6.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-13 00:00:00', 5.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-14 00:00:00', 6.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-15 00:00:00', 10.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-16 00:00:00', 10.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-17 00:00:00', 12.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-18 00:00:00', 14.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-19 00:00:00', 11.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-20 00:00:00', 12.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-21 00:00:00', 12.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-22 00:00:00', 12.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-23 00:00:00', 6.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-24 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-25 00:00:00', 8.52700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-26 00:00:00', 9.39000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-27 00:00:00', 10.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-02-28 00:00:00', 6.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-01 00:00:00', 5.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-02 00:00:00', 7.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-03 00:00:00', 7.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-04 00:00:00', 10.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-05 00:00:00', 14.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-06 00:00:00', 15.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-07 00:00:00', 9.97299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-08 00:00:00', 9.00399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-09 00:00:00', 13.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-10 00:00:00', 15.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-11 00:00:00', 12.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-12 00:00:00', 14.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-13 00:00:00', 17.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-14 00:00:00', 12.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-15 00:00:00', 11.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-16 00:00:00', 12.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-17 00:00:00', 7.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-18 00:00:00', 6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-19 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-20 00:00:00', 5.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-21 00:00:00', 9.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-22 00:00:00', 13.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-23 00:00:00', 15.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-24 00:00:00', 16.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-25 00:00:00', 7.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-26 00:00:00', 6.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-27 00:00:00', 10.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-28 00:00:00', 11.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-29 00:00:00', 14.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-30 00:00:00', 16.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-03-31 00:00:00', 14.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-01 00:00:00', 17.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-02 00:00:00', 17.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-03 00:00:00', 20.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-04 00:00:00', 18.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-05 00:00:00', 17.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-06 00:00:00', 20.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-07 00:00:00', 14.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-08 00:00:00', 14.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-09 00:00:00', 15.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-10 00:00:00', 16.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-11 00:00:00', 20.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-12 00:00:00', 11.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-13 00:00:00', 12.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-14 00:00:00', 17.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-15 00:00:00', 16.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-16 00:00:00', 15.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-17 00:00:00', 18.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-18 00:00:00', 22.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-19 00:00:00', 21.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-20 00:00:00', 23.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-21 00:00:00', 23.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-22 00:00:00', 21.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-23 00:00:00', 23.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-24 00:00:00', 22.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-25 00:00:00', 26.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-26 00:00:00', 26.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-27 00:00:00', 18.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-28 00:00:00', 24.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-29 00:00:00', 15.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-04-30 00:00:00', 12.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-01 00:00:00', 20.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-02 00:00:00', 25.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-03 00:00:00', 24.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-04 00:00:00', 19.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-05 00:00:00', 26.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-06 00:00:00', 29.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-07 00:00:00', 31.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-08 00:00:00', 24.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-09 00:00:00', 29.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-10 00:00:00', 27.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-11 00:00:00', 24.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-12 00:00:00', 28.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-13 00:00:00', 27.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-14 00:00:00', 29.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-15 00:00:00', 30.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-16 00:00:00', 32.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-17 00:00:00', 29.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-18 00:00:00', 31.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-19 00:00:00', 27.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-20 00:00:00', 29.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-21 00:00:00', 30.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-22 00:00:00', 28.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-23 00:00:00', 29.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-24 00:00:00', 29.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-25 00:00:00', 32.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-26 00:00:00', 34.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-27 00:00:00', 32.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-28 00:00:00', 30.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-29 00:00:00', 31.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-30 00:00:00', 28.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-05-31 00:00:00', 24.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-01 00:00:00', 28.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-02 00:00:00', 26.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-03 00:00:00', 28.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-04 00:00:00', 30.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-05 00:00:00', 31.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-06 00:00:00', 33.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-07 00:00:00', 32.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-08 00:00:00', 32.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-09 00:00:00', 31.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-10 00:00:00', 31.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-11 00:00:00', 33.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-12 00:00:00', 34.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-13 00:00:00', 37.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-14 00:00:00', 37.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-15 00:00:00', 33.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-16 00:00:00', 33.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-17 00:00:00', 32.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-18 00:00:00', 32.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-19 00:00:00', 35.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-20 00:00:00', 36.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-21 00:00:00', 38.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-22 00:00:00', 40.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-23 00:00:00', 38.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-24 00:00:00', 40.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-25 00:00:00', 41.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-26 00:00:00', 40.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-27 00:00:00', 39.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-28 00:00:00', 40.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-29 00:00:00', 40.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-06-30 00:00:00', 40.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-01 00:00:00', 39.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-02 00:00:00', 36.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-03 00:00:00', 35.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-04 00:00:00', 36.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-05 00:00:00', 35.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-06 00:00:00', 35.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-07 00:00:00', 34.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-08 00:00:00', 37.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-09 00:00:00', 37.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-10 00:00:00', 37.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-11 00:00:00', 36.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-12 00:00:00', 37.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-13 00:00:00', 37.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-14 00:00:00', 38.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-15 00:00:00', 38.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-16 00:00:00', 39.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-17 00:00:00', 38.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-18 00:00:00', 42.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-19 00:00:00', 37.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-20 00:00:00', 38.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-21 00:00:00', 39.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-22 00:00:00', 44.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-23 00:00:00', 44.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-24 00:00:00', 43.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-25 00:00:00', 43.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-26 00:00:00', 39.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-27 00:00:00', 38.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-28 00:00:00', 42.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-29 00:00:00', 44.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-30 00:00:00', 44.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-07-31 00:00:00', 43.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-01 00:00:00', 42.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-02 00:00:00', 39.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-03 00:00:00', 40.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-04 00:00:00', 41.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-05 00:00:00', 41.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-06 00:00:00', 41.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-07 00:00:00', 39.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-08 00:00:00', 38.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-09 00:00:00', 35.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-10 00:00:00', 35.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-11 00:00:00', 36.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-12 00:00:00', 37.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-13 00:00:00', 38.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-14 00:00:00', 38.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-15 00:00:00', 39.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-16 00:00:00', 40.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-17 00:00:00', 37.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-18 00:00:00', 38.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-19 00:00:00', 37.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-20 00:00:00', 37.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-21 00:00:00', 38.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-22 00:00:00', 38.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-23 00:00:00', 39.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-24 00:00:00', 38.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-25 00:00:00', 36.9550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-26 00:00:00', 35.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-27 00:00:00', 33.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-28 00:00:00', 35.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-29 00:00:00', 39.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-30 00:00:00', 39.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-08-31 00:00:00', 39.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-01 00:00:00', 24.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-03 00:00:00', 26.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-05 00:00:00', 26.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-07 00:00:00', 28.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-09 00:00:00', 28.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-11 00:00:00', 32.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-13 00:00:00', 28.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-15 00:00:00', 23.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-17 00:00:00', 22.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-19 00:00:00', 22.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-21 00:00:00', 24.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-23 00:00:00', 26.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-25 00:00:00', 26.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-27 00:00:00', 16.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-29 00:00:00', 20.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-01 00:00:00', 23.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-03 00:00:00', 18.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-05 00:00:00', 18.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-07 00:00:00', 19.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-09 00:00:00', 18.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-11 00:00:00', 16.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-13 00:00:00', 19.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-15 00:00:00', 19.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-17 00:00:00', 20.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-19 00:00:00', 20.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-21 00:00:00', 20.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-23 00:00:00', 18.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-25 00:00:00', 22.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-27 00:00:00', 23.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-29 00:00:00', 19.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-30 00:00:00', 21.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-10-31 00:00:00', 23.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-01 00:00:00', 25.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-02 00:00:00', 20.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-03 00:00:00', 18.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-04 00:00:00', 16.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-05 00:00:00', 9.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-06 00:00:00', 12.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-07 00:00:00', 18.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-08 00:00:00', 18.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-09 00:00:00', 17.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-10 00:00:00', 17.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-11 00:00:00', 20.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-12 00:00:00', 21.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-13 00:00:00', 23.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-14 00:00:00', 23.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-15 00:00:00', 22.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-16 00:00:00', 21.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-17 00:00:00', 16.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-18 00:00:00', 19.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-19 00:00:00', 20.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-20 00:00:00', 20.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-21 00:00:00', 20.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-22 00:00:00', 21.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-23 00:00:00', 22.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-24 00:00:00', 21.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-25 00:00:00', 21.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-26 00:00:00', 12.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-27 00:00:00', 11.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-28 00:00:00', 17.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-29 00:00:00', 20.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-11-30 00:00:00', 19.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-01 00:00:00', 17.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-02 00:00:00', 16.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-03 00:00:00', 14.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-04 00:00:00', 9.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-05 00:00:00', 10.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-06 00:00:00', 11.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-07 00:00:00', 13.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-08 00:00:00', 14.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-09 00:00:00', 16.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-10 00:00:00', 14.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-11 00:00:00', 15.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-12 00:00:00', 15.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-13 00:00:00', 16.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-14 00:00:00', 10.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-15 00:00:00', 10.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-16 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-17 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-18 00:00:00', 0.666999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-19 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-20 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-21 00:00:00', -0.402999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-22 00:00:00', -1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-23 00:00:00', 0.537000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-24 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-25 00:00:00', -1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-26 00:00:00', 1.50899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-27 00:00:00', 8.02999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-28 00:00:00', 5.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-29 00:00:00', 7.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-30 00:00:00', 8.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1983-12-31 00:00:00', 6.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-01 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-02 00:00:00', 10.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-03 00:00:00', 6.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-04 00:00:00', 6.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-05 00:00:00', 2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-06 00:00:00', 4.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-07 00:00:00', 7.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-08 00:00:00', 8.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-09 00:00:00', 10.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-10 00:00:00', 10.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-11 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-12 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-13 00:00:00', 7.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-14 00:00:00', 7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-15 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-16 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-17 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-18 00:00:00', 0.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-19 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-20 00:00:00', -0.773000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-21 00:00:00', -1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-22 00:00:00', -0.439999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-23 00:00:00', 0.0410000011324882507, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-24 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-25 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-26 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-27 00:00:00', 0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-28 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-29 00:00:00', 3.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-30 00:00:00', 7.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-01-31 00:00:00', 1.9450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-01 00:00:00', -1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-02 00:00:00', 0.646000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-03 00:00:00', -2.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-04 00:00:00', -2.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-05 00:00:00', 0.435000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-06 00:00:00', -3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-07 00:00:00', -4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-08 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-09 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-10 00:00:00', 0.620000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-11 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-12 00:00:00', 0.958999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-13 00:00:00', 2.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-14 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-15 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-16 00:00:00', -3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-17 00:00:00', -4.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-18 00:00:00', -5.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-19 00:00:00', -6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-20 00:00:00', -7.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-21 00:00:00', -7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-22 00:00:00', -3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-23 00:00:00', -3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-24 00:00:00', -1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-25 00:00:00', -1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-26 00:00:00', -0.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-27 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-28 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-02-29 00:00:00', 5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-01 00:00:00', 6.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-02 00:00:00', 10.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-03 00:00:00', 11.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-04 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-05 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-06 00:00:00', 7.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-07 00:00:00', 8.77200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-08 00:00:00', 7.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-09 00:00:00', 7.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-10 00:00:00', 4.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-11 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-12 00:00:00', 11.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-13 00:00:00', 15.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-14 00:00:00', 13.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-15 00:00:00', 14.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-16 00:00:00', 12.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-17 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-18 00:00:00', 9.98900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-19 00:00:00', 15.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-20 00:00:00', 18.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-21 00:00:00', 19.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-22 00:00:00', 17.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-23 00:00:00', 22.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-24 00:00:00', 20.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-25 00:00:00', 17.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-26 00:00:00', 21.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-27 00:00:00', 15.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-28 00:00:00', 12.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-29 00:00:00', 15.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-30 00:00:00', 18.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-03-31 00:00:00', 15.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-01 00:00:00', 18.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-02 00:00:00', 15.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-03 00:00:00', 16.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-04 00:00:00', 14.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-05 00:00:00', 11.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-06 00:00:00', 15.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-07 00:00:00', 17.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-08 00:00:00', 18.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-09 00:00:00', 20.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-10 00:00:00', 22.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-11 00:00:00', 22.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-12 00:00:00', 25.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-13 00:00:00', 15.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-14 00:00:00', 17.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-15 00:00:00', 20.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-16 00:00:00', 24.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-17 00:00:00', 27.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-18 00:00:00', 26.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-19 00:00:00', 16.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-20 00:00:00', 18.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-21 00:00:00', 21.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-22 00:00:00', 25.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-23 00:00:00', 29.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-24 00:00:00', 29.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-25 00:00:00', 30.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-26 00:00:00', 26.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-27 00:00:00', 17.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-28 00:00:00', 21.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-29 00:00:00', 19.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-04-30 00:00:00', 22.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-01 00:00:00', 23.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-02 00:00:00', 26.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-03 00:00:00', 17.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-04 00:00:00', 22.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-05 00:00:00', 25.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-06 00:00:00', 22.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-07 00:00:00', 23.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-08 00:00:00', 19.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-09 00:00:00', 23.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-10 00:00:00', 25.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-11 00:00:00', 24.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-12 00:00:00', 22.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-13 00:00:00', 22.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-14 00:00:00', 21.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-15 00:00:00', 23.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-16 00:00:00', 23.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-17 00:00:00', 25.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-18 00:00:00', 27.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-19 00:00:00', 26.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-20 00:00:00', 24.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-21 00:00:00', 29.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-22 00:00:00', 30.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-23 00:00:00', 27.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-24 00:00:00', 30.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-25 00:00:00', 32.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-26 00:00:00', 33.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-27 00:00:00', 35.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-28 00:00:00', 32.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-29 00:00:00', 36.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-30 00:00:00', 38.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-05-31 00:00:00', 40.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-01 00:00:00', 36.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-02 00:00:00', 36.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-03 00:00:00', 34.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-04 00:00:00', 35.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-05 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-06 00:00:00', 33.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-07 00:00:00', 34.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-08 00:00:00', 35.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-09 00:00:00', 37.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-10 00:00:00', 36.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-11 00:00:00', 34.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-12 00:00:00', 36.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-13 00:00:00', 37.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-14 00:00:00', 36.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-15 00:00:00', 37.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-16 00:00:00', 34.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-17 00:00:00', 30.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-18 00:00:00', 31.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-19 00:00:00', 32.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-20 00:00:00', 33.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-21 00:00:00', 35.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-22 00:00:00', 37.9490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-23 00:00:00', 39.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-24 00:00:00', 39.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-25 00:00:00', 40.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-26 00:00:00', 39.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-27 00:00:00', 39.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-28 00:00:00', 36.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-29 00:00:00', 36.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-06-30 00:00:00', 36.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-01 00:00:00', 36.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-02 00:00:00', 38.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-03 00:00:00', 37.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-04 00:00:00', 38.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-05 00:00:00', 39.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-06 00:00:00', 39.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-07 00:00:00', 39.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-08 00:00:00', 38.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-09 00:00:00', 39.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-10 00:00:00', 39.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-11 00:00:00', 39.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-12 00:00:00', 41.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-13 00:00:00', 41.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-14 00:00:00', 41.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-15 00:00:00', 41.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-16 00:00:00', 39.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-17 00:00:00', 40.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-18 00:00:00', 40.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-19 00:00:00', 39.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-20 00:00:00', 39.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-21 00:00:00', 38.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-22 00:00:00', 38.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-23 00:00:00', 39.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-24 00:00:00', 39.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-25 00:00:00', 38.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-26 00:00:00', 40.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-27 00:00:00', 39.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-28 00:00:00', 39.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-29 00:00:00', 39.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-30 00:00:00', 39.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-07-31 00:00:00', 39.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-01 00:00:00', 40.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-02 00:00:00', 41.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-03 00:00:00', 41.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-04 00:00:00', 40.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-05 00:00:00', 39.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-06 00:00:00', 38.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-07 00:00:00', 39.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-08 00:00:00', 40.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-09 00:00:00', 41.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-10 00:00:00', 40.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-11 00:00:00', 39.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-12 00:00:00', 38.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-13 00:00:00', 36.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-14 00:00:00', 37.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-15 00:00:00', 38.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-16 00:00:00', 39.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-17 00:00:00', 39.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-18 00:00:00', 39.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-19 00:00:00', 41.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-20 00:00:00', 41.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-21 00:00:00', 39.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-22 00:00:00', 38.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-23 00:00:00', 38.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-24 00:00:00', 39.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-25 00:00:00', 38.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-26 00:00:00', 37.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-27 00:00:00', 38.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-28 00:00:00', 38.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-29 00:00:00', 39.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-30 00:00:00', 39.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-08-31 00:00:00', 35.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-01 00:00:00', 34.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-02 00:00:00', 33.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-03 00:00:00', 34.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-04 00:00:00', 33.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-05 00:00:00', 32.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-06 00:00:00', 28.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-07 00:00:00', 29.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-08 00:00:00', 29.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-09 00:00:00', 31.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-10 00:00:00', 34.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-11 00:00:00', 31.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-12 00:00:00', 33.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-13 00:00:00', 31.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-14 00:00:00', 31.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-15 00:00:00', 32.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-16 00:00:00', 31.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-17 00:00:00', 31.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-18 00:00:00', 29.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-19 00:00:00', 24.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-20 00:00:00', 25.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-21 00:00:00', 27.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-22 00:00:00', 26.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-23 00:00:00', 27.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-24 00:00:00', 26.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-25 00:00:00', 27.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-26 00:00:00', 27.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-27 00:00:00', 26.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-28 00:00:00', 26.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-29 00:00:00', 27.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-09-30 00:00:00', 26.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-01 00:00:00', 25.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-02 00:00:00', 25.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-03 00:00:00', 25.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-04 00:00:00', 25.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-05 00:00:00', 25.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-06 00:00:00', 25.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-07 00:00:00', 26.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-08 00:00:00', 17.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-09 00:00:00', 15.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-10 00:00:00', 19.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-11 00:00:00', 21.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-12 00:00:00', 18.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-13 00:00:00', 16.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-14 00:00:00', 18.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-15 00:00:00', 20.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-16 00:00:00', 21.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-17 00:00:00', 22.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-18 00:00:00', 25.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-19 00:00:00', 28.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-20 00:00:00', 30.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-21 00:00:00', 16.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-22 00:00:00', 9.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-23 00:00:00', 11.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-24 00:00:00', 16.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-25 00:00:00', 16.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-26 00:00:00', 16.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-27 00:00:00', 16.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-28 00:00:00', 15.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-29 00:00:00', 14.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-30 00:00:00', 16.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-10-31 00:00:00', 19.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-01 00:00:00', 19.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-02 00:00:00', 19.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-03 00:00:00', 22.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-04 00:00:00', 16.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-05 00:00:00', 20.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-06 00:00:00', 20.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-07 00:00:00', 18.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-08 00:00:00', 11.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-09 00:00:00', 12.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-10 00:00:00', 16.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-11 00:00:00', 15.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-12 00:00:00', 18.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-13 00:00:00', 16.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-14 00:00:00', 17.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-15 00:00:00', 14.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-16 00:00:00', 11.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-17 00:00:00', 8.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-18 00:00:00', 11.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-19 00:00:00', 10.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-20 00:00:00', 8.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-21 00:00:00', 9.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-22 00:00:00', 6.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-23 00:00:00', 8.79800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-24 00:00:00', 11.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-25 00:00:00', 14.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-26 00:00:00', 15.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-27 00:00:00', 10.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-28 00:00:00', 13.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-29 00:00:00', 16.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-11-30 00:00:00', 13.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-01 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-02 00:00:00', 0.569000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-03 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-04 00:00:00', 2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-05 00:00:00', 0.192000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-06 00:00:00', -0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-07 00:00:00', 3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-08 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-09 00:00:00', 3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-10 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-11 00:00:00', 5.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-12 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-13 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-14 00:00:00', 6.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-15 00:00:00', 4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-16 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-17 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-18 00:00:00', 3.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-19 00:00:00', -0.0850000008940696716, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-20 00:00:00', -0.717000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-21 00:00:00', -4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-22 00:00:00', -3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-23 00:00:00', -2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-24 00:00:00', -2.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-25 00:00:00', -2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-26 00:00:00', -5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-27 00:00:00', -0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-28 00:00:00', 1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-29 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-30 00:00:00', -2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1984-12-31 00:00:00', -2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-01 00:00:00', -0.94300001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-02 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-03 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-04 00:00:00', 2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-05 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-06 00:00:00', 4.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-07 00:00:00', 4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-08 00:00:00', 4.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-09 00:00:00', 7.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-10 00:00:00', 6.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-11 00:00:00', 8.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-12 00:00:00', 10.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-13 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-14 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-15 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-16 00:00:00', 3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-17 00:00:00', 3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-18 00:00:00', -1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-19 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-20 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-21 00:00:00', 5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-22 00:00:00', 9.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-23 00:00:00', 9.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-24 00:00:00', 8.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-25 00:00:00', 3.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-26 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-27 00:00:00', 6.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-28 00:00:00', 6.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-29 00:00:00', 7.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-30 00:00:00', 10.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-01-31 00:00:00', 10.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-01 00:00:00', 9.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-02 00:00:00', 10.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-03 00:00:00', 8.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-04 00:00:00', 9.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-05 00:00:00', 10.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-06 00:00:00', 12.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-07 00:00:00', 8.78199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-08 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-09 00:00:00', 9.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-10 00:00:00', 9.44200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-11 00:00:00', 8.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-12 00:00:00', 12.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-13 00:00:00', 13.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-14 00:00:00', 15.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-15 00:00:00', 15.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-16 00:00:00', 17.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-17 00:00:00', 19.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-18 00:00:00', 10.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-19 00:00:00', 10.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-20 00:00:00', 11.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-21 00:00:00', 15.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-22 00:00:00', 17.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-23 00:00:00', 11.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-24 00:00:00', 6.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-25 00:00:00', 10.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-26 00:00:00', 16.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-27 00:00:00', 19.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-02-28 00:00:00', 8.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-01 00:00:00', 10.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-02 00:00:00', 12.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-03 00:00:00', 9.35299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-04 00:00:00', 5.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-05 00:00:00', 0.925999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-06 00:00:00', -0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-07 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-08 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-09 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-10 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-11 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-12 00:00:00', 5.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-13 00:00:00', 10.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-14 00:00:00', 12.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-15 00:00:00', 7.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-16 00:00:00', 12.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-17 00:00:00', 11.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-18 00:00:00', 15.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-19 00:00:00', 18.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-20 00:00:00', 19.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-21 00:00:00', 17.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-22 00:00:00', 18.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-23 00:00:00', 17.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-24 00:00:00', 18.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-25 00:00:00', 15.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-26 00:00:00', 10.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-27 00:00:00', 14.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-28 00:00:00', 19.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-29 00:00:00', 15.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-30 00:00:00', 17.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-03-31 00:00:00', 21.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-01 00:00:00', 23.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-02 00:00:00', 15.800999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-03 00:00:00', 20.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-04 00:00:00', 21.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-05 00:00:00', 14.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-06 00:00:00', 18.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-07 00:00:00', 12.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-08 00:00:00', 14.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-09 00:00:00', 14.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-10 00:00:00', 18.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-11 00:00:00', 21.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-12 00:00:00', 17.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-13 00:00:00', 20.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-14 00:00:00', 20.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-15 00:00:00', 23.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-16 00:00:00', 25.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-17 00:00:00', 14.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-18 00:00:00', 18.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-19 00:00:00', 23.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-20 00:00:00', 26.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-21 00:00:00', 25.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-22 00:00:00', 26.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-23 00:00:00', 27.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-24 00:00:00', 27.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-25 00:00:00', 29.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-26 00:00:00', 30.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-27 00:00:00', 28.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-28 00:00:00', 29.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-29 00:00:00', 29.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-04-30 00:00:00', 21.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-01 00:00:00', 19.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-02 00:00:00', 20.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-03 00:00:00', 24.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-04 00:00:00', 26.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-05 00:00:00', 28.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-06 00:00:00', 29.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-07 00:00:00', 25.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-08 00:00:00', 24.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-09 00:00:00', 25.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-10 00:00:00', 25.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-11 00:00:00', 24.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-12 00:00:00', 24.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-13 00:00:00', 25.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-14 00:00:00', 24.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-15 00:00:00', 27.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-16 00:00:00', 29.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-17 00:00:00', 31.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-18 00:00:00', 33.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-19 00:00:00', 35.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-20 00:00:00', 31.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-21 00:00:00', 32.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-22 00:00:00', 35.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-23 00:00:00', 30.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-24 00:00:00', 24.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-25 00:00:00', 24.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-26 00:00:00', 28.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-27 00:00:00', 32.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-28 00:00:00', 34.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-29 00:00:00', 34.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-30 00:00:00', 33.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-05-31 00:00:00', 34.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-01 00:00:00', 36.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-02 00:00:00', 33.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-03 00:00:00', 33.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-04 00:00:00', 37.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-05 00:00:00', 38.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-06 00:00:00', 35.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-07 00:00:00', 35.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-08 00:00:00', 35.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-09 00:00:00', 36.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-10 00:00:00', 31.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-11 00:00:00', 32.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-12 00:00:00', 34.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-13 00:00:00', 36.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-14 00:00:00', 36.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-15 00:00:00', 36.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-16 00:00:00', 37.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-17 00:00:00', 37.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-18 00:00:00', 36.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-19 00:00:00', 36.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-20 00:00:00', 36.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-21 00:00:00', 37.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-22 00:00:00', 38.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-23 00:00:00', 39.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-24 00:00:00', 39.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-25 00:00:00', 39.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-26 00:00:00', 40.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-27 00:00:00', 39.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-28 00:00:00', 38.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-29 00:00:00', 37.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-06-30 00:00:00', 38.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-01 00:00:00', 37.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-02 00:00:00', 38.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-03 00:00:00', 39.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-04 00:00:00', 40.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-05 00:00:00', 40.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-06 00:00:00', 41.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-07 00:00:00', 38.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-08 00:00:00', 37.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-09 00:00:00', 39.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-10 00:00:00', 42.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-11 00:00:00', 40.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-12 00:00:00', 39.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-13 00:00:00', 38.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-14 00:00:00', 37.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-15 00:00:00', 39.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-16 00:00:00', 41.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-17 00:00:00', 40.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-18 00:00:00', 35.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-19 00:00:00', 35.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-20 00:00:00', 38.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-21 00:00:00', 39.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-22 00:00:00', 40.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-23 00:00:00', 40.9490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-24 00:00:00', 39.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-25 00:00:00', 39.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-26 00:00:00', 39.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-27 00:00:00', 40.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-28 00:00:00', 41.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-29 00:00:00', 40.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-30 00:00:00', 36.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-07-31 00:00:00', 36.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-01 00:00:00', 36.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-02 00:00:00', 34.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-03 00:00:00', 35.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-04 00:00:00', 36.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-05 00:00:00', 36.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-06 00:00:00', 37.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-07 00:00:00', 36.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-08 00:00:00', 36.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-09 00:00:00', 35.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-10 00:00:00', 35.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-11 00:00:00', 34.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-12 00:00:00', 34.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-13 00:00:00', 35.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-14 00:00:00', 36.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-15 00:00:00', 35.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-16 00:00:00', 35.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-17 00:00:00', 35.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-18 00:00:00', 35.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-19 00:00:00', 35.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-20 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-21 00:00:00', 34.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-22 00:00:00', 35.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-23 00:00:00', 35.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-24 00:00:00', 34.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-25 00:00:00', 34.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-26 00:00:00', 33.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-27 00:00:00', 32.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-28 00:00:00', 32.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-29 00:00:00', 29.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-30 00:00:00', 30.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-08-31 00:00:00', 30.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-01 00:00:00', 32.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-02 00:00:00', 34.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-03 00:00:00', 34.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-04 00:00:00', 33.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-05 00:00:00', 31.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-06 00:00:00', 31.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-07 00:00:00', 31.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-08 00:00:00', 31.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-09 00:00:00', 31.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-10 00:00:00', 33.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-11 00:00:00', 32.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-12 00:00:00', 32.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-13 00:00:00', 32.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-14 00:00:00', 33.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-15 00:00:00', 33.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-16 00:00:00', 32.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-17 00:00:00', 31.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-18 00:00:00', 29.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-19 00:00:00', 29.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-20 00:00:00', 31.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-21 00:00:00', 31.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-22 00:00:00', 29.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-23 00:00:00', 28.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-24 00:00:00', 30.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-25 00:00:00', 30.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-26 00:00:00', 31.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-27 00:00:00', 30.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-28 00:00:00', 31.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-29 00:00:00', 31.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-09-30 00:00:00', 33.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-01 00:00:00', 33.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-02 00:00:00', 30.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-03 00:00:00', 25.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-04 00:00:00', 26.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-05 00:00:00', 23.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-06 00:00:00', 20.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-07 00:00:00', 21.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-08 00:00:00', 22.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-09 00:00:00', 21.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-10 00:00:00', 23.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-11 00:00:00', 26.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-12 00:00:00', 16.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-13 00:00:00', 17.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-14 00:00:00', 15.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-15 00:00:00', 17.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-16 00:00:00', 19.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-17 00:00:00', 20.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-18 00:00:00', 22.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-19 00:00:00', 24.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-20 00:00:00', 25.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-21 00:00:00', 27.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-22 00:00:00', 21.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-23 00:00:00', 16.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-24 00:00:00', 18.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-25 00:00:00', 18.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-26 00:00:00', 19.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-27 00:00:00', 21.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-28 00:00:00', 23.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-29 00:00:00', 20.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-30 00:00:00', 23.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-10-31 00:00:00', 19.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-01 00:00:00', 14.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-02 00:00:00', 19.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-03 00:00:00', 21.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-04 00:00:00', 21.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-05 00:00:00', 19.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-06 00:00:00', 19.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-07 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-08 00:00:00', 19.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-09 00:00:00', 17.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-10 00:00:00', 16.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-11 00:00:00', 18.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-12 00:00:00', 18.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-13 00:00:00', 19.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-14 00:00:00', 20.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-15 00:00:00', 18.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-16 00:00:00', 14.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-17 00:00:00', 14.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-18 00:00:00', 14.1549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-19 00:00:00', 9.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-20 00:00:00', 6.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-21 00:00:00', 9.24400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-22 00:00:00', 9.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-23 00:00:00', 11.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-24 00:00:00', 6.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-25 00:00:00', 9.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-26 00:00:00', 10.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-27 00:00:00', 13.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-28 00:00:00', 13.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-29 00:00:00', 14.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-11-30 00:00:00', 15.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-01 00:00:00', 16.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-02 00:00:00', 18.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-03 00:00:00', 18.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-04 00:00:00', 18.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-05 00:00:00', 17.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-06 00:00:00', 8.33800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-07 00:00:00', -0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-08 00:00:00', 0.551999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-09 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-10 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-11 00:00:00', 3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-12 00:00:00', 9.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-13 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-14 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-15 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-16 00:00:00', 7.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-17 00:00:00', 11.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-18 00:00:00', 12.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-19 00:00:00', 14.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-20 00:00:00', 18.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-21 00:00:00', 15.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-22 00:00:00', 12.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-23 00:00:00', 10.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-24 00:00:00', 8.06700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-25 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-26 00:00:00', 3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-27 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-28 00:00:00', 6.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-29 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-30 00:00:00', 8.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1985-12-31 00:00:00', 6.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-01 00:00:00', 6.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-02 00:00:00', 7.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-03 00:00:00', 8.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-04 00:00:00', 11.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-05 00:00:00', 10.9049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-06 00:00:00', 7.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-07 00:00:00', 11.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-08 00:00:00', 11.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-09 00:00:00', 11.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-10 00:00:00', 12.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-11 00:00:00', 9.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-12 00:00:00', 11.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-13 00:00:00', 12.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-14 00:00:00', 10.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-15 00:00:00', 13.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-16 00:00:00', 10.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-17 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-18 00:00:00', 10.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-19 00:00:00', 12.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-20 00:00:00', 12.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-21 00:00:00', 15.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-22 00:00:00', 8.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-23 00:00:00', 8.87600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-24 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-25 00:00:00', 0.726999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-26 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-27 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-28 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-29 00:00:00', 0.229000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-30 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-01-31 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-01 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-02 00:00:00', 6.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-03 00:00:00', 0.947000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-04 00:00:00', 6.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-05 00:00:00', 10.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-06 00:00:00', 10.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-07 00:00:00', 14.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-08 00:00:00', 11.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-09 00:00:00', 8.38599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-10 00:00:00', 13.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-11 00:00:00', 14.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-12 00:00:00', 7.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-13 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-14 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-15 00:00:00', 7.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-16 00:00:00', 10.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-17 00:00:00', 6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-18 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-19 00:00:00', 8.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-20 00:00:00', 9.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-21 00:00:00', 10.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-22 00:00:00', 12.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-23 00:00:00', 11.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-24 00:00:00', 14.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-25 00:00:00', 14.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-26 00:00:00', 17.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-27 00:00:00', 18.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-02-28 00:00:00', 19.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-01 00:00:00', 18.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-02 00:00:00', 18.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-03 00:00:00', 7.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-04 00:00:00', 13.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-05 00:00:00', 11.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-06 00:00:00', 15.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-07 00:00:00', 20.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-08 00:00:00', 19.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-09 00:00:00', 22.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-10 00:00:00', 14.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-11 00:00:00', 12.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-12 00:00:00', 8.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-13 00:00:00', 6.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-14 00:00:00', 7.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-15 00:00:00', 7.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-16 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-17 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-18 00:00:00', 6.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-19 00:00:00', 10.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-20 00:00:00', 11.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-21 00:00:00', 12.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-22 00:00:00', 14.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-23 00:00:00', 6.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-24 00:00:00', 12.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-25 00:00:00', 9.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-26 00:00:00', 11.2869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-27 00:00:00', 8.75399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-28 00:00:00', 9.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-29 00:00:00', 9.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-30 00:00:00', 7.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-03-31 00:00:00', 9.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-01 00:00:00', 11.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-02 00:00:00', 16.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-03 00:00:00', 19.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-04 00:00:00', 21.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-05 00:00:00', 22.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-06 00:00:00', 21.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-07 00:00:00', 23.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-08 00:00:00', 23.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-09 00:00:00', 23.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-10 00:00:00', 24.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-11 00:00:00', 26.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-12 00:00:00', 22.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-13 00:00:00', 25.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-14 00:00:00', 21.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-15 00:00:00', 23.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-16 00:00:00', 23.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-17 00:00:00', 26.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-18 00:00:00', 27.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-19 00:00:00', 25.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-20 00:00:00', 27.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-21 00:00:00', 27.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-22 00:00:00', 14.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-23 00:00:00', 17.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-24 00:00:00', 19.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-25 00:00:00', 19.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-26 00:00:00', 21.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-27 00:00:00', 21.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-28 00:00:00', 21.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-29 00:00:00', 23.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-04-30 00:00:00', 22.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-01 00:00:00', 26.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-02 00:00:00', 26.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-03 00:00:00', 29.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-04 00:00:00', 31.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-05 00:00:00', 36.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-06 00:00:00', 36.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-07 00:00:00', 31.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-08 00:00:00', 31.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-09 00:00:00', 30.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-10 00:00:00', 31.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-11 00:00:00', 34.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-12 00:00:00', 31.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-13 00:00:00', 31.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-14 00:00:00', 35.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-15 00:00:00', 31.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-16 00:00:00', 27.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-17 00:00:00', 21.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-18 00:00:00', 23.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-19 00:00:00', 23.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-20 00:00:00', 24.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-21 00:00:00', 26.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-22 00:00:00', 28.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-23 00:00:00', 30.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-24 00:00:00', 34.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-25 00:00:00', 28.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-26 00:00:00', 29.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-27 00:00:00', 31.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-28 00:00:00', 31.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-29 00:00:00', 29.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-30 00:00:00', 21.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-01 00:00:00', 28.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-02 00:00:00', 29.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-03 00:00:00', 30.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-04 00:00:00', 30.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-05 00:00:00', 32.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-06 00:00:00', 32.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-07 00:00:00', 33.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-08 00:00:00', 35.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-09 00:00:00', 38.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-10 00:00:00', 34.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-11 00:00:00', 32.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-12 00:00:00', 34.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-13 00:00:00', 34.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-14 00:00:00', 33.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-15 00:00:00', 33.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-16 00:00:00', 33.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-17 00:00:00', 36.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-18 00:00:00', 39.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-19 00:00:00', 41.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-20 00:00:00', 38.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-21 00:00:00', 38.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-22 00:00:00', 38.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-23 00:00:00', 39.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-24 00:00:00', 38.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-25 00:00:00', 37.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-26 00:00:00', 37.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-27 00:00:00', 36.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-28 00:00:00', 37.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-29 00:00:00', 37.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-06-30 00:00:00', 38.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-01 00:00:00', 39.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-02 00:00:00', 40.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-03 00:00:00', 40.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-04 00:00:00', 38.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-05 00:00:00', 38.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-06 00:00:00', 37.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-07 00:00:00', 38.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-08 00:00:00', 36.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-09 00:00:00', 35.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-10 00:00:00', 36.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-11 00:00:00', 37.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-12 00:00:00', 38.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-13 00:00:00', 39.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-14 00:00:00', 40.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-15 00:00:00', 41.5789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-16 00:00:00', 41.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-17 00:00:00', 41.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-18 00:00:00', 41.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-19 00:00:00', 39.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-20 00:00:00', 37.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-21 00:00:00', 37.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-22 00:00:00', 32.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-23 00:00:00', 32.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-24 00:00:00', 33.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-25 00:00:00', 36.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-26 00:00:00', 37.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-27 00:00:00', 39.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-28 00:00:00', 39.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-29 00:00:00', 41.0719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-30 00:00:00', 40.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-07-31 00:00:00', 40.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-01 00:00:00', 40.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-02 00:00:00', 40.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-03 00:00:00', 40.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-04 00:00:00', 41.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-05 00:00:00', 35.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-06 00:00:00', 35.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-07 00:00:00', 36.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-08 00:00:00', 32.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-09 00:00:00', 34.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-10 00:00:00', 33.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-11 00:00:00', 35.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-12 00:00:00', 36.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-13 00:00:00', 36.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-14 00:00:00', 37.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-15 00:00:00', 39.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-16 00:00:00', 39.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-17 00:00:00', 37.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-18 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-19 00:00:00', 35.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-20 00:00:00', 33.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-21 00:00:00', 33.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-22 00:00:00', 33.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-23 00:00:00', 34.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-24 00:00:00', 34.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-25 00:00:00', 34.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-26 00:00:00', 34.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-27 00:00:00', 33.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-28 00:00:00', 33.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-29 00:00:00', 34.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-30 00:00:00', 33.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-08-31 00:00:00', 31.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-01 00:00:00', 33.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-02 00:00:00', 33.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-03 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-04 00:00:00', 32.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-05 00:00:00', 32.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-06 00:00:00', 34.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-07 00:00:00', 33.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-08 00:00:00', 32.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-09 00:00:00', 31.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-10 00:00:00', 31.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-11 00:00:00', 32.1500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-12 00:00:00', 31.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-13 00:00:00', 30.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-14 00:00:00', 30.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-15 00:00:00', 31.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-16 00:00:00', 31.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-17 00:00:00', 32.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-18 00:00:00', 31.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-19 00:00:00', 30.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-20 00:00:00', 29.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-21 00:00:00', 30.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-22 00:00:00', 30.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-23 00:00:00', 31.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-24 00:00:00', 32.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-25 00:00:00', 33.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-26 00:00:00', 33.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-27 00:00:00', 32.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-28 00:00:00', 32.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-29 00:00:00', 31.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-09-30 00:00:00', 25.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-01 00:00:00', 25.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-02 00:00:00', 29.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-03 00:00:00', 31.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-04 00:00:00', 29.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-05 00:00:00', 31.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-06 00:00:00', 33.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-07 00:00:00', 32.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-08 00:00:00', 26.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-09 00:00:00', 26.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-10 00:00:00', 28.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-11 00:00:00', 29.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-12 00:00:00', 29.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-13 00:00:00', 26.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-14 00:00:00', 20.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-15 00:00:00', 15.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-16 00:00:00', 14.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-17 00:00:00', 15.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-18 00:00:00', 17.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-19 00:00:00', 19.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-20 00:00:00', 22.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-21 00:00:00', 23.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-22 00:00:00', 23.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-23 00:00:00', 25.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-24 00:00:00', 25.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-25 00:00:00', 26.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-26 00:00:00', 26.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-27 00:00:00', 23.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-28 00:00:00', 23.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-29 00:00:00', 21.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-30 00:00:00', 20.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-10-31 00:00:00', 22.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-01 00:00:00', 22.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-02 00:00:00', 22.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-03 00:00:00', 23.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-04 00:00:00', 24.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-05 00:00:00', 25.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-06 00:00:00', 18.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-07 00:00:00', 22.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-08 00:00:00', 23.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-09 00:00:00', 24.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-10 00:00:00', 23.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-11 00:00:00', 17.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-12 00:00:00', 14.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-13 00:00:00', 9.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-14 00:00:00', 9.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-15 00:00:00', 10.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-16 00:00:00', 8.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-17 00:00:00', 10.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-18 00:00:00', 12.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-19 00:00:00', 12.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-20 00:00:00', 8.46300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-21 00:00:00', 5.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-22 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-23 00:00:00', 8.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-24 00:00:00', 9.84099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-25 00:00:00', 4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-26 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-27 00:00:00', 8.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-28 00:00:00', 9.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-29 00:00:00', 11.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-11-30 00:00:00', 13.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-01 00:00:00', 15.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-02 00:00:00', 16.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-03 00:00:00', 14.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-04 00:00:00', 12.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-05 00:00:00', 11.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-06 00:00:00', 7.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-07 00:00:00', 9.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-08 00:00:00', 11.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-09 00:00:00', 11.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-10 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-11 00:00:00', -3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-12 00:00:00', -5.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-13 00:00:00', -6.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-14 00:00:00', 0.518999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-15 00:00:00', -1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-16 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-17 00:00:00', 1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-18 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-19 00:00:00', 4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-20 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-21 00:00:00', 5.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-22 00:00:00', 7.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-23 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-24 00:00:00', 2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-01 00:00:00', 7.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-02 00:00:00', 9.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-03 00:00:00', 11.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-04 00:00:00', 10.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-05 00:00:00', 12.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-06 00:00:00', 12.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-07 00:00:00', 14.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-08 00:00:00', 7.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-09 00:00:00', 12.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-10 00:00:00', 13.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-11 00:00:00', 13.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-12 00:00:00', 8.77700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-13 00:00:00', 9.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-14 00:00:00', 12.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-15 00:00:00', 9.82400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-16 00:00:00', 5.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-17 00:00:00', 9.68700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-18 00:00:00', 8.98200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-19 00:00:00', 5.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-20 00:00:00', 5.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-21 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-22 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-23 00:00:00', 8.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-24 00:00:00', 14.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-25 00:00:00', 16.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-26 00:00:00', 15.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-27 00:00:00', 18.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-28 00:00:00', 15.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-29 00:00:00', 14.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-30 00:00:00', 16.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-01-31 00:00:00', 15.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-01 00:00:00', 10.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-02 00:00:00', 11.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-03 00:00:00', 14.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-04 00:00:00', 17.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-05 00:00:00', 19.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-06 00:00:00', 10.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-07 00:00:00', 4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-08 00:00:00', 7.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-09 00:00:00', 12.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-10 00:00:00', 16.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-11 00:00:00', 12.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-12 00:00:00', 9.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-13 00:00:00', 10.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-14 00:00:00', 10.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-15 00:00:00', 7.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-16 00:00:00', 6.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-17 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-18 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-19 00:00:00', 12.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-20 00:00:00', 15.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-21 00:00:00', 14.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-22 00:00:00', 8.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-23 00:00:00', 8.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-24 00:00:00', 9.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-25 00:00:00', 13.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-26 00:00:00', 16.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-27 00:00:00', 17.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-02-28 00:00:00', 19.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-01 00:00:00', 19.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-02 00:00:00', 16.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-03 00:00:00', 20.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-04 00:00:00', 21.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-05 00:00:00', 14.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-06 00:00:00', 12.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-07 00:00:00', 13.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-08 00:00:00', 15.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-09 00:00:00', 17.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-10 00:00:00', 19.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-11 00:00:00', 18.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-12 00:00:00', 12.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-13 00:00:00', 9.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-14 00:00:00', 19.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-15 00:00:00', 14.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-16 00:00:00', 12.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-17 00:00:00', 17.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-18 00:00:00', 16.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-19 00:00:00', 15.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-20 00:00:00', 16.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-21 00:00:00', 13.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-22 00:00:00', 8.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-23 00:00:00', 10.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-24 00:00:00', 15.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-25 00:00:00', 17.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-26 00:00:00', 19.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-27 00:00:00', 18.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-28 00:00:00', 16.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-29 00:00:00', 19.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-30 00:00:00', 18.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-03-31 00:00:00', 21.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-01 00:00:00', 12.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-02 00:00:00', 12.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-03 00:00:00', 14.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-04 00:00:00', 18.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-05 00:00:00', 21.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-06 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-07 00:00:00', 16.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-08 00:00:00', 9.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-09 00:00:00', 14.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-10 00:00:00', 17.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-11 00:00:00', 18.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-12 00:00:00', 21.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-13 00:00:00', 22.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-14 00:00:00', 21.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-15 00:00:00', 23.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-16 00:00:00', 22.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-17 00:00:00', 24.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-18 00:00:00', 26.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-19 00:00:00', 29.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-20 00:00:00', 27.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-21 00:00:00', 17.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-22 00:00:00', 18.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-23 00:00:00', 21.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-24 00:00:00', 23.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-25 00:00:00', 24.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-26 00:00:00', 27.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-27 00:00:00', 30.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-28 00:00:00', 19.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-29 00:00:00', 23.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-04-30 00:00:00', 20.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-01 00:00:00', 21.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-02 00:00:00', 24.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-03 00:00:00', 25.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-04 00:00:00', 29.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-05 00:00:00', 27.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-06 00:00:00', 26.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-07 00:00:00', 23.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-08 00:00:00', 24.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-09 00:00:00', 26.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-10 00:00:00', 28.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-11 00:00:00', 30.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-12 00:00:00', 30.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-13 00:00:00', 31.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-14 00:00:00', 31.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-15 00:00:00', 32.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-16 00:00:00', 33.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-17 00:00:00', 34.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-18 00:00:00', 29.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-19 00:00:00', 29.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-20 00:00:00', 27.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-21 00:00:00', 28.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-22 00:00:00', 26.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-23 00:00:00', 28.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-24 00:00:00', 32.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-25 00:00:00', 35.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-26 00:00:00', 35.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-27 00:00:00', 32.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-28 00:00:00', 37.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-29 00:00:00', 31.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-30 00:00:00', 29.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-05-31 00:00:00', 32.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-01 00:00:00', 33.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-02 00:00:00', 29.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-03 00:00:00', 33.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-04 00:00:00', 36.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-05 00:00:00', 36.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-06 00:00:00', 37.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-07 00:00:00', 35.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-08 00:00:00', 33.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-09 00:00:00', 28.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-10 00:00:00', 31.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-11 00:00:00', 32.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-12 00:00:00', 31.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-13 00:00:00', 32.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-14 00:00:00', 34.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-15 00:00:00', 32.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-16 00:00:00', 33.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-17 00:00:00', 34.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-18 00:00:00', 36.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-19 00:00:00', 36.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-20 00:00:00', 29.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-21 00:00:00', 27.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-22 00:00:00', 31.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-23 00:00:00', 33.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-24 00:00:00', 34.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-25 00:00:00', 36.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-26 00:00:00', 37.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-27 00:00:00', 37.8170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-28 00:00:00', 38.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-29 00:00:00', 37.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-06-30 00:00:00', 38.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-01 00:00:00', 38.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-02 00:00:00', 37.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-03 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-04 00:00:00', 39.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-05 00:00:00', 31.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-06 00:00:00', 34.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-07 00:00:00', 35.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-08 00:00:00', 36.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-09 00:00:00', 38.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-10 00:00:00', 39.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-11 00:00:00', 31.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-12 00:00:00', 30.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-13 00:00:00', 30.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-14 00:00:00', 28.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-15 00:00:00', 33.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-16 00:00:00', 32.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-17 00:00:00', 34.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-18 00:00:00', 36.4630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-19 00:00:00', 34.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-20 00:00:00', 36.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-21 00:00:00', 38.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-22 00:00:00', 40.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-23 00:00:00', 41.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-24 00:00:00', 43.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-25 00:00:00', 36.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-26 00:00:00', 33.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-27 00:00:00', 34.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-28 00:00:00', 35.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-29 00:00:00', 36.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-30 00:00:00', 37.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-07-31 00:00:00', 34.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-01 00:00:00', 35.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-02 00:00:00', 37.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-03 00:00:00', 37.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-04 00:00:00', 37.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-05 00:00:00', 37.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-06 00:00:00', 39.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-07 00:00:00', 39.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-08 00:00:00', 38.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-09 00:00:00', 37.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-10 00:00:00', 38.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-11 00:00:00', 39.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-12 00:00:00', 38.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-13 00:00:00', 39.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-14 00:00:00', 40.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-15 00:00:00', 40.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-16 00:00:00', 40.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-17 00:00:00', 39.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-18 00:00:00', 39.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-19 00:00:00', 39.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-20 00:00:00', 39.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-21 00:00:00', 39.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-22 00:00:00', 39.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-23 00:00:00', 39.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-24 00:00:00', 38.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-25 00:00:00', 37.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-26 00:00:00', 38.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-27 00:00:00', 37.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-28 00:00:00', 36.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-29 00:00:00', 36.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-30 00:00:00', 39.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-08-31 00:00:00', 34.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-01 00:00:00', 33.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-02 00:00:00', 33.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-03 00:00:00', 34.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-04 00:00:00', 34.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-05 00:00:00', 37.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-06 00:00:00', 38.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-07 00:00:00', 37.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-08 00:00:00', 29.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-09 00:00:00', 29.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-10 00:00:00', 28.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-11 00:00:00', 29.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-12 00:00:00', 30.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-13 00:00:00', 31.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-14 00:00:00', 34.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-15 00:00:00', 33.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-16 00:00:00', 32.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-17 00:00:00', 34.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-18 00:00:00', 34.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-19 00:00:00', 35.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-20 00:00:00', 23.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-21 00:00:00', 25.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-22 00:00:00', 30.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-23 00:00:00', 32.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-24 00:00:00', 26.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-25 00:00:00', 28.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-26 00:00:00', 28.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-27 00:00:00', 27.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-28 00:00:00', 28.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-29 00:00:00', 30.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-09-30 00:00:00', 31.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-01 00:00:00', 26.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-02 00:00:00', 27.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-03 00:00:00', 25.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-04 00:00:00', 29.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-05 00:00:00', 31.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-06 00:00:00', 28.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-07 00:00:00', 27.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-08 00:00:00', 22.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-09 00:00:00', 23.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-10 00:00:00', 13.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-11 00:00:00', 13.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-12 00:00:00', 13.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-13 00:00:00', 13.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-14 00:00:00', 14.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-15 00:00:00', 16.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-16 00:00:00', 17.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-17 00:00:00', 14.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-18 00:00:00', 15.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-19 00:00:00', 16.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-20 00:00:00', 18.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-21 00:00:00', 19.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-22 00:00:00', 21.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-23 00:00:00', 23.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-24 00:00:00', 17.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-25 00:00:00', 22.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-26 00:00:00', 16.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-27 00:00:00', 10.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-28 00:00:00', 2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-29 00:00:00', 3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-30 00:00:00', 10.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-10-31 00:00:00', 6.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-01 00:00:00', 10.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-02 00:00:00', 12.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-03 00:00:00', 13.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-04 00:00:00', 16.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-05 00:00:00', 16.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-06 00:00:00', 19.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-07 00:00:00', 21.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-08 00:00:00', 22.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-09 00:00:00', 18.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-10 00:00:00', 18.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-11 00:00:00', 16.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-12 00:00:00', 16.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-13 00:00:00', 17.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-14 00:00:00', 19.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-15 00:00:00', 20.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-16 00:00:00', 15.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-17 00:00:00', 15.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-18 00:00:00', 14.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-19 00:00:00', 15.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-20 00:00:00', 15.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-21 00:00:00', 16.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-22 00:00:00', 17.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-23 00:00:00', 17.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-24 00:00:00', 12.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-25 00:00:00', 7.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-26 00:00:00', 6.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-27 00:00:00', 0.395999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-28 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-29 00:00:00', 1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-11-30 00:00:00', -3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-01 00:00:00', -0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-02 00:00:00', -1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-03 00:00:00', -0.540000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-04 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-05 00:00:00', 7.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-06 00:00:00', 7.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-07 00:00:00', 9.93700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-08 00:00:00', 9.59799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-09 00:00:00', 13.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-10 00:00:00', 15.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-11 00:00:00', 11.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-12 00:00:00', 15.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-13 00:00:00', 16.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-14 00:00:00', 15.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-15 00:00:00', 8.49600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-16 00:00:00', 10.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-17 00:00:00', 13.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-18 00:00:00', 14.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-19 00:00:00', 15.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-20 00:00:00', 17.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-21 00:00:00', 20.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-22 00:00:00', 16.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-23 00:00:00', 16.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-24 00:00:00', 19.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-25 00:00:00', 14.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-26 00:00:00', 15.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-27 00:00:00', 15.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-28 00:00:00', 15.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-29 00:00:00', 8.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-30 00:00:00', 9.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1987-12-31 00:00:00', 12.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-01 00:00:00', 8.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-02 00:00:00', 13.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-03 00:00:00', 6.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-04 00:00:00', 9.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-05 00:00:00', 8.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-06 00:00:00', 12.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-07 00:00:00', 12.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-08 00:00:00', 7.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-09 00:00:00', 8.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-10 00:00:00', 9.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-11 00:00:00', 8.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-12 00:00:00', 5.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-13 00:00:00', 9.25599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-14 00:00:00', 7.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-15 00:00:00', 5.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-16 00:00:00', 9.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-17 00:00:00', 6.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-18 00:00:00', 9.01099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-19 00:00:00', 11.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-20 00:00:00', 7.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-21 00:00:00', -2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-22 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-23 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-24 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-25 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-26 00:00:00', 6.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-27 00:00:00', 7.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-28 00:00:00', 9.92599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-29 00:00:00', 13.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-30 00:00:00', 7.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-01-31 00:00:00', 7.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-01 00:00:00', 8.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-02 00:00:00', 16.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-03 00:00:00', 19.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-04 00:00:00', 9.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-05 00:00:00', 5.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-06 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-07 00:00:00', -0.200000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-08 00:00:00', -1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-09 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-10 00:00:00', 9.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-11 00:00:00', 8.03400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-12 00:00:00', 7.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-13 00:00:00', 9.29800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-14 00:00:00', 7.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-15 00:00:00', 11.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-16 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-17 00:00:00', 12.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-18 00:00:00', 7.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-19 00:00:00', 6.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-20 00:00:00', 12.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-21 00:00:00', 5.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-22 00:00:00', 6.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-23 00:00:00', 7.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-24 00:00:00', 12.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-25 00:00:00', 16.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-26 00:00:00', 8.81299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-27 00:00:00', 7.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-28 00:00:00', 7.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-02-29 00:00:00', 12.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-01 00:00:00', 15.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-02 00:00:00', 11.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-03 00:00:00', 19.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-04 00:00:00', 21.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-05 00:00:00', 21.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-06 00:00:00', 13.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-07 00:00:00', 7.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-08 00:00:00', 14.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-09 00:00:00', 12.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-10 00:00:00', 10.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-11 00:00:00', 13.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-12 00:00:00', 13.7860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-13 00:00:00', 11.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-14 00:00:00', 14.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-15 00:00:00', 12.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-16 00:00:00', 10.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-17 00:00:00', 12.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-18 00:00:00', 10.7559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-19 00:00:00', 14.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-20 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-21 00:00:00', 18.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-22 00:00:00', 13.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-23 00:00:00', 10.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-24 00:00:00', 9.81299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-25 00:00:00', 6.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-26 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-27 00:00:00', 13.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-28 00:00:00', 10.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-29 00:00:00', 10.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-30 00:00:00', 12.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-03-31 00:00:00', 14.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-01 00:00:00', 19.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-02 00:00:00', 11.9289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-03 00:00:00', 9.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-04 00:00:00', 11.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-05 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-06 00:00:00', 19.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-07 00:00:00', 18.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-08 00:00:00', 19.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-09 00:00:00', 13.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-10 00:00:00', 15.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-11 00:00:00', 21.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-12 00:00:00', 24.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-13 00:00:00', 26.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-14 00:00:00', 26.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-15 00:00:00', 28.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-16 00:00:00', 30.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-17 00:00:00', 22.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-18 00:00:00', 19.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-19 00:00:00', 23.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-20 00:00:00', 27.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-21 00:00:00', 27.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-22 00:00:00', 28.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-23 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-24 00:00:00', 28.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-25 00:00:00', 29.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-26 00:00:00', 31.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-27 00:00:00', 31.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-28 00:00:00', 32.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-29 00:00:00', 22.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-04-30 00:00:00', 23.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-01 00:00:00', 22.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-02 00:00:00', 22.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-03 00:00:00', 26.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-04 00:00:00', 21.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-05 00:00:00', 18.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-06 00:00:00', 21.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-07 00:00:00', 24.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-08 00:00:00', 26.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-09 00:00:00', 26.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-10 00:00:00', 28.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-11 00:00:00', 29.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-12 00:00:00', 31.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-13 00:00:00', 28.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-14 00:00:00', 26.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-15 00:00:00', 29.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-16 00:00:00', 22.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-17 00:00:00', 27.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-18 00:00:00', 24.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-19 00:00:00', 27.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-20 00:00:00', 30.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-21 00:00:00', 30.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-22 00:00:00', 29.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-23 00:00:00', 29.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-24 00:00:00', 30.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-25 00:00:00', 30.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-26 00:00:00', 34.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-27 00:00:00', 33.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-28 00:00:00', 32.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-29 00:00:00', 37.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-30 00:00:00', 37.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-05-31 00:00:00', 30.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-01 00:00:00', 30.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-02 00:00:00', 31.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-03 00:00:00', 32.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-04 00:00:00', 29.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-05 00:00:00', 32.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-06 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-07 00:00:00', 33.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-08 00:00:00', 31.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-09 00:00:00', 31.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-10 00:00:00', 28.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-11 00:00:00', 33.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-12 00:00:00', 36.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-13 00:00:00', 37.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-14 00:00:00', 38.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-15 00:00:00', 37.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-16 00:00:00', 39.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-17 00:00:00', 40.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-18 00:00:00', 41.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-19 00:00:00', 40.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-20 00:00:00', 43.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-21 00:00:00', 40.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-22 00:00:00', 38.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-23 00:00:00', 39.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-24 00:00:00', 42.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-25 00:00:00', 44.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-26 00:00:00', 41.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-27 00:00:00', 36.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-28 00:00:00', 32.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-29 00:00:00', 34.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-06-30 00:00:00', 36.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-01 00:00:00', 40.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-02 00:00:00', 43.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-03 00:00:00', 40.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-04 00:00:00', 40.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-05 00:00:00', 39.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-06 00:00:00', 38.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-07 00:00:00', 37.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-08 00:00:00', 38.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-09 00:00:00', 39.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-10 00:00:00', 42.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-11 00:00:00', 42.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-12 00:00:00', 42.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-13 00:00:00', 44.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-14 00:00:00', 39.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-15 00:00:00', 38.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-16 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-17 00:00:00', 39.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-18 00:00:00', 40.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-19 00:00:00', 41.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-20 00:00:00', 41.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-21 00:00:00', 41.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-22 00:00:00', 38.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-23 00:00:00', 35.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-24 00:00:00', 35.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-25 00:00:00', 37.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-26 00:00:00', 38.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-27 00:00:00', 40.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-28 00:00:00', 41.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-29 00:00:00', 39.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-30 00:00:00', 39.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-07-31 00:00:00', 40.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-01 00:00:00', 37.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-02 00:00:00', 35.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-03 00:00:00', 35.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-04 00:00:00', 36.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-05 00:00:00', 38.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-06 00:00:00', 39.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-07 00:00:00', 39.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-08 00:00:00', 38.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-09 00:00:00', 37.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-10 00:00:00', 38.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-11 00:00:00', 38.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-12 00:00:00', 38.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-13 00:00:00', 38.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-14 00:00:00', 39.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-15 00:00:00', 37.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-16 00:00:00', 35.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-17 00:00:00', 36.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-18 00:00:00', 36.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-19 00:00:00', 36.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-20 00:00:00', 37.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-21 00:00:00', 36.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-22 00:00:00', 34.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-23 00:00:00', 33.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-24 00:00:00', 32.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-25 00:00:00', 32.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-26 00:00:00', 29.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-27 00:00:00', 31.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-28 00:00:00', 32.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-29 00:00:00', 34.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-30 00:00:00', 35.1899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-08-31 00:00:00', 35.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-01 00:00:00', 36.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-02 00:00:00', 34.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-03 00:00:00', 35.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-04 00:00:00', 35.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-05 00:00:00', 37.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-06 00:00:00', 39.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-07 00:00:00', 38.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-08 00:00:00', 34.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-09 00:00:00', 33.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-10 00:00:00', 35.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-11 00:00:00', 36.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-12 00:00:00', 36.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-13 00:00:00', 36.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-14 00:00:00', 33.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-15 00:00:00', 32.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-16 00:00:00', 30.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-17 00:00:00', 29.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-18 00:00:00', 31.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-19 00:00:00', 32.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-20 00:00:00', 32.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-21 00:00:00', 32.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-22 00:00:00', 24.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-23 00:00:00', 26.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-24 00:00:00', 25.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-25 00:00:00', 25.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-26 00:00:00', 24.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-27 00:00:00', 25.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-28 00:00:00', 24.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-29 00:00:00', 23.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-09-30 00:00:00', 24.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-01 00:00:00', 23.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-02 00:00:00', 23.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-03 00:00:00', 17.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-04 00:00:00', 21.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-05 00:00:00', 23.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-06 00:00:00', 24.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-07 00:00:00', 24.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-08 00:00:00', 24.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-09 00:00:00', 25.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-10 00:00:00', 26.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-11 00:00:00', 24.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-12 00:00:00', 23.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-13 00:00:00', 22.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-14 00:00:00', 22.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-15 00:00:00', 24.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-16 00:00:00', 19.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-17 00:00:00', 19.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-18 00:00:00', 19.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-19 00:00:00', 20.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-20 00:00:00', 22.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-21 00:00:00', 26.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-22 00:00:00', 25.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-23 00:00:00', 16.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-24 00:00:00', 19.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-25 00:00:00', 20.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-26 00:00:00', 21.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-27 00:00:00', 25.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-28 00:00:00', 25.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-29 00:00:00', 17.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-30 00:00:00', 21.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-10-31 00:00:00', 24.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-01 00:00:00', 23.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-02 00:00:00', 24.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-03 00:00:00', 24.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-04 00:00:00', 24.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-05 00:00:00', 24.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-06 00:00:00', 21.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-07 00:00:00', 21.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-08 00:00:00', 23.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-09 00:00:00', 25.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-10 00:00:00', 25.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-11 00:00:00', 27.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-12 00:00:00', 27.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-13 00:00:00', 26.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-14 00:00:00', 27.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-15 00:00:00', 17.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-16 00:00:00', 16.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-17 00:00:00', 21.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-18 00:00:00', 20.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-19 00:00:00', 20.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-20 00:00:00', 24.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-21 00:00:00', 16.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-22 00:00:00', 11.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-23 00:00:00', 8.52499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-24 00:00:00', 11.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-25 00:00:00', 11.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-26 00:00:00', 13.1549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-27 00:00:00', 15.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-28 00:00:00', 17.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-29 00:00:00', 18.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-11-30 00:00:00', 17.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-01 00:00:00', 16.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-02 00:00:00', 15.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-03 00:00:00', 18.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-04 00:00:00', 19.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-05 00:00:00', 15.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-06 00:00:00', 16.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-07 00:00:00', 16.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-08 00:00:00', 16.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-09 00:00:00', 16.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-10 00:00:00', 18.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-11 00:00:00', 15.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-12 00:00:00', 19.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-13 00:00:00', 18.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-14 00:00:00', 11.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-15 00:00:00', 14.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-16 00:00:00', 12.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-17 00:00:00', 10.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-18 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-19 00:00:00', 14.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-20 00:00:00', 13.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-21 00:00:00', 8.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-22 00:00:00', 6.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-23 00:00:00', 8.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-24 00:00:00', 8.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-25 00:00:00', 8.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-26 00:00:00', 12.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-27 00:00:00', 13.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-28 00:00:00', 10.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-29 00:00:00', 9.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-30 00:00:00', 5.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1988-12-31 00:00:00', 10.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-01 00:00:00', 6.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-02 00:00:00', 11.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-03 00:00:00', 9.71599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-04 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-05 00:00:00', 2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-06 00:00:00', 1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-07 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-08 00:00:00', 2.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-09 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-10 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-11 00:00:00', 5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-12 00:00:00', 6.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-13 00:00:00', 1.07700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-14 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-15 00:00:00', 1.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-16 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-17 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-18 00:00:00', 3.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-19 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-20 00:00:00', 3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-21 00:00:00', 6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-22 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-23 00:00:00', 6.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-24 00:00:00', 8.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-25 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-26 00:00:00', 7.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-27 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-28 00:00:00', 3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-29 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-30 00:00:00', 0.474999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-01-31 00:00:00', -0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-01 00:00:00', 5.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-02 00:00:00', 7.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-03 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-04 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-05 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-06 00:00:00', -0.634000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-07 00:00:00', 3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-08 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-09 00:00:00', 5.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-10 00:00:00', 9.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-11 00:00:00', 9.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-12 00:00:00', 6.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-13 00:00:00', 0.303000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-14 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-15 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-16 00:00:00', -1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-17 00:00:00', 3.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-18 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-19 00:00:00', 8.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-20 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-21 00:00:00', 3.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-22 00:00:00', 7.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-23 00:00:00', 9.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-24 00:00:00', 4.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-25 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-26 00:00:00', 1.00499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-27 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-02-28 00:00:00', 4.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-01 00:00:00', 7.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-02 00:00:00', 9.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-03 00:00:00', 10.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-04 00:00:00', 12.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-05 00:00:00', 14.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-06 00:00:00', 15.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-07 00:00:00', 15.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-08 00:00:00', 7.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-09 00:00:00', 11.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-10 00:00:00', 14.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-11 00:00:00', 16.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-12 00:00:00', 18.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-13 00:00:00', 9.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-14 00:00:00', 13.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-15 00:00:00', 19.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-16 00:00:00', 23.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-17 00:00:00', 14.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-18 00:00:00', 15.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-19 00:00:00', 17.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-20 00:00:00', 10.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-21 00:00:00', 16.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-22 00:00:00', 8.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-23 00:00:00', 12.814000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-24 00:00:00', 15.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-25 00:00:00', 18.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-26 00:00:00', 20.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-27 00:00:00', 22.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-28 00:00:00', 23.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-29 00:00:00', 15.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-30 00:00:00', 18.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-03-31 00:00:00', 10.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-01 00:00:00', 12.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-02 00:00:00', 14.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-03 00:00:00', 11.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-04 00:00:00', 6.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-05 00:00:00', 17.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-06 00:00:00', 19.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-07 00:00:00', 18.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-08 00:00:00', 15.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-09 00:00:00', 15.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-10 00:00:00', 16.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-11 00:00:00', 17.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-12 00:00:00', 18.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-13 00:00:00', 21.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-14 00:00:00', 24.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-15 00:00:00', 25.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-16 00:00:00', 19.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-17 00:00:00', 20.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-18 00:00:00', 20.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-19 00:00:00', 22.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-20 00:00:00', 24.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-21 00:00:00', 24.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-22 00:00:00', 22.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-23 00:00:00', 25.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-24 00:00:00', 22.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-25 00:00:00', 23.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-26 00:00:00', 25.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-27 00:00:00', 26.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-28 00:00:00', 26.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-29 00:00:00', 28.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-04-30 00:00:00', 18.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-01 00:00:00', 13.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-02 00:00:00', 13.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-03 00:00:00', 10.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-04 00:00:00', 12.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-05 00:00:00', 8.25599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-06 00:00:00', 14.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-07 00:00:00', 26.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-08 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-09 00:00:00', 19.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-10 00:00:00', 22.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-11 00:00:00', 25.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-12 00:00:00', 27.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-13 00:00:00', 29.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-14 00:00:00', 27.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-15 00:00:00', 23.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-16 00:00:00', 26.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-17 00:00:00', 26.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-18 00:00:00', 27.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-19 00:00:00', 31.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-20 00:00:00', 31.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-21 00:00:00', 26.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-22 00:00:00', 27.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-23 00:00:00', 26.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-24 00:00:00', 28.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-25 00:00:00', 30.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-26 00:00:00', 31.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-27 00:00:00', 33.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-28 00:00:00', 35.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-29 00:00:00', 38.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-30 00:00:00', 37.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-05-31 00:00:00', 35.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-01 00:00:00', 38.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-02 00:00:00', 37.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-03 00:00:00', 37.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-04 00:00:00', 35.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-05 00:00:00', 34.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-06 00:00:00', 32.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-07 00:00:00', 31.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-08 00:00:00', 32.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-09 00:00:00', 32.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-10 00:00:00', 32.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-11 00:00:00', 34.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-12 00:00:00', 37.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-13 00:00:00', 35.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-14 00:00:00', 34.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-15 00:00:00', 36.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-16 00:00:00', 34.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-17 00:00:00', 35.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-18 00:00:00', 34.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-19 00:00:00', 31.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-20 00:00:00', 30.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-21 00:00:00', 30.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-22 00:00:00', 33.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-23 00:00:00', 35.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-24 00:00:00', 37.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-25 00:00:00', 38.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-26 00:00:00', 39.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-27 00:00:00', 38.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-28 00:00:00', 38.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-29 00:00:00', 37.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-06-30 00:00:00', 37.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-01 00:00:00', 36.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-02 00:00:00', 35.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-03 00:00:00', 36.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-04 00:00:00', 35.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-05 00:00:00', 35.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-06 00:00:00', 36.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-07 00:00:00', 38.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-08 00:00:00', 40.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-09 00:00:00', 41.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-10 00:00:00', 42.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-11 00:00:00', 42.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-12 00:00:00', 41.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-13 00:00:00', 37.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-14 00:00:00', 36.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-15 00:00:00', 36.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-16 00:00:00', 36.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-17 00:00:00', 36.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-18 00:00:00', 36.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-19 00:00:00', 36.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-20 00:00:00', 37.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-21 00:00:00', 37.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-22 00:00:00', 38.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-23 00:00:00', 37.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-24 00:00:00', 35.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-25 00:00:00', 35.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-26 00:00:00', 35.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-27 00:00:00', 38.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-28 00:00:00', 39.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-29 00:00:00', 39.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-30 00:00:00', 37.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-07-31 00:00:00', 34.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-01 00:00:00', 36.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-02 00:00:00', 37.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-03 00:00:00', 39.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-04 00:00:00', 38.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-05 00:00:00', 37.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-06 00:00:00', 38.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-07 00:00:00', 38.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-08 00:00:00', 38.5530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-09 00:00:00', 39.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-10 00:00:00', 39.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-11 00:00:00', 40.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-12 00:00:00', 40.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-13 00:00:00', 38.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-14 00:00:00', 37.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-15 00:00:00', 35.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-16 00:00:00', 36.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-17 00:00:00', 37.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-18 00:00:00', 38.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-19 00:00:00', 35.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-20 00:00:00', 32.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-21 00:00:00', 33.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-22 00:00:00', 34.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-23 00:00:00', 34.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-24 00:00:00', 35.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-25 00:00:00', 35.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-26 00:00:00', 35.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-27 00:00:00', 33.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-28 00:00:00', 31.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-29 00:00:00', 33.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-30 00:00:00', 33.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-08-31 00:00:00', 33.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-01 00:00:00', 33.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-02 00:00:00', 35.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-03 00:00:00', 35.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-04 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-05 00:00:00', 28.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-06 00:00:00', 28.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-07 00:00:00', 30.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-08 00:00:00', 31.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-09 00:00:00', 32.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-10 00:00:00', 33.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-11 00:00:00', 34.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-12 00:00:00', 33.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-13 00:00:00', 34.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-14 00:00:00', 38.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-15 00:00:00', 39.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-16 00:00:00', 34.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-17 00:00:00', 32.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-18 00:00:00', 34.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-19 00:00:00', 34.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-20 00:00:00', 27.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-21 00:00:00', 26.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-22 00:00:00', 17.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-23 00:00:00', 20.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-24 00:00:00', 23.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-25 00:00:00', 27.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-26 00:00:00', 28.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-27 00:00:00', 28.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-28 00:00:00', 30.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-29 00:00:00', 29.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-09-30 00:00:00', 26.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-01 00:00:00', 28.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-02 00:00:00', 31.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-03 00:00:00', 32.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-04 00:00:00', 31.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-05 00:00:00', 30.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-06 00:00:00', 31.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-07 00:00:00', 31.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-08 00:00:00', 31.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-09 00:00:00', 30.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-10 00:00:00', 24.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-11 00:00:00', 17.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-12 00:00:00', 20.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-13 00:00:00', 22.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-14 00:00:00', 22.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-15 00:00:00', 23.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-16 00:00:00', 23.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-17 00:00:00', 25.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-18 00:00:00', 27.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-19 00:00:00', 26.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-20 00:00:00', 28.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-21 00:00:00', 26.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-22 00:00:00', 23.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-23 00:00:00', 20.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-24 00:00:00', 13.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-25 00:00:00', 19.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-26 00:00:00', 20.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-27 00:00:00', 19.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-28 00:00:00', 21.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-29 00:00:00', 23.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-30 00:00:00', 20.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-10-31 00:00:00', 25.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-01 00:00:00', 15.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-02 00:00:00', 10.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-03 00:00:00', 13.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-04 00:00:00', 14.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-05 00:00:00', 15.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-06 00:00:00', 16.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-07 00:00:00', 15.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-08 00:00:00', 9.85299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-09 00:00:00', 14.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-10 00:00:00', 7.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-11 00:00:00', 10.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-12 00:00:00', 13.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-13 00:00:00', 15.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-14 00:00:00', 16.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-15 00:00:00', 18.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-16 00:00:00', 20.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-17 00:00:00', 16.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-18 00:00:00', 12.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-19 00:00:00', 17.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-20 00:00:00', 19.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-21 00:00:00', 16.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-22 00:00:00', 11.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-23 00:00:00', 12.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-24 00:00:00', 13.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-25 00:00:00', 15.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-26 00:00:00', 17.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-27 00:00:00', 17.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-28 00:00:00', 18.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-29 00:00:00', 18.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-11-30 00:00:00', 18.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-01 00:00:00', 21.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-02 00:00:00', 20.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-03 00:00:00', 16.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-04 00:00:00', 12.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-05 00:00:00', 19.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-06 00:00:00', 14.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-07 00:00:00', 12.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-08 00:00:00', 10.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-09 00:00:00', 15.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-10 00:00:00', 12.7589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-11 00:00:00', 14.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-12 00:00:00', 15.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-13 00:00:00', 16.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-14 00:00:00', 14.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-15 00:00:00', 15.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-16 00:00:00', 11.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-17 00:00:00', 13.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-18 00:00:00', 9.08899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-19 00:00:00', 11.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-20 00:00:00', 8.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-21 00:00:00', 9.53199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-22 00:00:00', 7.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-23 00:00:00', 7.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-24 00:00:00', 9.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-25 00:00:00', 8.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-26 00:00:00', 10.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-27 00:00:00', 10.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-28 00:00:00', 7.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-29 00:00:00', 7.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-30 00:00:00', 9.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1989-12-31 00:00:00', 6.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-01 00:00:00', 4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-02 00:00:00', 6.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-03 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-04 00:00:00', 7.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-05 00:00:00', 11.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-06 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-07 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-08 00:00:00', 1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-09 00:00:00', 0.653999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-10 00:00:00', 4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-11 00:00:00', 0.570999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-12 00:00:00', 0.372000008821487427, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-13 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-14 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-15 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-16 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-17 00:00:00', 4.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-18 00:00:00', 8.16199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-19 00:00:00', 9.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-20 00:00:00', 6.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-21 00:00:00', 9.31999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-22 00:00:00', 9.92800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-23 00:00:00', 12.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-24 00:00:00', 14.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-25 00:00:00', 12.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-26 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-27 00:00:00', -0.794000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-28 00:00:00', 0.00800000037997961044, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-29 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-30 00:00:00', 4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-01-31 00:00:00', -0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-01 00:00:00', 1.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-02 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-03 00:00:00', 7.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-04 00:00:00', 7.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-05 00:00:00', 8.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-06 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-07 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-08 00:00:00', 4.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-09 00:00:00', 6.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-10 00:00:00', 10.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-11 00:00:00', 12.3660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-12 00:00:00', 7.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-13 00:00:00', 6.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-14 00:00:00', 7.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-15 00:00:00', 10.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-16 00:00:00', 11.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-17 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-18 00:00:00', 11.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-19 00:00:00', 12.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-20 00:00:00', 13.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-21 00:00:00', 14.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-22 00:00:00', 8.33899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-23 00:00:00', 6.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-24 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-25 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-26 00:00:00', 6.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-27 00:00:00', 5.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-02-28 00:00:00', 8.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-01 00:00:00', 11.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-02 00:00:00', 13.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-03 00:00:00', 13.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-04 00:00:00', 13.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-05 00:00:00', 14.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-06 00:00:00', 13.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-07 00:00:00', 14.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-08 00:00:00', 18.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-09 00:00:00', 9.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-10 00:00:00', 9.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-11 00:00:00', 14.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-12 00:00:00', 15.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-13 00:00:00', 19.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-14 00:00:00', 21.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-15 00:00:00', 19.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-16 00:00:00', 13.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-17 00:00:00', 9.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-18 00:00:00', 8.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-19 00:00:00', 8.35299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-20 00:00:00', 6.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-21 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-22 00:00:00', 5.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-23 00:00:00', 9.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-24 00:00:00', 11.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-25 00:00:00', 16.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-26 00:00:00', 14.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-27 00:00:00', 15.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-28 00:00:00', 17.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-29 00:00:00', 18.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-30 00:00:00', 15.255000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-03-31 00:00:00', 15.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-01 00:00:00', 18.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-02 00:00:00', 21.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-03 00:00:00', 21.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-04 00:00:00', 19.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-05 00:00:00', 21.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-06 00:00:00', 14.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-07 00:00:00', 19.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-08 00:00:00', 12.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-09 00:00:00', 17.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-10 00:00:00', 19.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-11 00:00:00', 20.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-12 00:00:00', 16.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-13 00:00:00', 20.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-14 00:00:00', 17.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-15 00:00:00', 17.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-16 00:00:00', 19.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-17 00:00:00', 14.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-18 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-19 00:00:00', 20.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-20 00:00:00', 19.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-21 00:00:00', 17.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-22 00:00:00', 24.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-23 00:00:00', 25.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-24 00:00:00', 21.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-25 00:00:00', 22.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-26 00:00:00', 23.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-27 00:00:00', 22.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-28 00:00:00', 26.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-29 00:00:00', 28.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-04-30 00:00:00', 28.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-01 00:00:00', 28.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-02 00:00:00', 26.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-03 00:00:00', 31.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-04 00:00:00', 32.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-05 00:00:00', 33.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-06 00:00:00', 31.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-07 00:00:00', 33.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-08 00:00:00', 28.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-09 00:00:00', 30.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-10 00:00:00', 31.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-11 00:00:00', 34.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-12 00:00:00', 36.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-13 00:00:00', 39.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-14 00:00:00', 35.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-15 00:00:00', 25.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-16 00:00:00', 28.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-17 00:00:00', 28.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-18 00:00:00', 28.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-19 00:00:00', 30.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-20 00:00:00', 32.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-21 00:00:00', 33.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-22 00:00:00', 33.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-23 00:00:00', 35.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-24 00:00:00', 34.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-25 00:00:00', 32.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-26 00:00:00', 32.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-27 00:00:00', 36.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-28 00:00:00', 30.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-29 00:00:00', 31.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-30 00:00:00', 31.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-05-31 00:00:00', 31.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-01 00:00:00', 32.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-02 00:00:00', 35.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-03 00:00:00', 34.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-04 00:00:00', 34.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-05 00:00:00', 34.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-06 00:00:00', 34.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-07 00:00:00', 36.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-08 00:00:00', 34.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-09 00:00:00', 30.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-10 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-11 00:00:00', 34.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-12 00:00:00', 33.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-13 00:00:00', 34.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-14 00:00:00', 36.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-15 00:00:00', 38.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-16 00:00:00', 40.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-17 00:00:00', 40.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-18 00:00:00', 41.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-19 00:00:00', 41.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-20 00:00:00', 42.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-21 00:00:00', 42.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-22 00:00:00', 44.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-23 00:00:00', 41.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-24 00:00:00', 39.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-25 00:00:00', 39.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-26 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-27 00:00:00', 39.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-28 00:00:00', 40.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-29 00:00:00', 41.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-06-30 00:00:00', 42.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-01 00:00:00', 39.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-02 00:00:00', 38.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-03 00:00:00', 38.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-04 00:00:00', 37.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-05 00:00:00', 37.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-06 00:00:00', 38.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-07 00:00:00', 38.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-08 00:00:00', 39.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-09 00:00:00', 37.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-10 00:00:00', 35.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-11 00:00:00', 35.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-12 00:00:00', 34.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-13 00:00:00', 32.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-14 00:00:00', 35.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-15 00:00:00', 36.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-16 00:00:00', 36.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-17 00:00:00', 38.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-18 00:00:00', 38.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-19 00:00:00', 37.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-20 00:00:00', 38.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-21 00:00:00', 36.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-22 00:00:00', 36.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-23 00:00:00', 37.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-24 00:00:00', 39.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-25 00:00:00', 41.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-26 00:00:00', 40.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-27 00:00:00', 37.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-28 00:00:00', 38.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-29 00:00:00', 39.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-30 00:00:00', 42.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-07-31 00:00:00', 42.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-01 00:00:00', 39.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-02 00:00:00', 38.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-03 00:00:00', 38.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-04 00:00:00', 38.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-05 00:00:00', 39.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-06 00:00:00', 40.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-07 00:00:00', 41.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-08 00:00:00', 42.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-09 00:00:00', 42.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-10 00:00:00', 42.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-11 00:00:00', 42.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-12 00:00:00', 40.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-13 00:00:00', 38.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-14 00:00:00', 35.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-15 00:00:00', 36.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-16 00:00:00', 38.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-17 00:00:00', 38.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-18 00:00:00', 38.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-19 00:00:00', 36.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-20 00:00:00', 38.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-21 00:00:00', 39.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-22 00:00:00', 38.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-23 00:00:00', 34.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-24 00:00:00', 35.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-25 00:00:00', 35.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-26 00:00:00', 35.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-27 00:00:00', 37.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-28 00:00:00', 39.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-29 00:00:00', 37.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-30 00:00:00', 34.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-08-31 00:00:00', 34.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-01 00:00:00', 35.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-02 00:00:00', 37.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-03 00:00:00', 34.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-04 00:00:00', 31.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-05 00:00:00', 32.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-06 00:00:00', 33.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-07 00:00:00', 34.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-08 00:00:00', 34.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-09 00:00:00', 33.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-10 00:00:00', 33.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-11 00:00:00', 33.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-12 00:00:00', 33.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-13 00:00:00', 34.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-14 00:00:00', 36.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-15 00:00:00', 36.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-16 00:00:00', 35.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-17 00:00:00', 33.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-18 00:00:00', 33.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-19 00:00:00', 33.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-20 00:00:00', 33.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-21 00:00:00', 34.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-22 00:00:00', 34.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-23 00:00:00', 33.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-24 00:00:00', 29.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-25 00:00:00', 31.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-26 00:00:00', 30.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-27 00:00:00', 30.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-28 00:00:00', 29.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-29 00:00:00', 30.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-09-30 00:00:00', 30.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-01 00:00:00', 31.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-02 00:00:00', 31.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-03 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-04 00:00:00', 30.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-05 00:00:00', 30.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-06 00:00:00', 22.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-07 00:00:00', 22.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-08 00:00:00', 24.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-09 00:00:00', 24.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-10 00:00:00', 26.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-11 00:00:00', 27.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-12 00:00:00', 25.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-13 00:00:00', 24.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-14 00:00:00', 25.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-15 00:00:00', 22.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-16 00:00:00', 14.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-17 00:00:00', 14.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-18 00:00:00', 15.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-19 00:00:00', 11.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-20 00:00:00', 17.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-21 00:00:00', 20.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-22 00:00:00', 22.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-23 00:00:00', 21.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-24 00:00:00', 24.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-25 00:00:00', 24.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-26 00:00:00', 25.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-27 00:00:00', 25.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-28 00:00:00', 25.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-29 00:00:00', 23.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-30 00:00:00', 15.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-10-31 00:00:00', 17.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-01 00:00:00', 17.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-02 00:00:00', 18.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-03 00:00:00', 18.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-04 00:00:00', 22.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-05 00:00:00', 21.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-06 00:00:00', 21.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-07 00:00:00', 22.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-08 00:00:00', 22.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-09 00:00:00', 22.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-10 00:00:00', 24.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-11 00:00:00', 24.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-12 00:00:00', 24.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-13 00:00:00', 25.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-14 00:00:00', 15.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-15 00:00:00', 12.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-16 00:00:00', 14.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-17 00:00:00', 9.87100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-18 00:00:00', 12.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-19 00:00:00', 15.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-20 00:00:00', 18.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-21 00:00:00', 18.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-22 00:00:00', 16.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-23 00:00:00', 14.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-24 00:00:00', 15.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-25 00:00:00', 16.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-26 00:00:00', 16.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-27 00:00:00', 14.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-28 00:00:00', 15.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-29 00:00:00', 16.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-11-30 00:00:00', 16.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-01 00:00:00', 16.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-02 00:00:00', 16.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-03 00:00:00', 18.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-04 00:00:00', 18.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-05 00:00:00', 18.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-06 00:00:00', 19.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-07 00:00:00', 19.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-08 00:00:00', 13.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-09 00:00:00', 13.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-10 00:00:00', 7.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-11 00:00:00', 6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-12 00:00:00', 6.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-13 00:00:00', 4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-14 00:00:00', 3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-15 00:00:00', 5.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-16 00:00:00', 5.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-17 00:00:00', 5.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-18 00:00:00', 9.97799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-19 00:00:00', 13.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-20 00:00:00', 8.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-21 00:00:00', 12.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-22 00:00:00', 10.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-23 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-24 00:00:00', 6.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-25 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-26 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-27 00:00:00', -2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-28 00:00:00', -3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-29 00:00:00', -7.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-30 00:00:00', -10.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1990-12-31 00:00:00', -5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-01 00:00:00', -2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-02 00:00:00', -0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-03 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-04 00:00:00', 3.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-05 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-06 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-07 00:00:00', 2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-08 00:00:00', 2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-09 00:00:00', 6.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-10 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-11 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-12 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-13 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-14 00:00:00', 4.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-15 00:00:00', 6.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-16 00:00:00', 1.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-17 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-18 00:00:00', 2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-19 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-20 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-21 00:00:00', 3.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-22 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-23 00:00:00', 1.89699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-24 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-25 00:00:00', 3.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-26 00:00:00', 8.60299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-27 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-28 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-29 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-30 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-01-31 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-01 00:00:00', 7.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-02 00:00:00', 8.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-03 00:00:00', 7.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-04 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-05 00:00:00', 6.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-06 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-07 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-08 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-09 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-10 00:00:00', 1.2489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-11 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-12 00:00:00', 3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-13 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-14 00:00:00', -3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-15 00:00:00', -1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-16 00:00:00', 1.07400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-17 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-18 00:00:00', 7.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-19 00:00:00', 10.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-20 00:00:00', 12.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-21 00:00:00', 13.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-22 00:00:00', 14.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-23 00:00:00', 9.26099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-24 00:00:00', 5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-25 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-26 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-27 00:00:00', 6.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-02-28 00:00:00', 13.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-01 00:00:00', 15.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-02 00:00:00', 8.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-03 00:00:00', 9.87399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-04 00:00:00', 6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-05 00:00:00', 6.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-06 00:00:00', 11.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-07 00:00:00', 9.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-08 00:00:00', 6.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-09 00:00:00', 10.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-10 00:00:00', 12.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-11 00:00:00', 11.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-12 00:00:00', 6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-13 00:00:00', 5.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-14 00:00:00', 6.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-15 00:00:00', 7.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-16 00:00:00', 6.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-17 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-18 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-19 00:00:00', 11.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-20 00:00:00', 8.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-21 00:00:00', 7.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-22 00:00:00', 9.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-23 00:00:00', 13.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-24 00:00:00', 16.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-25 00:00:00', 16.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-26 00:00:00', 17.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-27 00:00:00', 20.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-28 00:00:00', 23.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-29 00:00:00', 17.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-30 00:00:00', 21.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-03-31 00:00:00', 22.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-01 00:00:00', 24.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-02 00:00:00', 16.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-03 00:00:00', 20.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-04 00:00:00', 23.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-05 00:00:00', 24.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-06 00:00:00', 21.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-07 00:00:00', 19.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-08 00:00:00', 15.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-09 00:00:00', 14.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-10 00:00:00', 18.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-11 00:00:00', 20.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-12 00:00:00', 20.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-13 00:00:00', 17.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-14 00:00:00', 17.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-15 00:00:00', 11.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-16 00:00:00', 15.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-17 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-18 00:00:00', 20.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-19 00:00:00', 24.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-20 00:00:00', 24.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-21 00:00:00', 19.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-22 00:00:00', 23.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-23 00:00:00', 25.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-24 00:00:00', 25.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-25 00:00:00', 25.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-26 00:00:00', 26.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-27 00:00:00', 23.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-28 00:00:00', 21.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-29 00:00:00', 23.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-04-30 00:00:00', 26.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-01 00:00:00', 21.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-02 00:00:00', 21.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-03 00:00:00', 25.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-04 00:00:00', 23.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-05 00:00:00', 23.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-06 00:00:00', 25.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-07 00:00:00', 24.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-08 00:00:00', 21.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-09 00:00:00', 25.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-10 00:00:00', 27.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-11 00:00:00', 28.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-12 00:00:00', 25.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-13 00:00:00', 26.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-14 00:00:00', 26.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-15 00:00:00', 26.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-16 00:00:00', 24.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-17 00:00:00', 29.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-18 00:00:00', 29.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-19 00:00:00', 24.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-20 00:00:00', 18.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-21 00:00:00', 19.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-22 00:00:00', 27.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-23 00:00:00', 30.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-24 00:00:00', 25.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-25 00:00:00', 23.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-26 00:00:00', 25.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-27 00:00:00', 25.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-28 00:00:00', 29.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-29 00:00:00', 30.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-30 00:00:00', 31.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-05-31 00:00:00', 32.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-01 00:00:00', 35.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-02 00:00:00', 36.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-03 00:00:00', 36.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-04 00:00:00', 37.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-05 00:00:00', 38.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-06 00:00:00', 38.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-07 00:00:00', 34.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-08 00:00:00', 36.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-09 00:00:00', 34.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-10 00:00:00', 32.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-11 00:00:00', 30.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-12 00:00:00', 35.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-13 00:00:00', 39.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-14 00:00:00', 38.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-15 00:00:00', 35.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-16 00:00:00', 33.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-17 00:00:00', 35.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-18 00:00:00', 33.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-19 00:00:00', 30.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-20 00:00:00', 33.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-21 00:00:00', 32.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-22 00:00:00', 33.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-23 00:00:00', 30.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-24 00:00:00', 26.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-25 00:00:00', 27.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-26 00:00:00', 28.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-27 00:00:00', 33.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-28 00:00:00', 35.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-29 00:00:00', 36.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-06-30 00:00:00', 37.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-01 00:00:00', 37.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-02 00:00:00', 37.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-03 00:00:00', 38.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-04 00:00:00', 37.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-05 00:00:00', 37.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-06 00:00:00', 37.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-07 00:00:00', 38.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-08 00:00:00', 39.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-09 00:00:00', 40.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-10 00:00:00', 38.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-11 00:00:00', 37.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-12 00:00:00', 34.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-13 00:00:00', 32.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-14 00:00:00', 35.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-15 00:00:00', 36.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-16 00:00:00', 38.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-17 00:00:00', 37.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-18 00:00:00', 37.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-19 00:00:00', 37.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-20 00:00:00', 38.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-21 00:00:00', 37.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-22 00:00:00', 36.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-23 00:00:00', 36.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-24 00:00:00', 37.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-25 00:00:00', 37.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-26 00:00:00', 37.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-27 00:00:00', 37.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-28 00:00:00', 38.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-29 00:00:00', 40.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-30 00:00:00', 40.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-07-31 00:00:00', 39.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-01 00:00:00', 37.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-02 00:00:00', 38.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-03 00:00:00', 38.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-04 00:00:00', 38.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-05 00:00:00', 38.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-06 00:00:00', 37.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-07 00:00:00', 38.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-08 00:00:00', 35.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-09 00:00:00', 33.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-10 00:00:00', 33.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-11 00:00:00', 36.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-12 00:00:00', 38.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-13 00:00:00', 39.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-14 00:00:00', 39.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-15 00:00:00', 38.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-16 00:00:00', 38.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-17 00:00:00', 38.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-18 00:00:00', 39.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-19 00:00:00', 39.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-20 00:00:00', 37.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-21 00:00:00', 34.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-22 00:00:00', 33.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-23 00:00:00', 33.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-24 00:00:00', 33.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-25 00:00:00', 35.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-26 00:00:00', 36.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-27 00:00:00', 36.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-28 00:00:00', 35.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-29 00:00:00', 35.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-30 00:00:00', 35.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-08-31 00:00:00', 35.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-01 00:00:00', 35.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-02 00:00:00', 36.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-03 00:00:00', 37.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-04 00:00:00', 37.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-05 00:00:00', 35.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-06 00:00:00', 33.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-07 00:00:00', 32.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-08 00:00:00', 34.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-09 00:00:00', 35.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-10 00:00:00', 34.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-11 00:00:00', 34.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-12 00:00:00', 32.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-13 00:00:00', 32.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-14 00:00:00', 32.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-15 00:00:00', 32.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-16 00:00:00', 29.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-17 00:00:00', 29.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-18 00:00:00', 25.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-19 00:00:00', 28.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-20 00:00:00', 30.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-21 00:00:00', 32.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-22 00:00:00', 34.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-23 00:00:00', 34.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-24 00:00:00', 32.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-25 00:00:00', 30.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-26 00:00:00', 21.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-27 00:00:00', 15.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-28 00:00:00', 15.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-29 00:00:00', 13.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-09-30 00:00:00', 17.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-01 00:00:00', 20.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-02 00:00:00', 20.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-03 00:00:00', 24.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-04 00:00:00', 25.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-05 00:00:00', 26.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-06 00:00:00', 24.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-07 00:00:00', 22.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-08 00:00:00', 21.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-09 00:00:00', 23.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-10 00:00:00', 24.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-11 00:00:00', 16.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-12 00:00:00', 18.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-13 00:00:00', 18.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-14 00:00:00', 17.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-15 00:00:00', 19.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-16 00:00:00', 22.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-17 00:00:00', 23.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-18 00:00:00', 20.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-19 00:00:00', 22.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-20 00:00:00', 24.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-21 00:00:00', 20.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-22 00:00:00', 23.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-23 00:00:00', 24.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-24 00:00:00', 25.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-25 00:00:00', 24.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-26 00:00:00', 24.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-27 00:00:00', 24.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-28 00:00:00', 23.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-29 00:00:00', 22.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-30 00:00:00', 22.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-10-31 00:00:00', 23.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-01 00:00:00', 22.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-02 00:00:00', 22.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-03 00:00:00', 21.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-04 00:00:00', 19.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-05 00:00:00', 23.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-06 00:00:00', 23.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-07 00:00:00', 20.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-08 00:00:00', 16.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-09 00:00:00', 16.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-10 00:00:00', 16.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-11 00:00:00', 17.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-12 00:00:00', 18.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-13 00:00:00', 13.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-14 00:00:00', 13.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-15 00:00:00', 17.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-16 00:00:00', 14.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-17 00:00:00', 12.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-18 00:00:00', 16.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-19 00:00:00', 15.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-20 00:00:00', 13.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-21 00:00:00', 8.15699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-22 00:00:00', 12.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-23 00:00:00', 7.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-24 00:00:00', 11.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-25 00:00:00', 14.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-26 00:00:00', 14.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-27 00:00:00', 11.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-28 00:00:00', 6.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-29 00:00:00', 6.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-11-30 00:00:00', 9.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-01 00:00:00', 11.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-02 00:00:00', 15.7860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-03 00:00:00', 13.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-04 00:00:00', 12.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-05 00:00:00', 15.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-06 00:00:00', 13.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-07 00:00:00', 12.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-08 00:00:00', 13.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-09 00:00:00', 11.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-10 00:00:00', 11.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-11 00:00:00', 9.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-12 00:00:00', 11.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-13 00:00:00', 9.84799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-14 00:00:00', 8.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-15 00:00:00', 9.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-16 00:00:00', 8.32400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-17 00:00:00', 6.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-18 00:00:00', 2.76099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-19 00:00:00', 5.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-20 00:00:00', 0.870999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-21 00:00:00', 0.773000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-22 00:00:00', 6.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-23 00:00:00', 7.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-24 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-25 00:00:00', 4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-26 00:00:00', 6.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-27 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-28 00:00:00', 6.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-29 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-30 00:00:00', 4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1991-12-31 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-01 00:00:00', 6.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-02 00:00:00', 7.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-03 00:00:00', 6.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-04 00:00:00', 7.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-05 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-06 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-07 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-08 00:00:00', 6.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-09 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-10 00:00:00', -0.273999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-11 00:00:00', 0.938000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-12 00:00:00', 3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-13 00:00:00', 6.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-14 00:00:00', 6.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-15 00:00:00', 7.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-16 00:00:00', 8.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-17 00:00:00', 12.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-18 00:00:00', 7.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-19 00:00:00', 12.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-20 00:00:00', 12.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-21 00:00:00', 11.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-22 00:00:00', 11.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-23 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-24 00:00:00', 8.11900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-25 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-26 00:00:00', 6.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-27 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-28 00:00:00', 3.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-29 00:00:00', -1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-30 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-01-31 00:00:00', 7.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-01 00:00:00', 6.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-02 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-03 00:00:00', 9.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-04 00:00:00', 9.60700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-05 00:00:00', 9.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-06 00:00:00', 8.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-07 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-08 00:00:00', 8.19499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-09 00:00:00', 10.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-10 00:00:00', 10.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-11 00:00:00', 10.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-12 00:00:00', 6.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-13 00:00:00', 2.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-14 00:00:00', 5.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-15 00:00:00', 8.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-16 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-17 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-18 00:00:00', 9.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-19 00:00:00', 8.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-20 00:00:00', 11.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-21 00:00:00', 13.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-22 00:00:00', 10.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-23 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-24 00:00:00', 15.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-25 00:00:00', 17.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-26 00:00:00', 15.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-27 00:00:00', 7.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-28 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-02-29 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-01 00:00:00', 6.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-02 00:00:00', 9.60999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-03 00:00:00', 6.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-04 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-05 00:00:00', 9.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-06 00:00:00', 13.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-07 00:00:00', 11.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-08 00:00:00', 10.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-09 00:00:00', 8.07900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-10 00:00:00', 10.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-11 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-12 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-13 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-14 00:00:00', 9.18999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-15 00:00:00', 13.2100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-16 00:00:00', 13.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-17 00:00:00', 8.75300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-18 00:00:00', 13.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-19 00:00:00', 9.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-20 00:00:00', 8.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-21 00:00:00', 13.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-22 00:00:00', 11.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-23 00:00:00', 12.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-24 00:00:00', 13.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-25 00:00:00', 14.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-26 00:00:00', 8.13099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-27 00:00:00', 11.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-28 00:00:00', 14.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-29 00:00:00', 9.47299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-30 00:00:00', 12.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-03-31 00:00:00', 18.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-01 00:00:00', 17.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-02 00:00:00', 15.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-03 00:00:00', 17.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-04 00:00:00', 13.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-05 00:00:00', 20.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-06 00:00:00', 11.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-07 00:00:00', 15.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-08 00:00:00', 19.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-09 00:00:00', 20.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-10 00:00:00', 16.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-11 00:00:00', 18.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-12 00:00:00', 20.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-13 00:00:00', 23.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-14 00:00:00', 24.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-15 00:00:00', 25.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-16 00:00:00', 19.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-17 00:00:00', 14.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-18 00:00:00', 22.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-19 00:00:00', 24.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-20 00:00:00', 20.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-21 00:00:00', 15.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-22 00:00:00', 22.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-23 00:00:00', 25.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-24 00:00:00', 19.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-25 00:00:00', 25.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-26 00:00:00', 24.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-27 00:00:00', 25.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-28 00:00:00', 23.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-29 00:00:00', 22.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-04-30 00:00:00', 23.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-01 00:00:00', 19.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-02 00:00:00', 11.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-03 00:00:00', 15.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-04 00:00:00', 16.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-05 00:00:00', 19.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-06 00:00:00', 14.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-07 00:00:00', 20.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-08 00:00:00', 21.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-09 00:00:00', 24.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-10 00:00:00', 27.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-11 00:00:00', 29.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-12 00:00:00', 30.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-13 00:00:00', 27.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-14 00:00:00', 28.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-15 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-16 00:00:00', 20.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-17 00:00:00', 21.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-18 00:00:00', 23.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-19 00:00:00', 23.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-20 00:00:00', 24.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-21 00:00:00', 25.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-22 00:00:00', 27.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-23 00:00:00', 28.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-24 00:00:00', 29.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-25 00:00:00', 27.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-26 00:00:00', 24.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-27 00:00:00', 24.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-28 00:00:00', 26.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-29 00:00:00', 24.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-30 00:00:00', 28.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-05-31 00:00:00', 29.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-01 00:00:00', 31.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-02 00:00:00', 32.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-03 00:00:00', 32.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-04 00:00:00', 33.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-05 00:00:00', 35.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-06 00:00:00', 33.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-07 00:00:00', 33.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-08 00:00:00', 31.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-09 00:00:00', 32.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-10 00:00:00', 33.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-11 00:00:00', 32.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-12 00:00:00', 34.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-13 00:00:00', 30.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-14 00:00:00', 29.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-15 00:00:00', 31.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-16 00:00:00', 31.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-17 00:00:00', 30.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-18 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-19 00:00:00', 37.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-20 00:00:00', 39.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-21 00:00:00', 33.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-22 00:00:00', 34.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-23 00:00:00', 33.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-24 00:00:00', 34.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-25 00:00:00', 33.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-26 00:00:00', 35.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-27 00:00:00', 36.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-28 00:00:00', 36.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-29 00:00:00', 37.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-06-30 00:00:00', 35.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-01 00:00:00', 37.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-02 00:00:00', 33.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-03 00:00:00', 32.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-04 00:00:00', 35.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-05 00:00:00', 36.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-06 00:00:00', 39.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-07 00:00:00', 40.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-08 00:00:00', 38.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-09 00:00:00', 36.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-10 00:00:00', 39.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-11 00:00:00', 39.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-12 00:00:00', 38.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-13 00:00:00', 38.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-14 00:00:00', 34.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-15 00:00:00', 35.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-16 00:00:00', 36.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-17 00:00:00', 36.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-18 00:00:00', 37.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-19 00:00:00', 38.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-20 00:00:00', 39.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-21 00:00:00', 38.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-22 00:00:00', 39.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-23 00:00:00', 37.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-24 00:00:00', 37.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-25 00:00:00', 38.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-26 00:00:00', 38.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-27 00:00:00', 39.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-28 00:00:00', 40.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-29 00:00:00', 38.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-30 00:00:00', 36.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-07-31 00:00:00', 35.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-01 00:00:00', 38.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-02 00:00:00', 39.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-03 00:00:00', 39.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-04 00:00:00', 38.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-05 00:00:00', 36.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-06 00:00:00', 32.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-07 00:00:00', 33.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-08 00:00:00', 31.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-09 00:00:00', 31.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-10 00:00:00', 32.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-11 00:00:00', 34.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-12 00:00:00', 35.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-13 00:00:00', 33.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-14 00:00:00', 34.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-15 00:00:00', 33.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-16 00:00:00', 32.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-17 00:00:00', 29.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-18 00:00:00', 33.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-19 00:00:00', 34.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-20 00:00:00', 34.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-21 00:00:00', 34.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-22 00:00:00', 34.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-23 00:00:00', 36.0719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-24 00:00:00', 36.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-25 00:00:00', 38.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-26 00:00:00', 37.7949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-27 00:00:00', 37.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-28 00:00:00', 32.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-29 00:00:00', 32.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-30 00:00:00', 31.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-08-31 00:00:00', 29.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-01 00:00:00', 29.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-02 00:00:00', 26.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-03 00:00:00', 28.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-04 00:00:00', 30.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-05 00:00:00', 31.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-06 00:00:00', 31.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-07 00:00:00', 31.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-08 00:00:00', 31.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-09 00:00:00', 30.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-10 00:00:00', 26.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-11 00:00:00', 27.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-12 00:00:00', 28.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-13 00:00:00', 29.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-14 00:00:00', 29.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-15 00:00:00', 29.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-16 00:00:00', 28.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-17 00:00:00', 29.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-18 00:00:00', 29.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-19 00:00:00', 29.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-20 00:00:00', 28.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-21 00:00:00', 28.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-22 00:00:00', 29.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-23 00:00:00', 30.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-24 00:00:00', 30.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-25 00:00:00', 31.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-26 00:00:00', 33.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-27 00:00:00', 30.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-28 00:00:00', 31.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-29 00:00:00', 27.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-09-30 00:00:00', 22.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-01 00:00:00', 22.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-02 00:00:00', 22.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-03 00:00:00', 24.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-04 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-05 00:00:00', 23.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-06 00:00:00', 24.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-07 00:00:00', 21.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-08 00:00:00', 21.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-09 00:00:00', 22.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-10 00:00:00', 27.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-11 00:00:00', 29.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-12 00:00:00', 29.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-13 00:00:00', 28.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-14 00:00:00', 27.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-15 00:00:00', 24.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-16 00:00:00', 15.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-17 00:00:00', 11.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-18 00:00:00', 15.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-19 00:00:00', 20.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-20 00:00:00', 23.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-21 00:00:00', 20.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-22 00:00:00', 21.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-23 00:00:00', 21.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-24 00:00:00', 22.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-25 00:00:00', 23.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-26 00:00:00', 25.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-27 00:00:00', 27.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-28 00:00:00', 26.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-29 00:00:00', 27.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-30 00:00:00', 22.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-10-31 00:00:00', 22.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-01 00:00:00', 22.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-02 00:00:00', 21.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-03 00:00:00', 22.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-04 00:00:00', 13.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-05 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-06 00:00:00', 18.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-07 00:00:00', 21.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-08 00:00:00', 24.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-09 00:00:00', 22.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-10 00:00:00', 24.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-11 00:00:00', 23.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-12 00:00:00', 24.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-13 00:00:00', 26.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-14 00:00:00', 23.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-15 00:00:00', 23.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-16 00:00:00', 20.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-17 00:00:00', 16.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-18 00:00:00', 11.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-19 00:00:00', 7.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-20 00:00:00', 12.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-21 00:00:00', 7.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-22 00:00:00', 14.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-23 00:00:00', 20.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-24 00:00:00', 21.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-25 00:00:00', 21.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-26 00:00:00', 23.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-27 00:00:00', 12.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-28 00:00:00', 15.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-29 00:00:00', 18.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-11-30 00:00:00', 18.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-01 00:00:00', 15.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-02 00:00:00', 13.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-03 00:00:00', 7.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-04 00:00:00', 12.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-05 00:00:00', 11.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-06 00:00:00', 12.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-07 00:00:00', 13.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-08 00:00:00', 10.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-09 00:00:00', 13.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-10 00:00:00', 14.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-11 00:00:00', 7.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-12 00:00:00', 6.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-13 00:00:00', 8.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-14 00:00:00', 13.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-15 00:00:00', 13.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-16 00:00:00', 14.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-17 00:00:00', 14.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-18 00:00:00', 13.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-19 00:00:00', 16.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-20 00:00:00', 16.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-21 00:00:00', 15.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-22 00:00:00', 14.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-23 00:00:00', 11.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-24 00:00:00', 5.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-25 00:00:00', 7.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-26 00:00:00', 9.31200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-27 00:00:00', 9.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-28 00:00:00', 11.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-29 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-30 00:00:00', 7.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1992-12-31 00:00:00', 5.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-01 00:00:00', 7.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-02 00:00:00', 6.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-03 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-04 00:00:00', 6.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-05 00:00:00', 6.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-06 00:00:00', 1.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-07 00:00:00', -2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-08 00:00:00', -3.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-09 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-10 00:00:00', 2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-11 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-12 00:00:00', 2.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-13 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-14 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-15 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-16 00:00:00', 0.455000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-17 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-18 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-19 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-20 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-21 00:00:00', 1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-22 00:00:00', 4.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-23 00:00:00', 7.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-24 00:00:00', 7.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-25 00:00:00', 9.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-26 00:00:00', 9.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-27 00:00:00', 13.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-28 00:00:00', 13.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-29 00:00:00', 13.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-30 00:00:00', 14.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-01-31 00:00:00', 13.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-01 00:00:00', 12.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-02 00:00:00', 13.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-03 00:00:00', 17.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-04 00:00:00', 11.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-05 00:00:00', 13.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-06 00:00:00', 11.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-07 00:00:00', 15.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-08 00:00:00', 11.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-09 00:00:00', 13.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-10 00:00:00', 11.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-11 00:00:00', 13.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-12 00:00:00', 16.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-13 00:00:00', 10.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-14 00:00:00', 9.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-15 00:00:00', 13.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-16 00:00:00', 6.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-17 00:00:00', 1.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-18 00:00:00', -1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-19 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-20 00:00:00', 7.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-21 00:00:00', 8.53600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-22 00:00:00', 6.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-23 00:00:00', 10.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-24 00:00:00', 8.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-25 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-26 00:00:00', 8.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-27 00:00:00', 8.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-02-28 00:00:00', 12.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-01 00:00:00', 11.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-02 00:00:00', 6.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-03 00:00:00', 7.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-04 00:00:00', 14.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-05 00:00:00', 11.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-06 00:00:00', 17.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-07 00:00:00', 15.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-08 00:00:00', 19.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-09 00:00:00', 20.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-10 00:00:00', 11.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-11 00:00:00', 9.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-12 00:00:00', 12.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-13 00:00:00', 6.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-14 00:00:00', 5.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-15 00:00:00', 9.05799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-16 00:00:00', 9.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-17 00:00:00', 10.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-18 00:00:00', 11.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-19 00:00:00', 14.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-20 00:00:00', 7.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-21 00:00:00', 12.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-22 00:00:00', 13.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-23 00:00:00', 8.02700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-24 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-25 00:00:00', 7.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-26 00:00:00', 11.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-27 00:00:00', 14.5780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-28 00:00:00', 15.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-29 00:00:00', 17.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-30 00:00:00', 18.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-03-31 00:00:00', 17.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-01 00:00:00', 14.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-02 00:00:00', 15.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-03 00:00:00', 18.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-04 00:00:00', 21.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-05 00:00:00', 19.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-06 00:00:00', 22.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-07 00:00:00', 18.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-08 00:00:00', 21.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-09 00:00:00', 23.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-10 00:00:00', 21.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-11 00:00:00', 22.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-12 00:00:00', 25.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-13 00:00:00', 26.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-14 00:00:00', 21.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-15 00:00:00', 13.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-16 00:00:00', 18.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-17 00:00:00', 21.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-18 00:00:00', 25.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-19 00:00:00', 26.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-20 00:00:00', 28.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-21 00:00:00', 30.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-22 00:00:00', 28.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-23 00:00:00', 29.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-24 00:00:00', 19.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-25 00:00:00', 19.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-26 00:00:00', 24.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-27 00:00:00', 21.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-28 00:00:00', 23.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-29 00:00:00', 19.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-04-30 00:00:00', 25.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-01 00:00:00', 26.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-02 00:00:00', 25.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-03 00:00:00', 26.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-04 00:00:00', 28.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-05 00:00:00', 27.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-06 00:00:00', 26.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-07 00:00:00', 27.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-08 00:00:00', 21.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-09 00:00:00', 14.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-10 00:00:00', 17.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-11 00:00:00', 17.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-12 00:00:00', 20.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-13 00:00:00', 24.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-14 00:00:00', 28.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-15 00:00:00', 23.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-16 00:00:00', 22.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-17 00:00:00', 26.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-18 00:00:00', 26.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-19 00:00:00', 26.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-20 00:00:00', 28.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-21 00:00:00', 27.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-22 00:00:00', 29.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-23 00:00:00', 32.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-24 00:00:00', 24.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-25 00:00:00', 28.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-26 00:00:00', 27.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-27 00:00:00', 30.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-28 00:00:00', 31.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-29 00:00:00', 29.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-30 00:00:00', 21.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-05-31 00:00:00', 26.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-01 00:00:00', 30.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-02 00:00:00', 29.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-03 00:00:00', 30.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-04 00:00:00', 33.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-05 00:00:00', 33.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-06 00:00:00', 31.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-07 00:00:00', 30.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-08 00:00:00', 31.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-09 00:00:00', 34.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-10 00:00:00', 37.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-11 00:00:00', 37.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-12 00:00:00', 37.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-13 00:00:00', 33.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-14 00:00:00', 35.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-15 00:00:00', 33.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-16 00:00:00', 34.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-17 00:00:00', 34.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-18 00:00:00', 35.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-19 00:00:00', 36.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-20 00:00:00', 38.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-21 00:00:00', 38.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-22 00:00:00', 39.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-23 00:00:00', 28.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-24 00:00:00', 31.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-25 00:00:00', 33.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-26 00:00:00', 29.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-27 00:00:00', 35.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-28 00:00:00', 35.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-29 00:00:00', 38.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-06-30 00:00:00', 38.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-01 00:00:00', 38.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-02 00:00:00', 39.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-03 00:00:00', 40.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-04 00:00:00', 40.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-05 00:00:00', 40.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-06 00:00:00', 40.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-07 00:00:00', 40.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-08 00:00:00', 38.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-09 00:00:00', 34.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-10 00:00:00', 34.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-11 00:00:00', 35.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-12 00:00:00', 35.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-13 00:00:00', 37.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-14 00:00:00', 39.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-15 00:00:00', 37.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-16 00:00:00', 38.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-17 00:00:00', 38.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-18 00:00:00', 37.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-19 00:00:00', 39.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-20 00:00:00', 39.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-21 00:00:00', 39.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-22 00:00:00', 32.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-23 00:00:00', 33.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-24 00:00:00', 28.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-25 00:00:00', 32.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-26 00:00:00', 34.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-27 00:00:00', 36.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-28 00:00:00', 37.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-29 00:00:00', 36.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-30 00:00:00', 35.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-07-31 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-01 00:00:00', 35.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-02 00:00:00', 35.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-03 00:00:00', 35.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-04 00:00:00', 34.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-05 00:00:00', 35.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-06 00:00:00', 35.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-07 00:00:00', 35.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-08 00:00:00', 35.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-09 00:00:00', 34.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-10 00:00:00', 34.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-11 00:00:00', 32.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-12 00:00:00', 33.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-13 00:00:00', 35.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-14 00:00:00', 35.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-15 00:00:00', 36.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-16 00:00:00', 37.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-17 00:00:00', 36.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-18 00:00:00', 32.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-19 00:00:00', 31.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-20 00:00:00', 32.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-21 00:00:00', 33.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-22 00:00:00', 33.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-23 00:00:00', 34.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-24 00:00:00', 33.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-25 00:00:00', 31.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-26 00:00:00', 33.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-27 00:00:00', 36.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-28 00:00:00', 37.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-29 00:00:00', 36.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-30 00:00:00', 36.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-08-31 00:00:00', 37.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-01 00:00:00', 37.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-02 00:00:00', 36.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-03 00:00:00', 33.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-04 00:00:00', 34.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-05 00:00:00', 35.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-06 00:00:00', 34.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-07 00:00:00', 34.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-08 00:00:00', 34.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-09 00:00:00', 34.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-10 00:00:00', 34.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-11 00:00:00', 33.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-12 00:00:00', 32.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-13 00:00:00', 32.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-14 00:00:00', 34.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-15 00:00:00', 34.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-16 00:00:00', 28.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-17 00:00:00', 29.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-18 00:00:00', 31.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-19 00:00:00', 32.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-20 00:00:00', 33.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-21 00:00:00', 32.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-22 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-23 00:00:00', 26.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-24 00:00:00', 26.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-25 00:00:00', 29.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-26 00:00:00', 29.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-27 00:00:00', 27.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-28 00:00:00', 25.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-29 00:00:00', 29.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-09-30 00:00:00', 30.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-01 00:00:00', 30.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-02 00:00:00', 32.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-03 00:00:00', 27.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-04 00:00:00', 25.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-05 00:00:00', 17.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-06 00:00:00', 15.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-07 00:00:00', 15.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-08 00:00:00', 8.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-09 00:00:00', 14.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-10 00:00:00', 16.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-11 00:00:00', 19.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-12 00:00:00', 22.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-13 00:00:00', 21.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-14 00:00:00', 21.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-15 00:00:00', 22.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-16 00:00:00', 20.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-17 00:00:00', 20.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-18 00:00:00', 20.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-19 00:00:00', 21.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-20 00:00:00', 20.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-21 00:00:00', 19.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-22 00:00:00', 17.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-23 00:00:00', 19.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-24 00:00:00', 18.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-25 00:00:00', 16.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-26 00:00:00', 18.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-27 00:00:00', 21.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-28 00:00:00', 23.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-29 00:00:00', 25.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-30 00:00:00', 22.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-10-31 00:00:00', 23.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-01 00:00:00', 25.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-02 00:00:00', 19.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-03 00:00:00', 16.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-04 00:00:00', 11.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-05 00:00:00', 12.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-06 00:00:00', 9.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-07 00:00:00', 15.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-08 00:00:00', 8.99699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-09 00:00:00', 14.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-10 00:00:00', 20.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-11 00:00:00', 19.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-12 00:00:00', 22.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-13 00:00:00', 19.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-14 00:00:00', 22.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-15 00:00:00', 15.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-16 00:00:00', 16.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-17 00:00:00', 10.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-18 00:00:00', 9.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-19 00:00:00', 16.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-20 00:00:00', 15.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-21 00:00:00', 8.68700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-22 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-23 00:00:00', 8.18500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-24 00:00:00', 13.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-25 00:00:00', 14.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-26 00:00:00', 7.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-27 00:00:00', 6.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-28 00:00:00', 12.2100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-29 00:00:00', 12.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-11-30 00:00:00', 7.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-01 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-02 00:00:00', 5.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-03 00:00:00', 3.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-04 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-05 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-06 00:00:00', 9.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-07 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-08 00:00:00', 9.38099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-09 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-10 00:00:00', 7.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-11 00:00:00', 9.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-12 00:00:00', 9.68299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-13 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-14 00:00:00', 9.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-15 00:00:00', 11.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-16 00:00:00', 8.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-17 00:00:00', 6.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-18 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-19 00:00:00', 11.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-20 00:00:00', 11.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-21 00:00:00', 6.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-22 00:00:00', 7.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-23 00:00:00', 11.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-24 00:00:00', 11.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-25 00:00:00', 12.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-26 00:00:00', 10.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-27 00:00:00', 6.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-28 00:00:00', 8.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-29 00:00:00', 8.25100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-30 00:00:00', 9.33100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1993-12-31 00:00:00', 5.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-01 00:00:00', 1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-02 00:00:00', 5.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-03 00:00:00', 6.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-04 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-05 00:00:00', 11.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-06 00:00:00', 9.47999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-07 00:00:00', 6.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-08 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-09 00:00:00', 5.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-10 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-11 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-12 00:00:00', 6.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-13 00:00:00', 8.15400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-14 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-15 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-16 00:00:00', 6.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-17 00:00:00', 7.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-18 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-19 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-20 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-21 00:00:00', 7.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-22 00:00:00', 6.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-23 00:00:00', 10.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-24 00:00:00', 6.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-25 00:00:00', 11.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-26 00:00:00', 7.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-27 00:00:00', 6.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-28 00:00:00', 7.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-29 00:00:00', 9.38799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-30 00:00:00', 10.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-01-31 00:00:00', 7.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-01 00:00:00', 12.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-02 00:00:00', 8.97799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-03 00:00:00', 11.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-04 00:00:00', 4.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-05 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-06 00:00:00', 7.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-07 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-08 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-09 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-10 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-11 00:00:00', 0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-12 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-13 00:00:00', 3.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-14 00:00:00', 7.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-15 00:00:00', 2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-16 00:00:00', 0.894999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-17 00:00:00', 2.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-18 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-19 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-20 00:00:00', -3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-21 00:00:00', -1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-22 00:00:00', 2.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-23 00:00:00', 3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-24 00:00:00', 7.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-25 00:00:00', 8.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-26 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-27 00:00:00', 8.33800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-02-28 00:00:00', 12.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-01 00:00:00', 13.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-02 00:00:00', 11.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-03 00:00:00', 6.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-04 00:00:00', 10.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-05 00:00:00', 13.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-06 00:00:00', 14.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-07 00:00:00', 16.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-08 00:00:00', 18.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-09 00:00:00', 16.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-10 00:00:00', 14.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-11 00:00:00', 15.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-12 00:00:00', 17.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-13 00:00:00', 18.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-14 00:00:00', 12.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-15 00:00:00', 17.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-16 00:00:00', 16.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-17 00:00:00', 15.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-18 00:00:00', 14.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-19 00:00:00', 17.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-20 00:00:00', 17.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-21 00:00:00', 17.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-22 00:00:00', 19.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-23 00:00:00', 21.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-24 00:00:00', 22.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-25 00:00:00', 11.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-26 00:00:00', 17.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-27 00:00:00', 20.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-28 00:00:00', 21.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-29 00:00:00', 19.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-30 00:00:00', 21.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-03-31 00:00:00', 22.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-01 00:00:00', 20.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-02 00:00:00', 23.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-03 00:00:00', 13.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-04 00:00:00', 12.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-05 00:00:00', 6.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-06 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-07 00:00:00', 11.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-08 00:00:00', 13.5159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-09 00:00:00', 10.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-10 00:00:00', 14.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-11 00:00:00', 18.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-12 00:00:00', 19.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-13 00:00:00', 17.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-14 00:00:00', 19.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-15 00:00:00', 19.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-16 00:00:00', 18.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-17 00:00:00', 19.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-18 00:00:00', 21.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-19 00:00:00', 21.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-20 00:00:00', 20.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-21 00:00:00', 20.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-22 00:00:00', 21.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-23 00:00:00', 22.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-24 00:00:00', 25.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-25 00:00:00', 27.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-26 00:00:00', 29.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-27 00:00:00', 29.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-28 00:00:00', 19.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-29 00:00:00', 24.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-04-30 00:00:00', 19.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-01 00:00:00', 25.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-02 00:00:00', 28.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-03 00:00:00', 28.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-04 00:00:00', 30.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-05 00:00:00', 28.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-06 00:00:00', 31.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-07 00:00:00', 28.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-08 00:00:00', 20.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-09 00:00:00', 21.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-10 00:00:00', 24.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-11 00:00:00', 27.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-12 00:00:00', 29.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-13 00:00:00', 29.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-14 00:00:00', 30.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-15 00:00:00', 32.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-16 00:00:00', 32.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-17 00:00:00', 33.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-18 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-19 00:00:00', 26.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-20 00:00:00', 30.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-21 00:00:00', 32.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-22 00:00:00', 32.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-23 00:00:00', 29.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-24 00:00:00', 26.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-25 00:00:00', 30.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-26 00:00:00', 31.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-27 00:00:00', 32.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-28 00:00:00', 34.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-29 00:00:00', 35.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-30 00:00:00', 35.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-05-31 00:00:00', 32.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-01 00:00:00', 33.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-02 00:00:00', 34.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-03 00:00:00', 34.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-04 00:00:00', 35.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-05 00:00:00', 35.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-06 00:00:00', 37.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-07 00:00:00', 35.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-08 00:00:00', 33.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-09 00:00:00', 32.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-10 00:00:00', 34.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-11 00:00:00', 29.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-12 00:00:00', 30.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-13 00:00:00', 32.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-14 00:00:00', 33.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-15 00:00:00', 35.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-16 00:00:00', 35.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-17 00:00:00', 37.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-18 00:00:00', 39.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-19 00:00:00', 38.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-20 00:00:00', 38.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-21 00:00:00', 39.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-22 00:00:00', 39.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-23 00:00:00', 41.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-24 00:00:00', 38.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-25 00:00:00', 37.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-26 00:00:00', 37.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-27 00:00:00', 37.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-28 00:00:00', 39.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-29 00:00:00', 40.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-06-30 00:00:00', 42.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-01 00:00:00', 41.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-02 00:00:00', 37.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-03 00:00:00', 38.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-04 00:00:00', 39.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-05 00:00:00', 39.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-06 00:00:00', 41.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-07 00:00:00', 42.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-08 00:00:00', 42.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-09 00:00:00', 42.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-10 00:00:00', 41.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-11 00:00:00', 37.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-12 00:00:00', 36.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-13 00:00:00', 35.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-14 00:00:00', 35.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-15 00:00:00', 37.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-16 00:00:00', 38.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-17 00:00:00', 39.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-18 00:00:00', 40.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-19 00:00:00', 38.7739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-20 00:00:00', 38.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-21 00:00:00', 39.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-22 00:00:00', 40.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-23 00:00:00', 40.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-24 00:00:00', 38.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-25 00:00:00', 39.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-26 00:00:00', 39.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-27 00:00:00', 39.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-28 00:00:00', 38.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-29 00:00:00', 37.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-30 00:00:00', 37.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-07-31 00:00:00', 39.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-01 00:00:00', 41.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-02 00:00:00', 42.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-03 00:00:00', 43.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-04 00:00:00', 42.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-05 00:00:00', 41.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-06 00:00:00', 41.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-07 00:00:00', 40.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-08 00:00:00', 35.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-09 00:00:00', 33.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-10 00:00:00', 33.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-11 00:00:00', 36.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-12 00:00:00', 38.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-13 00:00:00', 40.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-14 00:00:00', 40.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-15 00:00:00', 37.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-16 00:00:00', 36.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-17 00:00:00', 36.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-18 00:00:00', 37.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-19 00:00:00', 38.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-20 00:00:00', 39.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-21 00:00:00', 39.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-22 00:00:00', 39.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-23 00:00:00', 38.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-24 00:00:00', 39.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-25 00:00:00', 39.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-26 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-27 00:00:00', 37.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-28 00:00:00', 36.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-29 00:00:00', 35.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-30 00:00:00', 36.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-08-31 00:00:00', 34.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-01 00:00:00', 34.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-02 00:00:00', 33.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-03 00:00:00', 34.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-04 00:00:00', 32.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-05 00:00:00', 28.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-06 00:00:00', 27.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-07 00:00:00', 28.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-08 00:00:00', 28.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-09 00:00:00', 29.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-10 00:00:00', 28.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-11 00:00:00', 29.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-12 00:00:00', 29.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-13 00:00:00', 28.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-14 00:00:00', 27.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-15 00:00:00', 24.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-16 00:00:00', 25.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-17 00:00:00', 24.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-18 00:00:00', 21.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-19 00:00:00', 20.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-20 00:00:00', 20.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-21 00:00:00', 21.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-22 00:00:00', 21.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-23 00:00:00', 24.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-24 00:00:00', 25.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-25 00:00:00', 26.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-26 00:00:00', 28.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-27 00:00:00', 29.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-28 00:00:00', 29.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-29 00:00:00', 29.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-09-30 00:00:00', 29.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-01 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-02 00:00:00', 28.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-03 00:00:00', 24.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-04 00:00:00', 26.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-05 00:00:00', 22.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-06 00:00:00', 23.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-07 00:00:00', 25.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-08 00:00:00', 24.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-09 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-10 00:00:00', 22.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-11 00:00:00', 19.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-12 00:00:00', 19.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-13 00:00:00', 20.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-14 00:00:00', 22.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-15 00:00:00', 23.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-16 00:00:00', 25.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-17 00:00:00', 21.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-18 00:00:00', 25.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-19 00:00:00', 27.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-20 00:00:00', 27.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-21 00:00:00', 27.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-22 00:00:00', 26.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-23 00:00:00', 21.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-24 00:00:00', 15.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-25 00:00:00', 9.56700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-26 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-27 00:00:00', 16.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-28 00:00:00', 18.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-29 00:00:00', 19.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-30 00:00:00', 19.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-10-31 00:00:00', 20.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-01 00:00:00', 18.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-02 00:00:00', 16.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-03 00:00:00', 18.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-04 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-05 00:00:00', 23.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-06 00:00:00', 24.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-07 00:00:00', 18.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-08 00:00:00', 22.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-09 00:00:00', 24.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-10 00:00:00', 17.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-11 00:00:00', 12.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-12 00:00:00', 17.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-13 00:00:00', 17.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-14 00:00:00', 18.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-15 00:00:00', 20.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-16 00:00:00', 19.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-17 00:00:00', 18.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-18 00:00:00', 20.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-19 00:00:00', 16.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-20 00:00:00', 17.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-21 00:00:00', 19.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-22 00:00:00', 19.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-23 00:00:00', 19.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-24 00:00:00', 18.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-25 00:00:00', 12.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-26 00:00:00', 18.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-27 00:00:00', 14.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-28 00:00:00', 17.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-29 00:00:00', 17.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-11-30 00:00:00', 17.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-01 00:00:00', 19.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-02 00:00:00', 13.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-03 00:00:00', 15.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-04 00:00:00', 16.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-05 00:00:00', 13.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-06 00:00:00', 8.50300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-07 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-08 00:00:00', -1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-09 00:00:00', 1.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-10 00:00:00', 3.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-11 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-12 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-13 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-14 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-15 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-16 00:00:00', 2.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-17 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-18 00:00:00', 8.92599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-19 00:00:00', 11.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-20 00:00:00', 10.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-21 00:00:00', 9.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-22 00:00:00', 6.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-23 00:00:00', 2.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-24 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-25 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-26 00:00:00', -1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-27 00:00:00', 0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-28 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-29 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-30 00:00:00', 5.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1994-12-31 00:00:00', 8.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-01 00:00:00', 10.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-02 00:00:00', 7.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-03 00:00:00', 7.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-04 00:00:00', 9.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-05 00:00:00', 10.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-06 00:00:00', 9.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-07 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-08 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-09 00:00:00', 1.81700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-10 00:00:00', 5.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-11 00:00:00', 8.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-12 00:00:00', 7.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-13 00:00:00', 6.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-14 00:00:00', 7.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-15 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-16 00:00:00', 3.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-17 00:00:00', 7.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-18 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-19 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-20 00:00:00', 5.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-21 00:00:00', 5.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-22 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-23 00:00:00', 6.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-24 00:00:00', 7.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-25 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-26 00:00:00', 8.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-27 00:00:00', 8.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-28 00:00:00', 9.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-29 00:00:00', 11.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-30 00:00:00', 12.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-01-31 00:00:00', 12.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-01 00:00:00', 13.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-02 00:00:00', 14.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-03 00:00:00', 13.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-04 00:00:00', 13.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-05 00:00:00', 14.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-06 00:00:00', 8.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-07 00:00:00', 8.30300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-08 00:00:00', 10.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-09 00:00:00', 9.94699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-10 00:00:00', 10.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-11 00:00:00', 6.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-12 00:00:00', 8.42800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-13 00:00:00', 9.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-14 00:00:00', 8.97099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-15 00:00:00', 8.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-16 00:00:00', 9.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-17 00:00:00', 5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-18 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-19 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-20 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-21 00:00:00', 8.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-22 00:00:00', 8.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-23 00:00:00', 10.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-24 00:00:00', 13.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-25 00:00:00', 6.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-26 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-27 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-02-28 00:00:00', 4.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-01 00:00:00', 8.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-02 00:00:00', 10.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-03 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-04 00:00:00', 6.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-05 00:00:00', 10.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-06 00:00:00', 8.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-07 00:00:00', 8.81499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-08 00:00:00', 9.12399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-09 00:00:00', 3.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-10 00:00:00', 7.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-11 00:00:00', 11.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-12 00:00:00', 12.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-13 00:00:00', 14.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-14 00:00:00', 15.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-15 00:00:00', 16.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-16 00:00:00', 19.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-17 00:00:00', 21.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-18 00:00:00', 20.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-19 00:00:00', 15.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-20 00:00:00', 12.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-21 00:00:00', 12.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-22 00:00:00', 11.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-23 00:00:00', 12.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-24 00:00:00', 18.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-25 00:00:00', 17.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-26 00:00:00', 20.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-27 00:00:00', 18.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-28 00:00:00', 11.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-29 00:00:00', 13.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-30 00:00:00', 15.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-03-31 00:00:00', 18.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-01 00:00:00', 16.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-02 00:00:00', 18.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-03 00:00:00', 21.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-04 00:00:00', 21.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-05 00:00:00', 24.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-06 00:00:00', 24.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-07 00:00:00', 16.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-08 00:00:00', 11.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-09 00:00:00', 19.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-10 00:00:00', 20.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-11 00:00:00', 22.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-12 00:00:00', 24.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-13 00:00:00', 26.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-14 00:00:00', 25.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-15 00:00:00', 23.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-16 00:00:00', 25.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-17 00:00:00', 17.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-18 00:00:00', 23.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-19 00:00:00', 20.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-20 00:00:00', 22.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-21 00:00:00', 21.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-22 00:00:00', 22.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-23 00:00:00', 23.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-24 00:00:00', 24.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-25 00:00:00', 27.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-26 00:00:00', 26.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-27 00:00:00', 22.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-28 00:00:00', 24.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-29 00:00:00', 24.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-04-30 00:00:00', 26.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-01 00:00:00', 28.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-02 00:00:00', 30.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-03 00:00:00', 31.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-04 00:00:00', 33.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-05 00:00:00', 32.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-06 00:00:00', 34.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-07 00:00:00', 35.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-08 00:00:00', 37.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-09 00:00:00', 36.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-10 00:00:00', 31.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-11 00:00:00', 30.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-12 00:00:00', 32.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-13 00:00:00', 32.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-14 00:00:00', 32.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-15 00:00:00', 33.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-16 00:00:00', 33.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-17 00:00:00', 26.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-18 00:00:00', 29.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-19 00:00:00', 26.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-20 00:00:00', 28.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-21 00:00:00', 27.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-22 00:00:00', 28.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-23 00:00:00', 29.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-24 00:00:00', 26.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-25 00:00:00', 20.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-26 00:00:00', 26.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-27 00:00:00', 25.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-28 00:00:00', 27.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-29 00:00:00', 26.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-30 00:00:00', 28.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-05-31 00:00:00', 30.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-01 00:00:00', 30.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-02 00:00:00', 30.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-03 00:00:00', 29.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-04 00:00:00', 33.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-05 00:00:00', 37.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-06 00:00:00', 37.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-07 00:00:00', 36.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-08 00:00:00', 36.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-09 00:00:00', 36.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-10 00:00:00', 32.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-11 00:00:00', 33.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-12 00:00:00', 35.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-13 00:00:00', 31.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-14 00:00:00', 36.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-15 00:00:00', 40.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-16 00:00:00', 41.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-17 00:00:00', 39.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-18 00:00:00', 37.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-19 00:00:00', 36.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-20 00:00:00', 34.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-21 00:00:00', 32.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-22 00:00:00', 33.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-23 00:00:00', 35.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-24 00:00:00', 26.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-25 00:00:00', 33.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-26 00:00:00', 34.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-27 00:00:00', 36.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-28 00:00:00', 36.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-29 00:00:00', 37.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-06-30 00:00:00', 37.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-01 00:00:00', 39.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-02 00:00:00', 39.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-03 00:00:00', 39.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-04 00:00:00', 38.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-05 00:00:00', 38.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-06 00:00:00', 38.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-07 00:00:00', 37.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-08 00:00:00', 37.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-09 00:00:00', 37.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-10 00:00:00', 38.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-11 00:00:00', 37.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-12 00:00:00', 38.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-13 00:00:00', 40.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-14 00:00:00', 40.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-15 00:00:00', 41.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-16 00:00:00', 42.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-17 00:00:00', 43.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-18 00:00:00', 44.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-19 00:00:00', 41.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-20 00:00:00', 37.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-21 00:00:00', 39.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-22 00:00:00', 40.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-23 00:00:00', 41.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-24 00:00:00', 38.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-25 00:00:00', 34.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-26 00:00:00', 35.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-27 00:00:00', 38.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-28 00:00:00', 38.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-29 00:00:00', 38.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-30 00:00:00', 39.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-07-31 00:00:00', 40.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-01 00:00:00', 40.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-02 00:00:00', 40.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-03 00:00:00', 40.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-04 00:00:00', 40.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-05 00:00:00', 38.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-06 00:00:00', 35.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-07 00:00:00', 35.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-08 00:00:00', 37.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-09 00:00:00', 38.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-10 00:00:00', 40.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-11 00:00:00', 40.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-12 00:00:00', 41.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-13 00:00:00', 40.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-14 00:00:00', 39.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-15 00:00:00', 38.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-16 00:00:00', 38.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-17 00:00:00', 38.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-18 00:00:00', 37.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-19 00:00:00', 39.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-20 00:00:00', 38.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-21 00:00:00', 35.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-22 00:00:00', 36.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-23 00:00:00', 38.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-24 00:00:00', 40.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-25 00:00:00', 34.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-26 00:00:00', 36.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-27 00:00:00', 36.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-28 00:00:00', 36.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-29 00:00:00', 32.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-30 00:00:00', 31.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-08-31 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-01 00:00:00', 31.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-02 00:00:00', 30.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-03 00:00:00', 29.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-04 00:00:00', 28.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-05 00:00:00', 28.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-06 00:00:00', 30.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-07 00:00:00', 31.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-08 00:00:00', 31.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-09 00:00:00', 33.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-10 00:00:00', 34.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-11 00:00:00', 32.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-12 00:00:00', 32.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-13 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-14 00:00:00', 31.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-15 00:00:00', 31.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-16 00:00:00', 32.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-17 00:00:00', 33.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-18 00:00:00', 34.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-19 00:00:00', 35.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-20 00:00:00', 36.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-21 00:00:00', 38.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-22 00:00:00', 26.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-23 00:00:00', 24.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-24 00:00:00', 29.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-25 00:00:00', 32.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-26 00:00:00', 33.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-27 00:00:00', 32.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-28 00:00:00', 21.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-29 00:00:00', 26.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-09-30 00:00:00', 29.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-01 00:00:00', 27.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-02 00:00:00', 24.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-03 00:00:00', 25.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-04 00:00:00', 22.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-05 00:00:00', 29.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-06 00:00:00', 30.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-07 00:00:00', 30.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-08 00:00:00', 30.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-09 00:00:00', 28.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-10 00:00:00', 23.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-11 00:00:00', 24.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-12 00:00:00', 27.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-13 00:00:00', 22.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-14 00:00:00', 13.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-15 00:00:00', 19.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-16 00:00:00', 16.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-17 00:00:00', 20.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-18 00:00:00', 8.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-19 00:00:00', 6.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-20 00:00:00', 6.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-21 00:00:00', 15.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-22 00:00:00', 17.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-23 00:00:00', 20.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-24 00:00:00', 15.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-25 00:00:00', 10.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-26 00:00:00', 13.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-27 00:00:00', 11.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-28 00:00:00', 10.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-29 00:00:00', 13.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-30 00:00:00', 12.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-10-31 00:00:00', 13.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-01 00:00:00', 17.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-02 00:00:00', 9.58800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-03 00:00:00', 20.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-04 00:00:00', 21.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-05 00:00:00', 21.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-06 00:00:00', 19.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-07 00:00:00', 17.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-08 00:00:00', 22.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-09 00:00:00', 22.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-10 00:00:00', 22.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-11 00:00:00', 21.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-12 00:00:00', 21.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-13 00:00:00', 15.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-14 00:00:00', 17.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-15 00:00:00', 14.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-16 00:00:00', 9.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-17 00:00:00', 10.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-18 00:00:00', 13.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-19 00:00:00', 11.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-20 00:00:00', 14.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-21 00:00:00', 14.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-22 00:00:00', 14.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-23 00:00:00', 13.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-24 00:00:00', 15.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-25 00:00:00', 16.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-26 00:00:00', 14.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-27 00:00:00', 7.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-28 00:00:00', 2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-29 00:00:00', -0.284000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-11-30 00:00:00', 1.23199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-01 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-02 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-03 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-04 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-05 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-06 00:00:00', 3.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-07 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-08 00:00:00', 2.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-09 00:00:00', 3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-10 00:00:00', 0.981000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-11 00:00:00', 0.261999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-12 00:00:00', 1.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-13 00:00:00', -0.610000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-14 00:00:00', -0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-15 00:00:00', -0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-16 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-17 00:00:00', 3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-18 00:00:00', 3.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-19 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-20 00:00:00', 1.05799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-21 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-22 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-23 00:00:00', 1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-24 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-25 00:00:00', 1.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-26 00:00:00', 2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-27 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-28 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-29 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-30 00:00:00', 2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1995-12-31 00:00:00', 3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-01 00:00:00', 6.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-02 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-03 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-04 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-05 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-06 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-07 00:00:00', 7.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-08 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-09 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-10 00:00:00', -1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-11 00:00:00', -5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-12 00:00:00', -2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-13 00:00:00', -4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-14 00:00:00', -6.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-15 00:00:00', -7.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-16 00:00:00', -5.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-17 00:00:00', 0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-18 00:00:00', 0.998000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-19 00:00:00', 0.824999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-20 00:00:00', 1.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-21 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-22 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-23 00:00:00', 0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-24 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-25 00:00:00', -0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-26 00:00:00', -0.0320000015199184418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-27 00:00:00', 0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-28 00:00:00', 0.098999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-29 00:00:00', 1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-30 00:00:00', 1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-01-31 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-01 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-02 00:00:00', 2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-03 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-04 00:00:00', 0.773999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-05 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-06 00:00:00', 7.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-07 00:00:00', 6.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-08 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-09 00:00:00', 8.87899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-10 00:00:00', 10.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-11 00:00:00', 11.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-12 00:00:00', 7.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-13 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-14 00:00:00', -1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-15 00:00:00', -0.787999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-16 00:00:00', 2.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-17 00:00:00', 6.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-18 00:00:00', 11.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-19 00:00:00', 13.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-20 00:00:00', 13.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-21 00:00:00', 7.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-22 00:00:00', 7.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-23 00:00:00', 5.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-24 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-25 00:00:00', 3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-26 00:00:00', 0.654999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-27 00:00:00', 0.0540000014007091522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-28 00:00:00', 2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-02-29 00:00:00', 5.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-01 00:00:00', 4.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-02 00:00:00', 7.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-03 00:00:00', 11.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-04 00:00:00', 13.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-05 00:00:00', 12.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-06 00:00:00', 9.97500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-07 00:00:00', 11.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-08 00:00:00', 13.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-09 00:00:00', 15.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-10 00:00:00', 14.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-11 00:00:00', 14.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-12 00:00:00', 9.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-13 00:00:00', 16.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-14 00:00:00', 15.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-15 00:00:00', 8.35999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-16 00:00:00', 8.01099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-17 00:00:00', 9.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-18 00:00:00', 5.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-19 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-20 00:00:00', 7.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-21 00:00:00', 7.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-22 00:00:00', 11.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-23 00:00:00', 15.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-24 00:00:00', 12.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-25 00:00:00', 14.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-26 00:00:00', 19.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-27 00:00:00', 10.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-28 00:00:00', 9.30799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-29 00:00:00', 9.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-30 00:00:00', 9.92599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-03-31 00:00:00', 12.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-01 00:00:00', 16.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-02 00:00:00', 9.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-03 00:00:00', 13.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-04 00:00:00', 8.51799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-05 00:00:00', 7.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-06 00:00:00', 11.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-07 00:00:00', 13.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-08 00:00:00', 16.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-09 00:00:00', 17.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-10 00:00:00', 17.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-11 00:00:00', 19.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-12 00:00:00', 17.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-13 00:00:00', 22.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-14 00:00:00', 24.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-15 00:00:00', 26.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-16 00:00:00', 22.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-17 00:00:00', 14.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-18 00:00:00', 18.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-19 00:00:00', 26.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-20 00:00:00', 22.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-21 00:00:00', 21.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-22 00:00:00', 23.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-23 00:00:00', 25.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-24 00:00:00', 23.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-25 00:00:00', 25.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-26 00:00:00', 22.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-27 00:00:00', 20.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-28 00:00:00', 23.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-29 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-04-30 00:00:00', 19.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-01 00:00:00', 22.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-02 00:00:00', 20.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-03 00:00:00', 20.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-04 00:00:00', 20.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-05 00:00:00', 20.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-06 00:00:00', 21.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-07 00:00:00', 24.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-08 00:00:00', 25.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-09 00:00:00', 21.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-10 00:00:00', 24.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-11 00:00:00', 23.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-12 00:00:00', 23.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-13 00:00:00', 26.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-14 00:00:00', 27.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-15 00:00:00', 26.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-16 00:00:00', 28.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-17 00:00:00', 29.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-18 00:00:00', 29.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-19 00:00:00', 29.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-20 00:00:00', 27.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-21 00:00:00', 28.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-22 00:00:00', 29.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-23 00:00:00', 29.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-24 00:00:00', 27.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-25 00:00:00', 34.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-26 00:00:00', 33.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-27 00:00:00', 29.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-28 00:00:00', 28.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-29 00:00:00', 28.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-30 00:00:00', 31.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-05-31 00:00:00', 32.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-01 00:00:00', 32.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-02 00:00:00', 34.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-03 00:00:00', 35.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-04 00:00:00', 34.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-05 00:00:00', 34.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-06 00:00:00', 36.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-07 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-08 00:00:00', 38.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-09 00:00:00', 37.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-10 00:00:00', 39.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-11 00:00:00', 38.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-12 00:00:00', 34.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-13 00:00:00', 34.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-14 00:00:00', 33.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-15 00:00:00', 31.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-16 00:00:00', 28.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-17 00:00:00', 29.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-18 00:00:00', 30.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-19 00:00:00', 32.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-20 00:00:00', 32.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-21 00:00:00', 36.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-22 00:00:00', 38.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-23 00:00:00', 38.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-24 00:00:00', 37.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-25 00:00:00', 36.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-26 00:00:00', 38.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-27 00:00:00', 36.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-28 00:00:00', 37.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-29 00:00:00', 31.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-06-30 00:00:00', 34.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-01 00:00:00', 36.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-02 00:00:00', 38.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-03 00:00:00', 35.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-04 00:00:00', 34.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-05 00:00:00', 34.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-06 00:00:00', 36.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-07 00:00:00', 38.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-08 00:00:00', 40.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-09 00:00:00', 40.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-10 00:00:00', 36.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-11 00:00:00', 35.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-12 00:00:00', 35.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-13 00:00:00', 34.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-14 00:00:00', 31.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-15 00:00:00', 27.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-16 00:00:00', 31.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-17 00:00:00', 33.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-18 00:00:00', 36.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-19 00:00:00', 35.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-20 00:00:00', 35.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-21 00:00:00', 36.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-22 00:00:00', 36.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-23 00:00:00', 35.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-24 00:00:00', 38.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-25 00:00:00', 40.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-26 00:00:00', 39.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-27 00:00:00', 40.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-28 00:00:00', 40.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-29 00:00:00', 40.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-30 00:00:00', 40.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-07-31 00:00:00', 42.3909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-01 00:00:00', 40.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-02 00:00:00', 36.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-03 00:00:00', 38.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-04 00:00:00', 38.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-05 00:00:00', 38.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-06 00:00:00', 38.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-07 00:00:00', 38.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-08 00:00:00', 38.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-09 00:00:00', 40.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-10 00:00:00', 40.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-11 00:00:00', 40.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-12 00:00:00', 41.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-13 00:00:00', 39.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-14 00:00:00', 38.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-15 00:00:00', 36.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-16 00:00:00', 32.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-17 00:00:00', 31.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-18 00:00:00', 31.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-19 00:00:00', 31.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-20 00:00:00', 32.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-21 00:00:00', 33.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-22 00:00:00', 33.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-23 00:00:00', 33.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-24 00:00:00', 34.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-25 00:00:00', 34.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-26 00:00:00', 36.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-27 00:00:00', 36.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-28 00:00:00', 37.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-29 00:00:00', 34.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-30 00:00:00', 26.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-08-31 00:00:00', 30.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-01 00:00:00', 32.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-02 00:00:00', 31.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-03 00:00:00', 32.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-04 00:00:00', 30.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-05 00:00:00', 32.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-06 00:00:00', 34.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-07 00:00:00', 33.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-08 00:00:00', 34.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-09 00:00:00', 38.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-10 00:00:00', 38.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-11 00:00:00', 39.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-12 00:00:00', 38.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-13 00:00:00', 37.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-14 00:00:00', 36.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-15 00:00:00', 33.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-16 00:00:00', 32.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-17 00:00:00', 31.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-18 00:00:00', 32.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-19 00:00:00', 33.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-20 00:00:00', 33.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-21 00:00:00', 33.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-22 00:00:00', 36.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-23 00:00:00', 34.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-24 00:00:00', 31.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-25 00:00:00', 27.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-26 00:00:00', 28.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-27 00:00:00', 28.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-28 00:00:00', 29.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-29 00:00:00', 31.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-09-30 00:00:00', 32.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-01 00:00:00', 28.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-02 00:00:00', 18.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-03 00:00:00', 18.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-04 00:00:00', 20.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-05 00:00:00', 23.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-06 00:00:00', 23.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-07 00:00:00', 24.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-08 00:00:00', 23.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-09 00:00:00', 23.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-10 00:00:00', 24.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-11 00:00:00', 24.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-12 00:00:00', 25.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-13 00:00:00', 26.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-14 00:00:00', 28.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-15 00:00:00', 27.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-16 00:00:00', 19.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-17 00:00:00', 17.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-18 00:00:00', 17.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-19 00:00:00', 16.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-20 00:00:00', 16.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-21 00:00:00', 18.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-22 00:00:00', 20.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-23 00:00:00', 22.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-24 00:00:00', 24.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-25 00:00:00', 23.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-26 00:00:00', 24.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-27 00:00:00', 24.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-28 00:00:00', 26.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-29 00:00:00', 21.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-30 00:00:00', 21.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-10-31 00:00:00', 24.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-01 00:00:00', 15.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-02 00:00:00', 18.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-03 00:00:00', 18.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-04 00:00:00', 16.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-05 00:00:00', 17.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-06 00:00:00', 17.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-07 00:00:00', 19.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-08 00:00:00', 21.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-09 00:00:00', 21.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-10 00:00:00', 20.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-11 00:00:00', 15.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-12 00:00:00', 12.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-13 00:00:00', 6.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-14 00:00:00', 1.1239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-15 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-16 00:00:00', 8.46800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-17 00:00:00', 6.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-18 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-19 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-20 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-21 00:00:00', 6.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-22 00:00:00', 8.56999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-23 00:00:00', 10.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-24 00:00:00', 10.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-25 00:00:00', 9.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-26 00:00:00', 9.57400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-27 00:00:00', 10.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-28 00:00:00', 11.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-29 00:00:00', 13.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-11-30 00:00:00', 12.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-01 00:00:00', 10.4420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-02 00:00:00', 4.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-03 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-04 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-05 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-06 00:00:00', 5.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-07 00:00:00', 4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-08 00:00:00', 5.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-09 00:00:00', 5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-10 00:00:00', 9.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-11 00:00:00', 11.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-12 00:00:00', 10.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-13 00:00:00', 11.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-14 00:00:00', 13.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-15 00:00:00', 14.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-16 00:00:00', 11.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-17 00:00:00', 13.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-18 00:00:00', 12.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-19 00:00:00', 13.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-20 00:00:00', 14.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-21 00:00:00', 13.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-22 00:00:00', 14.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-23 00:00:00', 15.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-24 00:00:00', 9.96599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-25 00:00:00', 12.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-26 00:00:00', 14.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-27 00:00:00', 14.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-28 00:00:00', 10.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-29 00:00:00', 15.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-30 00:00:00', 18.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1996-12-31 00:00:00', 16.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-01 00:00:00', 15.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-02 00:00:00', 17.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-03 00:00:00', 15.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-04 00:00:00', 8.66199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-05 00:00:00', 10.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-06 00:00:00', 11.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-07 00:00:00', 13.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-08 00:00:00', 10.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-09 00:00:00', 13.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-10 00:00:00', 15.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-11 00:00:00', 14.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-12 00:00:00', 10.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-13 00:00:00', 8.10700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-14 00:00:00', 4.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-15 00:00:00', 8.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-16 00:00:00', 10.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-17 00:00:00', 11.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-18 00:00:00', 6.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-19 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-20 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-21 00:00:00', 2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-22 00:00:00', 5.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-23 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-24 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-25 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-26 00:00:00', 7.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-27 00:00:00', 8.86699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-28 00:00:00', 11.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-29 00:00:00', 6.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-30 00:00:00', 9.31700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-01-31 00:00:00', 9.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-01 00:00:00', 9.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-02 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-03 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-04 00:00:00', 8.17099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-05 00:00:00', 9.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-06 00:00:00', 10.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-07 00:00:00', 8.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-08 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-09 00:00:00', 3.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-10 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-11 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-12 00:00:00', 8.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-13 00:00:00', 10.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-14 00:00:00', 10.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-15 00:00:00', 11.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-16 00:00:00', 11.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-17 00:00:00', 12.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-18 00:00:00', 12.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-19 00:00:00', 14.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-20 00:00:00', 11.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-21 00:00:00', 11.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-22 00:00:00', 11.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-23 00:00:00', 12.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-24 00:00:00', 10.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-25 00:00:00', 9.39000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-26 00:00:00', 12.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-27 00:00:00', 16.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-02-28 00:00:00', 13.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-01 00:00:00', 9.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-02 00:00:00', 6.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-03 00:00:00', 10.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-04 00:00:00', 15.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-05 00:00:00', 13.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-06 00:00:00', 12.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-07 00:00:00', 10.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-08 00:00:00', 19.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-09 00:00:00', 10.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-10 00:00:00', 6.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-11 00:00:00', 8.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-12 00:00:00', 11.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-13 00:00:00', 14.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-14 00:00:00', 8.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-15 00:00:00', 9.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-16 00:00:00', 13.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-17 00:00:00', 14.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-18 00:00:00', 15.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-19 00:00:00', 14.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-20 00:00:00', 17.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-21 00:00:00', 16.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-22 00:00:00', 16.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-23 00:00:00', 16.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-24 00:00:00', 21.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-25 00:00:00', 25.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-26 00:00:00', 26.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-27 00:00:00', 15.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-28 00:00:00', 15.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-29 00:00:00', 19.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-30 00:00:00', 24.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-03-31 00:00:00', 21.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-01 00:00:00', 13.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-02 00:00:00', 16.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-03 00:00:00', 17.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-04 00:00:00', 19.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-05 00:00:00', 22.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-06 00:00:00', 17.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-07 00:00:00', 22.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-08 00:00:00', 23.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-09 00:00:00', 23.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-10 00:00:00', 26.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-11 00:00:00', 26.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-12 00:00:00', 18.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-13 00:00:00', 15.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-14 00:00:00', 12.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-15 00:00:00', 11.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-16 00:00:00', 21.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-17 00:00:00', 24.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-18 00:00:00', 25.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-19 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-20 00:00:00', 18.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-21 00:00:00', 22.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-22 00:00:00', 26.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-23 00:00:00', 29.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-24 00:00:00', 30.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-25 00:00:00', 30.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-26 00:00:00', 31.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-27 00:00:00', 26.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-28 00:00:00', 28.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-29 00:00:00', 29.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-04-30 00:00:00', 25.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-01 00:00:00', 24.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-02 00:00:00', 26.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-03 00:00:00', 27.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-04 00:00:00', 28.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-05 00:00:00', 32.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-06 00:00:00', 23.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-07 00:00:00', 18.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-08 00:00:00', 19.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-09 00:00:00', 22.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-10 00:00:00', 24.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-11 00:00:00', 23.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-12 00:00:00', 16.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-13 00:00:00', 23.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-14 00:00:00', 27.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-15 00:00:00', 26.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-16 00:00:00', 17.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-17 00:00:00', 22.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-18 00:00:00', 25.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-19 00:00:00', 29.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-20 00:00:00', 31.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-21 00:00:00', 30.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-22 00:00:00', 31.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-23 00:00:00', 32.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-24 00:00:00', 33.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-25 00:00:00', 34.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-26 00:00:00', 35.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-27 00:00:00', 32.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-28 00:00:00', 32.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-29 00:00:00', 34.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-30 00:00:00', 34.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-05-31 00:00:00', 33.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-01 00:00:00', 34.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-02 00:00:00', 34.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-03 00:00:00', 35.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-04 00:00:00', 28.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-05 00:00:00', 33.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-06 00:00:00', 34.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-07 00:00:00', 35.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-08 00:00:00', 35.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-09 00:00:00', 35.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-10 00:00:00', 35.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-11 00:00:00', 33.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-12 00:00:00', 32.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-13 00:00:00', 34.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-14 00:00:00', 35.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-15 00:00:00', 36.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-16 00:00:00', 37.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-17 00:00:00', 37.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-18 00:00:00', 37.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-19 00:00:00', 33.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-20 00:00:00', 36.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-21 00:00:00', 36.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-22 00:00:00', 35.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-23 00:00:00', 37.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-24 00:00:00', 39.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-25 00:00:00', 39.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-26 00:00:00', 40.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-27 00:00:00', 38.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-28 00:00:00', 36.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-29 00:00:00', 35.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-06-30 00:00:00', 34.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-01 00:00:00', 36.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-02 00:00:00', 38.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-03 00:00:00', 39.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-04 00:00:00', 39.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-05 00:00:00', 39.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-06 00:00:00', 39.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-07 00:00:00', 41.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-08 00:00:00', 40.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-09 00:00:00', 37.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-10 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-11 00:00:00', 38.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-12 00:00:00', 38.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-13 00:00:00', 39.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-14 00:00:00', 40.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-15 00:00:00', 41.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-16 00:00:00', 43.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-17 00:00:00', 44.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-18 00:00:00', 45.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-19 00:00:00', 45.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-20 00:00:00', 43.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-21 00:00:00', 40.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-22 00:00:00', 36.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-23 00:00:00', 38.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-24 00:00:00', 39.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-25 00:00:00', 40.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-26 00:00:00', 41.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-27 00:00:00', 41.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-28 00:00:00', 42.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-29 00:00:00', 39.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-30 00:00:00', 39.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-07-31 00:00:00', 38.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-01 00:00:00', 35.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-02 00:00:00', 33.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-03 00:00:00', 32.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-04 00:00:00', 33.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-05 00:00:00', 36.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-06 00:00:00', 38.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-07 00:00:00', 40.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-08 00:00:00', 41.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-09 00:00:00', 40.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-10 00:00:00', 39.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-11 00:00:00', 37.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-12 00:00:00', 34.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-13 00:00:00', 36.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-14 00:00:00', 38.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-15 00:00:00', 40.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-16 00:00:00', 40.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-17 00:00:00', 39.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-18 00:00:00', 40.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-19 00:00:00', 40.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-20 00:00:00', 41.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-21 00:00:00', 40.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-22 00:00:00', 40.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-23 00:00:00', 39.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-24 00:00:00', 35.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-25 00:00:00', 31.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-26 00:00:00', 32.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-27 00:00:00', 32.4760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-28 00:00:00', 33.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-29 00:00:00', 32.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-30 00:00:00', 34.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-08-31 00:00:00', 35.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-01 00:00:00', 38.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-02 00:00:00', 39.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-03 00:00:00', 41.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-04 00:00:00', 38.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-05 00:00:00', 36.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-06 00:00:00', 31.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-07 00:00:00', 29.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-08 00:00:00', 28.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-09 00:00:00', 28.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-10 00:00:00', 31.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-11 00:00:00', 34.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-12 00:00:00', 33.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-13 00:00:00', 34.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-14 00:00:00', 33.9410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-15 00:00:00', 31.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-16 00:00:00', 29.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-17 00:00:00', 30.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-18 00:00:00', 30.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-19 00:00:00', 29.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-20 00:00:00', 29.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-21 00:00:00', 29.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-22 00:00:00', 30.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-23 00:00:00', 30.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-24 00:00:00', 30.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-25 00:00:00', 30.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-26 00:00:00', 31.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-27 00:00:00', 32.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-28 00:00:00', 30.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-29 00:00:00', 30.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-09-30 00:00:00', 30.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-01 00:00:00', 31.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-02 00:00:00', 31.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-03 00:00:00', 31.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-04 00:00:00', 32.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-05 00:00:00', 30.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-06 00:00:00', 28.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-07 00:00:00', 29.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-08 00:00:00', 23.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-09 00:00:00', 24.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-10 00:00:00', 24.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-11 00:00:00', 25.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-12 00:00:00', 25.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-13 00:00:00', 26.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-14 00:00:00', 27.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-15 00:00:00', 25.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-16 00:00:00', 25.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-17 00:00:00', 25.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-18 00:00:00', 19.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-19 00:00:00', 24.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-20 00:00:00', 25.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-21 00:00:00', 24.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-22 00:00:00', 22.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-23 00:00:00', 24.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-24 00:00:00', 25.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-25 00:00:00', 22.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-26 00:00:00', 17.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-27 00:00:00', 21.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-28 00:00:00', 22.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-29 00:00:00', 21.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-30 00:00:00', 22.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-10-31 00:00:00', 23.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-01 00:00:00', 23.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-02 00:00:00', 13.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-03 00:00:00', 19.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-04 00:00:00', 22.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-05 00:00:00', 25.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-06 00:00:00', 17.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-07 00:00:00', 11.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-08 00:00:00', 11.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-09 00:00:00', 10.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-10 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-11 00:00:00', 16.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-12 00:00:00', 17.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-13 00:00:00', 19.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-14 00:00:00', 17.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-15 00:00:00', 10.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-16 00:00:00', 13.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-17 00:00:00', 15.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-18 00:00:00', 16.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-19 00:00:00', 16.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-20 00:00:00', 16.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-21 00:00:00', 17.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-22 00:00:00', 14.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-23 00:00:00', 14.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-24 00:00:00', 10.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-25 00:00:00', 6.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-26 00:00:00', 7.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-27 00:00:00', 10.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-28 00:00:00', 11.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-29 00:00:00', 11.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-11-30 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-01 00:00:00', 13.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-02 00:00:00', 10.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-03 00:00:00', 9.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-04 00:00:00', 10.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-05 00:00:00', 12.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-06 00:00:00', 12.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-07 00:00:00', 14.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-08 00:00:00', 14.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-09 00:00:00', 13.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-10 00:00:00', 12.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-11 00:00:00', 16.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-12 00:00:00', 9.89299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-13 00:00:00', 9.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-14 00:00:00', 11.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-15 00:00:00', 10.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-16 00:00:00', 11.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-17 00:00:00', 12.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-18 00:00:00', 7.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-19 00:00:00', 5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-20 00:00:00', 7.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-21 00:00:00', 9.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-22 00:00:00', 5.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-23 00:00:00', 6.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-24 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-25 00:00:00', 7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-26 00:00:00', 9.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-27 00:00:00', 4.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-28 00:00:00', 4.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-29 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-30 00:00:00', 7.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1997-12-31 00:00:00', 7.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-01 00:00:00', 10.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-02 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-03 00:00:00', 8.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-04 00:00:00', 5.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-05 00:00:00', 7.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-06 00:00:00', 7.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-07 00:00:00', 7.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-08 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-09 00:00:00', 6.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-10 00:00:00', 6.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-11 00:00:00', 6.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-12 00:00:00', 6.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-13 00:00:00', 7.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-14 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-15 00:00:00', 0.448000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-16 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-17 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-18 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-19 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-20 00:00:00', 1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-21 00:00:00', 4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-22 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-23 00:00:00', 0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-24 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-25 00:00:00', 4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-26 00:00:00', 8.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-27 00:00:00', 9.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-28 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-29 00:00:00', 8.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-30 00:00:00', 8.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-01-31 00:00:00', 10.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-01 00:00:00', 6.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-02 00:00:00', 6.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-03 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-04 00:00:00', 9.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-05 00:00:00', 7.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-06 00:00:00', 11.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-07 00:00:00', 13.4280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-08 00:00:00', 9.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-09 00:00:00', 8.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-10 00:00:00', 10.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-11 00:00:00', 5.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-12 00:00:00', 11.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-13 00:00:00', 10.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-14 00:00:00', 7.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-15 00:00:00', 9.21800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-16 00:00:00', 6.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-17 00:00:00', 2.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-18 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-19 00:00:00', 9.40200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-20 00:00:00', 4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-21 00:00:00', 5.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-22 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-23 00:00:00', 0.634000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-24 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-25 00:00:00', 4.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-26 00:00:00', 10.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-27 00:00:00', 5.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-02-28 00:00:00', 10.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-01 00:00:00', 5.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-02 00:00:00', 8.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-03 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-04 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-05 00:00:00', 7.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-06 00:00:00', 5.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-07 00:00:00', 5.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-08 00:00:00', 8.54399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-09 00:00:00', 11.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-10 00:00:00', 13.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-11 00:00:00', 13.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-12 00:00:00', 12.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-13 00:00:00', 13.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-14 00:00:00', 12.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-15 00:00:00', 16.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-16 00:00:00', 16.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-17 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-18 00:00:00', 17.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-19 00:00:00', 12.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-20 00:00:00', 14.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-21 00:00:00', 15.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-22 00:00:00', 13.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-23 00:00:00', 15.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-24 00:00:00', 16.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-25 00:00:00', 20.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-26 00:00:00', 17.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-27 00:00:00', 17.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-28 00:00:00', 19.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-29 00:00:00', 19.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-30 00:00:00', 23.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-03-31 00:00:00', 24.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-01 00:00:00', 23.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-02 00:00:00', 19.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-03 00:00:00', 17.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-04 00:00:00', 22.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-05 00:00:00', 26.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-06 00:00:00', 22.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-07 00:00:00', 24.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-08 00:00:00', 11.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-09 00:00:00', 18.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-10 00:00:00', 21.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-11 00:00:00', 22.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-12 00:00:00', 22.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-13 00:00:00', 23.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-14 00:00:00', 27.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-15 00:00:00', 28.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-16 00:00:00', 29.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-17 00:00:00', 30.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-18 00:00:00', 29.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-19 00:00:00', 31.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-20 00:00:00', 28.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-21 00:00:00', 26.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-22 00:00:00', 28.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-23 00:00:00', 31.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-24 00:00:00', 22.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-25 00:00:00', 16.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-26 00:00:00', 19.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-27 00:00:00', 21.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-28 00:00:00', 25.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-29 00:00:00', 26.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-04-30 00:00:00', 26.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-01 00:00:00', 26.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-02 00:00:00', 20.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-03 00:00:00', 14.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-04 00:00:00', 22.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-05 00:00:00', 18.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-06 00:00:00', 19.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-07 00:00:00', 23.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-08 00:00:00', 25.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-09 00:00:00', 26.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-10 00:00:00', 27.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-11 00:00:00', 23.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-12 00:00:00', 28.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-13 00:00:00', 27.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-14 00:00:00', 32.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-15 00:00:00', 33.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-16 00:00:00', 32.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-17 00:00:00', 32.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-18 00:00:00', 25.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-19 00:00:00', 27.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-20 00:00:00', 30.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-21 00:00:00', 31.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-22 00:00:00', 34.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-23 00:00:00', 35.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-24 00:00:00', 34.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-25 00:00:00', 34.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-26 00:00:00', 31.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-27 00:00:00', 31.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-28 00:00:00', 26.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-29 00:00:00', 27.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-30 00:00:00', 30.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-05-31 00:00:00', 26.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-01 00:00:00', 31.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-02 00:00:00', 32.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-03 00:00:00', 30.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-04 00:00:00', 31.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-05 00:00:00', 32.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-06 00:00:00', 29.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-07 00:00:00', 30.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-08 00:00:00', 32.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-09 00:00:00', 33.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-10 00:00:00', 32.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-11 00:00:00', 27.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-12 00:00:00', 26.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-13 00:00:00', 29.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-14 00:00:00', 26.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-15 00:00:00', 32.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-16 00:00:00', 34.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-17 00:00:00', 32.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-18 00:00:00', 33.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-19 00:00:00', 34.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-20 00:00:00', 35.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-21 00:00:00', 35.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-22 00:00:00', 32.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-23 00:00:00', 32.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-24 00:00:00', 37.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-25 00:00:00', 37.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-26 00:00:00', 37.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-27 00:00:00', 38.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-28 00:00:00', 37.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-29 00:00:00', 39.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-06-30 00:00:00', 37.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-01 00:00:00', 34.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-02 00:00:00', 35.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-03 00:00:00', 36.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-04 00:00:00', 37.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-05 00:00:00', 38.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-06 00:00:00', 40.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-07 00:00:00', 42.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-08 00:00:00', 43.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-09 00:00:00', 43.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-10 00:00:00', 44.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-11 00:00:00', 41.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-12 00:00:00', 38.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-13 00:00:00', 38.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-14 00:00:00', 40.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-15 00:00:00', 39.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-16 00:00:00', 39.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-17 00:00:00', 37.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-18 00:00:00', 39.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-19 00:00:00', 37.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-20 00:00:00', 37.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-21 00:00:00', 37.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-22 00:00:00', 38.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-23 00:00:00', 35.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-24 00:00:00', 37.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-25 00:00:00', 35.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-26 00:00:00', 30.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-27 00:00:00', 35.4059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-28 00:00:00', 36.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-29 00:00:00', 37.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-30 00:00:00', 37.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-07-31 00:00:00', 38.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-01 00:00:00', 39.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-02 00:00:00', 38.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-03 00:00:00', 38.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-04 00:00:00', 38.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-05 00:00:00', 32.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-06 00:00:00', 35.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-07 00:00:00', 37.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-08 00:00:00', 34.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-09 00:00:00', 36.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-10 00:00:00', 37.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-11 00:00:00', 39.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-12 00:00:00', 39.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-13 00:00:00', 39.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-14 00:00:00', 38.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-15 00:00:00', 37.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-16 00:00:00', 35.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-17 00:00:00', 36.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-18 00:00:00', 37.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-19 00:00:00', 38.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-20 00:00:00', 36.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-21 00:00:00', 34.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-22 00:00:00', 35.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-23 00:00:00', 35.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-24 00:00:00', 36.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-25 00:00:00', 35.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-26 00:00:00', 35.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-27 00:00:00', 36.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-28 00:00:00', 37.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-29 00:00:00', 36.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-30 00:00:00', 35.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-08-31 00:00:00', 35.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-01 00:00:00', 36.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-02 00:00:00', 39.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-03 00:00:00', 40.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-04 00:00:00', 38.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-05 00:00:00', 39.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-06 00:00:00', 38.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-07 00:00:00', 38.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-08 00:00:00', 36.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-09 00:00:00', 34.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-10 00:00:00', 33.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-11 00:00:00', 33.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-12 00:00:00', 29.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-13 00:00:00', 23.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-14 00:00:00', 22.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-15 00:00:00', 26.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-16 00:00:00', 29.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-17 00:00:00', 30.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-18 00:00:00', 30.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-19 00:00:00', 30.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-20 00:00:00', 29.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-21 00:00:00', 30.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-22 00:00:00', 29.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-23 00:00:00', 30.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-24 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-25 00:00:00', 35.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-26 00:00:00', 35.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-27 00:00:00', 35.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-28 00:00:00', 31.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-29 00:00:00', 29.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-09-30 00:00:00', 29.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-01 00:00:00', 31.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-02 00:00:00', 32.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-03 00:00:00', 30.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-04 00:00:00', 29.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-05 00:00:00', 29.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-06 00:00:00', 28.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-07 00:00:00', 29.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-08 00:00:00', 30.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-09 00:00:00', 20.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-10 00:00:00', 15.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-11 00:00:00', 19.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-12 00:00:00', 24.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-13 00:00:00', 23.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-14 00:00:00', 21.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-15 00:00:00', 22.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-16 00:00:00', 24.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-17 00:00:00', 25.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-18 00:00:00', 26.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-19 00:00:00', 24.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-20 00:00:00', 24.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-21 00:00:00', 23.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-22 00:00:00', 22.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-23 00:00:00', 22.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-24 00:00:00', 21.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-25 00:00:00', 18.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-26 00:00:00', 16.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-27 00:00:00', 18.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-28 00:00:00', 16.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-29 00:00:00', 18.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-30 00:00:00', 21.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-10-31 00:00:00', 24.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-01 00:00:00', 26.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-02 00:00:00', 25.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-03 00:00:00', 24.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-04 00:00:00', 23.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-05 00:00:00', 21.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-06 00:00:00', 22.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-07 00:00:00', 21.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-08 00:00:00', 21.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-09 00:00:00', 23.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-10 00:00:00', 23.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-11 00:00:00', 24.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-12 00:00:00', 22.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-13 00:00:00', 16.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-14 00:00:00', 16.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-15 00:00:00', 21.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-16 00:00:00', 21.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-17 00:00:00', 19.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-18 00:00:00', 20.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-19 00:00:00', 20.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-20 00:00:00', 20.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-21 00:00:00', 16.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-22 00:00:00', 15.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-23 00:00:00', 15.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-24 00:00:00', 14.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-25 00:00:00', 15.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-26 00:00:00', 16.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-27 00:00:00', 15.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-28 00:00:00', 8.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-29 00:00:00', 6.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-11-30 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-01 00:00:00', 11.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-02 00:00:00', 8.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-03 00:00:00', 8.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-04 00:00:00', 9.39700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-05 00:00:00', 12.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-06 00:00:00', 7.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-07 00:00:00', 10.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-08 00:00:00', 14.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-09 00:00:00', 14.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-10 00:00:00', 16.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-11 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-12 00:00:00', 19.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-13 00:00:00', 18.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-14 00:00:00', 18.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-15 00:00:00', 14.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-16 00:00:00', 15.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-17 00:00:00', 17.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-18 00:00:00', 19.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-19 00:00:00', 16.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-20 00:00:00', 11.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-21 00:00:00', 14.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-22 00:00:00', 11.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-23 00:00:00', 12.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-24 00:00:00', 14.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-25 00:00:00', 10.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-26 00:00:00', 12.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-27 00:00:00', 14.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-28 00:00:00', 13.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-29 00:00:00', 6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-30 00:00:00', 8.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1998-12-31 00:00:00', 12.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-02 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-04 00:00:00', 7.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-06 00:00:00', 10.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-08 00:00:00', 10.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-10 00:00:00', 9.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-12 00:00:00', 8.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-14 00:00:00', 6.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-16 00:00:00', 12.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-18 00:00:00', 8.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-20 00:00:00', 14.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-22 00:00:00', 12.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-24 00:00:00', 10.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-26 00:00:00', 14.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-28 00:00:00', 14.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-30 00:00:00', 11.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-01 00:00:00', 12.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-03 00:00:00', 12.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-05 00:00:00', 15.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-07 00:00:00', 15.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-09 00:00:00', 17.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-11 00:00:00', 12.800999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-13 00:00:00', 10.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-15 00:00:00', 12.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-17 00:00:00', 13.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-19 00:00:00', 13.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-21 00:00:00', 16.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-23 00:00:00', 16.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-25 00:00:00', 17.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-27 00:00:00', 10.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-01 00:00:00', 13.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-03 00:00:00', 12.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-04 00:00:00', 14.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-05 00:00:00', 7.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-06 00:00:00', 11.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-07 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-08 00:00:00', 9.54399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-09 00:00:00', 12.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-10 00:00:00', 15.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-11 00:00:00', 16.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-12 00:00:00', 17.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-13 00:00:00', 18.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-14 00:00:00', 11.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-15 00:00:00', 16.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-16 00:00:00', 7.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-17 00:00:00', 12.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-18 00:00:00', 13.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-19 00:00:00', 6.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-20 00:00:00', 9.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-21 00:00:00', 15.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-22 00:00:00', 18.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-23 00:00:00', 19.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-24 00:00:00', 16.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-25 00:00:00', 17.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-26 00:00:00', 19.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-27 00:00:00', 20.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-28 00:00:00', 20.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-29 00:00:00', 13.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-30 00:00:00', 20.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-03-31 00:00:00', 16.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-01 00:00:00', 16.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-02 00:00:00', 18.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-03 00:00:00', 23.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-04 00:00:00', 22.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-05 00:00:00', 24.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-06 00:00:00', 23.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-07 00:00:00', 17.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-08 00:00:00', 19.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-09 00:00:00', 22.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-10 00:00:00', 14.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-11 00:00:00', 11.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-12 00:00:00', 18.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-13 00:00:00', 19.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-14 00:00:00', 20.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-15 00:00:00', 25.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-16 00:00:00', 27.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-17 00:00:00', 27.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-18 00:00:00', 27.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-19 00:00:00', 23.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-20 00:00:00', 24.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-21 00:00:00', 25.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-22 00:00:00', 21.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-23 00:00:00', 18.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-24 00:00:00', 20.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-25 00:00:00', 23.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-26 00:00:00', 26.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-27 00:00:00', 27.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-28 00:00:00', 27.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-29 00:00:00', 28.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-04-30 00:00:00', 28.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-01 00:00:00', 28.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-02 00:00:00', 28.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-03 00:00:00', 28.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-04 00:00:00', 31.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-05 00:00:00', 30.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-06 00:00:00', 29.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-07 00:00:00', 31.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-08 00:00:00', 33.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-09 00:00:00', 32.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-10 00:00:00', 30.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-11 00:00:00', 31.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-12 00:00:00', 22.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-13 00:00:00', 26.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-14 00:00:00', 30.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-15 00:00:00', 33.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-16 00:00:00', 31.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-17 00:00:00', 34.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-18 00:00:00', 35.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-19 00:00:00', 36.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-20 00:00:00', 35.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-21 00:00:00', 38.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-22 00:00:00', 27.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-23 00:00:00', 24.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-24 00:00:00', 27.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-25 00:00:00', 27.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-26 00:00:00', 26.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-27 00:00:00', 29.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-28 00:00:00', 31.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-29 00:00:00', 31.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-30 00:00:00', 31.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-05-31 00:00:00', 32.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-01 00:00:00', 33.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-02 00:00:00', 31.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-03 00:00:00', 31.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-04 00:00:00', 32.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-05 00:00:00', 33.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-06 00:00:00', 35.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-07 00:00:00', 35.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-08 00:00:00', 37.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-09 00:00:00', 33.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-10 00:00:00', 31.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-11 00:00:00', 32.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-12 00:00:00', 32.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-13 00:00:00', 34.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-14 00:00:00', 36.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-15 00:00:00', 39.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-16 00:00:00', 37.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-17 00:00:00', 33.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-18 00:00:00', 34.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-19 00:00:00', 35.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-20 00:00:00', 34.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-21 00:00:00', 34.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-22 00:00:00', 35.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-23 00:00:00', 33.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-24 00:00:00', 32.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-25 00:00:00', 36.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-26 00:00:00', 41.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-27 00:00:00', 43.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-28 00:00:00', 41.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-29 00:00:00', 39.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-06-30 00:00:00', 40.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-01 00:00:00', 39.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-02 00:00:00', 37.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-03 00:00:00', 36.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-04 00:00:00', 37.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-05 00:00:00', 38.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-06 00:00:00', 38.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-07 00:00:00', 37.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-08 00:00:00', 37.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-09 00:00:00', 41.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-10 00:00:00', 38.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-11 00:00:00', 37.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-12 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-13 00:00:00', 32.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-14 00:00:00', 34.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-15 00:00:00', 36.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-16 00:00:00', 38.9269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-17 00:00:00', 40.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-18 00:00:00', 39.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-19 00:00:00', 35.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-20 00:00:00', 36.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-21 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-22 00:00:00', 36.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-23 00:00:00', 36.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-24 00:00:00', 36.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-25 00:00:00', 35.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-26 00:00:00', 35.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-27 00:00:00', 34.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-28 00:00:00', 36.9550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-29 00:00:00', 36.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-30 00:00:00', 37.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-07-31 00:00:00', 37.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-01 00:00:00', 39.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-02 00:00:00', 39.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-03 00:00:00', 38.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-04 00:00:00', 39.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-05 00:00:00', 41.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-06 00:00:00', 40.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-07 00:00:00', 40.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-08 00:00:00', 39.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-09 00:00:00', 40.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-10 00:00:00', 38.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-11 00:00:00', 37.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-12 00:00:00', 34.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-13 00:00:00', 33.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-14 00:00:00', 33.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-15 00:00:00', 36.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-16 00:00:00', 37.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-17 00:00:00', 37.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-18 00:00:00', 38.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-19 00:00:00', 38.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-20 00:00:00', 39.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-21 00:00:00', 39.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-22 00:00:00', 38.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-23 00:00:00', 38.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-24 00:00:00', 39.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-25 00:00:00', 38.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-26 00:00:00', 38.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-27 00:00:00', 38.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-28 00:00:00', 39.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-29 00:00:00', 39.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-30 00:00:00', 41.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-08-31 00:00:00', 38.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-01 00:00:00', 34.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-02 00:00:00', 34.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-03 00:00:00', 33.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-04 00:00:00', 34.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-05 00:00:00', 33.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-06 00:00:00', 30.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-07 00:00:00', 32.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-08 00:00:00', 31.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-09 00:00:00', 32.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-10 00:00:00', 33.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-11 00:00:00', 33.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-12 00:00:00', 34.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-13 00:00:00', 36.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-14 00:00:00', 37.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-15 00:00:00', 37.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-16 00:00:00', 37.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-17 00:00:00', 36.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-18 00:00:00', 34.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-19 00:00:00', 33.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-20 00:00:00', 32.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-21 00:00:00', 33.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-22 00:00:00', 34.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-23 00:00:00', 35.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-24 00:00:00', 27.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-25 00:00:00', 27.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-26 00:00:00', 28.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-27 00:00:00', 30.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-28 00:00:00', 31.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-29 00:00:00', 15.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-09-30 00:00:00', 24.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-01 00:00:00', 25.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-02 00:00:00', 27.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-03 00:00:00', 27.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-04 00:00:00', 28.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-05 00:00:00', 27.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-06 00:00:00', 26.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-07 00:00:00', 25.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-08 00:00:00', 24.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-09 00:00:00', 25.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-10 00:00:00', 25.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-11 00:00:00', 26.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-12 00:00:00', 26.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-13 00:00:00', 27.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-14 00:00:00', 23.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-15 00:00:00', 26.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-16 00:00:00', 29.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-17 00:00:00', 28.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-18 00:00:00', 27.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-19 00:00:00', 28.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-20 00:00:00', 26.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-21 00:00:00', 25.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-22 00:00:00', 25.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-23 00:00:00', 26.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-24 00:00:00', 27.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-25 00:00:00', 28.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-26 00:00:00', 18.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-27 00:00:00', 19.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-28 00:00:00', 17.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-29 00:00:00', 23.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-30 00:00:00', 22.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-10-31 00:00:00', 23.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-01 00:00:00', 24.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-02 00:00:00', 20.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-03 00:00:00', 11.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-04 00:00:00', 14.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-05 00:00:00', 8.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-06 00:00:00', 14.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-07 00:00:00', 14.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-08 00:00:00', 16.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-09 00:00:00', 10.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-10 00:00:00', 14.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-11 00:00:00', 8.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-12 00:00:00', 12.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-13 00:00:00', 8.37399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-14 00:00:00', 12.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-15 00:00:00', 15.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-16 00:00:00', 16.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-17 00:00:00', 15.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-18 00:00:00', 15.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-19 00:00:00', 12.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-20 00:00:00', 11.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-21 00:00:00', 8.89700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-22 00:00:00', 9.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-23 00:00:00', 13.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-24 00:00:00', 8.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-25 00:00:00', 13.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-26 00:00:00', 13.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-27 00:00:00', 14.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-28 00:00:00', 17.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-29 00:00:00', 12.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-11-30 00:00:00', 7.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-01 00:00:00', 5.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-02 00:00:00', 9.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-03 00:00:00', 13.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-04 00:00:00', 12.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-05 00:00:00', 12.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-06 00:00:00', 7.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-07 00:00:00', 9.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-08 00:00:00', 12.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-09 00:00:00', 11.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-10 00:00:00', 13.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-11 00:00:00', 7.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-12 00:00:00', 10.1579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-13 00:00:00', 12.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-14 00:00:00', 13.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-15 00:00:00', 16.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-16 00:00:00', 17.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-17 00:00:00', 14.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-18 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-19 00:00:00', 7.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-20 00:00:00', 12.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-21 00:00:00', 12.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-22 00:00:00', 14.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-23 00:00:00', 14.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-24 00:00:00', 13.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-25 00:00:00', 7.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-26 00:00:00', 9.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-27 00:00:00', 12.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-28 00:00:00', 14.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-29 00:00:00', 14.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-30 00:00:00', 15.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '1999-12-31 00:00:00', 16.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-01 00:00:00', 15.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-02 00:00:00', 16.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-03 00:00:00', 16.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-04 00:00:00', 15.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-05 00:00:00', 15.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-06 00:00:00', 16.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-07 00:00:00', 14.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-08 00:00:00', 9.31499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-09 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-10 00:00:00', 7.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-11 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-12 00:00:00', -0.665000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-13 00:00:00', -2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-14 00:00:00', 0.503000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-15 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-16 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-17 00:00:00', 11.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-18 00:00:00', 6.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-19 00:00:00', 9.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-20 00:00:00', 12.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-21 00:00:00', 14.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-22 00:00:00', 9.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-23 00:00:00', 13.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-24 00:00:00', 8.94200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-25 00:00:00', 7.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-26 00:00:00', 9.66100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-27 00:00:00', 12.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-28 00:00:00', 15.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-29 00:00:00', 16.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-30 00:00:00', 12.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-01-31 00:00:00', 6.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-01 00:00:00', 7.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-02 00:00:00', 9.55500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-03 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-04 00:00:00', 7.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-05 00:00:00', 10.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-06 00:00:00', 10.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-07 00:00:00', 12.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-08 00:00:00', 10.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-09 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-10 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-11 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-12 00:00:00', 2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-13 00:00:00', 8.89299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-14 00:00:00', 12.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-15 00:00:00', 6.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-16 00:00:00', 5.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-17 00:00:00', 8.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-18 00:00:00', 9.62100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-19 00:00:00', 9.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-20 00:00:00', 9.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-21 00:00:00', 11.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-22 00:00:00', 11.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-23 00:00:00', 12.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-24 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-25 00:00:00', 14.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-26 00:00:00', 13.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-27 00:00:00', 7.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-28 00:00:00', 12.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-02-29 00:00:00', 10.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-01 00:00:00', 10.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-02 00:00:00', 10.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-03 00:00:00', 12.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-04 00:00:00', 5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-05 00:00:00', 9.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-06 00:00:00', 9.07699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-07 00:00:00', 13.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-08 00:00:00', 16.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-09 00:00:00', 17.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-10 00:00:00', 15.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-11 00:00:00', 14.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-12 00:00:00', 17.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-13 00:00:00', 17.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-14 00:00:00', 20.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-15 00:00:00', 20.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-16 00:00:00', 11.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-17 00:00:00', 11.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-18 00:00:00', 14.4280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-19 00:00:00', 18.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-20 00:00:00', 19.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-21 00:00:00', 20.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-22 00:00:00', 20.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-23 00:00:00', 22.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-24 00:00:00', 24.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-25 00:00:00', 29.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-26 00:00:00', 25.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-27 00:00:00', 13.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-28 00:00:00', 12.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-29 00:00:00', 12.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-30 00:00:00', 18.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-03-31 00:00:00', 21.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-01 00:00:00', 22.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-02 00:00:00', 23.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-03 00:00:00', 18.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-04 00:00:00', 18.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-05 00:00:00', 21.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-06 00:00:00', 23.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-07 00:00:00', 25.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-08 00:00:00', 27.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-09 00:00:00', 29.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-10 00:00:00', 30.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-11 00:00:00', 34.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-12 00:00:00', 33.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-13 00:00:00', 27.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-14 00:00:00', 25.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-15 00:00:00', 26.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-16 00:00:00', 28.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-17 00:00:00', 31.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-18 00:00:00', 29.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-19 00:00:00', 29.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-20 00:00:00', 31.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-21 00:00:00', 31.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-22 00:00:00', 32.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-23 00:00:00', 31.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-24 00:00:00', 33.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-25 00:00:00', 30.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-26 00:00:00', 29.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-27 00:00:00', 28.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-28 00:00:00', 26.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-29 00:00:00', 27.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-04-30 00:00:00', 30.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-01 00:00:00', 34.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-02 00:00:00', 31.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-03 00:00:00', 34.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-04 00:00:00', 32.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-05 00:00:00', 34.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-06 00:00:00', 33.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-07 00:00:00', 36.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-08 00:00:00', 38.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-09 00:00:00', 40.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-10 00:00:00', 38.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-11 00:00:00', 33.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-12 00:00:00', 32.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-13 00:00:00', 34.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-14 00:00:00', 34.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-15 00:00:00', 33.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-16 00:00:00', 35.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-17 00:00:00', 36.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-18 00:00:00', 36.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-19 00:00:00', 36.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-20 00:00:00', 38.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-21 00:00:00', 36.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-22 00:00:00', 33.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-23 00:00:00', 32.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-24 00:00:00', 32.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-25 00:00:00', 33.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-26 00:00:00', 33.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-27 00:00:00', 35.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-28 00:00:00', 39.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-29 00:00:00', 36.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-30 00:00:00', 34.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-05-31 00:00:00', 35.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-01 00:00:00', 34.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-02 00:00:00', 32.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-03 00:00:00', 31.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-04 00:00:00', 32.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-05 00:00:00', 34.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-06 00:00:00', 36.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-07 00:00:00', 36.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-08 00:00:00', 36.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-09 00:00:00', 37.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-10 00:00:00', 35.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-11 00:00:00', 36.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-12 00:00:00', 36.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-13 00:00:00', 36.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-14 00:00:00', 29.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-15 00:00:00', 33.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-16 00:00:00', 33.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-17 00:00:00', 34.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-18 00:00:00', 36.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-19 00:00:00', 35.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-20 00:00:00', 36.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-21 00:00:00', 37.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-22 00:00:00', 37.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-23 00:00:00', 38.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-24 00:00:00', 40.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-25 00:00:00', 41.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-26 00:00:00', 40.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-27 00:00:00', 40.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-28 00:00:00', 39.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-29 00:00:00', 38.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-06-30 00:00:00', 38.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-01 00:00:00', 38.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-02 00:00:00', 38.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-03 00:00:00', 38.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-04 00:00:00', 37.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-05 00:00:00', 37.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-06 00:00:00', 39.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-07 00:00:00', 39.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-08 00:00:00', 40.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-09 00:00:00', 40.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-10 00:00:00', 40.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-11 00:00:00', 39.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-12 00:00:00', 39.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-13 00:00:00', 38.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-14 00:00:00', 37.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-15 00:00:00', 36.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-16 00:00:00', 35.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-17 00:00:00', 33.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-18 00:00:00', 33.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-19 00:00:00', 35.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-20 00:00:00', 35.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-21 00:00:00', 37.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-22 00:00:00', 37.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-23 00:00:00', 37.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-24 00:00:00', 36.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-25 00:00:00', 35.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-26 00:00:00', 35.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-27 00:00:00', 36.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-28 00:00:00', 38.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-29 00:00:00', 39.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-30 00:00:00', 40.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-07-31 00:00:00', 41.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-01 00:00:00', 39.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-02 00:00:00', 38.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-03 00:00:00', 39.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-04 00:00:00', 39.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-05 00:00:00', 38.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-06 00:00:00', 39.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-07 00:00:00', 39.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-08 00:00:00', 39.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-09 00:00:00', 37.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-10 00:00:00', 38.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-11 00:00:00', 38.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-12 00:00:00', 38.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-13 00:00:00', 37.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-14 00:00:00', 37.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-15 00:00:00', 37.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-16 00:00:00', 37.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-17 00:00:00', 35.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-18 00:00:00', 33.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-19 00:00:00', 35.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-20 00:00:00', 34.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-21 00:00:00', 35.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-22 00:00:00', 35.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-23 00:00:00', 36.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-24 00:00:00', 37.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-25 00:00:00', 37.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-26 00:00:00', 39.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-27 00:00:00', 39.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-28 00:00:00', 39.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-29 00:00:00', 39.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-30 00:00:00', 38.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-08-31 00:00:00', 37.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-01 00:00:00', 36.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-02 00:00:00', 36.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-03 00:00:00', 36.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-04 00:00:00', 36.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-05 00:00:00', 36.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-06 00:00:00', 34.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-07 00:00:00', 33.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-08 00:00:00', 34.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-09 00:00:00', 32.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-10 00:00:00', 33.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-11 00:00:00', 32.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-12 00:00:00', 33.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-13 00:00:00', 34.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-14 00:00:00', 35.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-15 00:00:00', 35.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-16 00:00:00', 35.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-17 00:00:00', 36.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-18 00:00:00', 35.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-19 00:00:00', 34.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-20 00:00:00', 30.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-21 00:00:00', 28.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-22 00:00:00', 28.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-23 00:00:00', 29.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-24 00:00:00', 30.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-25 00:00:00', 27.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-26 00:00:00', 23.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-27 00:00:00', 27.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-28 00:00:00', 29.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-29 00:00:00', 30.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-09-30 00:00:00', 27.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-01 00:00:00', 28.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-02 00:00:00', 27.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-03 00:00:00', 27.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-04 00:00:00', 24.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-05 00:00:00', 17.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-06 00:00:00', 22.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-07 00:00:00', 20.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-08 00:00:00', 21.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-09 00:00:00', 21.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-10 00:00:00', 22.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-11 00:00:00', 24.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-12 00:00:00', 26.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-13 00:00:00', 26.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-14 00:00:00', 26.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-15 00:00:00', 21.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-16 00:00:00', 13.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-17 00:00:00', 21.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-18 00:00:00', 24.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-19 00:00:00', 22.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-20 00:00:00', 23.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-21 00:00:00', 23.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-22 00:00:00', 21.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-23 00:00:00', 20.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-24 00:00:00', 22.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-25 00:00:00', 22.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-26 00:00:00', 23.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-27 00:00:00', 26.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-28 00:00:00', 27.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-29 00:00:00', 26.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-30 00:00:00', 23.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-10-31 00:00:00', 23.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-01 00:00:00', 20.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-02 00:00:00', 21.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-03 00:00:00', 23.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-04 00:00:00', 24.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-05 00:00:00', 20.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-06 00:00:00', 20.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-07 00:00:00', 18.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-08 00:00:00', 8.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-09 00:00:00', 14.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-10 00:00:00', 17.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-11 00:00:00', 10.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-12 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-13 00:00:00', 9.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-14 00:00:00', 13.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-15 00:00:00', 14.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-16 00:00:00', 9.73900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-17 00:00:00', 7.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-18 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-19 00:00:00', 11.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-20 00:00:00', 12.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-21 00:00:00', 12.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-22 00:00:00', 12.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-23 00:00:00', 11.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-24 00:00:00', 13.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-25 00:00:00', 13.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-26 00:00:00', 13.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-27 00:00:00', 12.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-28 00:00:00', 12.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-29 00:00:00', 8.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-11-30 00:00:00', 8.49600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-01 00:00:00', 11.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-02 00:00:00', 7.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-03 00:00:00', 7.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-04 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-05 00:00:00', 8.59599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-06 00:00:00', 10.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-07 00:00:00', 9.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-08 00:00:00', 10.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-09 00:00:00', 11.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-10 00:00:00', 6.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-11 00:00:00', 9.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-12 00:00:00', 9.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-13 00:00:00', 12.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-14 00:00:00', 10.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-15 00:00:00', 13.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-16 00:00:00', 9.38099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-17 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-18 00:00:00', 8.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-19 00:00:00', 10.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-20 00:00:00', 12.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-21 00:00:00', 14.2309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-22 00:00:00', 15.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-23 00:00:00', 13.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-24 00:00:00', 12.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-25 00:00:00', 11.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-26 00:00:00', 14.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-27 00:00:00', 11.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-28 00:00:00', 6.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-29 00:00:00', 9.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-30 00:00:00', 9.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2000-12-31 00:00:00', 9.12800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-01 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-02 00:00:00', 8.91199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-03 00:00:00', 8.19200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-04 00:00:00', 10.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-05 00:00:00', 12.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-06 00:00:00', 9.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-07 00:00:00', 8.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-08 00:00:00', 8.11900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-09 00:00:00', 8.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-10 00:00:00', 9.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-11 00:00:00', 10.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-12 00:00:00', 10.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-13 00:00:00', 11.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-14 00:00:00', 12.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-15 00:00:00', 12.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-16 00:00:00', 5.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-17 00:00:00', 6.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-18 00:00:00', 8.42800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-19 00:00:00', 8.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-20 00:00:00', 8.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-21 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-22 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-23 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-24 00:00:00', 4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-25 00:00:00', 2.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-26 00:00:00', 2.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-27 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-28 00:00:00', 6.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-29 00:00:00', -5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-30 00:00:00', -3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-01-31 00:00:00', 1.6109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-01 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-02 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-03 00:00:00', 5.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-04 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-05 00:00:00', 5.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-06 00:00:00', 2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-07 00:00:00', 5.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-08 00:00:00', 7.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-09 00:00:00', 7.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-10 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-11 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-12 00:00:00', 7.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-13 00:00:00', 8.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-14 00:00:00', 11.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-15 00:00:00', 15.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-16 00:00:00', 9.27499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-17 00:00:00', 11.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-18 00:00:00', 13.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-19 00:00:00', 16.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-20 00:00:00', 9.72000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-21 00:00:00', 14.9049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-22 00:00:00', 9.42099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-23 00:00:00', 12.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-24 00:00:00', 14.0679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-25 00:00:00', 13.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-26 00:00:00', 15.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-27 00:00:00', 15.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-02-28 00:00:00', 15.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-01 00:00:00', 16.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-02 00:00:00', 17.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-03 00:00:00', 17.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-04 00:00:00', 20.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-05 00:00:00', 19.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-06 00:00:00', 16.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-07 00:00:00', 18.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-08 00:00:00', 20.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-09 00:00:00', 22.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-10 00:00:00', 21.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-11 00:00:00', 15.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-12 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-13 00:00:00', 8.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-14 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-15 00:00:00', 17.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-16 00:00:00', 20.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-17 00:00:00', 20.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-18 00:00:00', 19.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-19 00:00:00', 11.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-20 00:00:00', 17.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-21 00:00:00', 19.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-22 00:00:00', 21.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-23 00:00:00', 23.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-24 00:00:00', 25.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-25 00:00:00', 24.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-26 00:00:00', 26.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-27 00:00:00', 16.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-28 00:00:00', 10.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-29 00:00:00', 15.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-30 00:00:00', 20.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-03-31 00:00:00', 22.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-01 00:00:00', 22.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-02 00:00:00', 16.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-03 00:00:00', 20.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-04 00:00:00', 25.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-05 00:00:00', 25.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-06 00:00:00', 26.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-07 00:00:00', 30.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-08 00:00:00', 31.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-09 00:00:00', 30.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-10 00:00:00', 30.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-11 00:00:00', 30.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-12 00:00:00', 30.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-13 00:00:00', 30.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-14 00:00:00', 28.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-15 00:00:00', 29.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-16 00:00:00', 28.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-17 00:00:00', 27.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-18 00:00:00', 26.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-19 00:00:00', 19.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-20 00:00:00', 25.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-21 00:00:00', 28.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-22 00:00:00', 30.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-23 00:00:00', 28.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-24 00:00:00', 29.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-25 00:00:00', 29.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-26 00:00:00', 29.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-27 00:00:00', 31.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-28 00:00:00', 31.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-29 00:00:00', 31.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-04-30 00:00:00', 31.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-01 00:00:00', 31.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-02 00:00:00', 30.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-03 00:00:00', 32.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-04 00:00:00', 34.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-05 00:00:00', 35.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-06 00:00:00', 36.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-07 00:00:00', 33.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-08 00:00:00', 34.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-09 00:00:00', 36.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-10 00:00:00', 38.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-11 00:00:00', 38.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-12 00:00:00', 38.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-13 00:00:00', 37.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-14 00:00:00', 36.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-15 00:00:00', 36.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-16 00:00:00', 38.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-17 00:00:00', 38.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-18 00:00:00', 37.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-19 00:00:00', 34.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-20 00:00:00', 31.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-21 00:00:00', 31.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-22 00:00:00', 33.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-23 00:00:00', 34.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-24 00:00:00', 33.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-25 00:00:00', 33.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-26 00:00:00', 36.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-27 00:00:00', 37.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-28 00:00:00', 35.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-29 00:00:00', 35.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-30 00:00:00', 38.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-05-31 00:00:00', 39.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-01 00:00:00', 40.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-02 00:00:00', 37.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-03 00:00:00', 35.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-04 00:00:00', 35.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-05 00:00:00', 35.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-06 00:00:00', 36.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-07 00:00:00', 37.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-08 00:00:00', 37.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-09 00:00:00', 39.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-10 00:00:00', 40.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-11 00:00:00', 38.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-12 00:00:00', 37.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-13 00:00:00', 37.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-14 00:00:00', 35.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-15 00:00:00', 37.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-16 00:00:00', 36.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-17 00:00:00', 36.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-18 00:00:00', 38.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-19 00:00:00', 39.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-20 00:00:00', 40.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-21 00:00:00', 39.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-22 00:00:00', 36.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-23 00:00:00', 37.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-24 00:00:00', 38.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-25 00:00:00', 39.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-26 00:00:00', 40.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-27 00:00:00', 42.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-28 00:00:00', 44.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-29 00:00:00', 44.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-06-30 00:00:00', 43.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-01 00:00:00', 41.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-02 00:00:00', 38.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-03 00:00:00', 38.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-04 00:00:00', 37.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-05 00:00:00', 35.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-06 00:00:00', 36.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-07 00:00:00', 36.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-08 00:00:00', 38.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-09 00:00:00', 39.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-10 00:00:00', 40.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-11 00:00:00', 42.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-12 00:00:00', 42.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-13 00:00:00', 41.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-14 00:00:00', 41.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-15 00:00:00', 37.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-16 00:00:00', 35.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-17 00:00:00', 35.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-18 00:00:00', 37.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-19 00:00:00', 41.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-20 00:00:00', 39.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-21 00:00:00', 37.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-22 00:00:00', 37.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-23 00:00:00', 37.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-24 00:00:00', 36.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-25 00:00:00', 38.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-26 00:00:00', 39.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-27 00:00:00', 39.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-28 00:00:00', 37.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-29 00:00:00', 33.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-30 00:00:00', 31.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-07-31 00:00:00', 34.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-01 00:00:00', 36.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-02 00:00:00', 37.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-03 00:00:00', 38.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-04 00:00:00', 39.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-05 00:00:00', 39.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-06 00:00:00', 38.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-07 00:00:00', 38.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-08 00:00:00', 36.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-09 00:00:00', 37.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-10 00:00:00', 37.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-11 00:00:00', 37.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-12 00:00:00', 36.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-13 00:00:00', 36.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-14 00:00:00', 33.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-15 00:00:00', 33.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-16 00:00:00', 34.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-17 00:00:00', 35.3300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-18 00:00:00', 36.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-19 00:00:00', 34.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-20 00:00:00', 35.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-21 00:00:00', 36.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-22 00:00:00', 35.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-23 00:00:00', 35.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-24 00:00:00', 36.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-25 00:00:00', 36.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-26 00:00:00', 32.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-27 00:00:00', 35.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-28 00:00:00', 33.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-29 00:00:00', 32.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-30 00:00:00', 33.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-08-31 00:00:00', 35.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-01 00:00:00', 38.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-02 00:00:00', 37.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-03 00:00:00', 34.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-04 00:00:00', 32.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-05 00:00:00', 34.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-06 00:00:00', 34.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-07 00:00:00', 35.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-08 00:00:00', 37.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-09 00:00:00', 38.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-10 00:00:00', 33.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-11 00:00:00', 32.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-12 00:00:00', 29.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-13 00:00:00', 28.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-14 00:00:00', 27.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-15 00:00:00', 29.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-16 00:00:00', 30.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-17 00:00:00', 30.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-18 00:00:00', 29.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-19 00:00:00', 26.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-20 00:00:00', 22.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-21 00:00:00', 25.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-22 00:00:00', 24.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-23 00:00:00', 25.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-24 00:00:00', 26.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-25 00:00:00', 27.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-26 00:00:00', 28.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-27 00:00:00', 31.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-28 00:00:00', 31.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-29 00:00:00', 31.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-09-30 00:00:00', 32.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-01 00:00:00', 32.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-02 00:00:00', 30.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-03 00:00:00', 24.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-04 00:00:00', 24.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-05 00:00:00', 23.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-06 00:00:00', 26.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-07 00:00:00', 31.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-08 00:00:00', 30.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-09 00:00:00', 25.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-10 00:00:00', 20.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-11 00:00:00', 17.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-12 00:00:00', 23.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-13 00:00:00', 24.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-14 00:00:00', 25.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-15 00:00:00', 26.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-16 00:00:00', 26.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-17 00:00:00', 25.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-18 00:00:00', 22.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-19 00:00:00', 22.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-20 00:00:00', 28.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-21 00:00:00', 26.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-22 00:00:00', 26.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-23 00:00:00', 19.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-24 00:00:00', 23.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-25 00:00:00', 27.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-26 00:00:00', 29.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-27 00:00:00', 19.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-28 00:00:00', 17.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-29 00:00:00', 20.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-30 00:00:00', 19.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-10-31 00:00:00', 21.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-01 00:00:00', 19.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-02 00:00:00', 15.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-03 00:00:00', 12.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-04 00:00:00', 17.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-05 00:00:00', 17.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-06 00:00:00', 17.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-07 00:00:00', 19.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-08 00:00:00', 21.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-09 00:00:00', 15.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-10 00:00:00', 17.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-11 00:00:00', 18.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-12 00:00:00', 21.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-13 00:00:00', 24.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-14 00:00:00', 23.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-15 00:00:00', 19.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-16 00:00:00', 22.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-17 00:00:00', 24.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-18 00:00:00', 24.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-19 00:00:00', 24.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-20 00:00:00', 15.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-21 00:00:00', 17.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-22 00:00:00', 20.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-23 00:00:00', 23.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-24 00:00:00', 17.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-25 00:00:00', 16.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-26 00:00:00', 16.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-27 00:00:00', 15.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-28 00:00:00', 15.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-29 00:00:00', 9.94200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-11-30 00:00:00', 10.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-01 00:00:00', 9.81999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-02 00:00:00', 7.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-03 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-04 00:00:00', 8.62800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-05 00:00:00', 8.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-06 00:00:00', 11.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-07 00:00:00', 11.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-08 00:00:00', 11.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-09 00:00:00', 11.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-10 00:00:00', 5.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-11 00:00:00', 8.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-12 00:00:00', 10.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-13 00:00:00', 8.62100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-14 00:00:00', 11.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-15 00:00:00', 12.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-16 00:00:00', 9.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-17 00:00:00', 9.71100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-18 00:00:00', 8.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-19 00:00:00', 11.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-20 00:00:00', 13.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-21 00:00:00', 14.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-22 00:00:00', 8.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-23 00:00:00', 8.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-24 00:00:00', 11.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-25 00:00:00', 13.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-26 00:00:00', 14.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-27 00:00:00', 15.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-28 00:00:00', 14.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-29 00:00:00', 15.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-30 00:00:00', 16.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2001-12-31 00:00:00', 15.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-01 00:00:00', 15.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-02 00:00:00', 17.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-03 00:00:00', 19.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-04 00:00:00', 17.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-05 00:00:00', 15.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-06 00:00:00', 15.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-07 00:00:00', 16.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-08 00:00:00', 18.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-09 00:00:00', 11.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-10 00:00:00', 11.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-11 00:00:00', 10.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-12 00:00:00', 8.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-13 00:00:00', 5.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-14 00:00:00', 3.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-15 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-16 00:00:00', 3.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-17 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-18 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-19 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-20 00:00:00', 7.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-21 00:00:00', 8.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-22 00:00:00', 9.68000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-23 00:00:00', 7.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-24 00:00:00', 7.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-25 00:00:00', 6.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-26 00:00:00', 5.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-27 00:00:00', 5.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-28 00:00:00', 7.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-29 00:00:00', 11.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-30 00:00:00', 12.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-01-31 00:00:00', 10.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-01 00:00:00', 7.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-02 00:00:00', 5.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-03 00:00:00', 7.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-04 00:00:00', 6.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-05 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-06 00:00:00', 0.252999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-07 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-08 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-09 00:00:00', 9.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-10 00:00:00', 10.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-11 00:00:00', 10.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-12 00:00:00', 9.46100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-13 00:00:00', 13.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-14 00:00:00', 16.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-15 00:00:00', 12.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-16 00:00:00', 13.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-17 00:00:00', 8.27700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-18 00:00:00', 12.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-19 00:00:00', 10.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-20 00:00:00', 13.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-21 00:00:00', 15.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-22 00:00:00', 8.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-23 00:00:00', 11.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-24 00:00:00', 13.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-25 00:00:00', 14.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-26 00:00:00', 15.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-27 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-02-28 00:00:00', 17.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-01 00:00:00', 11.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-02 00:00:00', 12.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-03 00:00:00', 14.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-04 00:00:00', 17.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-05 00:00:00', 19.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-06 00:00:00', 20.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-07 00:00:00', 10.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-08 00:00:00', 11.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-09 00:00:00', 14.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-10 00:00:00', 15.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-11 00:00:00', 6.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-12 00:00:00', 11.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-13 00:00:00', 15.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-14 00:00:00', 17.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-15 00:00:00', 21.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-16 00:00:00', 23.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-17 00:00:00', 24.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-18 00:00:00', 24.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-19 00:00:00', 27.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-20 00:00:00', 19.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-21 00:00:00', 22.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-22 00:00:00', 22.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-23 00:00:00', 19.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-24 00:00:00', 11.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-25 00:00:00', 17.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-26 00:00:00', 21.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-27 00:00:00', 24.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-28 00:00:00', 26.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-29 00:00:00', 27.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-30 00:00:00', 16.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-03-31 00:00:00', 17.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-01 00:00:00', 16.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-02 00:00:00', 19.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-03 00:00:00', 23.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-04 00:00:00', 20.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-05 00:00:00', 16.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-06 00:00:00', 21.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-07 00:00:00', 22.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-08 00:00:00', 24.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-09 00:00:00', 27.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-10 00:00:00', 28.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-11 00:00:00', 28.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-12 00:00:00', 25.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-13 00:00:00', 27.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-14 00:00:00', 24.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-15 00:00:00', 15.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-16 00:00:00', 22.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-17 00:00:00', 25.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-18 00:00:00', 27.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-19 00:00:00', 30.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-20 00:00:00', 33.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-21 00:00:00', 33.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-22 00:00:00', 24.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-23 00:00:00', 17.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-24 00:00:00', 20.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-25 00:00:00', 21.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-26 00:00:00', 17.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-27 00:00:00', 17.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-28 00:00:00', 20.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-29 00:00:00', 22.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-04-30 00:00:00', 21.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-01 00:00:00', 24.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-02 00:00:00', 23.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-03 00:00:00', 26.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-04 00:00:00', 28.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-05 00:00:00', 26.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-06 00:00:00', 27.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-07 00:00:00', 29.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-08 00:00:00', 32.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-09 00:00:00', 32.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-10 00:00:00', 31.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-11 00:00:00', 34.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-12 00:00:00', 35.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-13 00:00:00', 30.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-14 00:00:00', 19.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-15 00:00:00', 27.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-16 00:00:00', 30.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-17 00:00:00', 30.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-18 00:00:00', 26.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-19 00:00:00', 26.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-20 00:00:00', 27.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-21 00:00:00', 29.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-22 00:00:00', 31.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-23 00:00:00', 32.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-24 00:00:00', 33.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-25 00:00:00', 35.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-26 00:00:00', 36.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-27 00:00:00', 32.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-28 00:00:00', 31.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-29 00:00:00', 32.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-30 00:00:00', 34.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-05-31 00:00:00', 37.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-01 00:00:00', 37.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-02 00:00:00', 38.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-03 00:00:00', 38.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-04 00:00:00', 37.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-05 00:00:00', 34.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-06 00:00:00', 33.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-07 00:00:00', 38.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-08 00:00:00', 33.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-09 00:00:00', 32.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-10 00:00:00', 33.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-11 00:00:00', 35.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-12 00:00:00', 36.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-13 00:00:00', 37.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-14 00:00:00', 39.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-15 00:00:00', 36.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-16 00:00:00', 33.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-17 00:00:00', 32.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-18 00:00:00', 34.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-19 00:00:00', 35.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-20 00:00:00', 36.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-21 00:00:00', 40.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-22 00:00:00', 39.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-23 00:00:00', 33.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-24 00:00:00', 33.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-25 00:00:00', 34.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-26 00:00:00', 37.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-27 00:00:00', 40.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-28 00:00:00', 40.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-29 00:00:00', 38.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-06-30 00:00:00', 38.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-01 00:00:00', 38.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-02 00:00:00', 34.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-03 00:00:00', 35.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-04 00:00:00', 35.9410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-05 00:00:00', 34.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-06 00:00:00', 34.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-07 00:00:00', 35.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-08 00:00:00', 35.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-09 00:00:00', 34.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-10 00:00:00', 35.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-11 00:00:00', 36.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-12 00:00:00', 37.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-13 00:00:00', 38.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-14 00:00:00', 38.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-15 00:00:00', 39.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-16 00:00:00', 40.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-17 00:00:00', 40.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-18 00:00:00', 41.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-19 00:00:00', 41.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-20 00:00:00', 41.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-21 00:00:00', 36.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-22 00:00:00', 32.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-23 00:00:00', 35.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-24 00:00:00', 38.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-25 00:00:00', 39.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-26 00:00:00', 39.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-27 00:00:00', 38.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-28 00:00:00', 37.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-29 00:00:00', 36.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-30 00:00:00', 36.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-07-31 00:00:00', 36.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-01 00:00:00', 38.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-02 00:00:00', 38.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-03 00:00:00', 38.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-04 00:00:00', 39.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-05 00:00:00', 40.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-06 00:00:00', 40.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-07 00:00:00', 41.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-08 00:00:00', 42.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-09 00:00:00', 43.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-10 00:00:00', 42.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-11 00:00:00', 43.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-12 00:00:00', 41.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-13 00:00:00', 34.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-14 00:00:00', 31.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-15 00:00:00', 34.0120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-16 00:00:00', 36.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-17 00:00:00', 38.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-18 00:00:00', 38.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-19 00:00:00', 39.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-20 00:00:00', 40.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-21 00:00:00', 36.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-22 00:00:00', 37.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-23 00:00:00', 40.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-24 00:00:00', 39.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-25 00:00:00', 39.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-26 00:00:00', 38.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-27 00:00:00', 39.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-28 00:00:00', 39.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-29 00:00:00', 38.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-30 00:00:00', 38.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-08-31 00:00:00', 35.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-01 00:00:00', 33.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-02 00:00:00', 31.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-03 00:00:00', 30.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-04 00:00:00', 30.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-05 00:00:00', 31.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-06 00:00:00', 31.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-07 00:00:00', 30.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-08 00:00:00', 32.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-09 00:00:00', 31.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-10 00:00:00', 32.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-11 00:00:00', 34.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-12 00:00:00', 35.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-13 00:00:00', 35.9410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-14 00:00:00', 36.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-15 00:00:00', 36.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-16 00:00:00', 35.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-17 00:00:00', 30.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-18 00:00:00', 32.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-19 00:00:00', 33.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-20 00:00:00', 34.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-21 00:00:00', 33.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-22 00:00:00', 32.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-23 00:00:00', 31.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-24 00:00:00', 29.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-25 00:00:00', 29.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-26 00:00:00', 29.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-27 00:00:00', 29.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-28 00:00:00', 29.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-29 00:00:00', 30.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-09-30 00:00:00', 30.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-01 00:00:00', 31.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-02 00:00:00', 32.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-03 00:00:00', 31.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-04 00:00:00', 32.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-05 00:00:00', 31.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-06 00:00:00', 31.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-07 00:00:00', 30.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-08 00:00:00', 31.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-09 00:00:00', 30.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-10 00:00:00', 30.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-11 00:00:00', 29.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-12 00:00:00', 29.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-13 00:00:00', 28.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-14 00:00:00', 28.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-15 00:00:00', 26.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-16 00:00:00', 25.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-17 00:00:00', 25.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-18 00:00:00', 25.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-19 00:00:00', 24.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-20 00:00:00', 24.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-21 00:00:00', 25.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-22 00:00:00', 27.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-23 00:00:00', 22.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-24 00:00:00', 20.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-25 00:00:00', 23.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-26 00:00:00', 24.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-27 00:00:00', 25.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-28 00:00:00', 24.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-29 00:00:00', 24.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-30 00:00:00', 25.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-10-31 00:00:00', 26.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-01 00:00:00', 24.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-02 00:00:00', 26.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-03 00:00:00', 23.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-04 00:00:00', 22.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-05 00:00:00', 15.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-06 00:00:00', 19.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-07 00:00:00', 21.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-08 00:00:00', 20.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-09 00:00:00', 17.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-10 00:00:00', 18.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-11 00:00:00', 20.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-12 00:00:00', 21.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-13 00:00:00', 23.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-14 00:00:00', 19.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-15 00:00:00', 16.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-16 00:00:00', 11.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-17 00:00:00', 15.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-18 00:00:00', 10.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-19 00:00:00', 14.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-20 00:00:00', 16.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-21 00:00:00', 16.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-22 00:00:00', 16.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-23 00:00:00', 16.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-24 00:00:00', 18.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-25 00:00:00', 20.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-26 00:00:00', 18.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-27 00:00:00', 14.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-28 00:00:00', 13.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-29 00:00:00', 14.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-11-30 00:00:00', 9.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-01 00:00:00', 12.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-02 00:00:00', 8.66399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-03 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-04 00:00:00', -4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-05 00:00:00', -3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-06 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-07 00:00:00', 1.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-08 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-09 00:00:00', 4.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-10 00:00:00', 9.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-11 00:00:00', 8.95600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-12 00:00:00', 8.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-13 00:00:00', 10.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-14 00:00:00', 11.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-15 00:00:00', 7.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-16 00:00:00', 9.41199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-17 00:00:00', 7.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-18 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-19 00:00:00', 2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-20 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-21 00:00:00', 9.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-22 00:00:00', 13.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-23 00:00:00', 9.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-24 00:00:00', 5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-25 00:00:00', 4.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-26 00:00:00', 8.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-27 00:00:00', 6.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-28 00:00:00', 5.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-29 00:00:00', 7.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-30 00:00:00', 4.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2002-12-31 00:00:00', 7.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-01 00:00:00', 11.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-02 00:00:00', 10.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-03 00:00:00', 11.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-04 00:00:00', 13.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-05 00:00:00', 13.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-06 00:00:00', 11.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-07 00:00:00', 10.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-08 00:00:00', 7.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-09 00:00:00', 10.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-10 00:00:00', 12.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-11 00:00:00', 9.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-12 00:00:00', 10.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-13 00:00:00', 12.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-14 00:00:00', 14.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-15 00:00:00', 15.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-16 00:00:00', 15.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-17 00:00:00', 16.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-18 00:00:00', 17.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-19 00:00:00', 8.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-20 00:00:00', 15.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-21 00:00:00', 10.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-22 00:00:00', 9.93700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-23 00:00:00', 8.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-24 00:00:00', 9.52499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-25 00:00:00', 9.34799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-26 00:00:00', 8.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-27 00:00:00', 9.70600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-28 00:00:00', 11.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-29 00:00:00', 7.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-30 00:00:00', 7.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-01-31 00:00:00', 7.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-01 00:00:00', 9.25300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-02 00:00:00', 12.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-03 00:00:00', 15.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-04 00:00:00', 16.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-05 00:00:00', 18.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-06 00:00:00', 11.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-07 00:00:00', 6.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-08 00:00:00', 10.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-09 00:00:00', 11.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-10 00:00:00', 14.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-11 00:00:00', 16.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-12 00:00:00', 12.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-13 00:00:00', 6.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-14 00:00:00', 11.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-15 00:00:00', 11.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-16 00:00:00', 8.25599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-17 00:00:00', 5.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-18 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-19 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-20 00:00:00', 8.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-21 00:00:00', 10.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-22 00:00:00', 9.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-23 00:00:00', 11.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-24 00:00:00', 10.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-25 00:00:00', 11.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-26 00:00:00', 12.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-27 00:00:00', 8.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-02-28 00:00:00', 7.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-01 00:00:00', 5.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-02 00:00:00', 1.55099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-03 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-04 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-05 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-06 00:00:00', 10.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-07 00:00:00', 13.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-08 00:00:00', 17.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-09 00:00:00', 8.59300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-10 00:00:00', 11.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-11 00:00:00', 14.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-12 00:00:00', 16.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-13 00:00:00', 18.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-14 00:00:00', 15.560999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-15 00:00:00', 11.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-16 00:00:00', 11.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-17 00:00:00', 17.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-18 00:00:00', 15.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-19 00:00:00', 16.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-20 00:00:00', 20.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-21 00:00:00', 24.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-22 00:00:00', 19.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-23 00:00:00', 22.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-24 00:00:00', 17.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-25 00:00:00', 20.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-26 00:00:00', 24.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-27 00:00:00', 16.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-28 00:00:00', 13.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-29 00:00:00', 17.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-30 00:00:00', 19.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-03-31 00:00:00', 11.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-01 00:00:00', 13.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-02 00:00:00', 15.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-03 00:00:00', 15.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-04 00:00:00', 16.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-05 00:00:00', 18.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-06 00:00:00', 22.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-07 00:00:00', 27.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-08 00:00:00', 29.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-09 00:00:00', 29.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-10 00:00:00', 29.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-11 00:00:00', 29.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-12 00:00:00', 29.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-13 00:00:00', 28.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-14 00:00:00', 26.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-15 00:00:00', 15.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-16 00:00:00', 13.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-17 00:00:00', 20.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-18 00:00:00', 15.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-19 00:00:00', 4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-20 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-21 00:00:00', 21.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-22 00:00:00', 26.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-23 00:00:00', 29.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-24 00:00:00', 19.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-25 00:00:00', 23.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-26 00:00:00', 25.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-27 00:00:00', 28.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-28 00:00:00', 30.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-29 00:00:00', 29.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-04-30 00:00:00', 24.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-01 00:00:00', 19.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-02 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-03 00:00:00', 17.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-04 00:00:00', 20.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-05 00:00:00', 21.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-06 00:00:00', 25.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-07 00:00:00', 29.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-08 00:00:00', 30.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-09 00:00:00', 31.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-10 00:00:00', 23.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-11 00:00:00', 24.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-12 00:00:00', 24.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-13 00:00:00', 26.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-14 00:00:00', 23.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-15 00:00:00', 27.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-16 00:00:00', 29.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-17 00:00:00', 30.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-18 00:00:00', 30.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-19 00:00:00', 31.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-20 00:00:00', 31.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-21 00:00:00', 32.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-22 00:00:00', 32.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-23 00:00:00', 31.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-24 00:00:00', 32.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-25 00:00:00', 31.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-26 00:00:00', 25.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-27 00:00:00', 22.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-28 00:00:00', 26.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-29 00:00:00', 29.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-30 00:00:00', 33.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-05-31 00:00:00', 34.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-01 00:00:00', 33.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-02 00:00:00', 36.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-03 00:00:00', 34.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-04 00:00:00', 34.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-05 00:00:00', 36.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-06 00:00:00', 36.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-07 00:00:00', 30.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-08 00:00:00', 30.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-09 00:00:00', 32.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-10 00:00:00', 33.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-11 00:00:00', 31.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-12 00:00:00', 28.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-13 00:00:00', 33.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-14 00:00:00', 34.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-15 00:00:00', 34.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-16 00:00:00', 36.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-17 00:00:00', 37.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-18 00:00:00', 37.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-19 00:00:00', 37.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-20 00:00:00', 36.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-21 00:00:00', 35.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-22 00:00:00', 34.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-23 00:00:00', 36.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-24 00:00:00', 37.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-25 00:00:00', 39.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-26 00:00:00', 34.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-27 00:00:00', 36.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-28 00:00:00', 36.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-29 00:00:00', 35.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-06-30 00:00:00', 36.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-01 00:00:00', 38.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-02 00:00:00', 40.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-03 00:00:00', 43.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-04 00:00:00', 40.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-05 00:00:00', 36.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-06 00:00:00', 37.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-07 00:00:00', 38.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-08 00:00:00', 39.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-09 00:00:00', 37.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-10 00:00:00', 39.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-11 00:00:00', 39.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-12 00:00:00', 39.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-13 00:00:00', 36.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-14 00:00:00', 38.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-15 00:00:00', 38.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-16 00:00:00', 39.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-17 00:00:00', 39.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-18 00:00:00', 42.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-19 00:00:00', 43.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-20 00:00:00', 44.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-21 00:00:00', 44.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-22 00:00:00', 42.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-23 00:00:00', 38.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-24 00:00:00', 36.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-25 00:00:00', 37.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-26 00:00:00', 38.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-27 00:00:00', 38.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-28 00:00:00', 39.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-29 00:00:00', 38.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-30 00:00:00', 38.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-07-31 00:00:00', 40.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-01 00:00:00', 42.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-02 00:00:00', 40.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-03 00:00:00', 37.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-04 00:00:00', 35.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-05 00:00:00', 33.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-06 00:00:00', 34.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-07 00:00:00', 34.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-08 00:00:00', 35.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-09 00:00:00', 35.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-10 00:00:00', 36.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-11 00:00:00', 36.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-12 00:00:00', 36.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-13 00:00:00', 36.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-14 00:00:00', 38.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-15 00:00:00', 40.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-16 00:00:00', 40.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-17 00:00:00', 40.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-18 00:00:00', 39.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-19 00:00:00', 38.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-20 00:00:00', 36.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-21 00:00:00', 34.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-22 00:00:00', 35.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-23 00:00:00', 36.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-24 00:00:00', 35.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-25 00:00:00', 36.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-26 00:00:00', 35.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-27 00:00:00', 36.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-28 00:00:00', 37.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-29 00:00:00', 36.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-30 00:00:00', 35.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-08-31 00:00:00', 35.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-01 00:00:00', 35.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-02 00:00:00', 36.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-03 00:00:00', 36.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-04 00:00:00', 35.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-05 00:00:00', 34.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-06 00:00:00', 35.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-07 00:00:00', 36.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-08 00:00:00', 36.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-09 00:00:00', 38.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-10 00:00:00', 37.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-11 00:00:00', 37.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-12 00:00:00', 35.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-13 00:00:00', 33.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-14 00:00:00', 34.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-15 00:00:00', 32.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-16 00:00:00', 28.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-17 00:00:00', 30.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-18 00:00:00', 33.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-19 00:00:00', 35.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-20 00:00:00', 36.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-21 00:00:00', 33.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-22 00:00:00', 31.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-23 00:00:00', 27.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-24 00:00:00', 24.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-25 00:00:00', 26.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-26 00:00:00', 24.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-27 00:00:00', 23.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-28 00:00:00', 23.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-29 00:00:00', 24.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-09-30 00:00:00', 25.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-01 00:00:00', 27.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-02 00:00:00', 27.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-03 00:00:00', 30.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-04 00:00:00', 32.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-05 00:00:00', 32.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-06 00:00:00', 26.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-07 00:00:00', 23.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-08 00:00:00', 20.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-09 00:00:00', 22.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-10 00:00:00', 23.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-11 00:00:00', 24.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-12 00:00:00', 23.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-13 00:00:00', 24.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-14 00:00:00', 24.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-15 00:00:00', 23.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-16 00:00:00', 22.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-17 00:00:00', 25.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-18 00:00:00', 26.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-19 00:00:00', 26.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-20 00:00:00', 27.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-21 00:00:00', 25.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-22 00:00:00', 25.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-23 00:00:00', 26.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-24 00:00:00', 25.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-25 00:00:00', 26.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-26 00:00:00', 28.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-27 00:00:00', 28.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-28 00:00:00', 29.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-29 00:00:00', 30.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-30 00:00:00', 29.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-10-31 00:00:00', 29.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-01 00:00:00', 28.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-02 00:00:00', 26.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-03 00:00:00', 28.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-04 00:00:00', 19.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-05 00:00:00', 13.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-06 00:00:00', 13.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-07 00:00:00', 10.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-08 00:00:00', 10.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-09 00:00:00', 16.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-10 00:00:00', 19.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-11 00:00:00', 22.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-12 00:00:00', 19.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-13 00:00:00', 14.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-14 00:00:00', 16.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-15 00:00:00', 14.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-16 00:00:00', 8.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-17 00:00:00', 6.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-18 00:00:00', 7.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-19 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-20 00:00:00', 13.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-21 00:00:00', 15.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-22 00:00:00', 15.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-23 00:00:00', 7.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-24 00:00:00', 9.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-25 00:00:00', 13.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-26 00:00:00', 12.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-27 00:00:00', 12.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-28 00:00:00', 14.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-29 00:00:00', 14.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-11-30 00:00:00', 12.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-01 00:00:00', 13.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-02 00:00:00', 11.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-03 00:00:00', 12.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-04 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-05 00:00:00', 10.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-06 00:00:00', 14.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-07 00:00:00', 13.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-08 00:00:00', 12.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-09 00:00:00', 12.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-10 00:00:00', 13.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-11 00:00:00', 11.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-12 00:00:00', 2.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-13 00:00:00', -3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-14 00:00:00', -0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-15 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-16 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-17 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-18 00:00:00', 9.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-19 00:00:00', 12.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-20 00:00:00', 12.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-21 00:00:00', 13.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-22 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-23 00:00:00', 1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-24 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-25 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-26 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-27 00:00:00', 5.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-28 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-29 00:00:00', 6.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-30 00:00:00', 4.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2003-12-31 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-01 00:00:00', 0.744000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-02 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-03 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-04 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-05 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-06 00:00:00', 6.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-07 00:00:00', 6.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-08 00:00:00', 6.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-09 00:00:00', 12.2130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-10 00:00:00', 11.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-11 00:00:00', 10.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-12 00:00:00', 7.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-13 00:00:00', 9.05300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-14 00:00:00', 13.4420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-15 00:00:00', 13.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-16 00:00:00', 8.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-17 00:00:00', 9.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-18 00:00:00', 11.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-19 00:00:00', 11.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-20 00:00:00', 8.97000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-21 00:00:00', 7.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-22 00:00:00', 7.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-23 00:00:00', 9.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-24 00:00:00', 11.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-25 00:00:00', 11.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-26 00:00:00', 11.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-27 00:00:00', 12.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-28 00:00:00', 6.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-29 00:00:00', 5.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-30 00:00:00', 4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-01-31 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-01 00:00:00', 6.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-02 00:00:00', 8.77000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-03 00:00:00', 11.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-04 00:00:00', 8.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-05 00:00:00', 10.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-06 00:00:00', 11.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-07 00:00:00', 8.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-08 00:00:00', 10.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-09 00:00:00', 8.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-10 00:00:00', 13.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-11 00:00:00', 17.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-12 00:00:00', 19.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-13 00:00:00', 15.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-14 00:00:00', 17.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-15 00:00:00', 19.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-16 00:00:00', 21.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-17 00:00:00', 11.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-18 00:00:00', 13.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-19 00:00:00', 12.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-20 00:00:00', 15.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-21 00:00:00', 11.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-22 00:00:00', 16.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-23 00:00:00', 17.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-24 00:00:00', 18.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-25 00:00:00', 15.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-26 00:00:00', 12.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-27 00:00:00', 14.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-28 00:00:00', 16.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-02-29 00:00:00', 16.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-01 00:00:00', 13.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-02 00:00:00', 17.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-03 00:00:00', 16.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-04 00:00:00', 17.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-05 00:00:00', 19.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-06 00:00:00', 24.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-07 00:00:00', 28.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-08 00:00:00', 24.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-09 00:00:00', 16.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-10 00:00:00', 17.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-11 00:00:00', 20.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-12 00:00:00', 23.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-13 00:00:00', 23.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-14 00:00:00', 17.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-15 00:00:00', 21.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-16 00:00:00', 23.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-17 00:00:00', 9.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-18 00:00:00', 15.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-19 00:00:00', 18.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-20 00:00:00', 18.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-21 00:00:00', 10.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-22 00:00:00', 13.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-23 00:00:00', 15.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-24 00:00:00', 17.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-25 00:00:00', 19.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-26 00:00:00', 22.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-27 00:00:00', 23.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-28 00:00:00', 24.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-29 00:00:00', 26.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-30 00:00:00', 27.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-03-31 00:00:00', 28.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-01 00:00:00', 25.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-02 00:00:00', 26.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-03 00:00:00', 22.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-04 00:00:00', 28.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-05 00:00:00', 31.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-06 00:00:00', 19.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-07 00:00:00', 17.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-08 00:00:00', 20.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-09 00:00:00', 19.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-10 00:00:00', 21.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-11 00:00:00', 23.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-12 00:00:00', 23.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-13 00:00:00', 24.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-14 00:00:00', 26.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-15 00:00:00', 29.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-16 00:00:00', 25.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-17 00:00:00', 27.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-18 00:00:00', 27.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-19 00:00:00', 22.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-20 00:00:00', 28.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-21 00:00:00', 30.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-22 00:00:00', 20.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-23 00:00:00', 25.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-24 00:00:00', 31.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-25 00:00:00', 32.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-26 00:00:00', 29.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-27 00:00:00', 26.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-28 00:00:00', 25.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-29 00:00:00', 17.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-04-30 00:00:00', 20.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-01 00:00:00', 24.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-02 00:00:00', 26.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-03 00:00:00', 29.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-04 00:00:00', 30.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-05 00:00:00', 33.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-06 00:00:00', 33.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-07 00:00:00', 18.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-08 00:00:00', 27.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-09 00:00:00', 29.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-10 00:00:00', 32.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-11 00:00:00', 33.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-12 00:00:00', 34.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-13 00:00:00', 36.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-14 00:00:00', 38.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-15 00:00:00', 39.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-16 00:00:00', 36.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-17 00:00:00', 37.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-18 00:00:00', 38.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-19 00:00:00', 33.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-20 00:00:00', 30.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-21 00:00:00', 33.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-22 00:00:00', 26.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-23 00:00:00', 27.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-24 00:00:00', 30.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-25 00:00:00', 33.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-26 00:00:00', 32.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-27 00:00:00', 30.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-28 00:00:00', 31.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-29 00:00:00', 33.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-30 00:00:00', 32.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-05-31 00:00:00', 32.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-01 00:00:00', 33.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-02 00:00:00', 33.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-03 00:00:00', 36.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-04 00:00:00', 37.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-05 00:00:00', 38.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-06 00:00:00', 36.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-07 00:00:00', 32.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-08 00:00:00', 33.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-09 00:00:00', 34.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-10 00:00:00', 37.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-11 00:00:00', 38.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-12 00:00:00', 39.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-13 00:00:00', 38.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-14 00:00:00', 32.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-15 00:00:00', 36.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-16 00:00:00', 38.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-17 00:00:00', 38.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-18 00:00:00', 39.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-19 00:00:00', 39.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-20 00:00:00', 39.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-21 00:00:00', 39.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-22 00:00:00', 39.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-23 00:00:00', 39.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-24 00:00:00', 37.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-25 00:00:00', 36.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-26 00:00:00', 36.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-27 00:00:00', 35.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-28 00:00:00', 37.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-29 00:00:00', 38.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-06-30 00:00:00', 40.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-01 00:00:00', 39.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-02 00:00:00', 39.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-03 00:00:00', 40.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-04 00:00:00', 40.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-05 00:00:00', 37.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-06 00:00:00', 34.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-07 00:00:00', 36.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-08 00:00:00', 35.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-09 00:00:00', 35.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-10 00:00:00', 37.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-11 00:00:00', 39.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-12 00:00:00', 36.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-13 00:00:00', 35.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-14 00:00:00', 35.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-15 00:00:00', 34.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-16 00:00:00', 33.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-17 00:00:00', 33.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-18 00:00:00', 31.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-19 00:00:00', 28.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-20 00:00:00', 32.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-21 00:00:00', 34.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-22 00:00:00', 34.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-23 00:00:00', 37.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-24 00:00:00', 39.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-25 00:00:00', 40.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-26 00:00:00', 40.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-27 00:00:00', 40.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-28 00:00:00', 40.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-29 00:00:00', 41.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-30 00:00:00', 38.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-07-31 00:00:00', 37.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-01 00:00:00', 34.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-02 00:00:00', 33.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-03 00:00:00', 35.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-04 00:00:00', 37.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-05 00:00:00', 40.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-06 00:00:00', 40.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-07 00:00:00', 34.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-08 00:00:00', 34.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-09 00:00:00', 34.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-10 00:00:00', 35.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-11 00:00:00', 35.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-12 00:00:00', 37.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-13 00:00:00', 40.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-14 00:00:00', 41.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-15 00:00:00', 40.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-16 00:00:00', 40.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-17 00:00:00', 37.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-18 00:00:00', 37.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-19 00:00:00', 36.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-20 00:00:00', 36.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-21 00:00:00', 36.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-22 00:00:00', 37.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-23 00:00:00', 39.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-24 00:00:00', 38.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-25 00:00:00', 36.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-26 00:00:00', 35.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-27 00:00:00', 35.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-28 00:00:00', 35.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-29 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-30 00:00:00', 34.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-08-31 00:00:00', 33.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-01 00:00:00', 32.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-02 00:00:00', 32.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-03 00:00:00', 33.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-04 00:00:00', 32.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-05 00:00:00', 34.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-06 00:00:00', 36.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-07 00:00:00', 38.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-08 00:00:00', 36.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-09 00:00:00', 36.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-10 00:00:00', 35.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-11 00:00:00', 37.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-12 00:00:00', 35.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-13 00:00:00', 35.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-14 00:00:00', 32.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-15 00:00:00', 28.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-16 00:00:00', 29.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-17 00:00:00', 29.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-18 00:00:00', 31.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-19 00:00:00', 31.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-20 00:00:00', 30.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-21 00:00:00', 28.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-22 00:00:00', 26.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-23 00:00:00', 29.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-24 00:00:00', 30.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-25 00:00:00', 30.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-26 00:00:00', 30.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-27 00:00:00', 30.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-28 00:00:00', 29.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-29 00:00:00', 29.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-09-30 00:00:00', 30.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-01 00:00:00', 28.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-02 00:00:00', 26.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-03 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-04 00:00:00', 30.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-05 00:00:00', 29.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-06 00:00:00', 26.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-07 00:00:00', 19.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-08 00:00:00', 16.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-09 00:00:00', 16.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-10 00:00:00', 16.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-11 00:00:00', 22.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-12 00:00:00', 24.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-13 00:00:00', 24.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-14 00:00:00', 25.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-15 00:00:00', 18.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-16 00:00:00', 18.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-17 00:00:00', 20.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-18 00:00:00', 19.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-19 00:00:00', 19.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-20 00:00:00', 20.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-21 00:00:00', 23.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-22 00:00:00', 26.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-23 00:00:00', 27.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-24 00:00:00', 20.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-25 00:00:00', 18.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-26 00:00:00', 21.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-27 00:00:00', 16.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-28 00:00:00', 17.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-29 00:00:00', 21.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-30 00:00:00', 22.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-10-31 00:00:00', 21.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-01 00:00:00', 20.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-02 00:00:00', 20.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-03 00:00:00', 22.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-04 00:00:00', 24.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-05 00:00:00', 22.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-06 00:00:00', 22.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-07 00:00:00', 21.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-08 00:00:00', 21.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-09 00:00:00', 19.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-10 00:00:00', 17.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-11 00:00:00', 17.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-12 00:00:00', 16.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-13 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-14 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-15 00:00:00', 19.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-16 00:00:00', 17.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-17 00:00:00', 20.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-18 00:00:00', 21.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-19 00:00:00', 15.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-20 00:00:00', 16.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-21 00:00:00', 15.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-22 00:00:00', 15.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-23 00:00:00', 18.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-24 00:00:00', 20.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-25 00:00:00', 15.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-26 00:00:00', 16.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-27 00:00:00', 19.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-28 00:00:00', 20.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-29 00:00:00', 11.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-11-30 00:00:00', 9.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-01 00:00:00', 10.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-02 00:00:00', 14.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-03 00:00:00', 8.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-04 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-05 00:00:00', 10.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-06 00:00:00', 10.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-07 00:00:00', 9.75300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-08 00:00:00', 11.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-09 00:00:00', 15.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-10 00:00:00', 16.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-11 00:00:00', 15.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-12 00:00:00', 15.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-13 00:00:00', 16.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-14 00:00:00', 12.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-15 00:00:00', 13.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-16 00:00:00', 13.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-17 00:00:00', 17.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-18 00:00:00', 10.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-19 00:00:00', 2.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-20 00:00:00', 6.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-21 00:00:00', 6.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-22 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-23 00:00:00', 2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-24 00:00:00', 5.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-25 00:00:00', 6.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-26 00:00:00', 8.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-27 00:00:00', 8.21300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-28 00:00:00', 3.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-29 00:00:00', -0.0949999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-30 00:00:00', 0.716000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2004-12-31 00:00:00', 6.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-01 00:00:00', 5.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-02 00:00:00', 6.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-03 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-04 00:00:00', 10.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-05 00:00:00', 6.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-06 00:00:00', 10.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-07 00:00:00', 8.18700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-08 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-09 00:00:00', 6.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-10 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-11 00:00:00', 11.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-12 00:00:00', 5.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-13 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-14 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-15 00:00:00', 6.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-16 00:00:00', 7.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-17 00:00:00', 4.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-18 00:00:00', 5.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-19 00:00:00', 7.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-20 00:00:00', 10.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-21 00:00:00', 6.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-22 00:00:00', 5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-23 00:00:00', 7.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-24 00:00:00', 6.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-25 00:00:00', 10.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-26 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-27 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-28 00:00:00', 1.12999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-29 00:00:00', 3.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-30 00:00:00', 3.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-01-31 00:00:00', 5.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-01 00:00:00', 7.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-02 00:00:00', 7.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-03 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-04 00:00:00', 3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-05 00:00:00', 6.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-06 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-07 00:00:00', 3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-08 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-09 00:00:00', 9.41199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-10 00:00:00', 6.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-11 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-12 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-13 00:00:00', 0.773999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-14 00:00:00', 1.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-15 00:00:00', 0.75700002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-16 00:00:00', 0.159999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-17 00:00:00', 0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-18 00:00:00', -0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-19 00:00:00', 0.365000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-20 00:00:00', 7.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-21 00:00:00', 10.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-22 00:00:00', 11.5159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-23 00:00:00', 5.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-24 00:00:00', 5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-25 00:00:00', 8.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-26 00:00:00', 12.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-27 00:00:00', 14.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-02-28 00:00:00', 14.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-01 00:00:00', 17.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-02 00:00:00', 19.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-03 00:00:00', 19.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-04 00:00:00', 19.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-05 00:00:00', 21.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-06 00:00:00', 22.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-07 00:00:00', 19.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-08 00:00:00', 19.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-09 00:00:00', 17.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-10 00:00:00', 19.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-11 00:00:00', 22.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-12 00:00:00', 26.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-13 00:00:00', 24.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-14 00:00:00', 16.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-15 00:00:00', 18.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-16 00:00:00', 13.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-17 00:00:00', 13.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-18 00:00:00', 16.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-19 00:00:00', 13.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-20 00:00:00', 17.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-21 00:00:00', 17.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-22 00:00:00', 19.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-23 00:00:00', 19.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-24 00:00:00', 21.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-25 00:00:00', 15.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-26 00:00:00', 17.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-27 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-28 00:00:00', 14.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-29 00:00:00', 17.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-30 00:00:00', 19.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-03-31 00:00:00', 22.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-01 00:00:00', 24.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-02 00:00:00', 25.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-03 00:00:00', 26.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-04 00:00:00', 24.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-05 00:00:00', 15.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-06 00:00:00', 12.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-07 00:00:00', 10.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-08 00:00:00', 11.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-09 00:00:00', 13.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-10 00:00:00', 15.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-11 00:00:00', 18.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-12 00:00:00', 18.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-13 00:00:00', 19.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-14 00:00:00', 20.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-15 00:00:00', 23.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-16 00:00:00', 25.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-17 00:00:00', 28.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-18 00:00:00', 30.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-19 00:00:00', 30.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-20 00:00:00', 29.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-21 00:00:00', 31.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-22 00:00:00', 30.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-23 00:00:00', 30.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-24 00:00:00', 27.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-25 00:00:00', 25.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-26 00:00:00', 25.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-27 00:00:00', 27.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-28 00:00:00', 29.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-29 00:00:00', 29.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-04-30 00:00:00', 31.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-01 00:00:00', 31.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-02 00:00:00', 31.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-03 00:00:00', 30.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-04 00:00:00', 30.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-05 00:00:00', 31.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-06 00:00:00', 30.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-07 00:00:00', 27.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-08 00:00:00', 17.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-09 00:00:00', 22.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-10 00:00:00', 28.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-11 00:00:00', 28.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-12 00:00:00', 27.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-13 00:00:00', 24.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-14 00:00:00', 24.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-15 00:00:00', 27.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-16 00:00:00', 27.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-17 00:00:00', 29.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-18 00:00:00', 28.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-19 00:00:00', 24.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-20 00:00:00', 21.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-21 00:00:00', 26.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-22 00:00:00', 27.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-23 00:00:00', 29.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-24 00:00:00', 25.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-25 00:00:00', 25.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-26 00:00:00', 27.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-27 00:00:00', 28.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-28 00:00:00', 30.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-29 00:00:00', 31.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-30 00:00:00', 32.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-05-31 00:00:00', 32.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-01 00:00:00', 33.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-02 00:00:00', 34.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-03 00:00:00', 36.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-04 00:00:00', 35.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-05 00:00:00', 34.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-06 00:00:00', 34.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-07 00:00:00', 34.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-08 00:00:00', 35.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-09 00:00:00', 30.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-10 00:00:00', 25.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-11 00:00:00', 27.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-12 00:00:00', 30.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-13 00:00:00', 32.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-14 00:00:00', 34.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-15 00:00:00', 37.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-16 00:00:00', 38.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-17 00:00:00', 38.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-18 00:00:00', 39.4760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-19 00:00:00', 38.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-20 00:00:00', 39.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-21 00:00:00', 40.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-22 00:00:00', 43.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-23 00:00:00', 44.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-24 00:00:00', 40.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-25 00:00:00', 36.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-26 00:00:00', 36.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-27 00:00:00', 39.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-28 00:00:00', 37.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-29 00:00:00', 36.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-06-30 00:00:00', 37.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-01 00:00:00', 38.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-02 00:00:00', 37.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-03 00:00:00', 38.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-04 00:00:00', 38.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-05 00:00:00', 37.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-06 00:00:00', 40.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-07 00:00:00', 40.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-08 00:00:00', 42.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-09 00:00:00', 43.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-10 00:00:00', 40.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-11 00:00:00', 39.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-12 00:00:00', 39.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-13 00:00:00', 39.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-14 00:00:00', 38.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-15 00:00:00', 37.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-16 00:00:00', 34.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-17 00:00:00', 35.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-18 00:00:00', 37.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-19 00:00:00', 37.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-20 00:00:00', 38.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-21 00:00:00', 39.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-22 00:00:00', 38.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-23 00:00:00', 37.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-24 00:00:00', 38.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-25 00:00:00', 38.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-26 00:00:00', 37.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-27 00:00:00', 38.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-28 00:00:00', 37.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-29 00:00:00', 37.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-30 00:00:00', 37.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-07-31 00:00:00', 38.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-01 00:00:00', 35.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-02 00:00:00', 35.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-03 00:00:00', 35.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-04 00:00:00', 36.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-05 00:00:00', 37.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-06 00:00:00', 38.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-07 00:00:00', 37.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-08 00:00:00', 37.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-09 00:00:00', 38.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-10 00:00:00', 37.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-11 00:00:00', 36.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-12 00:00:00', 34.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-13 00:00:00', 35.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-14 00:00:00', 36.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-15 00:00:00', 36.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-16 00:00:00', 36.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-17 00:00:00', 35.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-18 00:00:00', 34.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-19 00:00:00', 36.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-20 00:00:00', 36.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-21 00:00:00', 36.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-22 00:00:00', 37.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-23 00:00:00', 36.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-24 00:00:00', 34.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-25 00:00:00', 33.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-26 00:00:00', 32.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-27 00:00:00', 28.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-28 00:00:00', 28.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-29 00:00:00', 30.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-30 00:00:00', 29.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-08-31 00:00:00', 32.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-01 00:00:00', 33.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-02 00:00:00', 35.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-03 00:00:00', 36.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-04 00:00:00', 37.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-05 00:00:00', 39.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-06 00:00:00', 39.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-07 00:00:00', 37.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-08 00:00:00', 34.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-09 00:00:00', 32.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-10 00:00:00', 30.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-11 00:00:00', 32.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-12 00:00:00', 32.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-13 00:00:00', 34.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-14 00:00:00', 33.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-15 00:00:00', 35.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-16 00:00:00', 36.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-17 00:00:00', 34.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-18 00:00:00', 32.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-19 00:00:00', 31.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-20 00:00:00', 32.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-21 00:00:00', 32.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-22 00:00:00', 32.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-23 00:00:00', 30.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-24 00:00:00', 30.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-25 00:00:00', 30.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-26 00:00:00', 29.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-27 00:00:00', 28.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-28 00:00:00', 28.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-29 00:00:00', 29.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-09-30 00:00:00', 30.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-01 00:00:00', 34.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-02 00:00:00', 32.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-03 00:00:00', 27.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-04 00:00:00', 27.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-05 00:00:00', 28.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-06 00:00:00', 32.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-07 00:00:00', 32.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-08 00:00:00', 30.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-09 00:00:00', 29.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-10 00:00:00', 28.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-11 00:00:00', 24.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-12 00:00:00', 22.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-13 00:00:00', 21.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-14 00:00:00', 19.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-15 00:00:00', 19.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-16 00:00:00', 19.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-17 00:00:00', 22.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-18 00:00:00', 24.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-19 00:00:00', 26.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-20 00:00:00', 27.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-21 00:00:00', 28.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-22 00:00:00', 27.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-23 00:00:00', 21.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-24 00:00:00', 13.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-25 00:00:00', 17.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-26 00:00:00', 21.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-27 00:00:00', 19.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-28 00:00:00', 23.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-29 00:00:00', 25.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-30 00:00:00', 24.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-10-31 00:00:00', 20.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-01 00:00:00', 18.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-02 00:00:00', 18.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-03 00:00:00', 20.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-04 00:00:00', 20.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-05 00:00:00', 20.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-06 00:00:00', 21.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-07 00:00:00', 16.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-08 00:00:00', 18.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-09 00:00:00', 22.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-10 00:00:00', 15.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-11 00:00:00', 10.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-12 00:00:00', 14.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-13 00:00:00', 15.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-14 00:00:00', 10.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-15 00:00:00', 12.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-16 00:00:00', 11.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-17 00:00:00', 15.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-18 00:00:00', 18.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-19 00:00:00', 20.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-20 00:00:00', 22.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-21 00:00:00', 16.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-22 00:00:00', 18.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-23 00:00:00', 17.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-24 00:00:00', 14.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-25 00:00:00', 10.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-26 00:00:00', 9.58800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-27 00:00:00', 8.49199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-28 00:00:00', 9.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-29 00:00:00', 10.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-11-30 00:00:00', 10.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-01 00:00:00', 13.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-02 00:00:00', 13.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-03 00:00:00', 12.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-04 00:00:00', 13.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-05 00:00:00', 9.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-06 00:00:00', 13.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-07 00:00:00', 14.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-08 00:00:00', 9.34099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-09 00:00:00', 9.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-10 00:00:00', 10.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-11 00:00:00', 11.2489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-12 00:00:00', 8.96599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-13 00:00:00', 11.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-14 00:00:00', 9.81999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-15 00:00:00', 12.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-16 00:00:00', 14.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-17 00:00:00', 16.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-18 00:00:00', 17.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-19 00:00:00', 12.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-20 00:00:00', 13.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-21 00:00:00', 13.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-22 00:00:00', 12.7559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-23 00:00:00', 13.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-24 00:00:00', 15.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-25 00:00:00', 14.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-26 00:00:00', 16.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-27 00:00:00', 11.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-28 00:00:00', 6.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-29 00:00:00', 4.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-30 00:00:00', 4.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2005-12-31 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-01 00:00:00', -1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-02 00:00:00', -2.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-03 00:00:00', -3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-04 00:00:00', -3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-05 00:00:00', -2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-06 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-07 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-08 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-09 00:00:00', 8.78600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-10 00:00:00', 4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-11 00:00:00', 5.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-12 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-13 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-14 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-15 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-16 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-17 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-18 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-19 00:00:00', 4.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-20 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-21 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-22 00:00:00', 6.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-23 00:00:00', 4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-24 00:00:00', 5.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-25 00:00:00', 6.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-26 00:00:00', 6.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-27 00:00:00', 7.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-28 00:00:00', 5.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-29 00:00:00', 3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-30 00:00:00', 5.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-01-31 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-01 00:00:00', 6.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-02 00:00:00', 8.87399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-03 00:00:00', 11.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-04 00:00:00', 18.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-05 00:00:00', 17.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-06 00:00:00', 14.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-07 00:00:00', 17.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-08 00:00:00', 18.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-09 00:00:00', 19.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-10 00:00:00', 15.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-11 00:00:00', 14.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-12 00:00:00', 17.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-13 00:00:00', 16.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-14 00:00:00', 18.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-15 00:00:00', 15.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-16 00:00:00', 16.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-17 00:00:00', 13.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-18 00:00:00', 15.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-19 00:00:00', 9.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-20 00:00:00', 13.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-21 00:00:00', 13.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-22 00:00:00', 13.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-23 00:00:00', 8.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-24 00:00:00', 6.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-25 00:00:00', 5.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-26 00:00:00', 13.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-27 00:00:00', 15.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-02-28 00:00:00', 18.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-01 00:00:00', 17.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-02 00:00:00', 17.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-03 00:00:00', 19.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-04 00:00:00', 16.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-05 00:00:00', 18.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-06 00:00:00', 14.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-07 00:00:00', 15.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-08 00:00:00', 18.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-09 00:00:00', 21.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-10 00:00:00', 23.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-11 00:00:00', 23.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-12 00:00:00', 21.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-13 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-14 00:00:00', 11.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-15 00:00:00', 11.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-16 00:00:00', 14.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-17 00:00:00', 18.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-18 00:00:00', 18.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-19 00:00:00', 18.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-20 00:00:00', 21.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-21 00:00:00', 20.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-22 00:00:00', 15.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-23 00:00:00', 19.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-24 00:00:00', 20.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-25 00:00:00', 21.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-26 00:00:00', 13.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-27 00:00:00', 18.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-28 00:00:00', 23.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-29 00:00:00', 24.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-30 00:00:00', 23.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-03-31 00:00:00', 17.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-01 00:00:00', 14.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-02 00:00:00', 20.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-03 00:00:00', 22.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-04 00:00:00', 26.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-05 00:00:00', 26.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-06 00:00:00', 25.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-07 00:00:00', 27.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-08 00:00:00', 26.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-09 00:00:00', 13.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-10 00:00:00', 13.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-11 00:00:00', 17.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-12 00:00:00', 18.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-13 00:00:00', 21.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-14 00:00:00', 21.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-15 00:00:00', 21.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-16 00:00:00', 23.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-17 00:00:00', 24.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-18 00:00:00', 25.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-19 00:00:00', 28.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-20 00:00:00', 27.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-21 00:00:00', 23.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-22 00:00:00', 26.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-23 00:00:00', 28.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-24 00:00:00', 31.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-25 00:00:00', 33.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-26 00:00:00', 34.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-27 00:00:00', 35.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-28 00:00:00', 33.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-29 00:00:00', 30.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-04-30 00:00:00', 28.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-01 00:00:00', 28.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-02 00:00:00', 30.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-03 00:00:00', 30.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-04 00:00:00', 31.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-05 00:00:00', 31.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-06 00:00:00', 32.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-07 00:00:00', 29.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-08 00:00:00', 32.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-09 00:00:00', 33.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-10 00:00:00', 34.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-11 00:00:00', 35.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-12 00:00:00', 36.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-13 00:00:00', 36.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-14 00:00:00', 37.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-15 00:00:00', 39.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-16 00:00:00', 40.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-17 00:00:00', 36.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-18 00:00:00', 34.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-19 00:00:00', 35.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-20 00:00:00', 37.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-21 00:00:00', 34.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-22 00:00:00', 35.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-23 00:00:00', 35.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-24 00:00:00', 35.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-25 00:00:00', 34.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-26 00:00:00', 34.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-27 00:00:00', 34.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-28 00:00:00', 34.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-29 00:00:00', 33.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-30 00:00:00', 35.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-05-31 00:00:00', 31.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-01 00:00:00', 31.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-02 00:00:00', 34.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-03 00:00:00', 33.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-04 00:00:00', 33.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-05 00:00:00', 34.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-06 00:00:00', 33.9410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-07 00:00:00', 32.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-08 00:00:00', 32.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-09 00:00:00', 32.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-10 00:00:00', 33.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-11 00:00:00', 32.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-12 00:00:00', 34.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-13 00:00:00', 36.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-14 00:00:00', 37.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-15 00:00:00', 36.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-16 00:00:00', 36.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-17 00:00:00', 37.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-18 00:00:00', 38.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-19 00:00:00', 39.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-20 00:00:00', 39.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-21 00:00:00', 40.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-22 00:00:00', 39.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-23 00:00:00', 39.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-24 00:00:00', 39.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-25 00:00:00', 39.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-26 00:00:00', 40.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-27 00:00:00', 39.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-28 00:00:00', 39.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-29 00:00:00', 37.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-06-30 00:00:00', 38.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-01 00:00:00', 35.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-02 00:00:00', 35.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-03 00:00:00', 37.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-04 00:00:00', 38.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-05 00:00:00', 39.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-06 00:00:00', 41.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-07 00:00:00', 39.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-08 00:00:00', 39.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-09 00:00:00', 41.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-10 00:00:00', 40.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-11 00:00:00', 38.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-12 00:00:00', 33.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-13 00:00:00', 30.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-14 00:00:00', 31.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-15 00:00:00', 32.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-16 00:00:00', 35.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-17 00:00:00', 36.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-18 00:00:00', 36.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-19 00:00:00', 37.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-20 00:00:00', 38.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-21 00:00:00', 40.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-22 00:00:00', 41.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-23 00:00:00', 42.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-24 00:00:00', 41.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-25 00:00:00', 41.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-26 00:00:00', 39.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-27 00:00:00', 39.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-28 00:00:00', 37.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-29 00:00:00', 39.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-30 00:00:00', 43.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-07-31 00:00:00', 42.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-01 00:00:00', 41.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-02 00:00:00', 41.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-03 00:00:00', 40.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-04 00:00:00', 39.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-05 00:00:00', 39.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-06 00:00:00', 38.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-07 00:00:00', 39.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-08 00:00:00', 39.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-09 00:00:00', 40.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-10 00:00:00', 40.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-11 00:00:00', 39.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-12 00:00:00', 39.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-13 00:00:00', 41.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-14 00:00:00', 40.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-15 00:00:00', 36.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-16 00:00:00', 35.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-17 00:00:00', 34.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-18 00:00:00', 36.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-19 00:00:00', 37.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-20 00:00:00', 36.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-21 00:00:00', 37.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-22 00:00:00', 37.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-23 00:00:00', 38.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-24 00:00:00', 38.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-25 00:00:00', 38.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-26 00:00:00', 37.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-27 00:00:00', 35.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-28 00:00:00', 35.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-29 00:00:00', 34.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-30 00:00:00', 36.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-08-31 00:00:00', 36.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-01 00:00:00', 34.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-02 00:00:00', 32.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-03 00:00:00', 31.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-04 00:00:00', 30.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-05 00:00:00', 31.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-06 00:00:00', 33.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-07 00:00:00', 35.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-08 00:00:00', 34.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-09 00:00:00', 34.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-10 00:00:00', 33.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-11 00:00:00', 32.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-12 00:00:00', 32.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-13 00:00:00', 32.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-14 00:00:00', 32.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-15 00:00:00', 31.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-16 00:00:00', 34.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-17 00:00:00', 35.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-18 00:00:00', 29.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-19 00:00:00', 24.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-20 00:00:00', 25.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-21 00:00:00', 27.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-22 00:00:00', 28.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-23 00:00:00', 29.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-24 00:00:00', 29.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-25 00:00:00', 27.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-26 00:00:00', 29.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-27 00:00:00', 31.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-28 00:00:00', 32.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-29 00:00:00', 27.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-09-30 00:00:00', 29.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-01 00:00:00', 30.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-02 00:00:00', 30.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-03 00:00:00', 30.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-04 00:00:00', 32.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-05 00:00:00', 30.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-06 00:00:00', 28.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-07 00:00:00', 29.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-08 00:00:00', 29.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-09 00:00:00', 31.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-10 00:00:00', 31.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-11 00:00:00', 31.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-12 00:00:00', 29.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-13 00:00:00', 28.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-14 00:00:00', 26.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-15 00:00:00', 26.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-16 00:00:00', 29.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-17 00:00:00', 29.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-18 00:00:00', 27.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-19 00:00:00', 26.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-20 00:00:00', 26.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-21 00:00:00', 22.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-22 00:00:00', 25.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-23 00:00:00', 27.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-24 00:00:00', 22.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-25 00:00:00', 17.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-26 00:00:00', 21.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-27 00:00:00', 23.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-28 00:00:00', 24.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-29 00:00:00', 24.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-30 00:00:00', 26.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-10-31 00:00:00', 27.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-01 00:00:00', 27.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-02 00:00:00', 25.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-03 00:00:00', 27.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-04 00:00:00', 28.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-05 00:00:00', 28.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-06 00:00:00', 27.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-07 00:00:00', 26.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-08 00:00:00', 26.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-09 00:00:00', 20.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-10 00:00:00', 14.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-11 00:00:00', 18.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-12 00:00:00', 19.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-13 00:00:00', 18.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-14 00:00:00', 18.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-15 00:00:00', 18.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-16 00:00:00', 12.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-17 00:00:00', 10.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-18 00:00:00', 17.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-19 00:00:00', 18.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-20 00:00:00', 14.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-21 00:00:00', 8.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-22 00:00:00', 4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-23 00:00:00', 6.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-24 00:00:00', 9.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-25 00:00:00', 7.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-26 00:00:00', 8.22799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-27 00:00:00', 8.03400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-28 00:00:00', 10.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-29 00:00:00', 10.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-11-30 00:00:00', 9.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-01 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-02 00:00:00', 7.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-03 00:00:00', 8.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-04 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-05 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-06 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-07 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-08 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-09 00:00:00', 6.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-10 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-11 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-12 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-13 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-14 00:00:00', 6.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-15 00:00:00', 5.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-16 00:00:00', 6.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-17 00:00:00', 9.77200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-18 00:00:00', 11.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-19 00:00:00', 10.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-20 00:00:00', 6.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-21 00:00:00', 13.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-22 00:00:00', 13.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-23 00:00:00', 12.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-24 00:00:00', 7.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-25 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-26 00:00:00', 9.52200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-27 00:00:00', 9.53600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-28 00:00:00', 11.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-29 00:00:00', 11.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-30 00:00:00', 5.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2006-12-31 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-01 00:00:00', -0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-02 00:00:00', -0.699000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-03 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-04 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-05 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-06 00:00:00', 7.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-07 00:00:00', 9.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-08 00:00:00', 9.67800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-09 00:00:00', 6.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-10 00:00:00', 7.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-11 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-12 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-13 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-14 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-15 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-16 00:00:00', 3.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-17 00:00:00', 7.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-18 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-19 00:00:00', 4.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-20 00:00:00', 8.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-21 00:00:00', 8.87600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-22 00:00:00', 11.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-23 00:00:00', 12.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-24 00:00:00', 6.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-25 00:00:00', 9.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-26 00:00:00', 12.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-27 00:00:00', 14.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-28 00:00:00', 16.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-29 00:00:00', 17.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-30 00:00:00', 18.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-01-31 00:00:00', 19.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-01 00:00:00', 18.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-02 00:00:00', 10.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-03 00:00:00', 15.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-04 00:00:00', 12.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-05 00:00:00', 12.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-06 00:00:00', 11.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-07 00:00:00', 14.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-08 00:00:00', 17.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-09 00:00:00', 11.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-10 00:00:00', 8.51500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-11 00:00:00', 6.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-12 00:00:00', 7.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-13 00:00:00', 9.50599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-14 00:00:00', 11.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-15 00:00:00', 12.9709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-16 00:00:00', 13.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-17 00:00:00', 12.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-18 00:00:00', 8.57900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-19 00:00:00', 6.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-20 00:00:00', 12.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-21 00:00:00', 7.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-22 00:00:00', 11.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-23 00:00:00', 14.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-24 00:00:00', 14.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-25 00:00:00', 14.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-26 00:00:00', 7.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-27 00:00:00', 2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-02-28 00:00:00', 5.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-01 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-02 00:00:00', 4.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-03 00:00:00', 9.45400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-04 00:00:00', 7.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-05 00:00:00', 13.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-06 00:00:00', 15.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-07 00:00:00', 18.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-08 00:00:00', 20.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-09 00:00:00', 7.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-10 00:00:00', 12.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-11 00:00:00', 8.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-12 00:00:00', 5.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-13 00:00:00', 11.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-14 00:00:00', 14.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-15 00:00:00', 17.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-16 00:00:00', 16.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-17 00:00:00', 16.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-18 00:00:00', 11.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-19 00:00:00', 10.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-20 00:00:00', 17.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-21 00:00:00', 17.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-22 00:00:00', 19.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-23 00:00:00', 20.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-24 00:00:00', 18.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-25 00:00:00', 21.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-26 00:00:00', 16.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-27 00:00:00', 24.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-28 00:00:00', 21.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-29 00:00:00', 17.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-30 00:00:00', 11.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-03-31 00:00:00', 7.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-01 00:00:00', 9.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-02 00:00:00', 16.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-03 00:00:00', 19.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-04 00:00:00', 20.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-05 00:00:00', 21.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-06 00:00:00', 21.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-07 00:00:00', 23.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-08 00:00:00', 25.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-09 00:00:00', 26.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-10 00:00:00', 30.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-11 00:00:00', 29.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-12 00:00:00', 32.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-13 00:00:00', 33.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-14 00:00:00', 28.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-15 00:00:00', 33.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-16 00:00:00', 31.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-17 00:00:00', 28.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-18 00:00:00', 28.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-19 00:00:00', 29.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-20 00:00:00', 32.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-21 00:00:00', 32.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-22 00:00:00', 26.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-23 00:00:00', 28.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-24 00:00:00', 28.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-25 00:00:00', 30.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-26 00:00:00', 33.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-27 00:00:00', 29.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-28 00:00:00', 31.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-29 00:00:00', 32.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-04-30 00:00:00', 33.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-01 00:00:00', 34.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-02 00:00:00', 30.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-03 00:00:00', 32.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-04 00:00:00', 33.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-05 00:00:00', 33.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-06 00:00:00', 33.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-07 00:00:00', 23.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-08 00:00:00', 25.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-09 00:00:00', 29.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-10 00:00:00', 32.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-11 00:00:00', 33.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-12 00:00:00', 34.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-13 00:00:00', 34.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-14 00:00:00', 36.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-15 00:00:00', 37.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-16 00:00:00', 27.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-17 00:00:00', 22.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-18 00:00:00', 19.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-19 00:00:00', 22.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-20 00:00:00', 25.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-21 00:00:00', 28.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-22 00:00:00', 30.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-23 00:00:00', 30.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-24 00:00:00', 31.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-25 00:00:00', 31.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-26 00:00:00', 31.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-27 00:00:00', 33.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-28 00:00:00', 33.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-29 00:00:00', 34.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-30 00:00:00', 36.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-05-31 00:00:00', 34.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-01 00:00:00', 35.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-02 00:00:00', 35.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-03 00:00:00', 33.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-04 00:00:00', 33.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-05 00:00:00', 26.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-06 00:00:00', 32.3219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-07 00:00:00', 34.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-08 00:00:00', 35.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-09 00:00:00', 38.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-10 00:00:00', 39.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-11 00:00:00', 39.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-12 00:00:00', 39.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-13 00:00:00', 39.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-14 00:00:00', 38.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-15 00:00:00', 36.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-16 00:00:00', 34.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-17 00:00:00', 35.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-18 00:00:00', 36.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-19 00:00:00', 37.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-20 00:00:00', 39.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-21 00:00:00', 41.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-22 00:00:00', 42.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-23 00:00:00', 44.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-24 00:00:00', 41.4760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-25 00:00:00', 41.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-26 00:00:00', 41.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-27 00:00:00', 40.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-28 00:00:00', 39.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-29 00:00:00', 37.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-06-30 00:00:00', 39.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-01 00:00:00', 38.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-02 00:00:00', 37.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-03 00:00:00', 39.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-04 00:00:00', 39.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-05 00:00:00', 39.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-06 00:00:00', 39.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-07 00:00:00', 36.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-08 00:00:00', 37.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-09 00:00:00', 38.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-10 00:00:00', 40.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-11 00:00:00', 40.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-12 00:00:00', 40.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-13 00:00:00', 38.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-14 00:00:00', 37.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-15 00:00:00', 36.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-16 00:00:00', 37.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-17 00:00:00', 37.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-18 00:00:00', 39.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-19 00:00:00', 41.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-20 00:00:00', 40.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-21 00:00:00', 29.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-22 00:00:00', 35.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-23 00:00:00', 38.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-24 00:00:00', 39.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-25 00:00:00', 39.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-26 00:00:00', 37.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-27 00:00:00', 35.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-28 00:00:00', 36.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-29 00:00:00', 38.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-30 00:00:00', 39.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-07-31 00:00:00', 38.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-01 00:00:00', 38.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-02 00:00:00', 37.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-03 00:00:00', 36.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-04 00:00:00', 36.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-05 00:00:00', 37.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-06 00:00:00', 37.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-07 00:00:00', 38.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-08 00:00:00', 39.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-09 00:00:00', 40.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-10 00:00:00', 41.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-11 00:00:00', 41.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-12 00:00:00', 33.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-13 00:00:00', 35.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-14 00:00:00', 36.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-15 00:00:00', 35.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-16 00:00:00', 35.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-17 00:00:00', 35.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-18 00:00:00', 36.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-19 00:00:00', 36.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-20 00:00:00', 36.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-21 00:00:00', 37.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-22 00:00:00', 36.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-23 00:00:00', 37.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-24 00:00:00', 37.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-25 00:00:00', 36.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-26 00:00:00', 35.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-27 00:00:00', 36.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-28 00:00:00', 36.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-29 00:00:00', 36.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-30 00:00:00', 36.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-08-31 00:00:00', 36.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-01 00:00:00', 37.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-02 00:00:00', 37.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-03 00:00:00', 37.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-04 00:00:00', 34.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-05 00:00:00', 33.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-06 00:00:00', 34.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-07 00:00:00', 34.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-08 00:00:00', 33.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-09 00:00:00', 34.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-10 00:00:00', 35.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-11 00:00:00', 36.0120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-12 00:00:00', 35.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-13 00:00:00', 35.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-14 00:00:00', 35.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-15 00:00:00', 35.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-16 00:00:00', 33.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-17 00:00:00', 34.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-18 00:00:00', 34.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-19 00:00:00', 32.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-20 00:00:00', 30.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-21 00:00:00', 28.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-22 00:00:00', 26.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-23 00:00:00', 25.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-24 00:00:00', 27.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-25 00:00:00', 27.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-26 00:00:00', 26.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-27 00:00:00', 24.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-28 00:00:00', 22.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-29 00:00:00', 24.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-09-30 00:00:00', 25.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-01 00:00:00', 24.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-02 00:00:00', 24.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-03 00:00:00', 21.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-04 00:00:00', 21.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-05 00:00:00', 20.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-06 00:00:00', 20.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-07 00:00:00', 21.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-08 00:00:00', 22.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-09 00:00:00', 22.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-10 00:00:00', 21.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-11 00:00:00', 22.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-12 00:00:00', 23.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-13 00:00:00', 24.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-14 00:00:00', 25.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-15 00:00:00', 26.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-16 00:00:00', 26.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-17 00:00:00', 26.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-18 00:00:00', 27.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-19 00:00:00', 20.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-20 00:00:00', 20.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-21 00:00:00', 22.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-22 00:00:00', 23.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-23 00:00:00', 22.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-24 00:00:00', 22.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-25 00:00:00', 20.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-26 00:00:00', 19.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-27 00:00:00', 21.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-28 00:00:00', 21.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-29 00:00:00', 18.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-30 00:00:00', 21.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-10-31 00:00:00', 23.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-01 00:00:00', 25.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-02 00:00:00', 24.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-03 00:00:00', 24.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-04 00:00:00', 27.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-05 00:00:00', 23.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-06 00:00:00', 26.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-07 00:00:00', 25.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-08 00:00:00', 25.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-09 00:00:00', 20.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-10 00:00:00', 23.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-11 00:00:00', 23.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-12 00:00:00', 24.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-13 00:00:00', 21.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-14 00:00:00', 18.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-15 00:00:00', 19.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-16 00:00:00', 19.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-17 00:00:00', 19.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-18 00:00:00', 19.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-19 00:00:00', 21.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-20 00:00:00', 17.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-21 00:00:00', 20.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-22 00:00:00', 23.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-23 00:00:00', 19.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-24 00:00:00', 15.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-25 00:00:00', 19.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-26 00:00:00', 19.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-27 00:00:00', 17.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-28 00:00:00', 12.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-29 00:00:00', 16.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-11-30 00:00:00', 11.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-01 00:00:00', 6.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-02 00:00:00', 11.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-03 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-04 00:00:00', 14.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-05 00:00:00', 12.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-06 00:00:00', 14.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-07 00:00:00', 10.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-08 00:00:00', 13.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-09 00:00:00', 7.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-10 00:00:00', 5.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-11 00:00:00', 4.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-12 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-13 00:00:00', 4.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-14 00:00:00', 7.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-15 00:00:00', 10.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-16 00:00:00', 9.07900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-17 00:00:00', 9.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-18 00:00:00', 7.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-19 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-20 00:00:00', 9.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-21 00:00:00', 7.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-22 00:00:00', 9.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-23 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-24 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-25 00:00:00', 3.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-26 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-27 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-28 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-29 00:00:00', 0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-30 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2007-12-31 00:00:00', 6.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-01 00:00:00', 6.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-02 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-03 00:00:00', 7.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-04 00:00:00', 3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-05 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-06 00:00:00', 5.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-07 00:00:00', 2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-08 00:00:00', -5.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-09 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-10 00:00:00', -1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-11 00:00:00', 0.518999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-12 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-13 00:00:00', -3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-14 00:00:00', -2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-15 00:00:00', -0.614000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-16 00:00:00', -3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-17 00:00:00', -3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-18 00:00:00', -2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-19 00:00:00', -5.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-20 00:00:00', -5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-21 00:00:00', -3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-22 00:00:00', -4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-23 00:00:00', -3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-24 00:00:00', -3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-25 00:00:00', -3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-26 00:00:00', -2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-27 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-28 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-29 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-30 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-01-31 00:00:00', 8.72500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-01 00:00:00', 7.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-02 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-03 00:00:00', -1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-04 00:00:00', -2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-05 00:00:00', -4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-06 00:00:00', -5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-07 00:00:00', -5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-08 00:00:00', -1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-09 00:00:00', 0.247999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-10 00:00:00', -1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-11 00:00:00', -0.978999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-12 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-13 00:00:00', 6.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-14 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-15 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-16 00:00:00', 4.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-17 00:00:00', 7.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-18 00:00:00', 10.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-19 00:00:00', 12.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-20 00:00:00', 13.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-21 00:00:00', 8.03600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-22 00:00:00', 5.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-23 00:00:00', 6.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-24 00:00:00', 9.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-25 00:00:00', 11.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-26 00:00:00', 14.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-27 00:00:00', 19.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-28 00:00:00', 16.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-02-29 00:00:00', 19.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-01 00:00:00', 15.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-02 00:00:00', 17.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-03 00:00:00', 17.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-04 00:00:00', 19.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-05 00:00:00', 17.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-06 00:00:00', 7.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-07 00:00:00', 14.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-08 00:00:00', 19.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-09 00:00:00', 16.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-10 00:00:00', 18.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-11 00:00:00', 21.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-12 00:00:00', 19.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-13 00:00:00', 22.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-14 00:00:00', 23.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-15 00:00:00', 26.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-16 00:00:00', 26.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-17 00:00:00', 21.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-18 00:00:00', 19.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-19 00:00:00', 22.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-20 00:00:00', 24.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-21 00:00:00', 25.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-22 00:00:00', 26.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-23 00:00:00', 27.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-24 00:00:00', 27.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-25 00:00:00', 27.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-26 00:00:00', 25.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-27 00:00:00', 28, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-28 00:00:00', 28.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-29 00:00:00', 27.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-30 00:00:00', 27.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-03-31 00:00:00', 24.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-01 00:00:00', 26.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-02 00:00:00', 27.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-03 00:00:00', 29.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-04 00:00:00', 19.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-05 00:00:00', 22.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-06 00:00:00', 24.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-07 00:00:00', 16.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-08 00:00:00', 22.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-09 00:00:00', 25.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-10 00:00:00', 24.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-11 00:00:00', 21.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-12 00:00:00', 24.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-13 00:00:00', 21.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-14 00:00:00', 17.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-15 00:00:00', 13.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-16 00:00:00', 21.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-17 00:00:00', 22.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-18 00:00:00', 24.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-19 00:00:00', 23.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-20 00:00:00', 28.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-21 00:00:00', 27.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-22 00:00:00', 23.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-23 00:00:00', 25.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-24 00:00:00', 27.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-25 00:00:00', 29.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-26 00:00:00', 31.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-27 00:00:00', 32.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-28 00:00:00', 32.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-29 00:00:00', 34.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-04-30 00:00:00', 34.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-01 00:00:00', 34.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-02 00:00:00', 34.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-03 00:00:00', 34.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-04 00:00:00', 27.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-05 00:00:00', 26.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-06 00:00:00', 29.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-07 00:00:00', 34.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-08 00:00:00', 36.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-09 00:00:00', 30.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-10 00:00:00', 32.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-11 00:00:00', 36.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-12 00:00:00', 36.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-13 00:00:00', 34.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-14 00:00:00', 36.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-15 00:00:00', 36.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-16 00:00:00', 31.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-17 00:00:00', 34.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-18 00:00:00', 34.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-19 00:00:00', 34.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-20 00:00:00', 36.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-21 00:00:00', 38.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-22 00:00:00', 35.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-23 00:00:00', 31.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-24 00:00:00', 31.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-25 00:00:00', 29.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-26 00:00:00', 29.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-27 00:00:00', 29.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-28 00:00:00', 34.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-29 00:00:00', 35.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-30 00:00:00', 38.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-05-31 00:00:00', 36.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-01 00:00:00', 37.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-02 00:00:00', 38.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-03 00:00:00', 37.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-04 00:00:00', 38.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-05 00:00:00', 39.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-06 00:00:00', 39.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-07 00:00:00', 38.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-08 00:00:00', 38.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-09 00:00:00', 41.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-10 00:00:00', 40.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-11 00:00:00', 39.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-12 00:00:00', 41.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-13 00:00:00', 42.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-14 00:00:00', 42.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-15 00:00:00', 38.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-16 00:00:00', 38.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-17 00:00:00', 37.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-18 00:00:00', 38.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-19 00:00:00', 38.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-20 00:00:00', 39.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-21 00:00:00', 39.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-22 00:00:00', 40.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-23 00:00:00', 39.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-24 00:00:00', 39.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-25 00:00:00', 38.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-26 00:00:00', 39.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-27 00:00:00', 37.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-28 00:00:00', 36.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-29 00:00:00', 35.4129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-06-30 00:00:00', 35.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-01 00:00:00', 37.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-02 00:00:00', 39.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-03 00:00:00', 39.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-04 00:00:00', 39.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-05 00:00:00', 40.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-06 00:00:00', 40.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-07 00:00:00', 40.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-08 00:00:00', 38.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-09 00:00:00', 38.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-10 00:00:00', 38.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-11 00:00:00', 39.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-12 00:00:00', 40.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-13 00:00:00', 40.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-14 00:00:00', 41.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-15 00:00:00', 40.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-16 00:00:00', 38.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-17 00:00:00', 39.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-18 00:00:00', 39.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-19 00:00:00', 39.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-20 00:00:00', 38.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-21 00:00:00', 38.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-22 00:00:00', 36.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-23 00:00:00', 36.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-24 00:00:00', 37.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-25 00:00:00', 36.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-26 00:00:00', 36.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-27 00:00:00', 37.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-28 00:00:00', 39.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-29 00:00:00', 41.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-30 00:00:00', 42.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-07-31 00:00:00', 42.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-01 00:00:00', 43.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-02 00:00:00', 43.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-03 00:00:00', 42.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-04 00:00:00', 39.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-05 00:00:00', 38.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-06 00:00:00', 39.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-07 00:00:00', 40.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-08 00:00:00', 41.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-09 00:00:00', 41.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-10 00:00:00', 37.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-11 00:00:00', 35.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-12 00:00:00', 35.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-13 00:00:00', 37.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-14 00:00:00', 38.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-15 00:00:00', 36.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-16 00:00:00', 34.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-17 00:00:00', 33.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-18 00:00:00', 35.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-19 00:00:00', 36.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-20 00:00:00', 36.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-21 00:00:00', 36.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-22 00:00:00', 36.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-23 00:00:00', 37.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-24 00:00:00', 38.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-25 00:00:00', 37.5439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-26 00:00:00', 38.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-27 00:00:00', 37.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-28 00:00:00', 36.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-29 00:00:00', 36.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-30 00:00:00', 34.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-08-31 00:00:00', 34.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-01 00:00:00', 35.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-02 00:00:00', 36.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-03 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-04 00:00:00', 33.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-05 00:00:00', 29.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-06 00:00:00', 29.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-07 00:00:00', 30.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-08 00:00:00', 31.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-09 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-10 00:00:00', 32.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-11 00:00:00', 34.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-12 00:00:00', 37.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-13 00:00:00', 37.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-14 00:00:00', 35.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-15 00:00:00', 35.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-16 00:00:00', 33.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-17 00:00:00', 32.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-18 00:00:00', 31.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-19 00:00:00', 30.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-20 00:00:00', 27.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-21 00:00:00', 27.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-22 00:00:00', 27.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-23 00:00:00', 27.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-24 00:00:00', 28.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-25 00:00:00', 30.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-26 00:00:00', 33.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-27 00:00:00', 31.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-28 00:00:00', 31.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-29 00:00:00', 34.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-09-30 00:00:00', 27.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-01 00:00:00', 29.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-02 00:00:00', 33.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-03 00:00:00', 32.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-04 00:00:00', 27.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-05 00:00:00', 27.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-06 00:00:00', 28.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-07 00:00:00', 27.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-08 00:00:00', 26.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-09 00:00:00', 27.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-10 00:00:00', 30.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-11 00:00:00', 26.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-12 00:00:00', 26.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-13 00:00:00', 23.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-14 00:00:00', 22.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-15 00:00:00', 23.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-16 00:00:00', 24.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-17 00:00:00', 28.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-18 00:00:00', 27.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-19 00:00:00', 19.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-20 00:00:00', 23.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-21 00:00:00', 24.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-22 00:00:00', 22.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-23 00:00:00', 24.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-24 00:00:00', 17.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-25 00:00:00', 19.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-26 00:00:00', 22.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-27 00:00:00', 21.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-28 00:00:00', 13.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-29 00:00:00', 10.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-30 00:00:00', 13.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-10-31 00:00:00', 14.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-01 00:00:00', 13.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-02 00:00:00', 15.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-03 00:00:00', 17.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-04 00:00:00', 21.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-05 00:00:00', 23.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-06 00:00:00', 21.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-07 00:00:00', 22.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-08 00:00:00', 19.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-09 00:00:00', 13.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-10 00:00:00', 9.67800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-11 00:00:00', 8.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-12 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-13 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-14 00:00:00', 6.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-15 00:00:00', 7.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-16 00:00:00', 11.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-17 00:00:00', 8.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-18 00:00:00', 14.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-19 00:00:00', 9.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-20 00:00:00', 13.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-21 00:00:00', 15.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-22 00:00:00', 16.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-23 00:00:00', 19.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-24 00:00:00', 18.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-25 00:00:00', 18.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-26 00:00:00', 20.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-27 00:00:00', 20.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-28 00:00:00', 22.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-29 00:00:00', 21.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-11-30 00:00:00', 20.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-01 00:00:00', 19.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-02 00:00:00', 19.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-03 00:00:00', 16.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-04 00:00:00', 13.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-05 00:00:00', 11.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-06 00:00:00', 10.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-07 00:00:00', 12.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-08 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-09 00:00:00', 12.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-10 00:00:00', 13.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-11 00:00:00', 13.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-12 00:00:00', 14.800999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-13 00:00:00', 15.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-14 00:00:00', 12.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-15 00:00:00', 15.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-16 00:00:00', 10.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-17 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-18 00:00:00', 0.00999999977648258209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-19 00:00:00', -0.0949999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-20 00:00:00', -0.767000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-21 00:00:00', 0.851999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-22 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-23 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-24 00:00:00', 10.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-25 00:00:00', 14.2899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-26 00:00:00', 15.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-27 00:00:00', 11.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-28 00:00:00', 10.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-29 00:00:00', 6.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-30 00:00:00', 10.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2008-12-31 00:00:00', 11.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-01 00:00:00', 13.2100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-02 00:00:00', 9.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-03 00:00:00', 6.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-04 00:00:00', 3.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-05 00:00:00', 8.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-06 00:00:00', 9.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-07 00:00:00', 9.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-08 00:00:00', 12.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-09 00:00:00', 12.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-10 00:00:00', 11.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-11 00:00:00', 7.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-12 00:00:00', 11.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-13 00:00:00', 5.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-14 00:00:00', 7.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-15 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-16 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-17 00:00:00', 6.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-18 00:00:00', 7.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-19 00:00:00', 10.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-20 00:00:00', 14.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-21 00:00:00', 13.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-22 00:00:00', 14.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-23 00:00:00', 12.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-24 00:00:00', 13.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-25 00:00:00', 6.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-26 00:00:00', 8.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-27 00:00:00', 10.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-28 00:00:00', 12.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-29 00:00:00', 8.67800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-30 00:00:00', 10.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-01-31 00:00:00', 14.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-01 00:00:00', 15.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-02 00:00:00', 14.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-03 00:00:00', 7.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-04 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-05 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-06 00:00:00', 8.16399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-07 00:00:00', 13.7030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-08 00:00:00', 16.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-09 00:00:00', 12.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-10 00:00:00', 10.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-11 00:00:00', 8.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-12 00:00:00', 11.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-13 00:00:00', 8.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-14 00:00:00', 9.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-15 00:00:00', 13.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-16 00:00:00', 15.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-17 00:00:00', 11.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-18 00:00:00', 15.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-19 00:00:00', 14.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-20 00:00:00', 7.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-21 00:00:00', 13.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-22 00:00:00', 14.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-23 00:00:00', 9.33800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-24 00:00:00', 10.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-25 00:00:00', 11.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-26 00:00:00', 13.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-27 00:00:00', 14.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-02-28 00:00:00', 17.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-01 00:00:00', 16.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-02 00:00:00', 16.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-03 00:00:00', 13.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-04 00:00:00', 14.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-05 00:00:00', 14.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-06 00:00:00', 10.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-07 00:00:00', 12.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-08 00:00:00', 14.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-09 00:00:00', 16.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-10 00:00:00', 19.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-11 00:00:00', 25.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-12 00:00:00', 23.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-13 00:00:00', 23.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-14 00:00:00', 25.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-15 00:00:00', 27.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-16 00:00:00', 24.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-17 00:00:00', 24.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-18 00:00:00', 16.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-19 00:00:00', 15.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-20 00:00:00', 20.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-21 00:00:00', 21.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-22 00:00:00', 22.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-23 00:00:00', 19.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-24 00:00:00', 17.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-25 00:00:00', 23.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-26 00:00:00', 21.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-27 00:00:00', 19.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-28 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-29 00:00:00', 21.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-30 00:00:00', 22.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-03-31 00:00:00', 23.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-01 00:00:00', 23.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-02 00:00:00', 13.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-03 00:00:00', 16.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-04 00:00:00', 23.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-05 00:00:00', 15.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-06 00:00:00', 13.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-07 00:00:00', 12.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-08 00:00:00', 19.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-09 00:00:00', 22.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-10 00:00:00', 21.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-11 00:00:00', 14.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-12 00:00:00', 23.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-13 00:00:00', 22.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-14 00:00:00', 20.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-15 00:00:00', 10.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-16 00:00:00', 18.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-17 00:00:00', 22.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-18 00:00:00', 26.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-19 00:00:00', 27.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-20 00:00:00', 25.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-21 00:00:00', 15.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-22 00:00:00', 20.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-23 00:00:00', 23.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-24 00:00:00', 26.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-25 00:00:00', 26.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-26 00:00:00', 19.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-27 00:00:00', 15.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-28 00:00:00', 18.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-29 00:00:00', 23.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-04-30 00:00:00', 28.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-01 00:00:00', 30.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-02 00:00:00', 27.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-03 00:00:00', 26.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-04 00:00:00', 18.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-05 00:00:00', 23.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-06 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-07 00:00:00', 29.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-08 00:00:00', 26.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-09 00:00:00', 24.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-10 00:00:00', 23.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-11 00:00:00', 26.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-12 00:00:00', 29.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-13 00:00:00', 28.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-14 00:00:00', 28.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-15 00:00:00', 27.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-16 00:00:00', 28.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-17 00:00:00', 33.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-18 00:00:00', 34.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-19 00:00:00', 29.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-20 00:00:00', 29.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-21 00:00:00', 29.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-22 00:00:00', 29.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-23 00:00:00', 32.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-24 00:00:00', 32.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-25 00:00:00', 30.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-26 00:00:00', 33.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-27 00:00:00', 33.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-28 00:00:00', 34.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-29 00:00:00', 35.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-30 00:00:00', 37.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-05-31 00:00:00', 34.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-01 00:00:00', 28.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-02 00:00:00', 27.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-03 00:00:00', 29.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-04 00:00:00', 29.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-05 00:00:00', 30.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-06 00:00:00', 28.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-07 00:00:00', 28.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-08 00:00:00', 31.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-09 00:00:00', 32.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-10 00:00:00', 33.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-11 00:00:00', 34.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-12 00:00:00', 34.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-13 00:00:00', 32.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-14 00:00:00', 34.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-15 00:00:00', 33.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-16 00:00:00', 33.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-17 00:00:00', 34.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-18 00:00:00', 33.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-19 00:00:00', 35.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-20 00:00:00', 35.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-21 00:00:00', 36.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-22 00:00:00', 36.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-23 00:00:00', 35.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-24 00:00:00', 34.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-25 00:00:00', 36.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-26 00:00:00', 37.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-27 00:00:00', 38.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-28 00:00:00', 38.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-29 00:00:00', 35.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-06-30 00:00:00', 33.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-01 00:00:00', 34.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-02 00:00:00', 35.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-03 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-04 00:00:00', 32.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-05 00:00:00', 35.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-06 00:00:00', 37.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-07 00:00:00', 39.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-08 00:00:00', 39.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-09 00:00:00', 38.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-10 00:00:00', 38.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-11 00:00:00', 38.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-12 00:00:00', 37.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-13 00:00:00', 36.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-14 00:00:00', 36.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-15 00:00:00', 38.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-16 00:00:00', 38.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-17 00:00:00', 38.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-18 00:00:00', 38.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-19 00:00:00', 39.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-20 00:00:00', 38.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-21 00:00:00', 40.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-22 00:00:00', 39.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-23 00:00:00', 39.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-24 00:00:00', 39.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-25 00:00:00', 41.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-26 00:00:00', 42.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-27 00:00:00', 42.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-28 00:00:00', 41.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-29 00:00:00', 40.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-30 00:00:00', 37.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-07-31 00:00:00', 39.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-01 00:00:00', 39.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-02 00:00:00', 40.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-03 00:00:00', 39.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-04 00:00:00', 37.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-05 00:00:00', 37.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-06 00:00:00', 36.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-07 00:00:00', 37.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-08 00:00:00', 38.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-09 00:00:00', 38.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-10 00:00:00', 40.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-11 00:00:00', 40.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-12 00:00:00', 42.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-13 00:00:00', 42.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-14 00:00:00', 41.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-15 00:00:00', 40.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-16 00:00:00', 37.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-17 00:00:00', 37.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-18 00:00:00', 36.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-19 00:00:00', 35.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-20 00:00:00', 33.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-21 00:00:00', 33.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-22 00:00:00', 34.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-23 00:00:00', 35.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-24 00:00:00', 37.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-25 00:00:00', 32.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-26 00:00:00', 33.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-27 00:00:00', 34.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-28 00:00:00', 38.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-29 00:00:00', 37.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-30 00:00:00', 34.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-08-31 00:00:00', 34.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-01 00:00:00', 34.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-02 00:00:00', 31.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-03 00:00:00', 30.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-04 00:00:00', 30.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-05 00:00:00', 29.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-06 00:00:00', 28.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-07 00:00:00', 29.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-08 00:00:00', 28.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-09 00:00:00', 26.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-10 00:00:00', 28.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-11 00:00:00', 31.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-12 00:00:00', 31.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-13 00:00:00', 34.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-14 00:00:00', 34.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-15 00:00:00', 35.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-16 00:00:00', 31.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-17 00:00:00', 31.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-18 00:00:00', 35.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-19 00:00:00', 35.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-20 00:00:00', 36.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-21 00:00:00', 35.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-22 00:00:00', 33.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-23 00:00:00', 32.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-24 00:00:00', 34.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-25 00:00:00', 36.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-26 00:00:00', 29.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-27 00:00:00', 29.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-28 00:00:00', 31.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-29 00:00:00', 32.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-09-30 00:00:00', 35.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-01 00:00:00', 35.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-02 00:00:00', 30.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-03 00:00:00', 26.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-04 00:00:00', 27.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-05 00:00:00', 26.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-06 00:00:00', 27.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-07 00:00:00', 26.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-08 00:00:00', 24.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-09 00:00:00', 21.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-10 00:00:00', 22.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-11 00:00:00', 23.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-12 00:00:00', 25.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-13 00:00:00', 24.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-14 00:00:00', 25.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-15 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-16 00:00:00', 25.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-17 00:00:00', 23.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-18 00:00:00', 22.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-19 00:00:00', 23.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-20 00:00:00', 22.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-21 00:00:00', 22.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-22 00:00:00', 21.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-23 00:00:00', 21.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-24 00:00:00', 20.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-25 00:00:00', 22.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-26 00:00:00', 22.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-27 00:00:00', 21.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-28 00:00:00', 17.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-29 00:00:00', 22.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-30 00:00:00', 22.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-10-31 00:00:00', 25.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-01 00:00:00', 25.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-02 00:00:00', 18.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-03 00:00:00', 26.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-04 00:00:00', 25.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-05 00:00:00', 24.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-06 00:00:00', 24.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-07 00:00:00', 16.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-08 00:00:00', 11.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-09 00:00:00', 8.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-10 00:00:00', 10.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-11 00:00:00', 17.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-12 00:00:00', 17.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-13 00:00:00', 17.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-14 00:00:00', 14.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-15 00:00:00', 12.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-16 00:00:00', 12.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-17 00:00:00', 11.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-18 00:00:00', 14.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-19 00:00:00', 17.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-20 00:00:00', 18.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-21 00:00:00', 17.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-22 00:00:00', 18.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-23 00:00:00', 10.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-24 00:00:00', 14.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-25 00:00:00', 9.89000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-26 00:00:00', 11.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-27 00:00:00', 12.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-28 00:00:00', 7.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-29 00:00:00', 12.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-11-30 00:00:00', 12.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-01 00:00:00', 11.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-02 00:00:00', 13.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-03 00:00:00', 10.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-04 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-05 00:00:00', 7.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-06 00:00:00', 8.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-07 00:00:00', 10.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-08 00:00:00', 12.8970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-09 00:00:00', 7.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-10 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-11 00:00:00', 8.69200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-12 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-13 00:00:00', 10.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-14 00:00:00', 12.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-15 00:00:00', 13.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-16 00:00:00', 7.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-17 00:00:00', 11.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-18 00:00:00', 14.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-19 00:00:00', 16.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-20 00:00:00', 10.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-21 00:00:00', 9.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-22 00:00:00', 11.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-23 00:00:00', 11.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-24 00:00:00', 11.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-25 00:00:00', 12.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-26 00:00:00', 11.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-27 00:00:00', 11.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-28 00:00:00', 10.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-29 00:00:00', 11.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-30 00:00:00', 14.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2009-12-31 00:00:00', 15.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-01 00:00:00', 17.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-02 00:00:00', 16.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-03 00:00:00', 14.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-04 00:00:00', 15.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-05 00:00:00', 16.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-06 00:00:00', 14.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-07 00:00:00', 7.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-08 00:00:00', 7.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-09 00:00:00', 6.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-10 00:00:00', 6.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-11 00:00:00', 8.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-12 00:00:00', 13.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-13 00:00:00', 12.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-14 00:00:00', 14.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-15 00:00:00', 14.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-16 00:00:00', 16.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-17 00:00:00', 13.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-18 00:00:00', 7.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-19 00:00:00', 10.8389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-20 00:00:00', 15.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-21 00:00:00', 16.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-22 00:00:00', 11.814000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-23 00:00:00', 9.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-24 00:00:00', 12.6470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-25 00:00:00', 15.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-26 00:00:00', 17.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-27 00:00:00', 9.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-28 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-29 00:00:00', 8.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-30 00:00:00', 12.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-01-31 00:00:00', 8.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-01 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-02 00:00:00', 11.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-03 00:00:00', 12.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-04 00:00:00', 12.7100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-05 00:00:00', 9.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-06 00:00:00', 12.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-07 00:00:00', 7.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-08 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-09 00:00:00', -0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-10 00:00:00', 6.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-11 00:00:00', 7.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-12 00:00:00', 3.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-13 00:00:00', 0.368000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-14 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-15 00:00:00', -0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-16 00:00:00', 7.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-17 00:00:00', 12.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-18 00:00:00', 10.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-19 00:00:00', 9.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-20 00:00:00', 13.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-21 00:00:00', 20.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-22 00:00:00', 13.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-23 00:00:00', 19.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-24 00:00:00', 13.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-25 00:00:00', 17.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-26 00:00:00', 9.61400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-27 00:00:00', 12.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-02-28 00:00:00', 10.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-01 00:00:00', 12.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-02 00:00:00', 16.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-03 00:00:00', 18.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-04 00:00:00', 13.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-05 00:00:00', 16.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-06 00:00:00', 14.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-07 00:00:00', 17.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-08 00:00:00', 21.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-09 00:00:00', 18.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-10 00:00:00', 23.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-11 00:00:00', 21.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-12 00:00:00', 13.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-13 00:00:00', 19.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-14 00:00:00', 24.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-15 00:00:00', 25.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-16 00:00:00', 29.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-17 00:00:00', 30.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-18 00:00:00', 27.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-19 00:00:00', 32.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-20 00:00:00', 18.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-21 00:00:00', 11.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-22 00:00:00', 12.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-23 00:00:00', 16.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-24 00:00:00', 18.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-25 00:00:00', 21.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-26 00:00:00', 19.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-27 00:00:00', 18.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-28 00:00:00', 21.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-29 00:00:00', 21.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-30 00:00:00', 15.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-03-31 00:00:00', 21.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-01 00:00:00', 23.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-02 00:00:00', 23.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-03 00:00:00', 15.2130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-04 00:00:00', 21.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-05 00:00:00', 23.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-06 00:00:00', 24.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-07 00:00:00', 21.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-08 00:00:00', 26.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-09 00:00:00', 28.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-10 00:00:00', 24.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-11 00:00:00', 24.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-12 00:00:00', 19.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-13 00:00:00', 26.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-14 00:00:00', 31.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-15 00:00:00', 23.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-16 00:00:00', 27.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-17 00:00:00', 25.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-18 00:00:00', 25.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-19 00:00:00', 27.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-20 00:00:00', 25.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-21 00:00:00', 17.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-22 00:00:00', 22.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-23 00:00:00', 27.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-24 00:00:00', 28.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-25 00:00:00', 28.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-26 00:00:00', 27.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-27 00:00:00', 28.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-28 00:00:00', 30.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-29 00:00:00', 28.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-04-30 00:00:00', 31.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-01 00:00:00', 28.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-02 00:00:00', 27.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-03 00:00:00', 32.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-04 00:00:00', 22.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-05 00:00:00', 21.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-06 00:00:00', 26.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-07 00:00:00', 23.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-08 00:00:00', 29.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-09 00:00:00', 31.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-10 00:00:00', 26.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-11 00:00:00', 27.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-12 00:00:00', 26.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-13 00:00:00', 27.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-14 00:00:00', 30.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-15 00:00:00', 30.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-16 00:00:00', 22.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-17 00:00:00', 25.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-18 00:00:00', 29.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-19 00:00:00', 31.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-20 00:00:00', 32.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-21 00:00:00', 26.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-22 00:00:00', 30.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-23 00:00:00', 29.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-24 00:00:00', 30.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-25 00:00:00', 35.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-26 00:00:00', 29.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-27 00:00:00', 30.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-28 00:00:00', 30.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-29 00:00:00', 31.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-30 00:00:00', 34.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-05-31 00:00:00', 35.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-01 00:00:00', 36.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-02 00:00:00', 27.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-03 00:00:00', 29.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-04 00:00:00', 26.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-05 00:00:00', 29.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-06 00:00:00', 28.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-07 00:00:00', 31.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-08 00:00:00', 32.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-09 00:00:00', 33.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-10 00:00:00', 35.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-11 00:00:00', 37.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-12 00:00:00', 36.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-13 00:00:00', 36.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-14 00:00:00', 33.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-15 00:00:00', 33.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-16 00:00:00', 34.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-17 00:00:00', 34.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-18 00:00:00', 36.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-19 00:00:00', 37.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-20 00:00:00', 39.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-21 00:00:00', 40.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-22 00:00:00', 39.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-23 00:00:00', 39.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-24 00:00:00', 34.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-25 00:00:00', 32.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-26 00:00:00', 36.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-27 00:00:00', 38.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-28 00:00:00', 37.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-29 00:00:00', 37.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-06-30 00:00:00', 36.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-01 00:00:00', 36.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-02 00:00:00', 37.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-03 00:00:00', 38.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-04 00:00:00', 38.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-05 00:00:00', 37.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-06 00:00:00', 36.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-07 00:00:00', 38.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-08 00:00:00', 40.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-09 00:00:00', 40.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-10 00:00:00', 40.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-11 00:00:00', 38.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-12 00:00:00', 35.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-13 00:00:00', 36.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-14 00:00:00', 38.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-15 00:00:00', 41.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-16 00:00:00', 44.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-17 00:00:00', 43.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-18 00:00:00', 42.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-19 00:00:00', 39.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-20 00:00:00', 37.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-21 00:00:00', 36.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-22 00:00:00', 31.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-23 00:00:00', 35.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-24 00:00:00', 36.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-25 00:00:00', 36.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-26 00:00:00', 37.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-27 00:00:00', 36.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-28 00:00:00', 37.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-29 00:00:00', 36.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-30 00:00:00', 36.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-07-31 00:00:00', 35.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-01 00:00:00', 36.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-02 00:00:00', 37.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-03 00:00:00', 31.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-04 00:00:00', 29.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-05 00:00:00', 37.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-06 00:00:00', 33.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-07 00:00:00', 36.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-08 00:00:00', 39.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-09 00:00:00', 40.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-10 00:00:00', 37.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-11 00:00:00', 38.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-12 00:00:00', 38.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-13 00:00:00', 37.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-14 00:00:00', 36.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-15 00:00:00', 37.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-16 00:00:00', 38.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-17 00:00:00', 38.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-18 00:00:00', 38.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-19 00:00:00', 38.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-20 00:00:00', 39.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-21 00:00:00', 40.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-22 00:00:00', 41.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-23 00:00:00', 34.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-24 00:00:00', 29.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-25 00:00:00', 32.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-26 00:00:00', 33.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-27 00:00:00', 35.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-28 00:00:00', 36.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-29 00:00:00', 36.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-30 00:00:00', 36.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-08-31 00:00:00', 37.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-01 00:00:00', 38.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-02 00:00:00', 38.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-03 00:00:00', 37.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-04 00:00:00', 36.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-05 00:00:00', 36.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-06 00:00:00', 35.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-07 00:00:00', 35.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-08 00:00:00', 35.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-09 00:00:00', 35.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-10 00:00:00', 34.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-11 00:00:00', 34.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-12 00:00:00', 29.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-13 00:00:00', 26.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-14 00:00:00', 30.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-15 00:00:00', 31.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-16 00:00:00', 21.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-17 00:00:00', 20.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-18 00:00:00', 23.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-19 00:00:00', 25.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-20 00:00:00', 28.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-21 00:00:00', 29.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-22 00:00:00', 27.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-23 00:00:00', 27.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-24 00:00:00', 28.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-25 00:00:00', 28.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-26 00:00:00', 28.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-27 00:00:00', 27.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-28 00:00:00', 23.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-29 00:00:00', 27.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-09-30 00:00:00', 27.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-01 00:00:00', 30.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-02 00:00:00', 32.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-03 00:00:00', 32.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-04 00:00:00', 32.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-05 00:00:00', 33.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-06 00:00:00', 32.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-07 00:00:00', 32.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-08 00:00:00', 28.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-09 00:00:00', 25.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-10 00:00:00', 25.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-11 00:00:00', 27.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-12 00:00:00', 30.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-13 00:00:00', 22.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-14 00:00:00', 26.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-15 00:00:00', 29.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-16 00:00:00', 31.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-17 00:00:00', 31.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-18 00:00:00', 30.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-19 00:00:00', 29.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-20 00:00:00', 26.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-21 00:00:00', 22.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-22 00:00:00', 16.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-23 00:00:00', 20.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-24 00:00:00', 20.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-25 00:00:00', 20.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-26 00:00:00', 21.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-27 00:00:00', 22.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-28 00:00:00', 21.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-29 00:00:00', 21.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-30 00:00:00', 21.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-10-31 00:00:00', 24.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-01 00:00:00', 25.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-02 00:00:00', 22.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-03 00:00:00', 13.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-04 00:00:00', 16.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-05 00:00:00', 10.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-06 00:00:00', 16.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-07 00:00:00', 20.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-08 00:00:00', 22.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-09 00:00:00', 23.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-10 00:00:00', 23.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-11 00:00:00', 21.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-12 00:00:00', 19.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-13 00:00:00', 17.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-14 00:00:00', 18.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-15 00:00:00', 17.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-16 00:00:00', 15.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-17 00:00:00', 15.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-18 00:00:00', 15.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-19 00:00:00', 16.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-20 00:00:00', 16.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-21 00:00:00', 15.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-22 00:00:00', 15.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-23 00:00:00', 17.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-24 00:00:00', 18.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-25 00:00:00', 16.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-26 00:00:00', 15.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-27 00:00:00', 16.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-28 00:00:00', 18.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-29 00:00:00', 18.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-11-30 00:00:00', 15.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-01 00:00:00', 15.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-02 00:00:00', 17.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-03 00:00:00', 17.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-04 00:00:00', 9.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-05 00:00:00', 7.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-06 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-07 00:00:00', 9.63099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-08 00:00:00', 10.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-09 00:00:00', 12.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-10 00:00:00', 14.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-11 00:00:00', 16.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-12 00:00:00', 18.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-13 00:00:00', 18.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-14 00:00:00', 20.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-15 00:00:00', 11.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-16 00:00:00', 10.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-17 00:00:00', 12.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-18 00:00:00', 14.2869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-19 00:00:00', 16.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-20 00:00:00', 16.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-21 00:00:00', 11.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-22 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-23 00:00:00', 6.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-24 00:00:00', 9.07900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-25 00:00:00', 8.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-26 00:00:00', 6.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-27 00:00:00', 7.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-28 00:00:00', 7.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-29 00:00:00', 6.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-30 00:00:00', 6.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2010-12-31 00:00:00', 8.35299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-01 00:00:00', 11.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-02 00:00:00', 12.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-03 00:00:00', 9.13099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-04 00:00:00', 5.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-05 00:00:00', 8.15900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-06 00:00:00', 8.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-07 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-08 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-09 00:00:00', 6.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-10 00:00:00', 7.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-11 00:00:00', 2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-12 00:00:00', 4.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-13 00:00:00', -1.78499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-14 00:00:00', -4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-15 00:00:00', -2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-16 00:00:00', 1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-17 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-18 00:00:00', -0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-19 00:00:00', 1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-20 00:00:00', 6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-21 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-22 00:00:00', 4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-23 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-24 00:00:00', 6.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-25 00:00:00', 6.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-26 00:00:00', 8.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-27 00:00:00', 11.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-28 00:00:00', 8.72099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-29 00:00:00', 8.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-30 00:00:00', 7.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-01-31 00:00:00', 8.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-01 00:00:00', 9.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-02 00:00:00', 11.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-03 00:00:00', 11.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-04 00:00:00', 6.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-05 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-06 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-07 00:00:00', 2.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-08 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-09 00:00:00', -0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-10 00:00:00', 6.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-11 00:00:00', 8.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-12 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-13 00:00:00', 3.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-14 00:00:00', 7.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-15 00:00:00', 8.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-16 00:00:00', 8.89700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-17 00:00:00', 9.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-18 00:00:00', 7.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-19 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-20 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-21 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-22 00:00:00', 6.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-23 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-24 00:00:00', 0.662999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-25 00:00:00', -2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-26 00:00:00', -4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-27 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-02-28 00:00:00', -0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-01 00:00:00', 2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-02 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-03 00:00:00', 4.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-04 00:00:00', -0.361000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-05 00:00:00', 5.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-06 00:00:00', 7.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-07 00:00:00', 5.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-08 00:00:00', 11.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-09 00:00:00', 14.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-10 00:00:00', 16.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-11 00:00:00', 17.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-12 00:00:00', 17.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-13 00:00:00', 20.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-14 00:00:00', 22.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-15 00:00:00', 13.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-16 00:00:00', 11.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-17 00:00:00', 5.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-18 00:00:00', 12.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-19 00:00:00', 10.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-20 00:00:00', 12.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-21 00:00:00', 15.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-22 00:00:00', 16.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-23 00:00:00', 19.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-24 00:00:00', 19.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-25 00:00:00', 16.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-26 00:00:00', 16.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-27 00:00:00', 10.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-28 00:00:00', 11.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-29 00:00:00', 15.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-30 00:00:00', 14.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-03-31 00:00:00', 14.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-01 00:00:00', 15.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-02 00:00:00', 15.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-03 00:00:00', 9.01099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-04 00:00:00', 9.09799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-05 00:00:00', 14.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-06 00:00:00', 17.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-07 00:00:00', 20.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-08 00:00:00', 14.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-09 00:00:00', 15.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-10 00:00:00', 19.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-11 00:00:00', 19.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-12 00:00:00', 23.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-13 00:00:00', 24.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-14 00:00:00', 23.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-15 00:00:00', 16.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-16 00:00:00', 18.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-17 00:00:00', 21.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-18 00:00:00', 21.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-19 00:00:00', 22.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-20 00:00:00', 22.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-21 00:00:00', 26.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-22 00:00:00', 28.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-23 00:00:00', 29.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-24 00:00:00', 31.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-25 00:00:00', 30.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-26 00:00:00', 31.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-27 00:00:00', 30.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-28 00:00:00', 26.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-29 00:00:00', 20.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-04-30 00:00:00', 25.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-01 00:00:00', 29.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-02 00:00:00', 31.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-03 00:00:00', 32.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-04 00:00:00', 32.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-05 00:00:00', 24.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-06 00:00:00', 18.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-07 00:00:00', 24.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-08 00:00:00', 20.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-09 00:00:00', 23.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-10 00:00:00', 23.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-11 00:00:00', 20.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-12 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-13 00:00:00', 27.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-14 00:00:00', 31.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-15 00:00:00', 34.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-16 00:00:00', 36.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-17 00:00:00', 33.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-18 00:00:00', 31.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-19 00:00:00', 28.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-20 00:00:00', 27.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-21 00:00:00', 28.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-22 00:00:00', 29.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-23 00:00:00', 31.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-24 00:00:00', 32.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-25 00:00:00', 29.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-26 00:00:00', 30.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-27 00:00:00', 29.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-28 00:00:00', 30.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-29 00:00:00', 30.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-30 00:00:00', 30.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-05-31 00:00:00', 30.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-01 00:00:00', 27.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-02 00:00:00', 28.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-03 00:00:00', 30.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-04 00:00:00', 28.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-05 00:00:00', 30.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-06 00:00:00', 32.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-07 00:00:00', 34.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-08 00:00:00', 36.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-09 00:00:00', 35.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-10 00:00:00', 35.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-11 00:00:00', 32.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-12 00:00:00', 31.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-13 00:00:00', 29.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-14 00:00:00', 33.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-15 00:00:00', 35.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-16 00:00:00', 36.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-17 00:00:00', 32.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-18 00:00:00', 33.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-19 00:00:00', 33.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-20 00:00:00', 33.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-21 00:00:00', 35.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-22 00:00:00', 35.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-23 00:00:00', 35.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-24 00:00:00', 36.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-25 00:00:00', 34.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-26 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-27 00:00:00', 34.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-28 00:00:00', 34.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-29 00:00:00', 34.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-06-30 00:00:00', 33.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-01 00:00:00', 33.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-02 00:00:00', 33.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-03 00:00:00', 34.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-04 00:00:00', 35.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-05 00:00:00', 36.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-06 00:00:00', 36.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-07 00:00:00', 36.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-08 00:00:00', 36.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-09 00:00:00', 36.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-10 00:00:00', 35.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-11 00:00:00', 37.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-12 00:00:00', 38.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-13 00:00:00', 39.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-14 00:00:00', 35.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-15 00:00:00', 32.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-16 00:00:00', 33.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-17 00:00:00', 33.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-18 00:00:00', 34.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-19 00:00:00', 32.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-20 00:00:00', 33.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-21 00:00:00', 35.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-22 00:00:00', 35.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-23 00:00:00', 35.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-24 00:00:00', 35.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-25 00:00:00', 34.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-26 00:00:00', 34.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-27 00:00:00', 34.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-28 00:00:00', 34.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-29 00:00:00', 35.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-30 00:00:00', 34.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-07-31 00:00:00', 35.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-01 00:00:00', 36.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-02 00:00:00', 38.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-03 00:00:00', 39.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-04 00:00:00', 39.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-05 00:00:00', 40.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-06 00:00:00', 40.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-07 00:00:00', 40.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-08 00:00:00', 37.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-09 00:00:00', 33.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-10 00:00:00', 33.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-11 00:00:00', 34.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-12 00:00:00', 34.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-13 00:00:00', 34.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-14 00:00:00', 36.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-15 00:00:00', 36.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-16 00:00:00', 36.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-17 00:00:00', 35.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-18 00:00:00', 35.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-19 00:00:00', 35.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-20 00:00:00', 36.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-21 00:00:00', 37.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-22 00:00:00', 37.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-23 00:00:00', 37.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-24 00:00:00', 37.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-25 00:00:00', 34.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-26 00:00:00', 33.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-27 00:00:00', 30.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-28 00:00:00', 29.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-29 00:00:00', 27.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-30 00:00:00', 27.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-08-31 00:00:00', 30.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-01 00:00:00', 31.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-02 00:00:00', 31.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-03 00:00:00', 32.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-04 00:00:00', 33.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-05 00:00:00', 34.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-06 00:00:00', 33.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-07 00:00:00', 33.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-08 00:00:00', 31.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-09 00:00:00', 32.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-10 00:00:00', 31.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-11 00:00:00', 32.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-12 00:00:00', 33.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-13 00:00:00', 34.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-14 00:00:00', 32.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-15 00:00:00', 29.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-16 00:00:00', 25.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-17 00:00:00', 28.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-18 00:00:00', 26.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-19 00:00:00', 26.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-20 00:00:00', 26.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-21 00:00:00', 25.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-22 00:00:00', 26.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-23 00:00:00', 25.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-24 00:00:00', 27.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-25 00:00:00', 27.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-26 00:00:00', 27.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-27 00:00:00', 27.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-28 00:00:00', 25.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-29 00:00:00', 24.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-09-30 00:00:00', 25.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-01 00:00:00', 28.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-02 00:00:00', 30.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-03 00:00:00', 30.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-04 00:00:00', 28.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-05 00:00:00', 21.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-06 00:00:00', 22.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-07 00:00:00', 20.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-08 00:00:00', 22.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-09 00:00:00', 23.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-10 00:00:00', 24.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-11 00:00:00', 21.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-12 00:00:00', 19.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-13 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-14 00:00:00', 21.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-15 00:00:00', 23.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-16 00:00:00', 23.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-17 00:00:00', 23.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-18 00:00:00', 23.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-19 00:00:00', 21.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-20 00:00:00', 23.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-21 00:00:00', 20.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-22 00:00:00', 17.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-23 00:00:00', 9.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-24 00:00:00', 14.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-25 00:00:00', 16.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-26 00:00:00', 19.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-27 00:00:00', 20.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-28 00:00:00', 11.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-29 00:00:00', 8.06200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-30 00:00:00', 10.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-10-31 00:00:00', 11.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-01 00:00:00', 8.49199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-02 00:00:00', 11.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-03 00:00:00', 12.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-04 00:00:00', 10.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-05 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-06 00:00:00', 15.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-07 00:00:00', 18.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-08 00:00:00', 8.86400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-09 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-10 00:00:00', 9.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-11 00:00:00', 14.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-12 00:00:00', 14.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-13 00:00:00', 16.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-14 00:00:00', 9.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-15 00:00:00', 8.10700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-16 00:00:00', 10.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-17 00:00:00', 11.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-18 00:00:00', 11.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-19 00:00:00', 10.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-20 00:00:00', 13.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-21 00:00:00', 15.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-22 00:00:00', 12.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-23 00:00:00', 11.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-24 00:00:00', 7.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-25 00:00:00', 10.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-26 00:00:00', 5.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-27 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-28 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-29 00:00:00', 8.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-11-30 00:00:00', 12.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-01 00:00:00', 4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-02 00:00:00', 7.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-03 00:00:00', 7.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-04 00:00:00', 5.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-05 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-06 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-07 00:00:00', 3.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-08 00:00:00', 5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-09 00:00:00', 6.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-10 00:00:00', 7.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-11 00:00:00', 9.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-12 00:00:00', 1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-13 00:00:00', 5.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-14 00:00:00', 6.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-15 00:00:00', 4.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-16 00:00:00', 5.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-17 00:00:00', 8.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-18 00:00:00', 7.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-19 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-20 00:00:00', -5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-21 00:00:00', -5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-22 00:00:00', -5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-23 00:00:00', 1.36399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-24 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-25 00:00:00', 7.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-26 00:00:00', 6.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-27 00:00:00', 2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-28 00:00:00', -0.647000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-29 00:00:00', 1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-30 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2011-12-31 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-01 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-02 00:00:00', 3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-03 00:00:00', 3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-04 00:00:00', 2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-05 00:00:00', -0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-06 00:00:00', -4.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-07 00:00:00', -2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-08 00:00:00', 0.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-09 00:00:00', 1.60399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-10 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-11 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-12 00:00:00', 6.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-13 00:00:00', 1.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-14 00:00:00', 5.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-15 00:00:00', 1.6950000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-16 00:00:00', 0.755999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-17 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-18 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-19 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-20 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-21 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-22 00:00:00', -0.314999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-23 00:00:00', 0.144999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-24 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-25 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-26 00:00:00', 0.144999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-27 00:00:00', 4.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-28 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-29 00:00:00', 7.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-30 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-01-31 00:00:00', 0.739000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-01 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-02 00:00:00', 5.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-03 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-04 00:00:00', -3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-05 00:00:00', -8.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-06 00:00:00', -6.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-07 00:00:00', -3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-08 00:00:00', -0.31400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-09 00:00:00', 1.84099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-10 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-11 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-12 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-13 00:00:00', -3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-14 00:00:00', -3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-15 00:00:00', -0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-16 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-17 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-18 00:00:00', 4.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-19 00:00:00', 5.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-20 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-21 00:00:00', -1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-22 00:00:00', -3.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-23 00:00:00', -1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-24 00:00:00', 0.986000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-25 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-26 00:00:00', 6.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-27 00:00:00', 1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-28 00:00:00', 7.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-02-29 00:00:00', 8.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-01 00:00:00', 10.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-02 00:00:00', 11.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-03 00:00:00', 12.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-04 00:00:00', 5.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-05 00:00:00', 5.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-06 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-07 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-08 00:00:00', 7.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-09 00:00:00', 6.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-10 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-11 00:00:00', 1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-12 00:00:00', -0.749000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-13 00:00:00', 0.646000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-14 00:00:00', 4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-15 00:00:00', 10.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-16 00:00:00', 9.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-17 00:00:00', 13.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-18 00:00:00', 10.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-19 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-20 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-21 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-22 00:00:00', 10.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-23 00:00:00', 12.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-24 00:00:00', 13.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-25 00:00:00', 13.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-26 00:00:00', 14.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-27 00:00:00', 15.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-28 00:00:00', 19.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-29 00:00:00', 15.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-30 00:00:00', 19.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-03-31 00:00:00', 15.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-01 00:00:00', 16.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-02 00:00:00', 20.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-03 00:00:00', 21.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-04 00:00:00', 22.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-05 00:00:00', 21.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-06 00:00:00', 19.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-07 00:00:00', 20.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-08 00:00:00', 21.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-09 00:00:00', 19.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-10 00:00:00', 20.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-11 00:00:00', 18.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-12 00:00:00', 18.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-13 00:00:00', 20.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-14 00:00:00', 21.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-15 00:00:00', 22.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-16 00:00:00', 23.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-17 00:00:00', 23.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-18 00:00:00', 25.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-19 00:00:00', 26.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-20 00:00:00', 22.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-21 00:00:00', 17.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-22 00:00:00', 17.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-23 00:00:00', 18.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-24 00:00:00', 20.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-25 00:00:00', 17.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-26 00:00:00', 18.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-27 00:00:00', 18.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-28 00:00:00', 14.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-29 00:00:00', 17.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-04-30 00:00:00', 16.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-01 00:00:00', 18.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-02 00:00:00', 17.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-03 00:00:00', 20.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-04 00:00:00', 22.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-05 00:00:00', 22.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-06 00:00:00', 22.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-07 00:00:00', 20.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-08 00:00:00', 21.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-09 00:00:00', 26.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-10 00:00:00', 22.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-11 00:00:00', 20.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-12 00:00:00', 19.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-13 00:00:00', 21.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-14 00:00:00', 23.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-15 00:00:00', 23.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-16 00:00:00', 23.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-17 00:00:00', 21.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-18 00:00:00', 20.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-19 00:00:00', 23.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-20 00:00:00', 21.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-21 00:00:00', 21.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-22 00:00:00', 21.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-23 00:00:00', 24.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-24 00:00:00', 26.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-25 00:00:00', 20.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-26 00:00:00', 22.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-27 00:00:00', 24.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-28 00:00:00', 28.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-29 00:00:00', 27.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-30 00:00:00', 28.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-05-31 00:00:00', 28.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-01 00:00:00', 28.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-02 00:00:00', 29.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-03 00:00:00', 31.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-04 00:00:00', 29.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-05 00:00:00', 26.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-06 00:00:00', 27.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-07 00:00:00', 29.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-08 00:00:00', 29.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-09 00:00:00', 29.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-10 00:00:00', 29.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-11 00:00:00', 28.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-12 00:00:00', 29.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-13 00:00:00', 28.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-14 00:00:00', 30.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-15 00:00:00', 32.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-16 00:00:00', 32.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-17 00:00:00', 33.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-18 00:00:00', 35.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-19 00:00:00', 34.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-20 00:00:00', 33.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-21 00:00:00', 32.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-22 00:00:00', 28.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-23 00:00:00', 29.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-24 00:00:00', 28.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-25 00:00:00', 28.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-26 00:00:00', 29.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-27 00:00:00', 29.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-28 00:00:00', 32.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-29 00:00:00', 33.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-06-30 00:00:00', 34.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-01 00:00:00', 35.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-02 00:00:00', 37.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-03 00:00:00', 36.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-04 00:00:00', 36.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-05 00:00:00', 36.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-06 00:00:00', 35.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-07 00:00:00', 35.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-08 00:00:00', 36.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-09 00:00:00', 36.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-10 00:00:00', 37.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-11 00:00:00', 39.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-12 00:00:00', 36.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-13 00:00:00', 34.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-14 00:00:00', 33.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-15 00:00:00', 33.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-16 00:00:00', 34.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-17 00:00:00', 34.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-18 00:00:00', 35.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-19 00:00:00', 34.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-20 00:00:00', 34.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-21 00:00:00', 35.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-22 00:00:00', 35.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-23 00:00:00', 34.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-24 00:00:00', 34.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-25 00:00:00', 33.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-26 00:00:00', 33.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-27 00:00:00', 30.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-28 00:00:00', 31.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-29 00:00:00', 33.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-30 00:00:00', 34.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-07-31 00:00:00', 35.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-01 00:00:00', 34.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-02 00:00:00', 33.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-03 00:00:00', 31.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-04 00:00:00', 31.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-05 00:00:00', 33.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-06 00:00:00', 34.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-07 00:00:00', 35.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-08 00:00:00', 35.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-09 00:00:00', 35.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-10 00:00:00', 35.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-11 00:00:00', 34.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-12 00:00:00', 33.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-13 00:00:00', 33.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-14 00:00:00', 34.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-15 00:00:00', 35.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-16 00:00:00', 35.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-17 00:00:00', 36.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-18 00:00:00', 37.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-19 00:00:00', 37.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-20 00:00:00', 36.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-21 00:00:00', 37.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-22 00:00:00', 37.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-23 00:00:00', 36.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-24 00:00:00', 33.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-25 00:00:00', 31.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-26 00:00:00', 31.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-27 00:00:00', 31.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-28 00:00:00', 32.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-29 00:00:00', 34.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-30 00:00:00', 34.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-08-31 00:00:00', 34.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-01 00:00:00', 33.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-02 00:00:00', 33.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-03 00:00:00', 32.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-04 00:00:00', 28.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-05 00:00:00', 27.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-06 00:00:00', 30.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-07 00:00:00', 28.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-08 00:00:00', 30.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-09 00:00:00', 31.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-10 00:00:00', 32.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-11 00:00:00', 33.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-12 00:00:00', 31.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-13 00:00:00', 29.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-14 00:00:00', 27.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-15 00:00:00', 27.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-16 00:00:00', 26.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-17 00:00:00', 25.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-18 00:00:00', 26.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-19 00:00:00', 27.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-20 00:00:00', 26.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-21 00:00:00', 26.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-22 00:00:00', 26.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-23 00:00:00', 26.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-24 00:00:00', 27.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-25 00:00:00', 26.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-26 00:00:00', 26.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-27 00:00:00', 27.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-28 00:00:00', 26.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-29 00:00:00', 25.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-09-30 00:00:00', 21.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-01 00:00:00', 24.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-02 00:00:00', 23.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-03 00:00:00', 22.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-04 00:00:00', 21.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-05 00:00:00', 22.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-06 00:00:00', 23.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-07 00:00:00', 25.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-08 00:00:00', 24.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-09 00:00:00', 24.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-10 00:00:00', 25.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-11 00:00:00', 25.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-12 00:00:00', 24.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-13 00:00:00', 25.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-14 00:00:00', 15.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-15 00:00:00', 17.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-16 00:00:00', 19.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-17 00:00:00', 17.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-18 00:00:00', 17.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-19 00:00:00', 16.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-20 00:00:00', 14.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-21 00:00:00', 15.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-22 00:00:00', 17.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-23 00:00:00', 18.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-24 00:00:00', 19.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-25 00:00:00', 18.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-26 00:00:00', 17.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-27 00:00:00', 18.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-28 00:00:00', 19.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-29 00:00:00', 20.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-30 00:00:00', 24.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-10-31 00:00:00', 20.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-01 00:00:00', 14.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-02 00:00:00', 16.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-03 00:00:00', 18.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-04 00:00:00', 11.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-05 00:00:00', 12.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-06 00:00:00', 15.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-07 00:00:00', 16.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-08 00:00:00', 18.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-09 00:00:00', 18.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-10 00:00:00', 18.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-11 00:00:00', 19.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-12 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-13 00:00:00', 10.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-14 00:00:00', 15.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-15 00:00:00', 15.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-16 00:00:00', 8.04800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-17 00:00:00', 10.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-18 00:00:00', 9.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-19 00:00:00', 9.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-20 00:00:00', 7.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-21 00:00:00', 8.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-22 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-23 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-24 00:00:00', 5.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-25 00:00:00', 9.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-26 00:00:00', 7.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-27 00:00:00', 12.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-28 00:00:00', 6.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-29 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-11-30 00:00:00', 7.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-01 00:00:00', 10.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-02 00:00:00', 10.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-03 00:00:00', 11.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-04 00:00:00', 13.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-05 00:00:00', 14.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-06 00:00:00', 14.8730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-07 00:00:00', 11.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-08 00:00:00', 9.93999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-09 00:00:00', 12.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-10 00:00:00', 9.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-11 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-12 00:00:00', 6.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-13 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-14 00:00:00', 2.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-15 00:00:00', 2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-16 00:00:00', 1.55700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-17 00:00:00', 4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-18 00:00:00', -1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-19 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-20 00:00:00', 5.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-21 00:00:00', 8.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-22 00:00:00', 12.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-23 00:00:00', 7.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-24 00:00:00', 7.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-25 00:00:00', 9.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-26 00:00:00', 4.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-27 00:00:00', 1.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-28 00:00:00', -9.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-29 00:00:00', -4.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-30 00:00:00', 1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2012-12-31 00:00:00', 1.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-01 00:00:00', -5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-02 00:00:00', -0.00600000005215406418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-03 00:00:00', -1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-04 00:00:00', -1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-05 00:00:00', -0.0900000035762786865, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-06 00:00:00', 0.671999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-07 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-08 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-09 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-10 00:00:00', 4.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-11 00:00:00', 9.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-12 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-13 00:00:00', 0.381999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-14 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-15 00:00:00', 2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-16 00:00:00', -0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-17 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-18 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-19 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-20 00:00:00', 5.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-21 00:00:00', 6.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-22 00:00:00', 2.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-23 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-24 00:00:00', 8.57699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-25 00:00:00', 8.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-26 00:00:00', 9.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-27 00:00:00', 7.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-28 00:00:00', 10.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-29 00:00:00', 10.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-30 00:00:00', 12.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-01-31 00:00:00', 9.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-01 00:00:00', 10.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-02 00:00:00', 8.40699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-03 00:00:00', 7.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-04 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-05 00:00:00', 1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-06 00:00:00', 5.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-07 00:00:00', 9.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-08 00:00:00', 11.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-09 00:00:00', 6.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-10 00:00:00', 7.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-11 00:00:00', 7.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-12 00:00:00', 7.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-13 00:00:00', 8.65400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-14 00:00:00', 11.1190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-15 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-16 00:00:00', 8.02999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-17 00:00:00', 11.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-18 00:00:00', 6.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-19 00:00:00', 5.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-20 00:00:00', 10.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-21 00:00:00', 9.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-22 00:00:00', 9.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-23 00:00:00', 8.59099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-24 00:00:00', 10.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-25 00:00:00', 11.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-26 00:00:00', 6.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-27 00:00:00', -0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-02-28 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-01 00:00:00', 12.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-02 00:00:00', 16.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-03 00:00:00', 14.6470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-04 00:00:00', 13.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-05 00:00:00', 18.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-06 00:00:00', 21.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-07 00:00:00', 10.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-08 00:00:00', 5.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-09 00:00:00', 4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-10 00:00:00', 10.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-11 00:00:00', 14.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-12 00:00:00', 14.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-13 00:00:00', 11.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-14 00:00:00', 16.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-15 00:00:00', 16.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-16 00:00:00', 10.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-17 00:00:00', 12.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-18 00:00:00', 13.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-19 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-20 00:00:00', 17.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-21 00:00:00', 12.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-22 00:00:00', 14.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-23 00:00:00', 9.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-24 00:00:00', 11.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-25 00:00:00', 18.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-26 00:00:00', 12.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-27 00:00:00', 17.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-28 00:00:00', 19.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-29 00:00:00', 19.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-30 00:00:00', 20.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-03-31 00:00:00', 10.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-01 00:00:00', 9.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-02 00:00:00', 13.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-03 00:00:00', 15.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-04 00:00:00', 17.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-05 00:00:00', 13.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-06 00:00:00', 15.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-07 00:00:00', 18.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-08 00:00:00', 21.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-09 00:00:00', 21.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-10 00:00:00', 23.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-11 00:00:00', 24.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-12 00:00:00', 24.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-13 00:00:00', 19.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-14 00:00:00', 22.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-15 00:00:00', 13.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-16 00:00:00', 12.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-17 00:00:00', 16.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-18 00:00:00', 19.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-19 00:00:00', 18.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-20 00:00:00', 19.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-21 00:00:00', 21.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-22 00:00:00', 24.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-23 00:00:00', 22.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-24 00:00:00', 18.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-25 00:00:00', 17.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-26 00:00:00', 12.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-27 00:00:00', 19.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-28 00:00:00', 14.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-29 00:00:00', 8.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-04-30 00:00:00', 12.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-01 00:00:00', 17.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-02 00:00:00', 20.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-03 00:00:00', 19.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-04 00:00:00', 21.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-05 00:00:00', 22.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-06 00:00:00', 23.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-07 00:00:00', 24.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-08 00:00:00', 23.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-09 00:00:00', 24.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-10 00:00:00', 25.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-11 00:00:00', 23.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-12 00:00:00', 23.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-13 00:00:00', 22.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-14 00:00:00', 25.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-15 00:00:00', 27.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-16 00:00:00', 29.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-17 00:00:00', 30.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-18 00:00:00', 32.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-19 00:00:00', 23.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-20 00:00:00', 27.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-21 00:00:00', 24.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-22 00:00:00', 27.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-23 00:00:00', 28.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-24 00:00:00', 26.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-25 00:00:00', 21.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-26 00:00:00', 20.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-27 00:00:00', 21.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-28 00:00:00', 25.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-29 00:00:00', 28.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-30 00:00:00', 31.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-05-31 00:00:00', 33.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-01 00:00:00', 34.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-02 00:00:00', 31.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-03 00:00:00', 30.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-04 00:00:00', 30.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-05 00:00:00', 30.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-06 00:00:00', 32.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-07 00:00:00', 32.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-08 00:00:00', 37.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-09 00:00:00', 35.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-10 00:00:00', 34.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-11 00:00:00', 34.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-12 00:00:00', 34.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-13 00:00:00', 34.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-14 00:00:00', 30.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-15 00:00:00', 29.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-16 00:00:00', 30.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-17 00:00:00', 29.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-18 00:00:00', 31.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-19 00:00:00', 34.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-20 00:00:00', 36.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-21 00:00:00', 37.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-22 00:00:00', 37.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-23 00:00:00', 36.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-24 00:00:00', 37.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-25 00:00:00', 37.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-26 00:00:00', 38.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-27 00:00:00', 29.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-28 00:00:00', 30.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-29 00:00:00', 30.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-06-30 00:00:00', 30.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-01 00:00:00', 31.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-02 00:00:00', 32.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-03 00:00:00', 35.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-04 00:00:00', 37.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-05 00:00:00', 35.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-06 00:00:00', 32.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-07 00:00:00', 31.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-08 00:00:00', 32.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-09 00:00:00', 31.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-10 00:00:00', 32.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-11 00:00:00', 32.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-12 00:00:00', 33.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-13 00:00:00', 36.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-14 00:00:00', 34.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-15 00:00:00', 34.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-16 00:00:00', 34.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-17 00:00:00', 34.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-18 00:00:00', 36.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-19 00:00:00', 37.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-20 00:00:00', 38.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-21 00:00:00', 38.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-22 00:00:00', 33.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-23 00:00:00', 34.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-24 00:00:00', 35.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-25 00:00:00', 35.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-26 00:00:00', 37.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-27 00:00:00', 39.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-28 00:00:00', 40.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-29 00:00:00', 41.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-30 00:00:00', 40.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-07-31 00:00:00', 39.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-01 00:00:00', 37.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-02 00:00:00', 37.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-03 00:00:00', 37.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-04 00:00:00', 37.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-05 00:00:00', 36.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-06 00:00:00', 38.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-07 00:00:00', 35.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-08 00:00:00', 32.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-09 00:00:00', 32.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-10 00:00:00', 33.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-11 00:00:00', 32.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-12 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-13 00:00:00', 30.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-14 00:00:00', 30.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-15 00:00:00', 32.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-16 00:00:00', 32.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-17 00:00:00', 33.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-18 00:00:00', 32.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-19 00:00:00', 32.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-20 00:00:00', 33.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-21 00:00:00', 33.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-22 00:00:00', 34.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-23 00:00:00', 34.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-24 00:00:00', 33.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-25 00:00:00', 32.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-26 00:00:00', 34.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-27 00:00:00', 33.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-28 00:00:00', 34.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-29 00:00:00', 34.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-30 00:00:00', 30.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-08-31 00:00:00', 30.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-01 00:00:00', 31.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-02 00:00:00', 31.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-03 00:00:00', 31.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-04 00:00:00', 31.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-05 00:00:00', 33.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-06 00:00:00', 35.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-07 00:00:00', 34.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-08 00:00:00', 34.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-09 00:00:00', 34.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-10 00:00:00', 34.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-11 00:00:00', 33.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-12 00:00:00', 30.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-13 00:00:00', 29.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-14 00:00:00', 28.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-15 00:00:00', 26.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-16 00:00:00', 24.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-17 00:00:00', 28.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-18 00:00:00', 29.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-19 00:00:00', 32.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-20 00:00:00', 33.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-21 00:00:00', 33.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-22 00:00:00', 32.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-23 00:00:00', 32.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-24 00:00:00', 32.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-25 00:00:00', 34.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-26 00:00:00', 35.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-27 00:00:00', 28.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-28 00:00:00', 29.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-29 00:00:00', 30.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-09-30 00:00:00', 29.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-01 00:00:00', 29.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-02 00:00:00', 29.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-03 00:00:00', 31.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-04 00:00:00', 31.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-05 00:00:00', 32.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-06 00:00:00', 32.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-07 00:00:00', 31.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-08 00:00:00', 28.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-09 00:00:00', 23.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-10 00:00:00', 19.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-11 00:00:00', 20.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-12 00:00:00', 22.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-13 00:00:00', 22.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-14 00:00:00', 23.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-15 00:00:00', 21.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-16 00:00:00', 21.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-17 00:00:00', 21.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-18 00:00:00', 23.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-19 00:00:00', 25.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-20 00:00:00', 25.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-21 00:00:00', 25.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-22 00:00:00', 18.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-23 00:00:00', 14.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-24 00:00:00', 20.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-25 00:00:00', 18.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-26 00:00:00', 9.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-27 00:00:00', 12.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-28 00:00:00', 17.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-29 00:00:00', 20.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-30 00:00:00', 9.39299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-10-31 00:00:00', 11.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-01 00:00:00', 10.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-02 00:00:00', 14.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-03 00:00:00', 16.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-04 00:00:00', 13.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-05 00:00:00', 12.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-06 00:00:00', 9.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-07 00:00:00', 9.28400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-08 00:00:00', 14.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-09 00:00:00', 15.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-10 00:00:00', 14.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-11 00:00:00', 14.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-12 00:00:00', 11.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-13 00:00:00', 13.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-14 00:00:00', 15.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-15 00:00:00', 17.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-16 00:00:00', 13.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-17 00:00:00', 14.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-18 00:00:00', 17.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-19 00:00:00', 12.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-20 00:00:00', 7.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-21 00:00:00', 8.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-22 00:00:00', 13.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-23 00:00:00', 10.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-24 00:00:00', 10.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-25 00:00:00', 13.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-26 00:00:00', 11.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-27 00:00:00', 12.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-28 00:00:00', 14.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-29 00:00:00', 14.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-11-30 00:00:00', 17.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-01 00:00:00', 13.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-02 00:00:00', 6.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-03 00:00:00', 12.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-04 00:00:00', 13.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-05 00:00:00', 9.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-06 00:00:00', 7.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-07 00:00:00', 6.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-08 00:00:00', 10.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-09 00:00:00', 10.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-10 00:00:00', 12.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-11 00:00:00', 6.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-12 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-13 00:00:00', 11.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-14 00:00:00', 15.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-15 00:00:00', 15.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-16 00:00:00', 8.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-17 00:00:00', 2.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-18 00:00:00', 0.391999989748001099, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-19 00:00:00', 2.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-20 00:00:00', 4.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-21 00:00:00', -1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-22 00:00:00', -0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-23 00:00:00', 1.64900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-24 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-25 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-26 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-27 00:00:00', -2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-28 00:00:00', -4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-29 00:00:00', -6.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-30 00:00:00', -6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2013-12-31 00:00:00', -2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-01 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-02 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-03 00:00:00', 0.107000000774860382, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-04 00:00:00', 0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-05 00:00:00', -0.395999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-06 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-07 00:00:00', 1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-08 00:00:00', -2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-09 00:00:00', -1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-10 00:00:00', -1.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-11 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-12 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-13 00:00:00', 1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-14 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-15 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-16 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-17 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-18 00:00:00', 8.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-19 00:00:00', 8.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-20 00:00:00', 10.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-21 00:00:00', 3.50200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-22 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-23 00:00:00', 3.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-24 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-25 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-26 00:00:00', 8.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-27 00:00:00', 8.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-28 00:00:00', 11.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-29 00:00:00', 12.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-30 00:00:00', 6.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-01-31 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-01 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-02 00:00:00', -10.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-03 00:00:00', -11.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-04 00:00:00', -6.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-05 00:00:00', -4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-06 00:00:00', -5.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-07 00:00:00', -4.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-08 00:00:00', -2.34599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-09 00:00:00', -0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-10 00:00:00', -2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-11 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-12 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-13 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-14 00:00:00', -1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-15 00:00:00', 0.439999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-16 00:00:00', 4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-17 00:00:00', 7.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-18 00:00:00', 6.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-19 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-20 00:00:00', 5.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-21 00:00:00', 8.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-22 00:00:00', 9.93299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-23 00:00:00', 4.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-24 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-25 00:00:00', 7.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-26 00:00:00', 5.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-27 00:00:00', 7.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-02-28 00:00:00', 9.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-01 00:00:00', 11.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-02 00:00:00', 12.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-03 00:00:00', 9.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-04 00:00:00', 10.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-05 00:00:00', 12.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-06 00:00:00', 7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-07 00:00:00', 6.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-08 00:00:00', 10.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-09 00:00:00', 5.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-10 00:00:00', 5.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-11 00:00:00', 7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-12 00:00:00', 13.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-13 00:00:00', 14.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-14 00:00:00', 7.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-15 00:00:00', 5.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-16 00:00:00', 13.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-17 00:00:00', 8.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-18 00:00:00', 10.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-19 00:00:00', 14.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-20 00:00:00', 11.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-21 00:00:00', 10.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-22 00:00:00', 14.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-23 00:00:00', 7.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-24 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-25 00:00:00', 7.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-26 00:00:00', 11.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-27 00:00:00', 11.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-28 00:00:00', 14.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-29 00:00:00', 16.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-30 00:00:00', 18.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-03-31 00:00:00', 20.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-01 00:00:00', 19.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-02 00:00:00', 15.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-03 00:00:00', 17.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-04 00:00:00', 11.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-05 00:00:00', 9.52900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-06 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-07 00:00:00', 11.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-08 00:00:00', 14.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-09 00:00:00', 17.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-10 00:00:00', 17.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-11 00:00:00', 14.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-12 00:00:00', 11.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-13 00:00:00', 12.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-14 00:00:00', 16.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-15 00:00:00', 20.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-16 00:00:00', 16.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-17 00:00:00', 16.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-18 00:00:00', 17.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-19 00:00:00', 18.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-20 00:00:00', 19.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-21 00:00:00', 20.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-22 00:00:00', 22.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-23 00:00:00', 22.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-24 00:00:00', 16.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-25 00:00:00', 16.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-26 00:00:00', 17.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-27 00:00:00', 23.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-28 00:00:00', 24.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-29 00:00:00', 21.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-04-30 00:00:00', 25.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-01 00:00:00', 23.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-02 00:00:00', 26.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-03 00:00:00', 26.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-04 00:00:00', 22.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-05 00:00:00', 23.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-06 00:00:00', 22.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-07 00:00:00', 25.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-08 00:00:00', 17.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-09 00:00:00', 16.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-10 00:00:00', 22.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-11 00:00:00', 22.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-12 00:00:00', 21.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-13 00:00:00', 21.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-14 00:00:00', 23.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-15 00:00:00', 26.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-16 00:00:00', 26.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-17 00:00:00', 27.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-18 00:00:00', 17.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-19 00:00:00', 22.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-20 00:00:00', 25.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-21 00:00:00', 24.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-22 00:00:00', 23.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-23 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-24 00:00:00', 24.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-25 00:00:00', 27.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-26 00:00:00', 26.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-27 00:00:00', 28.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-28 00:00:00', 29.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-29 00:00:00', 29.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-30 00:00:00', 19.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-05-31 00:00:00', 23.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-01 00:00:00', 22.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-02 00:00:00', 25.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-03 00:00:00', 25.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-04 00:00:00', 25.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-05 00:00:00', 29.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-06 00:00:00', 28.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-07 00:00:00', 26.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-08 00:00:00', 26.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-09 00:00:00', 28.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-10 00:00:00', 28.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-11 00:00:00', 29.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-12 00:00:00', 31.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-13 00:00:00', 34.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-14 00:00:00', 34.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-15 00:00:00', 31.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-16 00:00:00', 30.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-17 00:00:00', 29.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-18 00:00:00', 30.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-19 00:00:00', 32.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-20 00:00:00', 33.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-21 00:00:00', 34.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-22 00:00:00', 34.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-23 00:00:00', 35.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-24 00:00:00', 34.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-25 00:00:00', 35.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-26 00:00:00', 35.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-27 00:00:00', 37.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-28 00:00:00', 38.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-29 00:00:00', 37.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-06-30 00:00:00', 37.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-01 00:00:00', 37.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-02 00:00:00', 33.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-03 00:00:00', 31.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-04 00:00:00', 31.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-05 00:00:00', 32.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-06 00:00:00', 32.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-07 00:00:00', 34.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-08 00:00:00', 34.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-09 00:00:00', 35.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-10 00:00:00', 36.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-11 00:00:00', 37.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-12 00:00:00', 37.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-13 00:00:00', 35.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-14 00:00:00', 34.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-15 00:00:00', 35.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-16 00:00:00', 32.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-17 00:00:00', 31.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-18 00:00:00', 31.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-19 00:00:00', 32.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-20 00:00:00', 33.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-21 00:00:00', 36.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-22 00:00:00', 38.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-23 00:00:00', 40.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-24 00:00:00', 34.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-25 00:00:00', 35.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-26 00:00:00', 36.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-27 00:00:00', 36.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-28 00:00:00', 39.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-29 00:00:00', 35.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-30 00:00:00', 33.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (38, '2014-07-31 00:00:00', 32.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-01 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-02 00:00:00', 5.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-03 00:00:00', 9.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-04 00:00:00', 10.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-05 00:00:00', 14.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-06 00:00:00', 11.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-07 00:00:00', 10.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-08 00:00:00', 8.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-09 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-10 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-11 00:00:00', 7.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-12 00:00:00', 11.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-13 00:00:00', 4.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-14 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-15 00:00:00', 4.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-16 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-17 00:00:00', 3.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-18 00:00:00', 0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-19 00:00:00', 1.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-20 00:00:00', 1.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-21 00:00:00', 1.36300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-22 00:00:00', 4.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-23 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-24 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-25 00:00:00', 4.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-26 00:00:00', -0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-27 00:00:00', -2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-28 00:00:00', -2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-29 00:00:00', -5.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-30 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-01-31 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-01 00:00:00', 5.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-02 00:00:00', 5.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-03 00:00:00', 7.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-04 00:00:00', 7.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-05 00:00:00', 7.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-06 00:00:00', 5.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-07 00:00:00', 9.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-08 00:00:00', 8.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-09 00:00:00', 10.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-10 00:00:00', 6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-11 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-12 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-13 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-14 00:00:00', 3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-15 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-16 00:00:00', 5.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-17 00:00:00', 5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-18 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-19 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-20 00:00:00', -2.75200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-21 00:00:00', 2.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-22 00:00:00', 1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-23 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-24 00:00:00', 4.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-25 00:00:00', 5.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-26 00:00:00', 5.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-27 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-02-28 00:00:00', 3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-01 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-02 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-03 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-04 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-05 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-06 00:00:00', -1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-07 00:00:00', -1.02199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-08 00:00:00', -0.820999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-09 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-10 00:00:00', 6.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-11 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-12 00:00:00', 8.57699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-13 00:00:00', 8.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-14 00:00:00', 9.81000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-15 00:00:00', 10.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-16 00:00:00', 10.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-17 00:00:00', 12.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-18 00:00:00', 12.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-19 00:00:00', 12.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-20 00:00:00', 14.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-21 00:00:00', 14.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-22 00:00:00', 15.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-23 00:00:00', 16.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-24 00:00:00', 19.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-25 00:00:00', 16.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-26 00:00:00', 16.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-27 00:00:00', 17.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-28 00:00:00', 17.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-29 00:00:00', 14.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-30 00:00:00', 7.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-03-31 00:00:00', 11.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-01 00:00:00', 16.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-02 00:00:00', 12.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-03 00:00:00', 14.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-04 00:00:00', 13.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-05 00:00:00', 15.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-06 00:00:00', 18.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-07 00:00:00', 15.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-08 00:00:00', 19.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-09 00:00:00', 20.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-10 00:00:00', 26.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-11 00:00:00', 23.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-12 00:00:00', 21.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-13 00:00:00', 21.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-14 00:00:00', 12.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-15 00:00:00', 10.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-16 00:00:00', 11.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-17 00:00:00', 12.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-18 00:00:00', 5.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-19 00:00:00', 6.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-20 00:00:00', 8.46800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-21 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-22 00:00:00', 10.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-23 00:00:00', 16.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-24 00:00:00', 20.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-25 00:00:00', 15.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-26 00:00:00', 15.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-27 00:00:00', 12.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-28 00:00:00', 12.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-29 00:00:00', 18.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-04-30 00:00:00', 12.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-01 00:00:00', 12.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-02 00:00:00', 13.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-03 00:00:00', 15.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-04 00:00:00', 20.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-05 00:00:00', 19.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-06 00:00:00', 22.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-07 00:00:00', 17.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-08 00:00:00', 19.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-09 00:00:00', 6.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-10 00:00:00', 16.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-11 00:00:00', 16.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-12 00:00:00', 7.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-13 00:00:00', 7.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-14 00:00:00', 11.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-15 00:00:00', 12.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-16 00:00:00', 16.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-17 00:00:00', 16.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-18 00:00:00', 15.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-19 00:00:00', 15.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-20 00:00:00', 18.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-21 00:00:00', 18.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-22 00:00:00', 23.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-23 00:00:00', 23.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-24 00:00:00', 20.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-25 00:00:00', 13.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-26 00:00:00', 20.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-27 00:00:00', 15.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-28 00:00:00', 18.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-29 00:00:00', 21.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-30 00:00:00', 23.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-05-31 00:00:00', 24.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-01 00:00:00', 25.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-02 00:00:00', 24.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-03 00:00:00', 26.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-04 00:00:00', 27.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-05 00:00:00', 26.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-06 00:00:00', 28.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-07 00:00:00', 28.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-08 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-09 00:00:00', 30.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-10 00:00:00', 33.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-11 00:00:00', 26.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-12 00:00:00', 27.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-13 00:00:00', 27.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-14 00:00:00', 29.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-15 00:00:00', 30.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-16 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-17 00:00:00', 32.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-18 00:00:00', 31.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-19 00:00:00', 31.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-20 00:00:00', 32.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-21 00:00:00', 33.6570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-22 00:00:00', 34.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-23 00:00:00', 36.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-24 00:00:00', 37.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-25 00:00:00', 37.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-26 00:00:00', 38.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-27 00:00:00', 36.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-28 00:00:00', 32.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-29 00:00:00', 33.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-06-30 00:00:00', 34.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-01 00:00:00', 34.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-02 00:00:00', 34.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-03 00:00:00', 34.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-04 00:00:00', 34.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-05 00:00:00', 35.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-06 00:00:00', 37.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-07 00:00:00', 38.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-08 00:00:00', 40.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-09 00:00:00', 43.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-10 00:00:00', 43.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-11 00:00:00', 40.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-12 00:00:00', 38.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-13 00:00:00', 36.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-14 00:00:00', 37.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-15 00:00:00', 39.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-16 00:00:00', 40.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-17 00:00:00', 40.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-18 00:00:00', 41.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-19 00:00:00', 41.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-20 00:00:00', 40.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-21 00:00:00', 35.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-22 00:00:00', 36.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-23 00:00:00', 35.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-24 00:00:00', 36.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-25 00:00:00', 37.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-26 00:00:00', 38.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-27 00:00:00', 37.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-28 00:00:00', 38.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-29 00:00:00', 40.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-30 00:00:00', 40.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-07-31 00:00:00', 42.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-01 00:00:00', 42.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-02 00:00:00', 41.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-03 00:00:00', 38.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-04 00:00:00', 37.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-05 00:00:00', 33.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-06 00:00:00', 35.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-07 00:00:00', 31.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-08 00:00:00', 35.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-09 00:00:00', 36.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-10 00:00:00', 36.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-11 00:00:00', 37.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-12 00:00:00', 37.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-13 00:00:00', 37.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-14 00:00:00', 37.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-15 00:00:00', 37.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-16 00:00:00', 37.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-17 00:00:00', 37.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-18 00:00:00', 39.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-19 00:00:00', 38.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-20 00:00:00', 31.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-21 00:00:00', 31.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-22 00:00:00', 30.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-23 00:00:00', 30.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-24 00:00:00', 32.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-25 00:00:00', 32.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-26 00:00:00', 33.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-27 00:00:00', 32.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-28 00:00:00', 27.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-29 00:00:00', 30.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-30 00:00:00', 30.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-08-31 00:00:00', 32.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-01 00:00:00', 32.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-02 00:00:00', 31.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-03 00:00:00', 32.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-04 00:00:00', 33.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-05 00:00:00', 34.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-06 00:00:00', 34.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-07 00:00:00', 35.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-08 00:00:00', 36.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-09 00:00:00', 34.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-10 00:00:00', 34.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-11 00:00:00', 35.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-12 00:00:00', 36.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-13 00:00:00', 32.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-14 00:00:00', 32.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-15 00:00:00', 30.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-16 00:00:00', 29.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-17 00:00:00', 29.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-18 00:00:00', 30.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-19 00:00:00', 30.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-20 00:00:00', 31.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-21 00:00:00', 30.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-22 00:00:00', 28.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-23 00:00:00', 25.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-24 00:00:00', 25.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-25 00:00:00', 27.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-26 00:00:00', 28.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-27 00:00:00', 27.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-28 00:00:00', 27.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-29 00:00:00', 27.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-09-30 00:00:00', 28.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-01 00:00:00', 28.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-02 00:00:00', 28.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-03 00:00:00', 28.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-04 00:00:00', 29.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-05 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-06 00:00:00', 30.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-07 00:00:00', 30.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-08 00:00:00', 29.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-09 00:00:00', 24.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-10 00:00:00', 22.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-11 00:00:00', 22.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-12 00:00:00', 23.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-13 00:00:00', 25.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-14 00:00:00', 27.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-15 00:00:00', 27.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-16 00:00:00', 26.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-17 00:00:00', 26.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-18 00:00:00', 27.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-19 00:00:00', 27.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-20 00:00:00', 21.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-21 00:00:00', 26.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-22 00:00:00', 26.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-23 00:00:00', 27.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-24 00:00:00', 29.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-25 00:00:00', 30.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-26 00:00:00', 29.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-27 00:00:00', 28.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-28 00:00:00', 23.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-29 00:00:00', 25.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-30 00:00:00', 21.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-10-31 00:00:00', 22.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-01 00:00:00', 20.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-02 00:00:00', 25.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-03 00:00:00', 25.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-04 00:00:00', 25.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-05 00:00:00', 17.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-06 00:00:00', 7.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-07 00:00:00', 7.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-08 00:00:00', 8.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-09 00:00:00', 15.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-10 00:00:00', 16.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-11 00:00:00', 11.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-12 00:00:00', 11.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-13 00:00:00', 6.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-14 00:00:00', 10.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-15 00:00:00', 13.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-16 00:00:00', 14.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-17 00:00:00', 15.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-18 00:00:00', 14.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-19 00:00:00', 12.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-20 00:00:00', 9.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-21 00:00:00', 8.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-22 00:00:00', 9.82400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-23 00:00:00', 12.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-24 00:00:00', 13.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-25 00:00:00', 14.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-26 00:00:00', 16.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-27 00:00:00', 17.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-28 00:00:00', 18.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-29 00:00:00', 19.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-11-30 00:00:00', 21.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-01 00:00:00', 19.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-02 00:00:00', 16.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-03 00:00:00', 8.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-04 00:00:00', 9.49899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-05 00:00:00', 10.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-06 00:00:00', 13.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-07 00:00:00', 15.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-08 00:00:00', 13.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-09 00:00:00', 13.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-10 00:00:00', 11.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-11 00:00:00', 8.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-12 00:00:00', 10.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-13 00:00:00', 13.3629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-14 00:00:00', 12.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-15 00:00:00', 10.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-16 00:00:00', 14.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-17 00:00:00', 9.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-18 00:00:00', 5.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-19 00:00:00', 5.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-20 00:00:00', 6.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-21 00:00:00', 9.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-22 00:00:00', 4.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-23 00:00:00', -0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-24 00:00:00', 6.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-25 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-26 00:00:00', 6.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-27 00:00:00', 6.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-28 00:00:00', 6.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-29 00:00:00', 5.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-30 00:00:00', 4.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1979-12-31 00:00:00', 5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-01 00:00:00', 3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-02 00:00:00', 4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-03 00:00:00', 5.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-04 00:00:00', 6.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-05 00:00:00', 6.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-06 00:00:00', 8.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-07 00:00:00', 9.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-08 00:00:00', 7.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-09 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-10 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-11 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-12 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-13 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-14 00:00:00', 6.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-15 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-16 00:00:00', -0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-17 00:00:00', 4.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-18 00:00:00', 5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-19 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-20 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-21 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-22 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-23 00:00:00', 3.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-24 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-25 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-26 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-27 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-28 00:00:00', -0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-29 00:00:00', 3.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-30 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-01-31 00:00:00', 2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-01 00:00:00', -1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-02 00:00:00', -6.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-03 00:00:00', -7.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-04 00:00:00', -8.23900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-05 00:00:00', -0.374000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-06 00:00:00', 0.397000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-07 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-08 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-09 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-10 00:00:00', 3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-11 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-12 00:00:00', 8.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-13 00:00:00', 6.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-14 00:00:00', 4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-15 00:00:00', 8.31000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-16 00:00:00', 9.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-17 00:00:00', 7.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-18 00:00:00', 9.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-19 00:00:00', 6.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-20 00:00:00', 3.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-21 00:00:00', 4.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-22 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-23 00:00:00', 3.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-24 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-25 00:00:00', 3.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-26 00:00:00', 3.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-27 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-28 00:00:00', 1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-02-29 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-01 00:00:00', 6.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-02 00:00:00', 6.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-03 00:00:00', 6.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-04 00:00:00', 8.43500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-05 00:00:00', 2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-06 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-07 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-08 00:00:00', 2.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-09 00:00:00', 1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-10 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-11 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-12 00:00:00', 7.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-13 00:00:00', 7.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-14 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-15 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-16 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-17 00:00:00', 3.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-18 00:00:00', 6.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-19 00:00:00', 14.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-20 00:00:00', 7.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-21 00:00:00', 12.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-22 00:00:00', 8.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-23 00:00:00', 9.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-24 00:00:00', 9.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-25 00:00:00', 9.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-26 00:00:00', 10.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-27 00:00:00', 11.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-28 00:00:00', 7.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-29 00:00:00', 10.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-30 00:00:00', 19.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-03-31 00:00:00', 11.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-01 00:00:00', 8.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-02 00:00:00', 6.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-03 00:00:00', 12.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-04 00:00:00', 16.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-05 00:00:00', 14.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-06 00:00:00', 15.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-07 00:00:00', 17.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-08 00:00:00', 22.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-09 00:00:00', 21.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-10 00:00:00', 24.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-11 00:00:00', 23.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-12 00:00:00', 21.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-13 00:00:00', 22.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-14 00:00:00', 23.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-15 00:00:00', 20.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-16 00:00:00', 22.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-17 00:00:00', 24.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-18 00:00:00', 11.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-19 00:00:00', 10.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-20 00:00:00', 11.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-21 00:00:00', 11.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-22 00:00:00', 13.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-23 00:00:00', 20.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-24 00:00:00', 22.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-25 00:00:00', 21.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-26 00:00:00', 23.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-27 00:00:00', 22.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-28 00:00:00', 20.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-29 00:00:00', 22.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-04-30 00:00:00', 25.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-01 00:00:00', 28.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-02 00:00:00', 26.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-03 00:00:00', 25.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-04 00:00:00', 28.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-05 00:00:00', 29.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-06 00:00:00', 31.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-07 00:00:00', 30.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-08 00:00:00', 20.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-09 00:00:00', 25.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-10 00:00:00', 26.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-11 00:00:00', 19.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-12 00:00:00', 20.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-13 00:00:00', 23.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-14 00:00:00', 25.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-15 00:00:00', 24.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-16 00:00:00', 26.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-17 00:00:00', 23.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-18 00:00:00', 25.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-19 00:00:00', 28.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-20 00:00:00', 26.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-21 00:00:00', 27.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-22 00:00:00', 30.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-23 00:00:00', 29.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-24 00:00:00', 31.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-25 00:00:00', 33.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-26 00:00:00', 33.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-27 00:00:00', 33.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-28 00:00:00', 32.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-29 00:00:00', 32.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-30 00:00:00', 33.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-05-31 00:00:00', 32.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-01 00:00:00', 28.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-02 00:00:00', 28.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-03 00:00:00', 30.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-04 00:00:00', 32.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-05 00:00:00', 33.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-06 00:00:00', 34.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-07 00:00:00', 36.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-08 00:00:00', 36.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-09 00:00:00', 38.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-10 00:00:00', 39.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-11 00:00:00', 39.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-12 00:00:00', 31.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-13 00:00:00', 29.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-14 00:00:00', 32.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-15 00:00:00', 34.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-16 00:00:00', 34.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-17 00:00:00', 37.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-18 00:00:00', 39.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-19 00:00:00', 38.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-20 00:00:00', 37.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-21 00:00:00', 36.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-22 00:00:00', 38.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-23 00:00:00', 38.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-24 00:00:00', 35.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-25 00:00:00', 33.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-26 00:00:00', 33.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-27 00:00:00', 34.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-28 00:00:00', 35.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-29 00:00:00', 36.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-06-30 00:00:00', 36.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-01 00:00:00', 37.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-02 00:00:00', 40.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-03 00:00:00', 40.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-04 00:00:00', 39.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-05 00:00:00', 39.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-06 00:00:00', 38.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-07 00:00:00', 39.7739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-08 00:00:00', 40.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-09 00:00:00', 41.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-10 00:00:00', 41.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-11 00:00:00', 40.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-12 00:00:00', 37.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-13 00:00:00', 37.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-14 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-15 00:00:00', 39.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-16 00:00:00', 39.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-17 00:00:00', 42.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-18 00:00:00', 39.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-19 00:00:00', 34.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-20 00:00:00', 35.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-21 00:00:00', 37.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-22 00:00:00', 36.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-23 00:00:00', 37.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-24 00:00:00', 38.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-25 00:00:00', 39.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-26 00:00:00', 38.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-27 00:00:00', 39.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-28 00:00:00', 39.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-29 00:00:00', 38.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-30 00:00:00', 39.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-07-31 00:00:00', 38.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-01 00:00:00', 39.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-02 00:00:00', 39.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-03 00:00:00', 38.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-04 00:00:00', 36.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-05 00:00:00', 37.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-06 00:00:00', 39.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-07 00:00:00', 38.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-08 00:00:00', 34.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-09 00:00:00', 36.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-10 00:00:00', 33.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-11 00:00:00', 34.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-12 00:00:00', 34.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-13 00:00:00', 35.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-14 00:00:00', 34.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-15 00:00:00', 34.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-16 00:00:00', 34.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-17 00:00:00', 34.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-18 00:00:00', 34.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-19 00:00:00', 36.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-20 00:00:00', 38.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-21 00:00:00', 39.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-22 00:00:00', 39.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-23 00:00:00', 35.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-24 00:00:00', 35.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-25 00:00:00', 34.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-26 00:00:00', 35.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-27 00:00:00', 35.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-28 00:00:00', 35.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-29 00:00:00', 36.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-30 00:00:00', 35.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-08-31 00:00:00', 30.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-01 00:00:00', 31.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-02 00:00:00', 30.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-03 00:00:00', 32.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-04 00:00:00', 33.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-05 00:00:00', 32.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-06 00:00:00', 34.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-07 00:00:00', 34.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-08 00:00:00', 34.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-09 00:00:00', 33.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-10 00:00:00', 28.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-11 00:00:00', 29.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-12 00:00:00', 28.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-13 00:00:00', 29.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-14 00:00:00', 30.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-15 00:00:00', 29.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-16 00:00:00', 33.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-17 00:00:00', 34.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-18 00:00:00', 32.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-19 00:00:00', 32.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-20 00:00:00', 32.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-21 00:00:00', 34.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-22 00:00:00', 35.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-23 00:00:00', 33.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-24 00:00:00', 31.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-25 00:00:00', 28.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-26 00:00:00', 29.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-27 00:00:00', 28.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-28 00:00:00', 28.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-29 00:00:00', 29.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-09-30 00:00:00', 29.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-01 00:00:00', 28.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-02 00:00:00', 29.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-03 00:00:00', 31.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-04 00:00:00', 30.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-05 00:00:00', 29.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-06 00:00:00', 30.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-07 00:00:00', 25.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-08 00:00:00', 23.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-09 00:00:00', 24.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-10 00:00:00', 17.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-11 00:00:00', 14.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-12 00:00:00', 20.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-13 00:00:00', 23.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-14 00:00:00', 24.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-15 00:00:00', 17.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-16 00:00:00', 14.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-17 00:00:00', 17.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-18 00:00:00', 14.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-19 00:00:00', 15.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-20 00:00:00', 24.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-21 00:00:00', 22.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-22 00:00:00', 11.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-23 00:00:00', 10.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-24 00:00:00', 17.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-25 00:00:00', 22.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-26 00:00:00', 22.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-27 00:00:00', 23.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-28 00:00:00', 19.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-29 00:00:00', 20.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-30 00:00:00', 20.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-10-31 00:00:00', 20.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-01 00:00:00', 20.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-02 00:00:00', 18.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-03 00:00:00', 15.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-04 00:00:00', 13.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-05 00:00:00', 13.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-06 00:00:00', 14.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-07 00:00:00', 20.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-08 00:00:00', 18.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-09 00:00:00', 22.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-10 00:00:00', 24.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-11 00:00:00', 22.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-12 00:00:00', 23.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-13 00:00:00', 23.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-14 00:00:00', 22.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-15 00:00:00', 21.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-16 00:00:00', 17.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-17 00:00:00', 22.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-18 00:00:00', 19.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-19 00:00:00', 12.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-20 00:00:00', 16.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-21 00:00:00', 17.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-22 00:00:00', 18.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-23 00:00:00', 19.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-24 00:00:00', 13.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-25 00:00:00', 8.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-26 00:00:00', 9.19200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-27 00:00:00', 11.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-28 00:00:00', 15.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-29 00:00:00', 17.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-11-30 00:00:00', 18.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-01 00:00:00', 16.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-02 00:00:00', 15.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-03 00:00:00', 13.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-04 00:00:00', 14.2309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-05 00:00:00', 6.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-06 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-07 00:00:00', 17.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-08 00:00:00', 11.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-09 00:00:00', 15.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-10 00:00:00', 17.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-11 00:00:00', 12.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-12 00:00:00', 13.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-13 00:00:00', 11.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-14 00:00:00', 7.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-15 00:00:00', 7.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-16 00:00:00', 9.13300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-17 00:00:00', 9.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-18 00:00:00', 8.03699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-19 00:00:00', 12.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-20 00:00:00', 7.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-21 00:00:00', 5.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-22 00:00:00', 11.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-23 00:00:00', 13.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-24 00:00:00', 11.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-25 00:00:00', 12.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-26 00:00:00', 7.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-27 00:00:00', 5.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-28 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-29 00:00:00', 6.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-30 00:00:00', 7.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1980-12-31 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-01 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-02 00:00:00', 5.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-03 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-04 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-05 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-06 00:00:00', 6.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-07 00:00:00', 7.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-08 00:00:00', 8.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-09 00:00:00', 6.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-10 00:00:00', 7.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-11 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-12 00:00:00', 10.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-13 00:00:00', 8.34500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-14 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-15 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-16 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-17 00:00:00', 5.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-18 00:00:00', 6.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-19 00:00:00', 8.83100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-20 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-21 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-22 00:00:00', 7.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-23 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-24 00:00:00', 1.45299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-25 00:00:00', 3.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-26 00:00:00', 4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-27 00:00:00', 5.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-28 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-29 00:00:00', 4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-30 00:00:00', 2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-01-31 00:00:00', 2.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-01 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-02 00:00:00', 4.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-03 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-04 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-05 00:00:00', 7.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-06 00:00:00', 10.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-07 00:00:00', 11.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-08 00:00:00', 10.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-09 00:00:00', 12.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-10 00:00:00', 10.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-11 00:00:00', 7.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-12 00:00:00', 7.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-13 00:00:00', 4.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-14 00:00:00', 5.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-15 00:00:00', 8.39000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-16 00:00:00', 10.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-17 00:00:00', 9.44499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-18 00:00:00', 9.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-19 00:00:00', 7.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-20 00:00:00', 7.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-21 00:00:00', 8.90400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-22 00:00:00', 8.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-23 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-24 00:00:00', 3.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-25 00:00:00', 6.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-26 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-27 00:00:00', 6.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-02-28 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-01 00:00:00', 5.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-02 00:00:00', 7.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-03 00:00:00', 10.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-04 00:00:00', 10.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-05 00:00:00', 6.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-06 00:00:00', 3.49099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-07 00:00:00', 7.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-08 00:00:00', 8.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-09 00:00:00', 5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-10 00:00:00', 6.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-11 00:00:00', 7.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-12 00:00:00', 9.36400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-13 00:00:00', 9.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-14 00:00:00', 9.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-15 00:00:00', 8.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-16 00:00:00', 6.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-17 00:00:00', 6.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-18 00:00:00', 4.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-19 00:00:00', 8.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-20 00:00:00', 4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-21 00:00:00', 2.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-22 00:00:00', 4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-23 00:00:00', 5.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-24 00:00:00', 6.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-25 00:00:00', 7.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-26 00:00:00', 15.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-27 00:00:00', 8.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-28 00:00:00', 11.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-29 00:00:00', 6.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-30 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-03-31 00:00:00', 6.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-01 00:00:00', 7.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-02 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-03 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-04 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-05 00:00:00', 3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-06 00:00:00', 6.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-07 00:00:00', 4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-08 00:00:00', 5.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-09 00:00:00', 10.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-10 00:00:00', 5.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-11 00:00:00', 6.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-12 00:00:00', 7.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-13 00:00:00', 7.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-14 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-15 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-16 00:00:00', 19.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-17 00:00:00', 22.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-18 00:00:00', 26.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-19 00:00:00', 16.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-20 00:00:00', 12.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-21 00:00:00', 17.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-22 00:00:00', 23.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-23 00:00:00', 21.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-24 00:00:00', 25.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-25 00:00:00', 26.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-26 00:00:00', 27.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-27 00:00:00', 27.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-28 00:00:00', 24.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-29 00:00:00', 26.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-04-30 00:00:00', 22.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-01 00:00:00', 27.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-02 00:00:00', 28.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-03 00:00:00', 29.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-04 00:00:00', 19.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-05 00:00:00', 23.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-06 00:00:00', 25.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-07 00:00:00', 27.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-08 00:00:00', 21.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-09 00:00:00', 26.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-10 00:00:00', 25.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-11 00:00:00', 25.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-12 00:00:00', 28.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-13 00:00:00', 27.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-14 00:00:00', 24.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-15 00:00:00', 27.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-16 00:00:00', 29.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-17 00:00:00', 31.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-18 00:00:00', 27.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-19 00:00:00', 17.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-20 00:00:00', 23.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-21 00:00:00', 25.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-22 00:00:00', 27.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-23 00:00:00', 28.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-24 00:00:00', 32.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-25 00:00:00', 31.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-26 00:00:00', 31.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-27 00:00:00', 30.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-28 00:00:00', 32.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-29 00:00:00', 32.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-30 00:00:00', 22.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-05-31 00:00:00', 24.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-01 00:00:00', 24.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-02 00:00:00', 24.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-03 00:00:00', 27.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-04 00:00:00', 28.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-05 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-06 00:00:00', 33.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-07 00:00:00', 27.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-08 00:00:00', 27.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-09 00:00:00', 28.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-10 00:00:00', 27.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-11 00:00:00', 28.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-12 00:00:00', 29.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-13 00:00:00', 30.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-14 00:00:00', 29.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-15 00:00:00', 32.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-16 00:00:00', 35.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-17 00:00:00', 37.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-18 00:00:00', 36.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-19 00:00:00', 37.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-20 00:00:00', 36.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-21 00:00:00', 34.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-22 00:00:00', 36.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-23 00:00:00', 35.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-24 00:00:00', 35.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-25 00:00:00', 35.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-26 00:00:00', 36.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-27 00:00:00', 36.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-28 00:00:00', 37.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-29 00:00:00', 37.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-06-30 00:00:00', 36.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-01 00:00:00', 35.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-02 00:00:00', 34.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-03 00:00:00', 35.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-04 00:00:00', 35.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-05 00:00:00', 36.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-06 00:00:00', 37.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-07 00:00:00', 39.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-08 00:00:00', 34.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-09 00:00:00', 35.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-10 00:00:00', 36.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-11 00:00:00', 38.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-12 00:00:00', 40.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-13 00:00:00', 43.6199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-14 00:00:00', 43.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-15 00:00:00', 40.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-16 00:00:00', 36.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-17 00:00:00', 36.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-18 00:00:00', 37.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-19 00:00:00', 35.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-20 00:00:00', 37.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-21 00:00:00', 39.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-22 00:00:00', 36.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-23 00:00:00', 28.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-24 00:00:00', 29.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-25 00:00:00', 33.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-26 00:00:00', 34.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-27 00:00:00', 35.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-28 00:00:00', 36.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-29 00:00:00', 34.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-30 00:00:00', 33.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-07-31 00:00:00', 34.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-01 00:00:00', 32.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-02 00:00:00', 33.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-03 00:00:00', 33.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-04 00:00:00', 34.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-05 00:00:00', 34.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-06 00:00:00', 36.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-07 00:00:00', 38.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-08 00:00:00', 37.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-09 00:00:00', 38.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-10 00:00:00', 37.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-11 00:00:00', 36.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-12 00:00:00', 36.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-13 00:00:00', 34.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-14 00:00:00', 34.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-15 00:00:00', 35.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-16 00:00:00', 36.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-17 00:00:00', 38.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-18 00:00:00', 36.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-19 00:00:00', 33.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-20 00:00:00', 31.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-21 00:00:00', 32.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-22 00:00:00', 33.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-23 00:00:00', 31.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-24 00:00:00', 32.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-25 00:00:00', 34.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-26 00:00:00', 34.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-27 00:00:00', 34.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-28 00:00:00', 34.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-29 00:00:00', 33.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-30 00:00:00', 33.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-08-31 00:00:00', 34.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-01 00:00:00', 33.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-02 00:00:00', 31.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-03 00:00:00', 31.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-04 00:00:00', 31.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-05 00:00:00', 30.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-06 00:00:00', 30.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-07 00:00:00', 31.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-08 00:00:00', 31.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-09 00:00:00', 30.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-10 00:00:00', 32.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-11 00:00:00', 29.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-12 00:00:00', 33.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-13 00:00:00', 35.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-14 00:00:00', 35.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-15 00:00:00', 37.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-16 00:00:00', 36.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-17 00:00:00', 35.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-18 00:00:00', 37.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-19 00:00:00', 36.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-20 00:00:00', 36.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-21 00:00:00', 33.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-22 00:00:00', 30.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-23 00:00:00', 23.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-24 00:00:00', 20.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-25 00:00:00', 24.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-26 00:00:00', 28.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-27 00:00:00', 26.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-28 00:00:00', 27.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-29 00:00:00', 25.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-09-30 00:00:00', 24.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-01 00:00:00', 23.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-02 00:00:00', 20.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-03 00:00:00', 21.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-04 00:00:00', 22.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-05 00:00:00', 22.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-06 00:00:00', 21.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-07 00:00:00', 21.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-08 00:00:00', 23.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-09 00:00:00', 24.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-10 00:00:00', 21.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-11 00:00:00', 21.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-12 00:00:00', 22.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-13 00:00:00', 23.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-14 00:00:00', 16.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-15 00:00:00', 19.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-16 00:00:00', 18.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-17 00:00:00', 22.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-18 00:00:00', 24.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-19 00:00:00', 13.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-20 00:00:00', 13.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-21 00:00:00', 19.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-22 00:00:00', 19.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-23 00:00:00', 17.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-24 00:00:00', 16.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-25 00:00:00', 19.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-26 00:00:00', 17.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-27 00:00:00', 16.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-28 00:00:00', 14.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-29 00:00:00', 15.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-30 00:00:00', 15.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-10-31 00:00:00', 15.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-01 00:00:00', 18.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-02 00:00:00', 20.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-03 00:00:00', 18.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-04 00:00:00', 19.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-05 00:00:00', 22.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-06 00:00:00', 24.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-07 00:00:00', 20.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-08 00:00:00', 16.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-09 00:00:00', 17.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-10 00:00:00', 16.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-11 00:00:00', 17.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-12 00:00:00', 19.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-13 00:00:00', 21.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-14 00:00:00', 23.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-15 00:00:00', 20.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-16 00:00:00', 13.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-17 00:00:00', 14.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-18 00:00:00', 16.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-19 00:00:00', 16.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-20 00:00:00', 15.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-21 00:00:00', 16.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-22 00:00:00', 15.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-23 00:00:00', 12.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-24 00:00:00', 7.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-25 00:00:00', 8.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-26 00:00:00', 10.4110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-27 00:00:00', 10.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-28 00:00:00', 13.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-29 00:00:00', 13.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-11-30 00:00:00', 13.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-01 00:00:00', 13.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-02 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-03 00:00:00', 6.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-04 00:00:00', 6.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-05 00:00:00', 9.85299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-06 00:00:00', 8.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-07 00:00:00', 8.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-08 00:00:00', 6.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-09 00:00:00', 11.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-10 00:00:00', 9.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-11 00:00:00', 7.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-12 00:00:00', 11.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-13 00:00:00', 11.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-14 00:00:00', 11.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-15 00:00:00', 10.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-16 00:00:00', 9.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-17 00:00:00', 13.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-18 00:00:00', 11.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-19 00:00:00', 14.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-20 00:00:00', 8.82699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-21 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-22 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-23 00:00:00', 10.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-24 00:00:00', 12.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-25 00:00:00', 8.92800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-26 00:00:00', 10.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-27 00:00:00', 6.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-28 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-29 00:00:00', 5.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-30 00:00:00', 3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1981-12-31 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-01 00:00:00', 6.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-02 00:00:00', 6.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-03 00:00:00', 5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-04 00:00:00', 6.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-05 00:00:00', 8.15900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-06 00:00:00', 11.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-07 00:00:00', 15.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-08 00:00:00', 15.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-09 00:00:00', 13.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-10 00:00:00', 13.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-11 00:00:00', 12.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-12 00:00:00', 6.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-13 00:00:00', 2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-14 00:00:00', 6.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-15 00:00:00', 8.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-16 00:00:00', 7.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-17 00:00:00', 9.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-18 00:00:00', 6.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-19 00:00:00', -1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-20 00:00:00', -0.395999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-21 00:00:00', -3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-22 00:00:00', -3.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-23 00:00:00', -2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-24 00:00:00', 0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-25 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-26 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-27 00:00:00', 4.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-28 00:00:00', 4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-29 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-30 00:00:00', 3.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-01-31 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-01 00:00:00', 8.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-02 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-03 00:00:00', 6.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-04 00:00:00', 9.12800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-05 00:00:00', 11.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-06 00:00:00', 6.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-07 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-08 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-09 00:00:00', 9.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-10 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-11 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-12 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-13 00:00:00', 7.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-14 00:00:00', 12.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-15 00:00:00', 5.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-16 00:00:00', 4.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-17 00:00:00', 8.82400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-18 00:00:00', 10.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-19 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-20 00:00:00', -0.561999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-21 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-22 00:00:00', 6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-23 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-24 00:00:00', 8.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-25 00:00:00', 11.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-26 00:00:00', 8.22500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-27 00:00:00', 10.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-02-28 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-01 00:00:00', 9.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-02 00:00:00', 10.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-03 00:00:00', 13.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-04 00:00:00', 7.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-05 00:00:00', 5.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-06 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-07 00:00:00', 9.38799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-08 00:00:00', 10.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-09 00:00:00', 7.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-10 00:00:00', 12.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-11 00:00:00', 13.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-12 00:00:00', 17.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-13 00:00:00', 12.9289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-14 00:00:00', 10.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-15 00:00:00', 16.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-16 00:00:00', 10.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-17 00:00:00', 11.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-18 00:00:00', 14.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-19 00:00:00', 15.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-20 00:00:00', 12.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-21 00:00:00', 7.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-22 00:00:00', 12.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-23 00:00:00', 16.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-24 00:00:00', 17.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-25 00:00:00', 17.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-26 00:00:00', 14.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-27 00:00:00', 14.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-28 00:00:00', 15.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-29 00:00:00', 14.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-30 00:00:00', 10.2440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-03-31 00:00:00', 12.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-01 00:00:00', 16.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-02 00:00:00', 20.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-03 00:00:00', 15.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-04 00:00:00', 12.3559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-05 00:00:00', 13.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-06 00:00:00', 17.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-07 00:00:00', 21.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-08 00:00:00', 22.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-09 00:00:00', 25.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-10 00:00:00', 25.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-11 00:00:00', 21.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-12 00:00:00', 24.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-13 00:00:00', 26.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-14 00:00:00', 25.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-15 00:00:00', 17.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-16 00:00:00', 18.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-17 00:00:00', 20.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-18 00:00:00', 23.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-19 00:00:00', 27.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-20 00:00:00', 28.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-21 00:00:00', 28.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-22 00:00:00', 29.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-23 00:00:00', 29.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-24 00:00:00', 25.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-25 00:00:00', 22.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-26 00:00:00', 23.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-27 00:00:00', 24.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-28 00:00:00', 25.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-29 00:00:00', 25.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-04-30 00:00:00', 28.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-01 00:00:00', 29.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-02 00:00:00', 29.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-03 00:00:00', 29.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-04 00:00:00', 30.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-05 00:00:00', 29.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-06 00:00:00', 29.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-07 00:00:00', 30.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-08 00:00:00', 31.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-09 00:00:00', 29.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-10 00:00:00', 25.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-11 00:00:00', 23.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-12 00:00:00', 23.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-13 00:00:00', 26.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-14 00:00:00', 25.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-15 00:00:00', 26.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-16 00:00:00', 31.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-17 00:00:00', 30.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-18 00:00:00', 30.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-19 00:00:00', 31.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-20 00:00:00', 33.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-21 00:00:00', 34.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-22 00:00:00', 32.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-23 00:00:00', 32.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-24 00:00:00', 33.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-25 00:00:00', 28.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-26 00:00:00', 24.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-27 00:00:00', 29.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-28 00:00:00', 28.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-29 00:00:00', 20.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-30 00:00:00', 26.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-05-31 00:00:00', 27.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-01 00:00:00', 29.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-02 00:00:00', 32.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-03 00:00:00', 32.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-04 00:00:00', 31.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-05 00:00:00', 35.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-06 00:00:00', 36.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-07 00:00:00', 35.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-08 00:00:00', 35.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-09 00:00:00', 35.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-10 00:00:00', 39.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-11 00:00:00', 39.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-12 00:00:00', 37.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-13 00:00:00', 37.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-14 00:00:00', 33.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-15 00:00:00', 34.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-16 00:00:00', 34.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-17 00:00:00', 34.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-18 00:00:00', 31.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-19 00:00:00', 33.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-20 00:00:00', 35.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-21 00:00:00', 36.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-22 00:00:00', 35.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-23 00:00:00', 37.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-24 00:00:00', 36.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-25 00:00:00', 37.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-26 00:00:00', 37.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-27 00:00:00', 36.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-28 00:00:00', 38.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-29 00:00:00', 37.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-06-30 00:00:00', 28.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-01 00:00:00', 28.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-02 00:00:00', 31.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-03 00:00:00', 32.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-04 00:00:00', 35.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-05 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-06 00:00:00', 34.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-07 00:00:00', 34.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-08 00:00:00', 34.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-09 00:00:00', 34.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-10 00:00:00', 37.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-11 00:00:00', 37.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-12 00:00:00', 33.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-13 00:00:00', 34.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-14 00:00:00', 37.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-15 00:00:00', 39.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-16 00:00:00', 38.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-17 00:00:00', 39.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-18 00:00:00', 39.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-19 00:00:00', 41.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-20 00:00:00', 38.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-21 00:00:00', 39.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-22 00:00:00', 38.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-23 00:00:00', 39.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-24 00:00:00', 40.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-25 00:00:00', 39.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-26 00:00:00', 41.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-27 00:00:00', 40.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-28 00:00:00', 39.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-29 00:00:00', 42.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-30 00:00:00', 41.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-07-31 00:00:00', 41.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-01 00:00:00', 43.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-02 00:00:00', 43.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-03 00:00:00', 41.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-04 00:00:00', 40.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-05 00:00:00', 41.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-06 00:00:00', 42.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-07 00:00:00', 41.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-08 00:00:00', 41.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-09 00:00:00', 40.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-10 00:00:00', 39.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-11 00:00:00', 31.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-12 00:00:00', 32.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-13 00:00:00', 35.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-14 00:00:00', 36.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-15 00:00:00', 35.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-16 00:00:00', 32.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-17 00:00:00', 33.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-18 00:00:00', 35.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-19 00:00:00', 36.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-20 00:00:00', 36.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-21 00:00:00', 36.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-22 00:00:00', 33.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-23 00:00:00', 34.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-24 00:00:00', 29.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-25 00:00:00', 27.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-26 00:00:00', 29.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-27 00:00:00', 30.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-28 00:00:00', 32.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-29 00:00:00', 32.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-30 00:00:00', 33.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-08-31 00:00:00', 31.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-01 00:00:00', 34.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-02 00:00:00', 32.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-03 00:00:00', 32.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-04 00:00:00', 32.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-05 00:00:00', 32.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-06 00:00:00', 33.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-07 00:00:00', 31.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-08 00:00:00', 31.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-09 00:00:00', 31.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-10 00:00:00', 33.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-11 00:00:00', 32.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-12 00:00:00', 33.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-13 00:00:00', 33.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-14 00:00:00', 31.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-15 00:00:00', 33.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-16 00:00:00', 32.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-17 00:00:00', 29.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-18 00:00:00', 27.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-19 00:00:00', 27.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-20 00:00:00', 25.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-21 00:00:00', 23.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-22 00:00:00', 23.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-23 00:00:00', 23.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-24 00:00:00', 25.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-25 00:00:00', 26.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-26 00:00:00', 25.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-27 00:00:00', 26.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-28 00:00:00', 26.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-29 00:00:00', 25.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-09-30 00:00:00', 23.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-01 00:00:00', 25.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-02 00:00:00', 28.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-03 00:00:00', 28.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-04 00:00:00', 21.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-05 00:00:00', 26.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-06 00:00:00', 26.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-07 00:00:00', 16.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-08 00:00:00', 14.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-09 00:00:00', 20.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-10 00:00:00', 25.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-11 00:00:00', 21.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-12 00:00:00', 22.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-13 00:00:00', 23.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-14 00:00:00', 25.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-15 00:00:00', 27.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-16 00:00:00', 26.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-17 00:00:00', 24.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-18 00:00:00', 20.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-19 00:00:00', 23.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-20 00:00:00', 24.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-21 00:00:00', 25.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-22 00:00:00', 22.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-23 00:00:00', 19.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-24 00:00:00', 16.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-25 00:00:00', 11.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-26 00:00:00', 3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-27 00:00:00', 8.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-28 00:00:00', 15.3559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-29 00:00:00', 19.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-30 00:00:00', 20.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-10-31 00:00:00', 14.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-01 00:00:00', 11.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-02 00:00:00', 12.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-03 00:00:00', 9.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-04 00:00:00', 15.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-05 00:00:00', 15.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-06 00:00:00', 18.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-07 00:00:00', 21.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-08 00:00:00', 17.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-09 00:00:00', 20.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-10 00:00:00', 12.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-11 00:00:00', 7.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-12 00:00:00', 12.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-13 00:00:00', 13.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-14 00:00:00', 9.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-15 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-16 00:00:00', 8.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-17 00:00:00', 10.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-18 00:00:00', 7.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-19 00:00:00', 9.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-20 00:00:00', 7.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-21 00:00:00', 8.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-22 00:00:00', 10.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-23 00:00:00', 9.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-24 00:00:00', 7.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-25 00:00:00', 8.01299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-26 00:00:00', 9.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-27 00:00:00', 11.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-28 00:00:00', 10.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-29 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-11-30 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-01 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-02 00:00:00', 3.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-03 00:00:00', 7.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-04 00:00:00', 9.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-05 00:00:00', 9.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-06 00:00:00', 8.23700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-07 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-08 00:00:00', 5.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-09 00:00:00', -2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-10 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-11 00:00:00', 2.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-12 00:00:00', 3.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-13 00:00:00', 3.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-14 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-15 00:00:00', 6.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-16 00:00:00', 5.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-17 00:00:00', 7.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-18 00:00:00', 8.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-19 00:00:00', 8.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-20 00:00:00', 7.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-21 00:00:00', 9.08899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-22 00:00:00', 7.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-23 00:00:00', 7.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-24 00:00:00', 7.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-25 00:00:00', 8.87600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-26 00:00:00', 8.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-27 00:00:00', 5.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-28 00:00:00', 6.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-29 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-30 00:00:00', 7.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1982-12-31 00:00:00', 6.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-01 00:00:00', 9.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-02 00:00:00', 9.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-03 00:00:00', 8.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-04 00:00:00', 9.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-05 00:00:00', 5.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-06 00:00:00', 10.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-07 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-08 00:00:00', 0.23399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-09 00:00:00', -0.384000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-10 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-11 00:00:00', 0.0560000017285346985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-12 00:00:00', 2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-13 00:00:00', 5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-14 00:00:00', 0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-15 00:00:00', -0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-16 00:00:00', 6.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-17 00:00:00', 6.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-18 00:00:00', 10.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-19 00:00:00', 11.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-20 00:00:00', 14.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-21 00:00:00', 17.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-22 00:00:00', 11.6029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-23 00:00:00', 13.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-24 00:00:00', 17.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-25 00:00:00', 12.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-26 00:00:00', 7.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-27 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-28 00:00:00', -0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-29 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-30 00:00:00', 4.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-01-31 00:00:00', 6.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-01 00:00:00', 5.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-02 00:00:00', 7.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-03 00:00:00', 8.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-04 00:00:00', 6.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-05 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-06 00:00:00', 4.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-07 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-08 00:00:00', 5.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-09 00:00:00', 5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-10 00:00:00', 4.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-11 00:00:00', 5.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-12 00:00:00', 6.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-13 00:00:00', 5.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-14 00:00:00', 7.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-15 00:00:00', 10.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-16 00:00:00', 10.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-17 00:00:00', 12.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-18 00:00:00', 13.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-19 00:00:00', 10.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-20 00:00:00', 12.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-21 00:00:00', 11.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-22 00:00:00', 12.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-23 00:00:00', 6.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-24 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-25 00:00:00', 8.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-26 00:00:00', 9.22799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-27 00:00:00', 10.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-02-28 00:00:00', 7.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-01 00:00:00', 4.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-02 00:00:00', 6.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-03 00:00:00', 7.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-04 00:00:00', 10.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-05 00:00:00', 14.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-06 00:00:00', 16.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-07 00:00:00', 9.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-08 00:00:00', 9.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-09 00:00:00', 13.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-10 00:00:00', 15.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-11 00:00:00', 11.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-12 00:00:00', 14.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-13 00:00:00', 17.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-14 00:00:00', 13.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-15 00:00:00', 11.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-16 00:00:00', 12.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-17 00:00:00', 6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-18 00:00:00', 7.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-19 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-20 00:00:00', 5.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-21 00:00:00', 9.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-22 00:00:00', 13.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-23 00:00:00', 15.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-24 00:00:00', 17.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-25 00:00:00', 8.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-26 00:00:00', 8.10299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-27 00:00:00', 10.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-28 00:00:00', 11.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-29 00:00:00', 14.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-30 00:00:00', 16.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-03-31 00:00:00', 14.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-01 00:00:00', 18.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-02 00:00:00', 18.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-03 00:00:00', 21.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-04 00:00:00', 18.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-05 00:00:00', 18.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-06 00:00:00', 20.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-07 00:00:00', 16.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-08 00:00:00', 13.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-09 00:00:00', 17.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-10 00:00:00', 17.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-11 00:00:00', 20.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-12 00:00:00', 11.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-13 00:00:00', 10.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-14 00:00:00', 15.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-15 00:00:00', 15.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-16 00:00:00', 15.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-17 00:00:00', 17.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-18 00:00:00', 20.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-19 00:00:00', 21.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-20 00:00:00', 22.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-21 00:00:00', 22.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-22 00:00:00', 20.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-23 00:00:00', 22.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-24 00:00:00', 22.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-25 00:00:00', 25.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-26 00:00:00', 25.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-27 00:00:00', 17.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-28 00:00:00', 22.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-29 00:00:00', 15.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-04-30 00:00:00', 11.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-01 00:00:00', 20.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-02 00:00:00', 24.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-03 00:00:00', 24.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-04 00:00:00', 18.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-05 00:00:00', 26.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-06 00:00:00', 29.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-07 00:00:00', 30.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-08 00:00:00', 25.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-09 00:00:00', 29.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-10 00:00:00', 27.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-11 00:00:00', 25.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-12 00:00:00', 29.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-13 00:00:00', 27.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-14 00:00:00', 30.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-15 00:00:00', 29.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-16 00:00:00', 29.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-17 00:00:00', 29.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-18 00:00:00', 30.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-19 00:00:00', 25.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-20 00:00:00', 29.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-21 00:00:00', 28.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-22 00:00:00', 25.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-23 00:00:00', 28.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-24 00:00:00', 28.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-25 00:00:00', 31.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-26 00:00:00', 34.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-27 00:00:00', 32.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-28 00:00:00', 30.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-29 00:00:00', 31.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-30 00:00:00', 26.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-05-31 00:00:00', 22.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-01 00:00:00', 25.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-02 00:00:00', 25.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-03 00:00:00', 28.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-04 00:00:00', 29.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-05 00:00:00', 32.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-06 00:00:00', 33.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-07 00:00:00', 30.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-08 00:00:00', 31.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-09 00:00:00', 29.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-10 00:00:00', 30.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-11 00:00:00', 32.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-12 00:00:00', 34.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-13 00:00:00', 36.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-14 00:00:00', 36.9490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-15 00:00:00', 33.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-16 00:00:00', 33.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-17 00:00:00', 33.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-18 00:00:00', 32.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-19 00:00:00', 35.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-20 00:00:00', 37.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-21 00:00:00', 38.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-22 00:00:00', 38.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-23 00:00:00', 38.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-24 00:00:00', 39.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-25 00:00:00', 40.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-26 00:00:00', 41.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-27 00:00:00', 40.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-28 00:00:00', 40.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-29 00:00:00', 41.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-06-30 00:00:00', 40.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-01 00:00:00', 38.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-02 00:00:00', 37.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-03 00:00:00', 34.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-04 00:00:00', 34.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-05 00:00:00', 34.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-06 00:00:00', 36.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-07 00:00:00', 31.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-08 00:00:00', 38.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-09 00:00:00', 37.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-10 00:00:00', 36.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-11 00:00:00', 36.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-12 00:00:00', 36.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-13 00:00:00', 36.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-14 00:00:00', 37.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-15 00:00:00', 38.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-16 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-17 00:00:00', 38.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-18 00:00:00', 42.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-19 00:00:00', 37.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-20 00:00:00', 37.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-21 00:00:00', 40.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-22 00:00:00', 43.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-23 00:00:00', 45.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-24 00:00:00', 43.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-25 00:00:00', 41.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-26 00:00:00', 40.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-27 00:00:00', 39.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-28 00:00:00', 42.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-29 00:00:00', 43.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-30 00:00:00', 44.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-07-31 00:00:00', 43.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-01 00:00:00', 42.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-02 00:00:00', 39.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-03 00:00:00', 40.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-04 00:00:00', 41.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-05 00:00:00', 41.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-06 00:00:00', 42.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-07 00:00:00', 39.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-08 00:00:00', 37.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-09 00:00:00', 34.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-10 00:00:00', 35.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-11 00:00:00', 36.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-12 00:00:00', 37.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-13 00:00:00', 37.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-14 00:00:00', 37.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-15 00:00:00', 38.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-16 00:00:00', 40.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-17 00:00:00', 38.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-18 00:00:00', 37.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-19 00:00:00', 38.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-20 00:00:00', 38.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-21 00:00:00', 37.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-22 00:00:00', 38.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-23 00:00:00', 39.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-24 00:00:00', 38.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-25 00:00:00', 37.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-26 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-27 00:00:00', 33.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-28 00:00:00', 35.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-29 00:00:00', 38.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-30 00:00:00', 39.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-08-31 00:00:00', 39.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-01 00:00:00', 27.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-03 00:00:00', 26.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-05 00:00:00', 26.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-07 00:00:00', 27.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-09 00:00:00', 28.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-11 00:00:00', 32.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-13 00:00:00', 28.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-15 00:00:00', 24.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-17 00:00:00', 22.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-19 00:00:00', 22.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-21 00:00:00', 24.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-23 00:00:00', 26.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-25 00:00:00', 25.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-27 00:00:00', 15.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-29 00:00:00', 20.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-01 00:00:00', 23.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-03 00:00:00', 17.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-05 00:00:00', 18.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-07 00:00:00', 19.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-09 00:00:00', 17.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-11 00:00:00', 16.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-13 00:00:00', 19.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-15 00:00:00', 19.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-17 00:00:00', 20.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-19 00:00:00', 19.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-21 00:00:00', 19.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-23 00:00:00', 17.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-25 00:00:00', 22.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-27 00:00:00', 23.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-29 00:00:00', 20.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-30 00:00:00', 21.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-10-31 00:00:00', 23.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-01 00:00:00', 24.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-02 00:00:00', 21.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-03 00:00:00', 17.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-04 00:00:00', 15.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-05 00:00:00', 8.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-06 00:00:00', 12.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-07 00:00:00', 18.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-08 00:00:00', 18.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-09 00:00:00', 17.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-10 00:00:00', 17.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-11 00:00:00', 19.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-12 00:00:00', 21.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-13 00:00:00', 22.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-14 00:00:00', 22.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-15 00:00:00', 21.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-16 00:00:00', 21.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-17 00:00:00', 16.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-18 00:00:00', 19.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-19 00:00:00', 20.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-20 00:00:00', 20.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-21 00:00:00', 19.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-22 00:00:00', 20.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-23 00:00:00', 22.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-24 00:00:00', 20.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-25 00:00:00', 20.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-26 00:00:00', 11.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-27 00:00:00', 11.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-28 00:00:00', 17.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-29 00:00:00', 19.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-11-30 00:00:00', 19.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-01 00:00:00', 17.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-02 00:00:00', 16.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-03 00:00:00', 14.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-04 00:00:00', 8.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-05 00:00:00', 10.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-06 00:00:00', 11.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-07 00:00:00', 13.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-08 00:00:00', 14.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-09 00:00:00', 15.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-10 00:00:00', 14.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-11 00:00:00', 14.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-12 00:00:00', 15.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-13 00:00:00', 16.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-14 00:00:00', 10.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-15 00:00:00', 11.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-16 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-17 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-18 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-19 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-20 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-21 00:00:00', 0.841000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-22 00:00:00', -0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-23 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-24 00:00:00', 1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-25 00:00:00', -0.435000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-26 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-27 00:00:00', 8.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-28 00:00:00', 7.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-29 00:00:00', 7.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-30 00:00:00', 8.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1983-12-31 00:00:00', 7.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-01 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-02 00:00:00', 10.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-03 00:00:00', 7.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-04 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-05 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-06 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-07 00:00:00', 7.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-08 00:00:00', 8.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-09 00:00:00', 10.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-10 00:00:00', 10.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-11 00:00:00', 5.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-12 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-13 00:00:00', 6.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-14 00:00:00', 7.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-15 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-16 00:00:00', 2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-17 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-18 00:00:00', 0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-19 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-20 00:00:00', 0.266999989748001099, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-21 00:00:00', -1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-22 00:00:00', -0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-23 00:00:00', 0.416000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-24 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-25 00:00:00', 0.698000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-26 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-27 00:00:00', 0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-28 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-29 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-30 00:00:00', 8.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-01-31 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-01 00:00:00', -1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-02 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-03 00:00:00', -2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-04 00:00:00', -2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-05 00:00:00', 0.492000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-06 00:00:00', -2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-07 00:00:00', -4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-08 00:00:00', 0.794000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-09 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-10 00:00:00', 0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-11 00:00:00', 0.259999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-12 00:00:00', 0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-13 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-14 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-15 00:00:00', 1.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-16 00:00:00', -1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-17 00:00:00', -4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-18 00:00:00', -5.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-19 00:00:00', -6.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-20 00:00:00', -8.30300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-21 00:00:00', -7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-22 00:00:00', -2.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-23 00:00:00', -3.27200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-24 00:00:00', -0.42300000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-25 00:00:00', -0.485000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-26 00:00:00', -0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-27 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-28 00:00:00', 1.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-02-29 00:00:00', 5.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-01 00:00:00', 5.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-02 00:00:00', 11.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-03 00:00:00', 12.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-04 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-05 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-06 00:00:00', 8.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-07 00:00:00', 9.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-08 00:00:00', 8.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-09 00:00:00', 6.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-10 00:00:00', 5.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-11 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-12 00:00:00', 12.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-13 00:00:00', 16.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-14 00:00:00', 13.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-15 00:00:00', 14.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-16 00:00:00', 11.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-17 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-18 00:00:00', 10.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-19 00:00:00', 16.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-20 00:00:00', 19.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-21 00:00:00', 19.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-22 00:00:00', 18.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-23 00:00:00', 22.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-24 00:00:00', 20.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-25 00:00:00', 17.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-26 00:00:00', 22.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-27 00:00:00', 15.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-28 00:00:00', 12.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-29 00:00:00', 15.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-30 00:00:00', 18.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-03-31 00:00:00', 16.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-01 00:00:00', 18.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-02 00:00:00', 15.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-03 00:00:00', 16.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-04 00:00:00', 14.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-05 00:00:00', 12.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-06 00:00:00', 16.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-07 00:00:00', 15.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-08 00:00:00', 17.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-09 00:00:00', 19.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-10 00:00:00', 21.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-11 00:00:00', 23.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-12 00:00:00', 24.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-13 00:00:00', 17.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-14 00:00:00', 17.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-15 00:00:00', 19.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-16 00:00:00', 24.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-17 00:00:00', 26.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-18 00:00:00', 26.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-19 00:00:00', 17.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-20 00:00:00', 17.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-21 00:00:00', 21.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-22 00:00:00', 26.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-23 00:00:00', 29.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-24 00:00:00', 28.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-25 00:00:00', 29.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-26 00:00:00', 26.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-27 00:00:00', 17.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-28 00:00:00', 22.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-29 00:00:00', 19.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-04-30 00:00:00', 22.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-01 00:00:00', 23.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-02 00:00:00', 26.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-03 00:00:00', 17.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-04 00:00:00', 22.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-05 00:00:00', 25.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-06 00:00:00', 22.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-07 00:00:00', 22.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-08 00:00:00', 18.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-09 00:00:00', 23.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-10 00:00:00', 25.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-11 00:00:00', 23.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-12 00:00:00', 20.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-13 00:00:00', 21.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-14 00:00:00', 20.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-15 00:00:00', 22.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-16 00:00:00', 24.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-17 00:00:00', 25.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-18 00:00:00', 27.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-19 00:00:00', 26.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-20 00:00:00', 25.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-21 00:00:00', 29.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-22 00:00:00', 29.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-23 00:00:00', 26.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-24 00:00:00', 30.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-25 00:00:00', 30.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-26 00:00:00', 32.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-27 00:00:00', 34.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-28 00:00:00', 31.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-29 00:00:00', 35.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-30 00:00:00', 37.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-05-31 00:00:00', 40.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-01 00:00:00', 36.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-02 00:00:00', 35.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-03 00:00:00', 34.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-04 00:00:00', 34.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-05 00:00:00', 36.0120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-06 00:00:00', 34.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-07 00:00:00', 33.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-08 00:00:00', 35.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-09 00:00:00', 36.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-10 00:00:00', 35.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-11 00:00:00', 35.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-12 00:00:00', 36.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-13 00:00:00', 36.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-14 00:00:00', 35.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-15 00:00:00', 37.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-16 00:00:00', 33.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-17 00:00:00', 30.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-18 00:00:00', 31.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-19 00:00:00', 32.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-20 00:00:00', 33.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-21 00:00:00', 34.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-22 00:00:00', 38.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-23 00:00:00', 38.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-24 00:00:00', 40.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-25 00:00:00', 39.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-26 00:00:00', 38.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-27 00:00:00', 37.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-28 00:00:00', 36.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-29 00:00:00', 38.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-06-30 00:00:00', 35.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-01 00:00:00', 36.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-02 00:00:00', 37.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-03 00:00:00', 37.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-04 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-05 00:00:00', 38.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-06 00:00:00', 39.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-07 00:00:00', 38.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-08 00:00:00', 39.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-09 00:00:00', 39.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-10 00:00:00', 38.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-11 00:00:00', 39.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-12 00:00:00', 40.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-13 00:00:00', 41.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-14 00:00:00', 40.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-15 00:00:00', 40.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-16 00:00:00', 38.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-17 00:00:00', 40.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-18 00:00:00', 40.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-19 00:00:00', 38.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-20 00:00:00', 39.1969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-21 00:00:00', 38.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-22 00:00:00', 38.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-23 00:00:00', 39.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-24 00:00:00', 39.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-25 00:00:00', 38.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-26 00:00:00', 39.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-27 00:00:00', 39.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-28 00:00:00', 39.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-29 00:00:00', 39.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-30 00:00:00', 39.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-07-31 00:00:00', 38.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-01 00:00:00', 40.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-02 00:00:00', 40.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-03 00:00:00', 40.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-04 00:00:00', 40.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-05 00:00:00', 39.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-06 00:00:00', 38.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-07 00:00:00', 39.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-08 00:00:00', 39.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-09 00:00:00', 41.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-10 00:00:00', 39.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-11 00:00:00', 39.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-12 00:00:00', 37.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-13 00:00:00', 36.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-14 00:00:00', 37.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-15 00:00:00', 37.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-16 00:00:00', 39.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-17 00:00:00', 39.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-18 00:00:00', 39.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-19 00:00:00', 41.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-20 00:00:00', 42.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-21 00:00:00', 39.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-22 00:00:00', 37.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-23 00:00:00', 38.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-24 00:00:00', 39.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-25 00:00:00', 38.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-26 00:00:00', 37.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-27 00:00:00', 38.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-28 00:00:00', 38.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-29 00:00:00', 38.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-30 00:00:00', 39.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-08-31 00:00:00', 35.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-01 00:00:00', 33.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-02 00:00:00', 33.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-03 00:00:00', 33.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-04 00:00:00', 33.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-05 00:00:00', 32.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-06 00:00:00', 29.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-07 00:00:00', 29.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-08 00:00:00', 28.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-09 00:00:00', 32.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-10 00:00:00', 33.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-11 00:00:00', 31.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-12 00:00:00', 33.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-13 00:00:00', 32.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-14 00:00:00', 31.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-15 00:00:00', 31.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-16 00:00:00', 31.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-17 00:00:00', 31.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-18 00:00:00', 29.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-19 00:00:00', 25.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-20 00:00:00', 26.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-21 00:00:00', 27.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-22 00:00:00', 26.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-23 00:00:00', 27.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-24 00:00:00', 26.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-25 00:00:00', 26.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-26 00:00:00', 27.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-27 00:00:00', 26.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-28 00:00:00', 26.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-29 00:00:00', 27.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-09-30 00:00:00', 25.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-01 00:00:00', 25.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-02 00:00:00', 24.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-03 00:00:00', 25.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-04 00:00:00', 24.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-05 00:00:00', 24.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-06 00:00:00', 24.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-07 00:00:00', 25.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-08 00:00:00', 16.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-09 00:00:00', 14.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-10 00:00:00', 19.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-11 00:00:00', 21.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-12 00:00:00', 18.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-13 00:00:00', 16.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-14 00:00:00', 19.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-15 00:00:00', 21.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-16 00:00:00', 21.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-17 00:00:00', 23.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-18 00:00:00', 25.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-19 00:00:00', 27.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-20 00:00:00', 29.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-21 00:00:00', 20.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-22 00:00:00', 9.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-23 00:00:00', 13.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-24 00:00:00', 17.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-25 00:00:00', 17.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-26 00:00:00', 16.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-27 00:00:00', 15.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-28 00:00:00', 15.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-29 00:00:00', 14.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-30 00:00:00', 15.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-10-31 00:00:00', 19.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-01 00:00:00', 18.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-02 00:00:00', 18.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-03 00:00:00', 21.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-04 00:00:00', 15.2899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-05 00:00:00', 20.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-06 00:00:00', 20.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-07 00:00:00', 18.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-08 00:00:00', 12.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-09 00:00:00', 12.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-10 00:00:00', 16.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-11 00:00:00', 15.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-12 00:00:00', 18.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-13 00:00:00', 15.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-14 00:00:00', 16.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-15 00:00:00', 13.6920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-16 00:00:00', 11.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-17 00:00:00', 7.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-18 00:00:00', 10.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-19 00:00:00', 11.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-20 00:00:00', 8.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-21 00:00:00', 9.77499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-22 00:00:00', 6.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-23 00:00:00', 8.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-24 00:00:00', 11.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-25 00:00:00', 14.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-26 00:00:00', 15.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-27 00:00:00', 9.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-28 00:00:00', 13.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-29 00:00:00', 15.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-11-30 00:00:00', 13.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-01 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-02 00:00:00', 0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-03 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-04 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-05 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-06 00:00:00', 1.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-07 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-08 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-09 00:00:00', 2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-10 00:00:00', 3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-11 00:00:00', 5.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-12 00:00:00', 2.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-13 00:00:00', 3.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-14 00:00:00', 6.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-15 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-16 00:00:00', 2.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-17 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-18 00:00:00', 3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-19 00:00:00', -0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-20 00:00:00', -0.300999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-21 00:00:00', -5.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-22 00:00:00', -3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-23 00:00:00', -1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-24 00:00:00', -1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-25 00:00:00', -1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-26 00:00:00', -4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-27 00:00:00', 0.540000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-28 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-29 00:00:00', 0.709999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-30 00:00:00', -2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1984-12-31 00:00:00', -1.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-01 00:00:00', -1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-02 00:00:00', 1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-03 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-04 00:00:00', 3.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-05 00:00:00', 2.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-06 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-07 00:00:00', 5.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-08 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-09 00:00:00', 7.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-10 00:00:00', 7.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-11 00:00:00', 8.77200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-12 00:00:00', 10.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-13 00:00:00', 8.71800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-14 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-15 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-16 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-17 00:00:00', 3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-18 00:00:00', 0.894999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-19 00:00:00', 7.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-20 00:00:00', 3.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-21 00:00:00', 6.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-22 00:00:00', 9.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-23 00:00:00', 10.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-24 00:00:00', 9.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-25 00:00:00', 3.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-26 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-27 00:00:00', 7.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-28 00:00:00', 6.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-29 00:00:00', 7.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-30 00:00:00', 10.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-01-31 00:00:00', 11.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-01 00:00:00', 9.13799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-02 00:00:00', 10.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-03 00:00:00', 8.92599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-04 00:00:00', 9.26500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-05 00:00:00', 9.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-06 00:00:00', 12.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-07 00:00:00', 8.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-08 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-09 00:00:00', 8.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-10 00:00:00', 8.64999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-11 00:00:00', 6.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-12 00:00:00', 11.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-13 00:00:00', 13.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-14 00:00:00', 14.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-15 00:00:00', 15.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-16 00:00:00', 16.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-17 00:00:00', 19.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-18 00:00:00', 10.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-19 00:00:00', 10.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-20 00:00:00', 11.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-21 00:00:00', 15.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-22 00:00:00', 17.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-23 00:00:00', 12.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-24 00:00:00', 6.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-25 00:00:00', 10.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-26 00:00:00', 15.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-27 00:00:00', 19.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-02-28 00:00:00', 7.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-01 00:00:00', 10.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-02 00:00:00', 12.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-03 00:00:00', 10.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-04 00:00:00', 6.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-05 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-06 00:00:00', 0.437999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-07 00:00:00', 6.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-08 00:00:00', 6.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-09 00:00:00', 5.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-10 00:00:00', 4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-11 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-12 00:00:00', 4.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-13 00:00:00', 10.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-14 00:00:00', 11.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-15 00:00:00', 6.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-16 00:00:00', 12.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-17 00:00:00', 11.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-18 00:00:00', 15.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-19 00:00:00', 18.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-20 00:00:00', 20.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-21 00:00:00', 17.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-22 00:00:00', 18.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-23 00:00:00', 19.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-24 00:00:00', 18.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-25 00:00:00', 15.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-26 00:00:00', 11.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-27 00:00:00', 14.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-28 00:00:00', 19.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-29 00:00:00', 15.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-30 00:00:00', 17.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-03-31 00:00:00', 21.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-01 00:00:00', 23.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-02 00:00:00', 16.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-03 00:00:00', 19.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-04 00:00:00', 21.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-05 00:00:00', 14.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-06 00:00:00', 18.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-07 00:00:00', 11.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-08 00:00:00', 11.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-09 00:00:00', 13.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-10 00:00:00', 18.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-11 00:00:00', 21.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-12 00:00:00', 17.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-13 00:00:00', 18.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-14 00:00:00', 21.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-15 00:00:00', 23.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-16 00:00:00', 24.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-17 00:00:00', 15.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-18 00:00:00', 17.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-19 00:00:00', 22.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-20 00:00:00', 26.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-21 00:00:00', 26.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-22 00:00:00', 26.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-23 00:00:00', 25.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-24 00:00:00', 28.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-25 00:00:00', 30.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-26 00:00:00', 29.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-27 00:00:00', 28.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-28 00:00:00', 29.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-29 00:00:00', 29.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-04-30 00:00:00', 20.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-01 00:00:00', 19.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-02 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-03 00:00:00', 25.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-04 00:00:00', 26.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-05 00:00:00', 28.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-06 00:00:00', 29.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-07 00:00:00', 27.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-08 00:00:00', 24.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-09 00:00:00', 24.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-10 00:00:00', 23.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-11 00:00:00', 24.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-12 00:00:00', 22.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-13 00:00:00', 24.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-14 00:00:00', 25.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-15 00:00:00', 27.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-16 00:00:00', 29.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-17 00:00:00', 31.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-18 00:00:00', 32.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-19 00:00:00', 34.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-20 00:00:00', 30.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-21 00:00:00', 31.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-22 00:00:00', 34.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-23 00:00:00', 30.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-24 00:00:00', 22.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-25 00:00:00', 24.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-26 00:00:00', 28.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-27 00:00:00', 30.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-28 00:00:00', 31.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-29 00:00:00', 33.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-30 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-05-31 00:00:00', 34.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-01 00:00:00', 35.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-02 00:00:00', 33.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-03 00:00:00', 32.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-04 00:00:00', 37.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-05 00:00:00', 37.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-06 00:00:00', 34.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-07 00:00:00', 34.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-08 00:00:00', 35.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-09 00:00:00', 36.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-10 00:00:00', 29.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-11 00:00:00', 31.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-12 00:00:00', 34.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-13 00:00:00', 35.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-14 00:00:00', 35.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-15 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-16 00:00:00', 37.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-17 00:00:00', 38.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-18 00:00:00', 37.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-19 00:00:00', 36.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-20 00:00:00', 35.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-21 00:00:00', 36.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-22 00:00:00', 37.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-23 00:00:00', 38.5530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-24 00:00:00', 39.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-25 00:00:00', 39.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-26 00:00:00', 39.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-27 00:00:00', 39.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-28 00:00:00', 39.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-29 00:00:00', 37.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-06-30 00:00:00', 38.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-01 00:00:00', 37.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-02 00:00:00', 37.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-03 00:00:00', 39.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-04 00:00:00', 40.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-05 00:00:00', 40.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-06 00:00:00', 40.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-07 00:00:00', 37.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-08 00:00:00', 37.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-09 00:00:00', 39.9550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-10 00:00:00', 42.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-11 00:00:00', 39.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-12 00:00:00', 39.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-13 00:00:00', 39.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-14 00:00:00', 39.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-15 00:00:00', 39.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-16 00:00:00', 41.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-17 00:00:00', 39.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-18 00:00:00', 33.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-19 00:00:00', 35.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-20 00:00:00', 38.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-21 00:00:00', 39.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-22 00:00:00', 40.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-23 00:00:00', 40.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-24 00:00:00', 38.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-25 00:00:00', 38.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-26 00:00:00', 40.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-27 00:00:00', 39.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-28 00:00:00', 40.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-29 00:00:00', 41.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-30 00:00:00', 36.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-07-31 00:00:00', 36.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-01 00:00:00', 36.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-02 00:00:00', 34.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-03 00:00:00', 35.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-04 00:00:00', 36.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-05 00:00:00', 36.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-06 00:00:00', 37.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-07 00:00:00', 36.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-08 00:00:00', 36.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-09 00:00:00', 34.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-10 00:00:00', 35.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-11 00:00:00', 34.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-12 00:00:00', 34.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-13 00:00:00', 35.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-14 00:00:00', 35.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-15 00:00:00', 35.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-16 00:00:00', 35.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-17 00:00:00', 34.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-18 00:00:00', 35.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-19 00:00:00', 35.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-20 00:00:00', 34.1899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-21 00:00:00', 34.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-22 00:00:00', 35.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-23 00:00:00', 35.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-24 00:00:00', 34.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-25 00:00:00', 33.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-26 00:00:00', 33.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-27 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-28 00:00:00', 31.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-29 00:00:00', 28.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-30 00:00:00', 29.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-08-31 00:00:00', 30.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-01 00:00:00', 32.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-02 00:00:00', 34.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-03 00:00:00', 34.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-04 00:00:00', 32.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-05 00:00:00', 32.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-06 00:00:00', 30.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-07 00:00:00', 31.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-08 00:00:00', 31.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-09 00:00:00', 31.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-10 00:00:00', 32.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-11 00:00:00', 32.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-12 00:00:00', 32.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-13 00:00:00', 31.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-14 00:00:00', 32.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-15 00:00:00', 32.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-16 00:00:00', 32.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-17 00:00:00', 31.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-18 00:00:00', 30.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-19 00:00:00', 29.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-20 00:00:00', 31.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-21 00:00:00', 31.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-22 00:00:00', 29.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-23 00:00:00', 28.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-24 00:00:00', 29.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-25 00:00:00', 29.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-26 00:00:00', 31.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-27 00:00:00', 31.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-28 00:00:00', 30.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-29 00:00:00', 31.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-09-30 00:00:00', 32.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-01 00:00:00', 33.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-02 00:00:00', 29.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-03 00:00:00', 25.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-04 00:00:00', 25.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-05 00:00:00', 22.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-06 00:00:00', 20.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-07 00:00:00', 21.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-08 00:00:00', 22.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-09 00:00:00', 21.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-10 00:00:00', 22.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-11 00:00:00', 24.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-12 00:00:00', 15.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-13 00:00:00', 17.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-14 00:00:00', 15.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-15 00:00:00', 16.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-16 00:00:00', 18.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-17 00:00:00', 19.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-18 00:00:00', 22.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-19 00:00:00', 23.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-20 00:00:00', 23.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-21 00:00:00', 26.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-22 00:00:00', 21.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-23 00:00:00', 16.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-24 00:00:00', 18.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-25 00:00:00', 17.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-26 00:00:00', 18.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-27 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-28 00:00:00', 22.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-29 00:00:00', 19.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-30 00:00:00', 22.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-10-31 00:00:00', 19.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-01 00:00:00', 14.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-02 00:00:00', 18.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-03 00:00:00', 21.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-04 00:00:00', 20.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-05 00:00:00', 19.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-06 00:00:00', 18.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-07 00:00:00', 18.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-08 00:00:00', 18.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-09 00:00:00', 16.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-10 00:00:00', 15.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-11 00:00:00', 17.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-12 00:00:00', 16.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-13 00:00:00', 18.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-14 00:00:00', 19.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-15 00:00:00', 18.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-16 00:00:00', 15.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-17 00:00:00', 14.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-18 00:00:00', 14.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-19 00:00:00', 8.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-20 00:00:00', 5.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-21 00:00:00', 9.34799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-22 00:00:00', 10.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-23 00:00:00', 11.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-24 00:00:00', 6.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-25 00:00:00', 9.23700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-26 00:00:00', 10.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-27 00:00:00', 13.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-28 00:00:00', 13.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-29 00:00:00', 13.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-11-30 00:00:00', 15.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-01 00:00:00', 15.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-02 00:00:00', 18.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-03 00:00:00', 18.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-04 00:00:00', 17.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-05 00:00:00', 17.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-06 00:00:00', 9.50800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-07 00:00:00', -0.241999998688697815, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-08 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-09 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-10 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-11 00:00:00', 5.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-12 00:00:00', 11.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-13 00:00:00', 11.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-14 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-15 00:00:00', 3.43899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-16 00:00:00', 8.31999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-17 00:00:00', 11.2130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-18 00:00:00', 10.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-19 00:00:00', 13.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-20 00:00:00', 18.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-21 00:00:00', 14.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-22 00:00:00', 12.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-23 00:00:00', 11.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-24 00:00:00', 8.63099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-25 00:00:00', 5.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-26 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-27 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-28 00:00:00', 7.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-29 00:00:00', 4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-30 00:00:00', 8.90400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1985-12-31 00:00:00', 6.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-01 00:00:00', 6.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-02 00:00:00', 7.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-03 00:00:00', 8.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-04 00:00:00', 11.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-05 00:00:00', 13.0819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-06 00:00:00', 7.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-07 00:00:00', 12.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-08 00:00:00', 12.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-09 00:00:00', 11.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-10 00:00:00', 12.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-11 00:00:00', 9.70600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-12 00:00:00', 11.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-13 00:00:00', 12.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-14 00:00:00', 10.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-15 00:00:00', 12.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-16 00:00:00', 11.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-17 00:00:00', 8.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-18 00:00:00', 9.72099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-19 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-20 00:00:00', 13.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-21 00:00:00', 15.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-22 00:00:00', 9.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-23 00:00:00', 9.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-24 00:00:00', 5.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-25 00:00:00', 0.0130000002682209015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-26 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-27 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-28 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-29 00:00:00', -0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-30 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-01-31 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-01 00:00:00', 7.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-02 00:00:00', 8.52000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-03 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-04 00:00:00', 7.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-05 00:00:00', 11.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-06 00:00:00', 10.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-07 00:00:00', 15.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-08 00:00:00', 11.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-09 00:00:00', 9.29800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-10 00:00:00', 12.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-11 00:00:00', 14.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-12 00:00:00', 8.81499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-13 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-14 00:00:00', 4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-15 00:00:00', 8.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-16 00:00:00', 11.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-17 00:00:00', 6.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-18 00:00:00', 5.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-19 00:00:00', 8.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-20 00:00:00', 9.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-21 00:00:00', 11.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-22 00:00:00', 11.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-23 00:00:00', 11.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-24 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-25 00:00:00', 14.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-26 00:00:00', 17.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-27 00:00:00', 18.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-02-28 00:00:00', 19.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-01 00:00:00', 18.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-02 00:00:00', 19.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-03 00:00:00', 9.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-04 00:00:00', 12.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-05 00:00:00', 11.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-06 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-07 00:00:00', 20.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-08 00:00:00', 20.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-09 00:00:00', 21.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-10 00:00:00', 14.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-11 00:00:00', 11.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-12 00:00:00', 7.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-13 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-14 00:00:00', 7.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-15 00:00:00', 6.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-16 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-17 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-18 00:00:00', 6.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-19 00:00:00', 10.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-20 00:00:00', 11.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-21 00:00:00', 12.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-22 00:00:00', 14.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-23 00:00:00', 6.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-24 00:00:00', 11.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-25 00:00:00', 9.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-26 00:00:00', 11.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-27 00:00:00', 10.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-28 00:00:00', 8.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-29 00:00:00', 9.31499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-30 00:00:00', 7.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-03-31 00:00:00', 9.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-01 00:00:00', 11.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-02 00:00:00', 15.9469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-03 00:00:00', 17.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-04 00:00:00', 21.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-05 00:00:00', 22.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-06 00:00:00', 20.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-07 00:00:00', 21.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-08 00:00:00', 23.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-09 00:00:00', 23.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-10 00:00:00', 24.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-11 00:00:00', 25.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-12 00:00:00', 22.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-13 00:00:00', 24.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-14 00:00:00', 21.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-15 00:00:00', 22.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-16 00:00:00', 22.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-17 00:00:00', 26.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-18 00:00:00', 26.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-19 00:00:00', 25.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-20 00:00:00', 26.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-21 00:00:00', 25.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-22 00:00:00', 14.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-23 00:00:00', 17.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-24 00:00:00', 19.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-25 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-26 00:00:00', 19.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-27 00:00:00', 20.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-28 00:00:00', 20.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-29 00:00:00', 22.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-04-30 00:00:00', 21.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-01 00:00:00', 26.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-02 00:00:00', 25.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-03 00:00:00', 28.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-04 00:00:00', 30.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-05 00:00:00', 35.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-06 00:00:00', 34.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-07 00:00:00', 31.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-08 00:00:00', 30.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-09 00:00:00', 30.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-10 00:00:00', 31.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-11 00:00:00', 33.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-12 00:00:00', 30.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-13 00:00:00', 31.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-14 00:00:00', 34.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-15 00:00:00', 30.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-16 00:00:00', 26.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-17 00:00:00', 21.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-18 00:00:00', 24.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-19 00:00:00', 22.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-20 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-21 00:00:00', 27.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-22 00:00:00', 27.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-23 00:00:00', 32.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-24 00:00:00', 35.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-25 00:00:00', 29.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-26 00:00:00', 29.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-27 00:00:00', 30.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-28 00:00:00', 30.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-29 00:00:00', 28.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-30 00:00:00', 19.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-01 00:00:00', 28.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-02 00:00:00', 30.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-03 00:00:00', 28.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-04 00:00:00', 29.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-05 00:00:00', 31.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-06 00:00:00', 31.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-07 00:00:00', 32.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-08 00:00:00', 34.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-09 00:00:00', 36.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-10 00:00:00', 34.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-11 00:00:00', 30.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-12 00:00:00', 33.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-13 00:00:00', 33.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-14 00:00:00', 32.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-15 00:00:00', 33.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-16 00:00:00', 32.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-17 00:00:00', 35.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-18 00:00:00', 38.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-19 00:00:00', 40.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-20 00:00:00', 37.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-21 00:00:00', 38.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-22 00:00:00', 38.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-23 00:00:00', 38.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-24 00:00:00', 37.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-25 00:00:00', 36.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-26 00:00:00', 37.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-27 00:00:00', 36.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-28 00:00:00', 36.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-29 00:00:00', 36.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-06-30 00:00:00', 37.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-01 00:00:00', 40.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-02 00:00:00', 40.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-03 00:00:00', 40.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-04 00:00:00', 39.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-05 00:00:00', 38.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-06 00:00:00', 37.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-07 00:00:00', 37.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-08 00:00:00', 35.9550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-09 00:00:00', 35.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-10 00:00:00', 35.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-11 00:00:00', 36.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-12 00:00:00', 37.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-13 00:00:00', 38.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-14 00:00:00', 39.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-15 00:00:00', 41.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-16 00:00:00', 40.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-17 00:00:00', 40.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-18 00:00:00', 40.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-19 00:00:00', 38.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-20 00:00:00', 36.9410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-21 00:00:00', 36.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-22 00:00:00', 33.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-23 00:00:00', 32.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-24 00:00:00', 33.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-25 00:00:00', 35.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-26 00:00:00', 36.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-27 00:00:00', 40.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-28 00:00:00', 39.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-29 00:00:00', 41.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-30 00:00:00', 39.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-07-31 00:00:00', 39.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-01 00:00:00', 40.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-02 00:00:00', 40.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-03 00:00:00', 40.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-04 00:00:00', 40.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-05 00:00:00', 36.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-06 00:00:00', 34.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-07 00:00:00', 35.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-08 00:00:00', 32.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-09 00:00:00', 33.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-10 00:00:00', 33.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-11 00:00:00', 34.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-12 00:00:00', 36.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-13 00:00:00', 36.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-14 00:00:00', 36.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-15 00:00:00', 38.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-16 00:00:00', 39.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-17 00:00:00', 37.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-18 00:00:00', 37.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-19 00:00:00', 34.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-20 00:00:00', 33.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-21 00:00:00', 33.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-22 00:00:00', 33.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-23 00:00:00', 33.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-24 00:00:00', 34.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-25 00:00:00', 35.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-26 00:00:00', 34.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-27 00:00:00', 33.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-28 00:00:00', 33.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-29 00:00:00', 33.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-30 00:00:00', 32.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-08-31 00:00:00', 32.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-01 00:00:00', 32.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-02 00:00:00', 33.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-03 00:00:00', 32.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-04 00:00:00', 32.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-05 00:00:00', 32.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-06 00:00:00', 33.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-07 00:00:00', 33.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-08 00:00:00', 31.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-09 00:00:00', 31.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-10 00:00:00', 31.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-11 00:00:00', 31.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-12 00:00:00', 31.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-13 00:00:00', 30.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-14 00:00:00', 30.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-15 00:00:00', 31.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-16 00:00:00', 31.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-17 00:00:00', 32.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-18 00:00:00', 32.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-19 00:00:00', 31.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-20 00:00:00', 29.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-21 00:00:00', 29.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-22 00:00:00', 30.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-23 00:00:00', 30.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-24 00:00:00', 32.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-25 00:00:00', 33.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-26 00:00:00', 32.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-27 00:00:00', 32.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-28 00:00:00', 31.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-29 00:00:00', 31.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-09-30 00:00:00', 24.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-01 00:00:00', 26.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-02 00:00:00', 29.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-03 00:00:00', 30.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-04 00:00:00', 29.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-05 00:00:00', 32.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-06 00:00:00', 32.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-07 00:00:00', 31.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-08 00:00:00', 23.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-09 00:00:00', 25.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-10 00:00:00', 27.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-11 00:00:00', 29.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-12 00:00:00', 28.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-13 00:00:00', 25.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-14 00:00:00', 19.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-15 00:00:00', 12.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-16 00:00:00', 13.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-17 00:00:00', 15.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-18 00:00:00', 17.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-19 00:00:00', 18.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-20 00:00:00', 21.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-21 00:00:00', 23.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-22 00:00:00', 23.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-23 00:00:00', 25.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-24 00:00:00', 25.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-25 00:00:00', 26.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-26 00:00:00', 26.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-27 00:00:00', 23.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-28 00:00:00', 23.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-29 00:00:00', 21.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-30 00:00:00', 20.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-10-31 00:00:00', 21.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-01 00:00:00', 21.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-02 00:00:00', 22.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-03 00:00:00', 23.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-04 00:00:00', 24.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-05 00:00:00', 25.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-06 00:00:00', 20.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-07 00:00:00', 21.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-08 00:00:00', 23.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-09 00:00:00', 22.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-10 00:00:00', 21.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-11 00:00:00', 18.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-12 00:00:00', 13.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-13 00:00:00', 8.53600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-14 00:00:00', 9.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-15 00:00:00', 9.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-16 00:00:00', 7.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-17 00:00:00', 9.07900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-18 00:00:00', 12.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-19 00:00:00', 10.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-20 00:00:00', 6.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-21 00:00:00', 5.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-22 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-23 00:00:00', 7.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-24 00:00:00', 10.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-25 00:00:00', 6.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-26 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-27 00:00:00', 9.64500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-28 00:00:00', 9.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-29 00:00:00', 10.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-11-30 00:00:00', 13.6059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-01 00:00:00', 15.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-02 00:00:00', 16.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-03 00:00:00', 14.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-04 00:00:00', 12.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-05 00:00:00', 11.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-06 00:00:00', 7.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-07 00:00:00', 8.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-08 00:00:00', 13.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-09 00:00:00', 12.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-10 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-11 00:00:00', -3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-12 00:00:00', -5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-13 00:00:00', -6.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-14 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-15 00:00:00', -1.04400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-16 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-17 00:00:00', 2.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-18 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-19 00:00:00', 3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-20 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-21 00:00:00', 6.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-22 00:00:00', 5.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-23 00:00:00', 6.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-24 00:00:00', 1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-01 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-02 00:00:00', 9.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-03 00:00:00', 12.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-04 00:00:00', 11.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-05 00:00:00', 12.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-06 00:00:00', 13.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-07 00:00:00', 14.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-08 00:00:00', 9.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-09 00:00:00', 12.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-10 00:00:00', 12.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-11 00:00:00', 14.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-12 00:00:00', 9.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-13 00:00:00', 8.15400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-14 00:00:00', 11.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-15 00:00:00', 9.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-16 00:00:00', 5.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-17 00:00:00', 9.14000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-18 00:00:00', 7.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-19 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-20 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-21 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-22 00:00:00', 2.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-23 00:00:00', 8.77200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-24 00:00:00', 14.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-25 00:00:00', 15.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-26 00:00:00', 15.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-27 00:00:00', 17.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-28 00:00:00', 15.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-29 00:00:00', 13.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-30 00:00:00', 16.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-01-31 00:00:00', 15.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-01 00:00:00', 10.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-02 00:00:00', 11.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-03 00:00:00', 12.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-04 00:00:00', 16.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-05 00:00:00', 19.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-06 00:00:00', 10.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-07 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-08 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-09 00:00:00', 12.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-10 00:00:00', 15.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-11 00:00:00', 11.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-12 00:00:00', 8.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-13 00:00:00', 9.81299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-14 00:00:00', 10.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-15 00:00:00', 6.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-16 00:00:00', 5.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-17 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-18 00:00:00', 5.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-19 00:00:00', 12.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-20 00:00:00', 14.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-21 00:00:00', 13.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-22 00:00:00', 8.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-23 00:00:00', 9.52499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-24 00:00:00', 9.47999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-25 00:00:00', 13.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-26 00:00:00', 16.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-27 00:00:00', 17.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-02-28 00:00:00', 18.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-01 00:00:00', 18.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-02 00:00:00', 16.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-03 00:00:00', 20.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-04 00:00:00', 20.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-05 00:00:00', 15.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-06 00:00:00', 11.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-07 00:00:00', 12.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-08 00:00:00', 15.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-09 00:00:00', 16.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-10 00:00:00', 18.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-11 00:00:00', 16.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-12 00:00:00', 11.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-13 00:00:00', 8.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-14 00:00:00', 18.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-15 00:00:00', 12.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-16 00:00:00', 12.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-17 00:00:00', 16.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-18 00:00:00', 16.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-19 00:00:00', 14.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-20 00:00:00', 17.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-21 00:00:00', 13.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-22 00:00:00', 7.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-23 00:00:00', 10.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-24 00:00:00', 15.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-25 00:00:00', 17.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-26 00:00:00', 18.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-27 00:00:00', 18.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-28 00:00:00', 15.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-29 00:00:00', 18.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-30 00:00:00', 18.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-03-31 00:00:00', 21.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-01 00:00:00', 13.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-02 00:00:00', 12.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-03 00:00:00', 14.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-04 00:00:00', 17.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-05 00:00:00', 21.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-06 00:00:00', 12.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-07 00:00:00', 16.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-08 00:00:00', 9.27200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-09 00:00:00', 15.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-10 00:00:00', 18.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-11 00:00:00', 18.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-12 00:00:00', 20.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-13 00:00:00', 20.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-14 00:00:00', 20.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-15 00:00:00', 22.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-16 00:00:00', 22.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-17 00:00:00', 22.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-18 00:00:00', 25.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-19 00:00:00', 27.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-20 00:00:00', 26.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-21 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-22 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-23 00:00:00', 19.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-24 00:00:00', 22.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-25 00:00:00', 25.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-26 00:00:00', 26.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-27 00:00:00', 28.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-28 00:00:00', 20.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-29 00:00:00', 21.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-04-30 00:00:00', 20.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-01 00:00:00', 21.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-02 00:00:00', 21.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-03 00:00:00', 24.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-04 00:00:00', 27.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-05 00:00:00', 25.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-06 00:00:00', 25.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-07 00:00:00', 23.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-08 00:00:00', 23.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-09 00:00:00', 24.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-10 00:00:00', 27.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-11 00:00:00', 27.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-12 00:00:00', 28.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-13 00:00:00', 29.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-14 00:00:00', 30.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-15 00:00:00', 31.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-16 00:00:00', 32.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-17 00:00:00', 32.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-18 00:00:00', 29.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-19 00:00:00', 28.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-20 00:00:00', 26.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-21 00:00:00', 26.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-22 00:00:00', 25.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-23 00:00:00', 29.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-24 00:00:00', 32.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-25 00:00:00', 35.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-26 00:00:00', 35.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-27 00:00:00', 32.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-28 00:00:00', 35.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-29 00:00:00', 32.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-30 00:00:00', 28.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-05-31 00:00:00', 33.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-01 00:00:00', 33.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-02 00:00:00', 28.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-03 00:00:00', 32.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-04 00:00:00', 34.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-05 00:00:00', 35.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-06 00:00:00', 36.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-07 00:00:00', 34.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-08 00:00:00', 32.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-09 00:00:00', 30.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-10 00:00:00', 31.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-11 00:00:00', 32.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-12 00:00:00', 32.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-13 00:00:00', 31.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-14 00:00:00', 33.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-15 00:00:00', 31.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-16 00:00:00', 31.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-17 00:00:00', 34.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-18 00:00:00', 35.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-19 00:00:00', 35.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-20 00:00:00', 29.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-21 00:00:00', 29.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-22 00:00:00', 31.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-23 00:00:00', 33.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-24 00:00:00', 34.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-25 00:00:00', 35.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-26 00:00:00', 36.1899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-27 00:00:00', 37.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-28 00:00:00', 37.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-29 00:00:00', 36.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-06-30 00:00:00', 37.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-01 00:00:00', 38.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-02 00:00:00', 37.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-03 00:00:00', 38.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-04 00:00:00', 38.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-05 00:00:00', 31.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-06 00:00:00', 34.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-07 00:00:00', 35.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-08 00:00:00', 35.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-09 00:00:00', 37.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-10 00:00:00', 41.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-11 00:00:00', 31.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-12 00:00:00', 30.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-13 00:00:00', 29.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-14 00:00:00', 28.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-15 00:00:00', 31.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-16 00:00:00', 33.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-17 00:00:00', 33.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-18 00:00:00', 35.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-19 00:00:00', 35.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-20 00:00:00', 35.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-21 00:00:00', 37.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-22 00:00:00', 40.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-23 00:00:00', 40.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-24 00:00:00', 42.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-25 00:00:00', 35.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-26 00:00:00', 32.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-27 00:00:00', 33.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-28 00:00:00', 34.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-29 00:00:00', 35.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-30 00:00:00', 36.5789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-07-31 00:00:00', 31.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-01 00:00:00', 33.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-02 00:00:00', 37.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-03 00:00:00', 37.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-04 00:00:00', 38.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-05 00:00:00', 37.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-06 00:00:00', 38.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-07 00:00:00', 39.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-08 00:00:00', 37.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-09 00:00:00', 36.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-10 00:00:00', 37.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-11 00:00:00', 37.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-12 00:00:00', 37.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-13 00:00:00', 39.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-14 00:00:00', 40.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-15 00:00:00', 39.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-16 00:00:00', 39.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-17 00:00:00', 38.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-18 00:00:00', 39.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-19 00:00:00', 39.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-20 00:00:00', 39.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-21 00:00:00', 39.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-22 00:00:00', 38.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-23 00:00:00', 38.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-24 00:00:00', 39.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-25 00:00:00', 36.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-26 00:00:00', 37.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-27 00:00:00', 37.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-28 00:00:00', 36.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-29 00:00:00', 36.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-30 00:00:00', 39.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-08-31 00:00:00', 34.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-01 00:00:00', 32.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-02 00:00:00', 32.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-03 00:00:00', 34.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-04 00:00:00', 33.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-05 00:00:00', 36.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-06 00:00:00', 37.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-07 00:00:00', 36.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-08 00:00:00', 29.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-09 00:00:00', 28.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-10 00:00:00', 27.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-11 00:00:00', 28.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-12 00:00:00', 30.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-13 00:00:00', 31.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-14 00:00:00', 33.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-15 00:00:00', 32.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-16 00:00:00', 32.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-17 00:00:00', 34.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-18 00:00:00', 33.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-19 00:00:00', 34.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-20 00:00:00', 24.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-21 00:00:00', 25.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-22 00:00:00', 30.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-23 00:00:00', 31.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-24 00:00:00', 25.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-25 00:00:00', 27.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-26 00:00:00', 27.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-27 00:00:00', 27.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-28 00:00:00', 28.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-29 00:00:00', 29.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-09-30 00:00:00', 32.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-01 00:00:00', 27.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-02 00:00:00', 26.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-03 00:00:00', 25.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-04 00:00:00', 28.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-05 00:00:00', 30.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-06 00:00:00', 28.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-07 00:00:00', 27.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-08 00:00:00', 21.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-09 00:00:00', 21.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-10 00:00:00', 12.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-11 00:00:00', 12.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-12 00:00:00', 12.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-13 00:00:00', 12.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-14 00:00:00', 13.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-15 00:00:00', 14.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-16 00:00:00', 14.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-17 00:00:00', 11.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-18 00:00:00', 13.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-19 00:00:00', 14.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-20 00:00:00', 17.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-21 00:00:00', 19.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-22 00:00:00', 19.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-23 00:00:00', 22.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-24 00:00:00', 16.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-25 00:00:00', 21.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-26 00:00:00', 14.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-27 00:00:00', 10.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-28 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-29 00:00:00', 5.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-30 00:00:00', 11.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-10-31 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-01 00:00:00', 6.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-02 00:00:00', 8.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-03 00:00:00', 12.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-04 00:00:00', 17.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-05 00:00:00', 15.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-06 00:00:00', 17.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-07 00:00:00', 20.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-08 00:00:00', 21.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-09 00:00:00', 17.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-10 00:00:00', 17.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-11 00:00:00', 15.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-12 00:00:00', 15.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-13 00:00:00', 16.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-14 00:00:00', 18.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-15 00:00:00', 19.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-16 00:00:00', 14.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-17 00:00:00', 10.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-18 00:00:00', 9.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-19 00:00:00', 11.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-20 00:00:00', 12.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-21 00:00:00', 12.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-22 00:00:00', 13.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-23 00:00:00', 15.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-24 00:00:00', 10.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-25 00:00:00', 10.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-26 00:00:00', 10.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-27 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-28 00:00:00', 4.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-29 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-11-30 00:00:00', -2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-01 00:00:00', -0.813000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-02 00:00:00', -2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-03 00:00:00', 0.716000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-04 00:00:00', 7.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-05 00:00:00', 9.97299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-06 00:00:00', 8.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-07 00:00:00', 10.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-08 00:00:00', 10.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-09 00:00:00', 13.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-10 00:00:00', 15.2489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-11 00:00:00', 11.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-12 00:00:00', 13.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-13 00:00:00', 15.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-14 00:00:00', 15.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-15 00:00:00', 8.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-16 00:00:00', 10.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-17 00:00:00', 12.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-18 00:00:00', 14.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-19 00:00:00', 15.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-20 00:00:00', 16.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-21 00:00:00', 19.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-22 00:00:00', 15.2309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-23 00:00:00', 15.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-24 00:00:00', 17.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-25 00:00:00', 13.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-26 00:00:00', 14.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-27 00:00:00', 14.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-28 00:00:00', 14.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-29 00:00:00', 8.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-30 00:00:00', 8.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1987-12-31 00:00:00', 11.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-01 00:00:00', 8.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-02 00:00:00', 13.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-03 00:00:00', 6.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-04 00:00:00', 11.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-05 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-06 00:00:00', 12.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-07 00:00:00', 12.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-08 00:00:00', 6.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-09 00:00:00', 8.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-10 00:00:00', 9.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-11 00:00:00', 8.65200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-12 00:00:00', 5.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-13 00:00:00', 10.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-14 00:00:00', 8.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-15 00:00:00', 5.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-16 00:00:00', 10.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-17 00:00:00', 6.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-18 00:00:00', 9.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-19 00:00:00', 12.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-20 00:00:00', 8.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-21 00:00:00', -1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-22 00:00:00', 3.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-23 00:00:00', 4.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-24 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-25 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-26 00:00:00', 6.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-27 00:00:00', 7.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-28 00:00:00', 9.70600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-29 00:00:00', 11.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-30 00:00:00', 7.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-01-31 00:00:00', 6.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-01 00:00:00', 8.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-02 00:00:00', 15.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-03 00:00:00', 18.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-04 00:00:00', 9.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-05 00:00:00', 6.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-06 00:00:00', 6.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-07 00:00:00', -0.155000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-08 00:00:00', -1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-09 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-10 00:00:00', 10.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-11 00:00:00', 8.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-12 00:00:00', 7.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-13 00:00:00', 9.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-14 00:00:00', 7.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-15 00:00:00', 11.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-16 00:00:00', 3.93199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-17 00:00:00', 11.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-18 00:00:00', 7.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-19 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-20 00:00:00', 12.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-21 00:00:00', 4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-22 00:00:00', 6.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-23 00:00:00', 7.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-24 00:00:00', 11.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-25 00:00:00', 15.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-26 00:00:00', 7.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-27 00:00:00', 7.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-28 00:00:00', 7.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-02-29 00:00:00', 11.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-01 00:00:00', 14.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-02 00:00:00', 12.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-03 00:00:00', 18.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-04 00:00:00', 19.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-05 00:00:00', 20.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-06 00:00:00', 12.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-07 00:00:00', 7, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-08 00:00:00', 14.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-09 00:00:00', 13.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-10 00:00:00', 10.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-11 00:00:00', 14.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-12 00:00:00', 12.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-13 00:00:00', 12.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-14 00:00:00', 13.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-15 00:00:00', 12.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-16 00:00:00', 9.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-17 00:00:00', 11.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-18 00:00:00', 9.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-19 00:00:00', 13.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-20 00:00:00', 14.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-21 00:00:00', 15.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-22 00:00:00', 12.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-23 00:00:00', 10.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-24 00:00:00', 11.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-25 00:00:00', 6.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-26 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-27 00:00:00', 12.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-28 00:00:00', 10.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-29 00:00:00', 11.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-30 00:00:00', 11.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-03-31 00:00:00', 12.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-01 00:00:00', 16.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-02 00:00:00', 11.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-03 00:00:00', 8.40699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-04 00:00:00', 11.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-05 00:00:00', 15.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-06 00:00:00', 18.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-07 00:00:00', 17.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-08 00:00:00', 18.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-09 00:00:00', 13.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-10 00:00:00', 15.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-11 00:00:00', 21.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-12 00:00:00', 23.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-13 00:00:00', 26.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-14 00:00:00', 26.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-15 00:00:00', 27.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-16 00:00:00', 28.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-17 00:00:00', 22.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-18 00:00:00', 19.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-19 00:00:00', 22.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-20 00:00:00', 25.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-21 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-22 00:00:00', 27.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-23 00:00:00', 25.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-24 00:00:00', 26.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-25 00:00:00', 28.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-26 00:00:00', 30.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-27 00:00:00', 31.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-28 00:00:00', 31.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-29 00:00:00', 25.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-04-30 00:00:00', 23.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-01 00:00:00', 22.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-02 00:00:00', 22.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-03 00:00:00', 24.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-04 00:00:00', 20.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-05 00:00:00', 16.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-06 00:00:00', 20.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-07 00:00:00', 23.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-08 00:00:00', 24.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-09 00:00:00', 25.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-10 00:00:00', 26.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-11 00:00:00', 28.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-12 00:00:00', 30.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-13 00:00:00', 30.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-14 00:00:00', 21.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-15 00:00:00', 26.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-16 00:00:00', 20.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-17 00:00:00', 24.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-18 00:00:00', 22.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-19 00:00:00', 26.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-20 00:00:00', 29.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-21 00:00:00', 28.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-22 00:00:00', 27.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-23 00:00:00', 28.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-24 00:00:00', 29.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-25 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-26 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-27 00:00:00', 33.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-28 00:00:00', 31.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-29 00:00:00', 35.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-30 00:00:00', 37.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-05-31 00:00:00', 28.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-01 00:00:00', 29.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-02 00:00:00', 30.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-03 00:00:00', 30.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-04 00:00:00', 26.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-05 00:00:00', 30.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-06 00:00:00', 30.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-07 00:00:00', 31.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-08 00:00:00', 31.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-09 00:00:00', 30.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-10 00:00:00', 27.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-11 00:00:00', 32.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-12 00:00:00', 35.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-13 00:00:00', 35.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-14 00:00:00', 38.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-15 00:00:00', 36.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-16 00:00:00', 39.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-17 00:00:00', 40.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-18 00:00:00', 40.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-19 00:00:00', 41.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-20 00:00:00', 41.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-21 00:00:00', 41.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-22 00:00:00', 37.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-23 00:00:00', 37.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-24 00:00:00', 40.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-25 00:00:00', 42.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-26 00:00:00', 40.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-27 00:00:00', 35.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-28 00:00:00', 33.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-29 00:00:00', 35.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-06-30 00:00:00', 35.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-01 00:00:00', 40.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-02 00:00:00', 42.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-03 00:00:00', 40.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-04 00:00:00', 41.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-05 00:00:00', 40.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-06 00:00:00', 37.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-07 00:00:00', 38.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-08 00:00:00', 37.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-09 00:00:00', 38.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-10 00:00:00', 41.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-11 00:00:00', 42.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-12 00:00:00', 41.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-13 00:00:00', 41.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-14 00:00:00', 38.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-15 00:00:00', 37.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-16 00:00:00', 38.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-17 00:00:00', 40.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-18 00:00:00', 40.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-19 00:00:00', 41.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-20 00:00:00', 41.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-21 00:00:00', 40.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-22 00:00:00', 38.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-23 00:00:00', 37.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-24 00:00:00', 34.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-25 00:00:00', 36.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-26 00:00:00', 37.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-27 00:00:00', 39.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-28 00:00:00', 41.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-29 00:00:00', 39.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-30 00:00:00', 39.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-07-31 00:00:00', 37.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-01 00:00:00', 38.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-02 00:00:00', 34.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-03 00:00:00', 35.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-04 00:00:00', 35.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-05 00:00:00', 39.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-06 00:00:00', 38.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-07 00:00:00', 38.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-08 00:00:00', 37.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-09 00:00:00', 37.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-10 00:00:00', 37.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-11 00:00:00', 38.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-12 00:00:00', 38.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-13 00:00:00', 39.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-14 00:00:00', 37.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-15 00:00:00', 37.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-16 00:00:00', 35.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-17 00:00:00', 36.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-18 00:00:00', 35.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-19 00:00:00', 35.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-20 00:00:00', 37.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-21 00:00:00', 36.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-22 00:00:00', 34.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-23 00:00:00', 32.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-24 00:00:00', 31.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-25 00:00:00', 31.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-26 00:00:00', 30.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-27 00:00:00', 30.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-28 00:00:00', 32.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-29 00:00:00', 33.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-30 00:00:00', 33.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-08-31 00:00:00', 33.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-01 00:00:00', 35.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-02 00:00:00', 33.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-03 00:00:00', 34.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-04 00:00:00', 34.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-05 00:00:00', 36.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-06 00:00:00', 38.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-07 00:00:00', 37.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-08 00:00:00', 34.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-09 00:00:00', 32.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-10 00:00:00', 34.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-11 00:00:00', 35.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-12 00:00:00', 36.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-13 00:00:00', 35.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-14 00:00:00', 33.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-15 00:00:00', 33.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-16 00:00:00', 30.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-17 00:00:00', 31.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-18 00:00:00', 29.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-19 00:00:00', 33.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-20 00:00:00', 31.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-21 00:00:00', 32.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-22 00:00:00', 24.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-23 00:00:00', 26.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-24 00:00:00', 25.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-25 00:00:00', 24.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-26 00:00:00', 24.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-27 00:00:00', 24.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-28 00:00:00', 25.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-29 00:00:00', 23.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-09-30 00:00:00', 23.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-01 00:00:00', 23.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-02 00:00:00', 23.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-03 00:00:00', 16.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-04 00:00:00', 19.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-05 00:00:00', 23.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-06 00:00:00', 23.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-07 00:00:00', 24.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-08 00:00:00', 23.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-09 00:00:00', 23.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-10 00:00:00', 25.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-11 00:00:00', 23.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-12 00:00:00', 22.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-13 00:00:00', 20.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-14 00:00:00', 20.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-15 00:00:00', 22.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-16 00:00:00', 19.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-17 00:00:00', 18.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-18 00:00:00', 19.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-19 00:00:00', 19.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-20 00:00:00', 21.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-21 00:00:00', 25.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-22 00:00:00', 25.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-23 00:00:00', 14.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-24 00:00:00', 18.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-25 00:00:00', 19.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-26 00:00:00', 20.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-27 00:00:00', 24.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-28 00:00:00', 25.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-29 00:00:00', 19.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-30 00:00:00', 21.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-10-31 00:00:00', 23.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-01 00:00:00', 23.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-02 00:00:00', 24.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-03 00:00:00', 24.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-04 00:00:00', 23.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-05 00:00:00', 24.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-06 00:00:00', 22.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-07 00:00:00', 21.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-08 00:00:00', 23.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-09 00:00:00', 24.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-10 00:00:00', 25.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-11 00:00:00', 26.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-12 00:00:00', 27.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-13 00:00:00', 25.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-14 00:00:00', 26.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-15 00:00:00', 17.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-16 00:00:00', 16.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-17 00:00:00', 22.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-18 00:00:00', 21.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-19 00:00:00', 20.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-20 00:00:00', 24.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-21 00:00:00', 17.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-22 00:00:00', 15.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-23 00:00:00', 11.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-24 00:00:00', 12.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-25 00:00:00', 11.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-26 00:00:00', 12.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-27 00:00:00', 15.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-28 00:00:00', 17.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-29 00:00:00', 18.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-11-30 00:00:00', 17.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-01 00:00:00', 15.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-02 00:00:00', 15.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-03 00:00:00', 18.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-04 00:00:00', 18.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-05 00:00:00', 14.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-06 00:00:00', 16.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-07 00:00:00', 15.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-08 00:00:00', 17.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-09 00:00:00', 17.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-10 00:00:00', 19.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-11 00:00:00', 16.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-12 00:00:00', 18.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-13 00:00:00', 18.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-14 00:00:00', 10.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-15 00:00:00', 13.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-16 00:00:00', 12.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-17 00:00:00', 10.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-18 00:00:00', 13.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-19 00:00:00', 13.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-20 00:00:00', 13.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-21 00:00:00', 8.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-22 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-23 00:00:00', 8.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-24 00:00:00', 7.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-25 00:00:00', 8.61699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-26 00:00:00', 12.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-27 00:00:00', 13.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-28 00:00:00', 11.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-29 00:00:00', 9.57199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-30 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1988-12-31 00:00:00', 10.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-01 00:00:00', 6.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-02 00:00:00', 11.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-03 00:00:00', 9.22799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-04 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-05 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-06 00:00:00', -0.222000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-07 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-08 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-09 00:00:00', 5.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-10 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-11 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-12 00:00:00', 4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-13 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-14 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-15 00:00:00', 1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-16 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-17 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-18 00:00:00', 3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-19 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-20 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-21 00:00:00', 6.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-22 00:00:00', 3.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-23 00:00:00', 5.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-24 00:00:00', 8.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-25 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-26 00:00:00', 6.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-27 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-28 00:00:00', 3.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-29 00:00:00', 4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-30 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-01-31 00:00:00', -1.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-01 00:00:00', 5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-02 00:00:00', 6.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-03 00:00:00', 3.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-04 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-05 00:00:00', 1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-06 00:00:00', -0.444000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-07 00:00:00', 2.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-08 00:00:00', 4.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-09 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-10 00:00:00', 9.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-11 00:00:00', 9.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-12 00:00:00', 7.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-13 00:00:00', -0.257999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-14 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-15 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-16 00:00:00', -1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-17 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-18 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-19 00:00:00', 7.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-20 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-21 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-22 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-23 00:00:00', 8.09500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-24 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-25 00:00:00', 4.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-26 00:00:00', 0.791999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-27 00:00:00', 0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-02-28 00:00:00', 5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-01 00:00:00', 6.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-02 00:00:00', 8.99600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-03 00:00:00', 9.32400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-04 00:00:00', 11.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-05 00:00:00', 13.508000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-06 00:00:00', 14.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-07 00:00:00', 15.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-08 00:00:00', 9.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-09 00:00:00', 10.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-10 00:00:00', 13.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-11 00:00:00', 16.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-12 00:00:00', 17.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-13 00:00:00', 10.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-14 00:00:00', 13.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-15 00:00:00', 18.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-16 00:00:00', 22.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-17 00:00:00', 15.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-18 00:00:00', 14.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-19 00:00:00', 17.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-20 00:00:00', 9.79800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-21 00:00:00', 17.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-22 00:00:00', 8.12399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-23 00:00:00', 12.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-24 00:00:00', 14.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-25 00:00:00', 17.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-26 00:00:00', 20.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-27 00:00:00', 22.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-28 00:00:00', 22.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-29 00:00:00', 16.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-30 00:00:00', 17.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-03-31 00:00:00', 11.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-01 00:00:00', 11.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-02 00:00:00', 13.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-03 00:00:00', 11.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-04 00:00:00', 4.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-05 00:00:00', 17.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-06 00:00:00', 18.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-07 00:00:00', 17.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-08 00:00:00', 14.814000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-09 00:00:00', 13.9709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-10 00:00:00', 14.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-11 00:00:00', 17.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-12 00:00:00', 16.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-13 00:00:00', 20.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-14 00:00:00', 23.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-15 00:00:00', 24.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-16 00:00:00', 18.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-17 00:00:00', 19.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-18 00:00:00', 20.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-19 00:00:00', 21.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-20 00:00:00', 23.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-21 00:00:00', 23.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-22 00:00:00', 22.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-23 00:00:00', 25.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-24 00:00:00', 19.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-25 00:00:00', 22.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-26 00:00:00', 24.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-27 00:00:00', 25.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-28 00:00:00', 24.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-29 00:00:00', 26.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-04-30 00:00:00', 18.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-01 00:00:00', 8.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-02 00:00:00', 12.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-03 00:00:00', 11.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-04 00:00:00', 12.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-05 00:00:00', 8.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-06 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-07 00:00:00', 25.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-08 00:00:00', 25.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-09 00:00:00', 17.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-10 00:00:00', 21.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-11 00:00:00', 24.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-12 00:00:00', 26.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-13 00:00:00', 27.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-14 00:00:00', 26.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-15 00:00:00', 23.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-16 00:00:00', 25.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-17 00:00:00', 26.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-18 00:00:00', 25.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-19 00:00:00', 29.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-20 00:00:00', 29.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-21 00:00:00', 24.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-22 00:00:00', 26.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-23 00:00:00', 25.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-24 00:00:00', 27.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-25 00:00:00', 28.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-26 00:00:00', 31.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-27 00:00:00', 32.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-28 00:00:00', 34.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-29 00:00:00', 37.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-30 00:00:00', 36.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-05-31 00:00:00', 34.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-01 00:00:00', 36.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-02 00:00:00', 37.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-03 00:00:00', 36.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-04 00:00:00', 36.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-05 00:00:00', 34.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-06 00:00:00', 32.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-07 00:00:00', 30.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-08 00:00:00', 30.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-09 00:00:00', 30.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-10 00:00:00', 31.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-11 00:00:00', 34.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-12 00:00:00', 37.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-13 00:00:00', 34.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-14 00:00:00', 34.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-15 00:00:00', 34.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-16 00:00:00', 33.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-17 00:00:00', 34.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-18 00:00:00', 32.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-19 00:00:00', 28.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-20 00:00:00', 28.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-21 00:00:00', 28.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-22 00:00:00', 32.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-23 00:00:00', 33.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-24 00:00:00', 37.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-25 00:00:00', 37.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-26 00:00:00', 38.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-27 00:00:00', 38.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-28 00:00:00', 37.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-29 00:00:00', 38.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-06-30 00:00:00', 37.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-01 00:00:00', 37.2480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-02 00:00:00', 34.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-03 00:00:00', 37.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-04 00:00:00', 35.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-05 00:00:00', 34.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-06 00:00:00', 35.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-07 00:00:00', 37.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-08 00:00:00', 39.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-09 00:00:00', 40.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-10 00:00:00', 42.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-11 00:00:00', 41.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-12 00:00:00', 40.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-13 00:00:00', 38.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-14 00:00:00', 35.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-15 00:00:00', 36.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-16 00:00:00', 35.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-17 00:00:00', 36.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-18 00:00:00', 35.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-19 00:00:00', 35.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-20 00:00:00', 36.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-21 00:00:00', 36.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-22 00:00:00', 37.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-23 00:00:00', 36.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-24 00:00:00', 35.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-25 00:00:00', 34.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-26 00:00:00', 34.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-27 00:00:00', 37.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-28 00:00:00', 38.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-29 00:00:00', 38.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-30 00:00:00', 36.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-07-31 00:00:00', 33.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-01 00:00:00', 35.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-02 00:00:00', 39.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-03 00:00:00', 38.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-04 00:00:00', 36.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-05 00:00:00', 39.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-06 00:00:00', 38.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-07 00:00:00', 38.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-08 00:00:00', 37.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-09 00:00:00', 38.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-10 00:00:00', 38.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-11 00:00:00', 39.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-12 00:00:00', 39.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-13 00:00:00', 37.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-14 00:00:00', 35.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-15 00:00:00', 35.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-16 00:00:00', 35.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-17 00:00:00', 37.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-18 00:00:00', 37.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-19 00:00:00', 35.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-20 00:00:00', 33.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-21 00:00:00', 33.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-22 00:00:00', 34.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-23 00:00:00', 34.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-24 00:00:00', 34.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-25 00:00:00', 34.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-26 00:00:00', 35.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-27 00:00:00', 32.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-28 00:00:00', 31.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-29 00:00:00', 32.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-30 00:00:00', 32.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-08-31 00:00:00', 32.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-01 00:00:00', 33.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-02 00:00:00', 34.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-03 00:00:00', 34.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-04 00:00:00', 32.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-05 00:00:00', 30.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-06 00:00:00', 28.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-07 00:00:00', 30.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-08 00:00:00', 31.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-09 00:00:00', 32.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-10 00:00:00', 33.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-11 00:00:00', 35.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-12 00:00:00', 33.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-13 00:00:00', 35.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-14 00:00:00', 38.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-15 00:00:00', 38.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-16 00:00:00', 35.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-17 00:00:00', 33.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-18 00:00:00', 34.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-19 00:00:00', 34.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-20 00:00:00', 27.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-21 00:00:00', 25.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-22 00:00:00', 16.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-23 00:00:00', 21.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-24 00:00:00', 23.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-25 00:00:00', 26.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-26 00:00:00', 29.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-27 00:00:00', 28.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-28 00:00:00', 31.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-29 00:00:00', 28.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-09-30 00:00:00', 26.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-01 00:00:00', 28.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-02 00:00:00', 30.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-03 00:00:00', 31.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-04 00:00:00', 32.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-05 00:00:00', 31.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-06 00:00:00', 31.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-07 00:00:00', 31.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-08 00:00:00', 32.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-09 00:00:00', 30.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-10 00:00:00', 27.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-11 00:00:00', 17.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-12 00:00:00', 20.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-13 00:00:00', 21.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-14 00:00:00', 22.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-15 00:00:00', 22.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-16 00:00:00', 23.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-17 00:00:00', 26.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-18 00:00:00', 27.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-19 00:00:00', 25.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-20 00:00:00', 28.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-21 00:00:00', 27.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-22 00:00:00', 24.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-23 00:00:00', 20.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-24 00:00:00', 13.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-25 00:00:00', 19.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-26 00:00:00', 20.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-27 00:00:00', 18.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-28 00:00:00', 21.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-29 00:00:00', 23.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-30 00:00:00', 19.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-10-31 00:00:00', 24.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-01 00:00:00', 14.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-02 00:00:00', 10.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-03 00:00:00', 13.6059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-04 00:00:00', 14.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-05 00:00:00', 14.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-06 00:00:00', 15.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-07 00:00:00', 15.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-08 00:00:00', 9.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-09 00:00:00', 13.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-10 00:00:00', 9.27200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-11 00:00:00', 10.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-12 00:00:00', 13.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-13 00:00:00', 15.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-14 00:00:00', 16.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-15 00:00:00', 17.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-16 00:00:00', 19.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-17 00:00:00', 15.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-18 00:00:00', 12.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-19 00:00:00', 16.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-20 00:00:00', 18.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-21 00:00:00', 16.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-22 00:00:00', 10.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-23 00:00:00', 11.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-24 00:00:00', 13.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-25 00:00:00', 14.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-26 00:00:00', 17.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-27 00:00:00', 17.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-28 00:00:00', 18.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-29 00:00:00', 18.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-11-30 00:00:00', 19.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-01 00:00:00', 21.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-02 00:00:00', 19.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-03 00:00:00', 16.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-04 00:00:00', 13.4329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-05 00:00:00', 19.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-06 00:00:00', 13.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-07 00:00:00', 12.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-08 00:00:00', 11.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-09 00:00:00', 15.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-10 00:00:00', 13.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-11 00:00:00', 14.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-12 00:00:00', 15.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-13 00:00:00', 15.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-14 00:00:00', 14.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-15 00:00:00', 15.2489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-16 00:00:00', 11.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-17 00:00:00', 12.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-18 00:00:00', 8.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-19 00:00:00', 11.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-20 00:00:00', 8.36699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-21 00:00:00', 10.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-22 00:00:00', 8.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-23 00:00:00', 7.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-24 00:00:00', 8.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-25 00:00:00', 8.08899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-26 00:00:00', 9.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-27 00:00:00', 10.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-28 00:00:00', 7.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-29 00:00:00', 7.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-30 00:00:00', 8.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1989-12-31 00:00:00', 7.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-01 00:00:00', 5.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-02 00:00:00', 7.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-03 00:00:00', 4.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-04 00:00:00', 6.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-05 00:00:00', 10.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-06 00:00:00', 7.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-07 00:00:00', 4.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-08 00:00:00', 1.06700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-09 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-10 00:00:00', 3.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-11 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-12 00:00:00', 1.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-13 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-14 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-15 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-16 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-17 00:00:00', 5.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-18 00:00:00', 5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-19 00:00:00', 7.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-20 00:00:00', 5.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-21 00:00:00', 7.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-22 00:00:00', 7.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-23 00:00:00', 10.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-24 00:00:00', 11.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-25 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-26 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-27 00:00:00', -0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-28 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-29 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-30 00:00:00', 4.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-01-31 00:00:00', -0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-01 00:00:00', 0.769999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-02 00:00:00', 3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-03 00:00:00', 6.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-04 00:00:00', 6.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-05 00:00:00', 8.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-06 00:00:00', 6.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-07 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-08 00:00:00', 5.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-09 00:00:00', 7.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-10 00:00:00', 9.98200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-11 00:00:00', 12.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-12 00:00:00', 7.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-13 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-14 00:00:00', 5.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-15 00:00:00', 9.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-16 00:00:00', 10.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-17 00:00:00', 5.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-18 00:00:00', 7.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-19 00:00:00', 10.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-20 00:00:00', 10.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-21 00:00:00', 12.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-22 00:00:00', 7.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-23 00:00:00', 6.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-24 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-25 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-26 00:00:00', 7.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-27 00:00:00', 3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-02-28 00:00:00', 7.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-01 00:00:00', 10.2869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-02 00:00:00', 12.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-03 00:00:00', 12.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-04 00:00:00', 12.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-05 00:00:00', 13.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-06 00:00:00', 12.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-07 00:00:00', 12.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-08 00:00:00', 16.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-09 00:00:00', 8.90499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-10 00:00:00', 8.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-11 00:00:00', 13.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-12 00:00:00', 15.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-13 00:00:00', 18.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-14 00:00:00', 19.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-15 00:00:00', 18.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-16 00:00:00', 12.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-17 00:00:00', 8.85999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-18 00:00:00', 7.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-19 00:00:00', 9.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-20 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-21 00:00:00', 3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-22 00:00:00', 4.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-23 00:00:00', 9.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-24 00:00:00', 11.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-25 00:00:00', 14.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-26 00:00:00', 14.2720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-27 00:00:00', 14.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-28 00:00:00', 16.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-29 00:00:00', 17.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-30 00:00:00', 14.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-03-31 00:00:00', 14.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-01 00:00:00', 17.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-02 00:00:00', 20.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-03 00:00:00', 20.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-04 00:00:00', 19.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-05 00:00:00', 20.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-06 00:00:00', 15.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-07 00:00:00', 18.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-08 00:00:00', 11.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-09 00:00:00', 17.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-10 00:00:00', 18.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-11 00:00:00', 19.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-12 00:00:00', 16.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-13 00:00:00', 19.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-14 00:00:00', 15.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-15 00:00:00', 17.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-16 00:00:00', 18.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-17 00:00:00', 13.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-18 00:00:00', 18.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-19 00:00:00', 18.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-20 00:00:00', 18.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-21 00:00:00', 16.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-22 00:00:00', 23.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-23 00:00:00', 25.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-24 00:00:00', 21.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-25 00:00:00', 21.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-26 00:00:00', 22.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-27 00:00:00', 22.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-28 00:00:00', 24.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-29 00:00:00', 27.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-04-30 00:00:00', 24.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-01 00:00:00', 26.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-02 00:00:00', 25.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-03 00:00:00', 29.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-04 00:00:00', 31.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-05 00:00:00', 31.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-06 00:00:00', 30.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-07 00:00:00', 32.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-08 00:00:00', 29.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-09 00:00:00', 29.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-10 00:00:00', 30.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-11 00:00:00', 33.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-12 00:00:00', 35.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-13 00:00:00', 38.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-14 00:00:00', 33.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-15 00:00:00', 23.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-16 00:00:00', 27.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-17 00:00:00', 27.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-18 00:00:00', 26.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-19 00:00:00', 31.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-20 00:00:00', 31.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-21 00:00:00', 31.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-22 00:00:00', 32.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-23 00:00:00', 33.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-24 00:00:00', 33.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-25 00:00:00', 32.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-26 00:00:00', 33.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-27 00:00:00', 35.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-28 00:00:00', 30.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-29 00:00:00', 30.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-30 00:00:00', 30.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-05-31 00:00:00', 30.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-01 00:00:00', 32.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-02 00:00:00', 35.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-03 00:00:00', 34.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-04 00:00:00', 33.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-05 00:00:00', 33.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-06 00:00:00', 34.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-07 00:00:00', 35.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-08 00:00:00', 34.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-09 00:00:00', 31.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-10 00:00:00', 31.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-11 00:00:00', 33.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-12 00:00:00', 33.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-13 00:00:00', 33.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-14 00:00:00', 35.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-15 00:00:00', 37.4129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-16 00:00:00', 39.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-17 00:00:00', 39.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-18 00:00:00', 40.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-19 00:00:00', 41.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-20 00:00:00', 41.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-21 00:00:00', 41.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-22 00:00:00', 43.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-23 00:00:00', 41.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-24 00:00:00', 39.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-25 00:00:00', 38.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-26 00:00:00', 37.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-27 00:00:00', 39.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-28 00:00:00', 40.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-29 00:00:00', 41.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-06-30 00:00:00', 42.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-01 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-02 00:00:00', 38.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-03 00:00:00', 37.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-04 00:00:00', 37.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-05 00:00:00', 37.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-06 00:00:00', 38.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-07 00:00:00', 38.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-08 00:00:00', 38.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-09 00:00:00', 35.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-10 00:00:00', 34.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-11 00:00:00', 35.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-12 00:00:00', 32.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-13 00:00:00', 33.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-14 00:00:00', 33.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-15 00:00:00', 35.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-16 00:00:00', 36.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-17 00:00:00', 37.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-18 00:00:00', 37.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-19 00:00:00', 37.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-20 00:00:00', 37.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-21 00:00:00', 36.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-22 00:00:00', 35.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-23 00:00:00', 36.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-24 00:00:00', 39.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-25 00:00:00', 40.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-26 00:00:00', 38.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-27 00:00:00', 36.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-28 00:00:00', 38.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-29 00:00:00', 39.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-30 00:00:00', 41.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-07-31 00:00:00', 42.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-01 00:00:00', 40.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-02 00:00:00', 38.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-03 00:00:00', 37.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-04 00:00:00', 39.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-05 00:00:00', 38.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-06 00:00:00', 40.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-07 00:00:00', 40.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-08 00:00:00', 41.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-09 00:00:00', 42.0719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-10 00:00:00', 42.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-11 00:00:00', 41.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-12 00:00:00', 39.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-13 00:00:00', 38.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-14 00:00:00', 36.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-15 00:00:00', 35.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-16 00:00:00', 37.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-17 00:00:00', 37.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-18 00:00:00', 38.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-19 00:00:00', 37.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-20 00:00:00', 38.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-21 00:00:00', 38.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-22 00:00:00', 37.8730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-23 00:00:00', 36.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-24 00:00:00', 34.5120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-25 00:00:00', 34.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-26 00:00:00', 35.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-27 00:00:00', 37.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-28 00:00:00', 38.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-29 00:00:00', 37.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-30 00:00:00', 33.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-08-31 00:00:00', 34.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-01 00:00:00', 34.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-02 00:00:00', 36.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-03 00:00:00', 34.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-04 00:00:00', 31.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-05 00:00:00', 32.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-06 00:00:00', 32.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-07 00:00:00', 34.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-08 00:00:00', 33.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-09 00:00:00', 32.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-10 00:00:00', 32.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-11 00:00:00', 32.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-12 00:00:00', 33.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-13 00:00:00', 34.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-14 00:00:00', 35.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-15 00:00:00', 36.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-16 00:00:00', 35.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-17 00:00:00', 34.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-18 00:00:00', 32.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-19 00:00:00', 33.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-20 00:00:00', 33.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-21 00:00:00', 34.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-22 00:00:00', 33.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-23 00:00:00', 33.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-24 00:00:00', 29.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-25 00:00:00', 30.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-26 00:00:00', 30.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-27 00:00:00', 30.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-28 00:00:00', 29.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-29 00:00:00', 29.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-09-30 00:00:00', 30.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-01 00:00:00', 31.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-02 00:00:00', 31.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-03 00:00:00', 29.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-04 00:00:00', 30.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-05 00:00:00', 29.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-06 00:00:00', 21.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-07 00:00:00', 23.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-08 00:00:00', 24.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-09 00:00:00', 24.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-10 00:00:00', 26.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-11 00:00:00', 27.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-12 00:00:00', 25.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-13 00:00:00', 23.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-14 00:00:00', 24.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-15 00:00:00', 23.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-16 00:00:00', 15.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-17 00:00:00', 13.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-18 00:00:00', 14.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-19 00:00:00', 10.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-20 00:00:00', 18.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-21 00:00:00', 20.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-22 00:00:00', 22.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-23 00:00:00', 22.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-24 00:00:00', 23.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-25 00:00:00', 23.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-26 00:00:00', 25.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-27 00:00:00', 24.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-28 00:00:00', 24.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-29 00:00:00', 22.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-30 00:00:00', 15.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-10-31 00:00:00', 17.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-01 00:00:00', 17.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-02 00:00:00', 17.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-03 00:00:00', 17.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-04 00:00:00', 22.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-05 00:00:00', 21.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-06 00:00:00', 21.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-07 00:00:00', 22.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-08 00:00:00', 22.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-09 00:00:00', 22.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-10 00:00:00', 23.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-11 00:00:00', 23.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-12 00:00:00', 23.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-13 00:00:00', 25.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-14 00:00:00', 15.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-15 00:00:00', 12.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-16 00:00:00', 14.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-17 00:00:00', 9.87100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-18 00:00:00', 12.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-19 00:00:00', 16.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-20 00:00:00', 18.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-21 00:00:00', 18.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-22 00:00:00', 16.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-23 00:00:00', 13.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-24 00:00:00', 16.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-25 00:00:00', 16.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-26 00:00:00', 16.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-27 00:00:00', 14.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-28 00:00:00', 14.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-29 00:00:00', 15.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-11-30 00:00:00', 15.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-01 00:00:00', 16.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-02 00:00:00', 16.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-03 00:00:00', 18.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-04 00:00:00', 17.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-05 00:00:00', 18.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-06 00:00:00', 18.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-07 00:00:00', 18.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-08 00:00:00', 11.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-09 00:00:00', 13.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-10 00:00:00', 8.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-11 00:00:00', 7.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-12 00:00:00', 7.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-13 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-14 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-15 00:00:00', 5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-16 00:00:00', 4.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-17 00:00:00', 6.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-18 00:00:00', 10.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-19 00:00:00', 13.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-20 00:00:00', 9.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-21 00:00:00', 12.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-22 00:00:00', 10.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-23 00:00:00', 6.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-24 00:00:00', 7.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-25 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-26 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-27 00:00:00', -1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-28 00:00:00', -3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-29 00:00:00', -7.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-30 00:00:00', -9.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1990-12-31 00:00:00', -3.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-01 00:00:00', -1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-02 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-03 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-04 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-05 00:00:00', 4.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-06 00:00:00', 2.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-07 00:00:00', 2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-08 00:00:00', 2.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-09 00:00:00', 5.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-10 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-11 00:00:00', 0.785000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-12 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-13 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-14 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-15 00:00:00', 6.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-16 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-17 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-18 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-19 00:00:00', 2.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-20 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-21 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-22 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-23 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-24 00:00:00', 3.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-25 00:00:00', 3.56399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-26 00:00:00', 6.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-27 00:00:00', 5.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-28 00:00:00', 2.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-29 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-30 00:00:00', 3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-01-31 00:00:00', 3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-01 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-02 00:00:00', 6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-03 00:00:00', 5.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-04 00:00:00', 3.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-05 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-06 00:00:00', 2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-07 00:00:00', 0.750999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-08 00:00:00', 3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-09 00:00:00', 2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-10 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-11 00:00:00', -0.187000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-12 00:00:00', 2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-13 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-14 00:00:00', -3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-15 00:00:00', -1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-16 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-17 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-18 00:00:00', 5.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-19 00:00:00', 8.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-20 00:00:00', 8.78199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-21 00:00:00', 10.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-22 00:00:00', 15.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-23 00:00:00', 8.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-24 00:00:00', 6.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-25 00:00:00', 1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-26 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-27 00:00:00', 5.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-02-28 00:00:00', 11.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-01 00:00:00', 14.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-02 00:00:00', 7.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-03 00:00:00', 7.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-04 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-05 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-06 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-07 00:00:00', 7.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-08 00:00:00', 6.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-09 00:00:00', 8.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-10 00:00:00', 11.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-11 00:00:00', 11.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-12 00:00:00', 5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-13 00:00:00', 3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-14 00:00:00', 2.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-15 00:00:00', 2.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-16 00:00:00', 5.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-17 00:00:00', 5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-18 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-19 00:00:00', 8.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-20 00:00:00', 8.31299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-21 00:00:00', 6.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-22 00:00:00', 7.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-23 00:00:00', 12.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-24 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-25 00:00:00', 16.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-26 00:00:00', 16.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-27 00:00:00', 19.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-28 00:00:00', 21.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-29 00:00:00', 17.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-30 00:00:00', 20.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-03-31 00:00:00', 21.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-01 00:00:00', 23.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-02 00:00:00', 15.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-03 00:00:00', 19.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-04 00:00:00', 23.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-05 00:00:00', 24.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-06 00:00:00', 21.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-07 00:00:00', 18.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-08 00:00:00', 15.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-09 00:00:00', 13.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-10 00:00:00', 17.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-11 00:00:00', 20.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-12 00:00:00', 19.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-13 00:00:00', 16.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-14 00:00:00', 16.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-15 00:00:00', 8.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-16 00:00:00', 14.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-17 00:00:00', 17.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-18 00:00:00', 19.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-19 00:00:00', 24.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-20 00:00:00', 23.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-21 00:00:00', 19.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-22 00:00:00', 21.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-23 00:00:00', 24.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-24 00:00:00', 24.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-25 00:00:00', 24.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-26 00:00:00', 25.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-27 00:00:00', 22.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-28 00:00:00', 20.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-29 00:00:00', 21.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-04-30 00:00:00', 24.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-01 00:00:00', 18.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-02 00:00:00', 20.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-03 00:00:00', 24.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-04 00:00:00', 21.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-05 00:00:00', 22.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-06 00:00:00', 23.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-07 00:00:00', 23.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-08 00:00:00', 22.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-09 00:00:00', 24.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-10 00:00:00', 26.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-11 00:00:00', 26.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-12 00:00:00', 23.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-13 00:00:00', 24.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-14 00:00:00', 25.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-15 00:00:00', 26.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-16 00:00:00', 23.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-17 00:00:00', 28.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-18 00:00:00', 27.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-19 00:00:00', 23.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-20 00:00:00', 19.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-21 00:00:00', 22.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-22 00:00:00', 26.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-23 00:00:00', 29.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-24 00:00:00', 23.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-25 00:00:00', 23.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-26 00:00:00', 24.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-27 00:00:00', 24.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-28 00:00:00', 28.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-29 00:00:00', 28.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-30 00:00:00', 30.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-05-31 00:00:00', 31.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-01 00:00:00', 36.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-02 00:00:00', 35.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-03 00:00:00', 36.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-04 00:00:00', 35.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-05 00:00:00', 37.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-06 00:00:00', 37.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-07 00:00:00', 33.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-08 00:00:00', 35.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-09 00:00:00', 34.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-10 00:00:00', 32.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-11 00:00:00', 30.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-12 00:00:00', 34.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-13 00:00:00', 39.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-14 00:00:00', 38.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-15 00:00:00', 34.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-16 00:00:00', 33.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-17 00:00:00', 34.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-18 00:00:00', 33.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-19 00:00:00', 30.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-20 00:00:00', 31.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-21 00:00:00', 32.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-22 00:00:00', 32.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-23 00:00:00', 30.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-24 00:00:00', 27.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-25 00:00:00', 27.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-26 00:00:00', 28.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-27 00:00:00', 33.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-28 00:00:00', 34.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-29 00:00:00', 35.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-06-30 00:00:00', 36.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-01 00:00:00', 37.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-02 00:00:00', 37.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-03 00:00:00', 37.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-04 00:00:00', 36.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-05 00:00:00', 36.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-06 00:00:00', 36.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-07 00:00:00', 38.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-08 00:00:00', 39.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-09 00:00:00', 39.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-10 00:00:00', 37.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-11 00:00:00', 36.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-12 00:00:00', 35.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-13 00:00:00', 31.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-14 00:00:00', 34.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-15 00:00:00', 35.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-16 00:00:00', 37.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-17 00:00:00', 36.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-18 00:00:00', 37.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-19 00:00:00', 37.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-20 00:00:00', 37.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-21 00:00:00', 37.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-22 00:00:00', 36.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-23 00:00:00', 36.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-24 00:00:00', 36.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-25 00:00:00', 36.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-26 00:00:00', 36.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-27 00:00:00', 37.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-28 00:00:00', 38.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-29 00:00:00', 39.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-30 00:00:00', 39.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-07-31 00:00:00', 38.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-01 00:00:00', 37.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-02 00:00:00', 38.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-03 00:00:00', 38.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-04 00:00:00', 38.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-05 00:00:00', 38.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-06 00:00:00', 37.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-07 00:00:00', 38.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-08 00:00:00', 35.9910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-09 00:00:00', 33.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-10 00:00:00', 34.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-11 00:00:00', 35.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-12 00:00:00', 38.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-13 00:00:00', 39.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-14 00:00:00', 39.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-15 00:00:00', 38.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-16 00:00:00', 38.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-17 00:00:00', 38.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-18 00:00:00', 38.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-19 00:00:00', 38.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-20 00:00:00', 36.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-21 00:00:00', 34.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-22 00:00:00', 33.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-23 00:00:00', 33.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-24 00:00:00', 33.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-25 00:00:00', 34.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-26 00:00:00', 36.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-27 00:00:00', 36.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-28 00:00:00', 35.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-29 00:00:00', 35.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-30 00:00:00', 35.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-08-31 00:00:00', 35.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-01 00:00:00', 36.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-02 00:00:00', 36.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-03 00:00:00', 37.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-04 00:00:00', 36.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-05 00:00:00', 35.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-06 00:00:00', 33.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-07 00:00:00', 32.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-08 00:00:00', 34.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-09 00:00:00', 35.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-10 00:00:00', 34.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-11 00:00:00', 33.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-12 00:00:00', 32.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-13 00:00:00', 32.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-14 00:00:00', 32.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-15 00:00:00', 32.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-16 00:00:00', 28.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-17 00:00:00', 29.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-18 00:00:00', 25.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-19 00:00:00', 28.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-20 00:00:00', 31.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-21 00:00:00', 33.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-22 00:00:00', 34.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-23 00:00:00', 34.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-24 00:00:00', 33.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-25 00:00:00', 30.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-26 00:00:00', 20.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-27 00:00:00', 16.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-28 00:00:00', 16.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-29 00:00:00', 15.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-09-30 00:00:00', 16.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-01 00:00:00', 20.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-02 00:00:00', 20.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-03 00:00:00', 23.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-04 00:00:00', 25.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-05 00:00:00', 25.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-06 00:00:00', 23.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-07 00:00:00', 21.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-08 00:00:00', 20.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-09 00:00:00', 22.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-10 00:00:00', 23.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-11 00:00:00', 14.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-12 00:00:00', 18.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-13 00:00:00', 17.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-14 00:00:00', 17.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-15 00:00:00', 19.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-16 00:00:00', 22.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-17 00:00:00', 24.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-18 00:00:00', 22.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-19 00:00:00', 21.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-20 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-21 00:00:00', 21.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-22 00:00:00', 22.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-23 00:00:00', 23.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-24 00:00:00', 24.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-25 00:00:00', 23.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-26 00:00:00', 24.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-27 00:00:00', 23.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-28 00:00:00', 23.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-29 00:00:00', 22.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-30 00:00:00', 22.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-10-31 00:00:00', 23.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-01 00:00:00', 22.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-02 00:00:00', 22.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-03 00:00:00', 20.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-04 00:00:00', 19.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-05 00:00:00', 24.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-06 00:00:00', 23.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-07 00:00:00', 21.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-08 00:00:00', 17.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-09 00:00:00', 17.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-10 00:00:00', 16.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-11 00:00:00', 16.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-12 00:00:00', 17.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-13 00:00:00', 15.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-14 00:00:00', 13.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-15 00:00:00', 16.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-16 00:00:00', 14.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-17 00:00:00', 12.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-18 00:00:00', 16.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-19 00:00:00', 15.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-20 00:00:00', 12.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-21 00:00:00', 8.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-22 00:00:00', 11.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-23 00:00:00', 9.13300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-24 00:00:00', 11.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-25 00:00:00', 13.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-26 00:00:00', 14.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-27 00:00:00', 11.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-28 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-29 00:00:00', 5.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-11-30 00:00:00', 8.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-01 00:00:00', 10.9429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-02 00:00:00', 15.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-03 00:00:00', 13.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-04 00:00:00', 11.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-05 00:00:00', 14.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-06 00:00:00', 13.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-07 00:00:00', 12.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-08 00:00:00', 14.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-09 00:00:00', 12.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-10 00:00:00', 12.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-11 00:00:00', 9.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-12 00:00:00', 10.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-13 00:00:00', 9.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-14 00:00:00', 8.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-15 00:00:00', 9.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-16 00:00:00', 7.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-17 00:00:00', 6.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-18 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-19 00:00:00', 5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-20 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-21 00:00:00', 2.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-22 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-23 00:00:00', 6.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-24 00:00:00', 2.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-25 00:00:00', 3.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-26 00:00:00', 6.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-27 00:00:00', 1.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-28 00:00:00', 6.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-29 00:00:00', 5.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-30 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1991-12-31 00:00:00', 2.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-01 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-02 00:00:00', 6.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-03 00:00:00', 6.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-04 00:00:00', 6.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-05 00:00:00', 4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-06 00:00:00', 7.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-07 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-08 00:00:00', 7.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-09 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-10 00:00:00', -0.449999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-11 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-12 00:00:00', 4.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-13 00:00:00', 8.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-14 00:00:00', 7.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-15 00:00:00', 8.46800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-16 00:00:00', 8.44200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-17 00:00:00', 11.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-18 00:00:00', 7.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-19 00:00:00', 11.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-20 00:00:00', 12.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-21 00:00:00', 11.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-22 00:00:00', 11.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-23 00:00:00', 7.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-24 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-25 00:00:00', 3.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-26 00:00:00', 6.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-27 00:00:00', 3.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-28 00:00:00', 3.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-29 00:00:00', -0.442000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-30 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-01-31 00:00:00', 7.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-01 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-02 00:00:00', 7.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-03 00:00:00', 9.80099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-04 00:00:00', 9.74899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-05 00:00:00', 10.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-06 00:00:00', 8.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-07 00:00:00', 6.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-08 00:00:00', 8.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-09 00:00:00', 9.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-10 00:00:00', 9.12800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-11 00:00:00', 9.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-12 00:00:00', 5.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-13 00:00:00', 1.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-14 00:00:00', 4.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-15 00:00:00', 7.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-16 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-17 00:00:00', 3.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-18 00:00:00', 9.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-19 00:00:00', 8.56000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-20 00:00:00', 11.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-21 00:00:00', 12.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-22 00:00:00', 10.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-23 00:00:00', 12.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-24 00:00:00', 15.0819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-25 00:00:00', 16.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-26 00:00:00', 14.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-27 00:00:00', 7.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-28 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-02-29 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-01 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-02 00:00:00', 8.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-03 00:00:00', 6.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-04 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-05 00:00:00', 8.56200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-06 00:00:00', 12.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-07 00:00:00', 10.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-08 00:00:00', 9.44499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-09 00:00:00', 7.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-10 00:00:00', 9.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-11 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-12 00:00:00', 2.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-13 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-14 00:00:00', 8.04800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-15 00:00:00', 11.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-16 00:00:00', 12.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-17 00:00:00', 8.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-18 00:00:00', 11.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-19 00:00:00', 9.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-20 00:00:00', 8.16899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-21 00:00:00', 12.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-22 00:00:00', 11.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-23 00:00:00', 10.7860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-24 00:00:00', 12.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-25 00:00:00', 14.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-26 00:00:00', 7.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-27 00:00:00', 11.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-28 00:00:00', 13.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-29 00:00:00', 10.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-30 00:00:00', 11.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-03-31 00:00:00', 17.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-01 00:00:00', 17.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-02 00:00:00', 14.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-03 00:00:00', 17.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-04 00:00:00', 12.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-05 00:00:00', 20.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-06 00:00:00', 10.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-07 00:00:00', 15.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-08 00:00:00', 18.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-09 00:00:00', 20.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-10 00:00:00', 15.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-11 00:00:00', 17.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-12 00:00:00', 19.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-13 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-14 00:00:00', 24.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-15 00:00:00', 24.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-16 00:00:00', 20.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-17 00:00:00', 13.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-18 00:00:00', 21.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-19 00:00:00', 23.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-20 00:00:00', 20.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-21 00:00:00', 16.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-22 00:00:00', 22.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-23 00:00:00', 25.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-24 00:00:00', 18.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-25 00:00:00', 24.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-26 00:00:00', 23.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-27 00:00:00', 24.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-28 00:00:00', 21.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-29 00:00:00', 21.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-04-30 00:00:00', 23.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-01 00:00:00', 17.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-02 00:00:00', 10.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-03 00:00:00', 12.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-04 00:00:00', 15.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-05 00:00:00', 17.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-06 00:00:00', 12.3629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-07 00:00:00', 19.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-08 00:00:00', 19.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-09 00:00:00', 23.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-10 00:00:00', 25.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-11 00:00:00', 28.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-12 00:00:00', 29.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-13 00:00:00', 27.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-14 00:00:00', 27.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-15 00:00:00', 22.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-16 00:00:00', 19.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-17 00:00:00', 20.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-18 00:00:00', 22.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-19 00:00:00', 22.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-20 00:00:00', 24.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-21 00:00:00', 25.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-22 00:00:00', 25.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-23 00:00:00', 27.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-24 00:00:00', 27.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-25 00:00:00', 26.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-26 00:00:00', 23.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-27 00:00:00', 23.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-28 00:00:00', 25.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-29 00:00:00', 21.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-30 00:00:00', 25.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-05-31 00:00:00', 28.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-01 00:00:00', 29.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-02 00:00:00', 29.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-03 00:00:00', 32.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-04 00:00:00', 32.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-05 00:00:00', 33.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-06 00:00:00', 32.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-07 00:00:00', 32.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-08 00:00:00', 30.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-09 00:00:00', 31.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-10 00:00:00', 32.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-11 00:00:00', 33.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-12 00:00:00', 32.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-13 00:00:00', 30.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-14 00:00:00', 28.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-15 00:00:00', 30.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-16 00:00:00', 30.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-17 00:00:00', 30.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-18 00:00:00', 33.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-19 00:00:00', 37.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-20 00:00:00', 38.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-21 00:00:00', 31.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-22 00:00:00', 32.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-23 00:00:00', 32.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-24 00:00:00', 33.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-25 00:00:00', 33.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-26 00:00:00', 35.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-27 00:00:00', 36.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-28 00:00:00', 35.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-29 00:00:00', 35.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-06-30 00:00:00', 36.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-01 00:00:00', 35.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-02 00:00:00', 34.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-03 00:00:00', 33.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-04 00:00:00', 34.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-05 00:00:00', 37.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-06 00:00:00', 38.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-07 00:00:00', 39.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-08 00:00:00', 38.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-09 00:00:00', 37.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-10 00:00:00', 38.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-11 00:00:00', 38.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-12 00:00:00', 38.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-13 00:00:00', 38.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-14 00:00:00', 34.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-15 00:00:00', 34.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-16 00:00:00', 36.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-17 00:00:00', 36.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-18 00:00:00', 37.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-19 00:00:00', 38.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-20 00:00:00', 39.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-21 00:00:00', 38.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-22 00:00:00', 39.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-23 00:00:00', 37.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-24 00:00:00', 37.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-25 00:00:00', 37.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-26 00:00:00', 38.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-27 00:00:00', 39.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-28 00:00:00', 39.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-29 00:00:00', 38.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-30 00:00:00', 36.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-07-31 00:00:00', 36.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-01 00:00:00', 37.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-02 00:00:00', 38.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-03 00:00:00', 39.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-04 00:00:00', 37.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-05 00:00:00', 36.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-06 00:00:00', 33.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-07 00:00:00', 33.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-08 00:00:00', 29.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-09 00:00:00', 30.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-10 00:00:00', 32.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-11 00:00:00', 33.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-12 00:00:00', 34.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-13 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-14 00:00:00', 33.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-15 00:00:00', 33.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-16 00:00:00', 31.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-17 00:00:00', 29.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-18 00:00:00', 33.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-19 00:00:00', 33.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-20 00:00:00', 34.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-21 00:00:00', 34.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-22 00:00:00', 34.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-23 00:00:00', 35.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-24 00:00:00', 35.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-25 00:00:00', 37.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-26 00:00:00', 37.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-27 00:00:00', 37.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-28 00:00:00', 34.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-29 00:00:00', 32.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-30 00:00:00', 31.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-08-31 00:00:00', 28.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-01 00:00:00', 29.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-02 00:00:00', 27.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-03 00:00:00', 28.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-04 00:00:00', 30.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-05 00:00:00', 30.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-06 00:00:00', 31.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-07 00:00:00', 31.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-08 00:00:00', 30.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-09 00:00:00', 29.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-10 00:00:00', 26.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-11 00:00:00', 27.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-12 00:00:00', 28.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-13 00:00:00', 28.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-14 00:00:00', 29.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-15 00:00:00', 28.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-16 00:00:00', 28.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-17 00:00:00', 28.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-18 00:00:00', 28.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-19 00:00:00', 28.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-20 00:00:00', 27.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-21 00:00:00', 27.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-22 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-23 00:00:00', 29.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-24 00:00:00', 30.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-25 00:00:00', 30.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-26 00:00:00', 34.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-27 00:00:00', 31.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-28 00:00:00', 32.1920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-29 00:00:00', 28.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-09-30 00:00:00', 21.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-01 00:00:00', 22.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-02 00:00:00', 21.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-03 00:00:00', 24.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-04 00:00:00', 25.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-05 00:00:00', 23.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-06 00:00:00', 23.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-07 00:00:00', 21.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-08 00:00:00', 22.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-09 00:00:00', 21.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-10 00:00:00', 26.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-11 00:00:00', 30.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-12 00:00:00', 29.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-13 00:00:00', 28.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-14 00:00:00', 27.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-15 00:00:00', 25.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-16 00:00:00', 16.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-17 00:00:00', 11.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-18 00:00:00', 15.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-19 00:00:00', 21.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-20 00:00:00', 23.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-21 00:00:00', 20.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-22 00:00:00', 21.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-23 00:00:00', 20.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-24 00:00:00', 22.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-25 00:00:00', 22.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-26 00:00:00', 24.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-27 00:00:00', 26.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-28 00:00:00', 25.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-29 00:00:00', 27.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-30 00:00:00', 23.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-10-31 00:00:00', 22.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-01 00:00:00', 22.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-02 00:00:00', 21.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-03 00:00:00', 21.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-04 00:00:00', 12.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-05 00:00:00', 12.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-06 00:00:00', 18.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-07 00:00:00', 20.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-08 00:00:00', 24.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-09 00:00:00', 22.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-10 00:00:00', 24.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-11 00:00:00', 23.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-12 00:00:00', 24.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-13 00:00:00', 26.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-14 00:00:00', 23.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-15 00:00:00', 22.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-16 00:00:00', 19.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-17 00:00:00', 18.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-18 00:00:00', 11.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-19 00:00:00', 8.19200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-20 00:00:00', 12.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-21 00:00:00', 8.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-22 00:00:00', 15.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-23 00:00:00', 21.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-24 00:00:00', 21.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-25 00:00:00', 21.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-26 00:00:00', 23.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-27 00:00:00', 13.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-28 00:00:00', 15.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-29 00:00:00', 16.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-11-30 00:00:00', 17.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-01 00:00:00', 15.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-02 00:00:00', 13.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-03 00:00:00', 7.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-04 00:00:00', 12.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-05 00:00:00', 12.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-06 00:00:00', 12.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-07 00:00:00', 13.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-08 00:00:00', 9.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-09 00:00:00', 12.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-10 00:00:00', 13.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-11 00:00:00', 7.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-12 00:00:00', 5.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-13 00:00:00', 7.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-14 00:00:00', 11.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-15 00:00:00', 12.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-16 00:00:00', 13.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-17 00:00:00', 13.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-18 00:00:00', 12.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-19 00:00:00', 15.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-20 00:00:00', 15.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-21 00:00:00', 14.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-22 00:00:00', 12.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-23 00:00:00', 10.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-24 00:00:00', 5.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-25 00:00:00', 7.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-26 00:00:00', 8.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-27 00:00:00', 9.09799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-28 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-29 00:00:00', 6.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-30 00:00:00', 7.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1992-12-31 00:00:00', 5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-01 00:00:00', 7.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-02 00:00:00', 6.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-03 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-04 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-05 00:00:00', 6.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-06 00:00:00', 1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-07 00:00:00', -2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-08 00:00:00', -2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-09 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-10 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-11 00:00:00', 3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-12 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-13 00:00:00', 2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-14 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-15 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-16 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-17 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-18 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-19 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-20 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-21 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-22 00:00:00', 4.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-23 00:00:00', 6.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-24 00:00:00', 6.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-25 00:00:00', 9.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-26 00:00:00', 8.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-27 00:00:00', 13.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-28 00:00:00', 12.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-29 00:00:00', 12.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-30 00:00:00', 13.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-01-31 00:00:00', 12.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-01 00:00:00', 11.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-02 00:00:00', 12.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-03 00:00:00', 15.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-04 00:00:00', 9.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-05 00:00:00', 11.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-06 00:00:00', 10.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-07 00:00:00', 14.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-08 00:00:00', 11.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-09 00:00:00', 13.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-10 00:00:00', 11.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-11 00:00:00', 12.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-12 00:00:00', 15.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-13 00:00:00', 8.53199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-14 00:00:00', 9.62199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-15 00:00:00', 12.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-16 00:00:00', 5.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-17 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-18 00:00:00', -0.957000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-19 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-20 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-21 00:00:00', 7.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-22 00:00:00', 6.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-23 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-24 00:00:00', 9.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-25 00:00:00', 3.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-26 00:00:00', 7.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-27 00:00:00', 7.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-02-28 00:00:00', 11.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-01 00:00:00', 11.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-02 00:00:00', 6.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-03 00:00:00', 5.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-04 00:00:00', 12.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-05 00:00:00', 10.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-06 00:00:00', 16.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-07 00:00:00', 15.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-08 00:00:00', 19.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-09 00:00:00', 20.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-10 00:00:00', 9.93999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-11 00:00:00', 7.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-12 00:00:00', 11.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-13 00:00:00', 7.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-14 00:00:00', 4.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-15 00:00:00', 8.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-16 00:00:00', 9.20600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-17 00:00:00', 9.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-18 00:00:00', 10.5819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-19 00:00:00', 13.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-20 00:00:00', 8.09099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-21 00:00:00', 11.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-22 00:00:00', 13.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-23 00:00:00', 8.59599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-24 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-25 00:00:00', 8.30500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-26 00:00:00', 10.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-27 00:00:00', 14.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-28 00:00:00', 15.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-29 00:00:00', 16.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-30 00:00:00', 18.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-03-31 00:00:00', 15.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-01 00:00:00', 14.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-02 00:00:00', 13.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-03 00:00:00', 17.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-04 00:00:00', 20.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-05 00:00:00', 18.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-06 00:00:00', 21.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-07 00:00:00', 18.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-08 00:00:00', 20.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-09 00:00:00', 23.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-10 00:00:00', 22.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-11 00:00:00', 22.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-12 00:00:00', 23.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-13 00:00:00', 25.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-14 00:00:00', 20.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-15 00:00:00', 12.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-16 00:00:00', 17.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-17 00:00:00', 20.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-18 00:00:00', 24.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-19 00:00:00', 26.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-20 00:00:00', 27.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-21 00:00:00', 28.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-22 00:00:00', 28.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-23 00:00:00', 27.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-24 00:00:00', 17.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-25 00:00:00', 18.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-26 00:00:00', 23.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-27 00:00:00', 20.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-28 00:00:00', 20.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-29 00:00:00', 20.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-04-30 00:00:00', 23.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-01 00:00:00', 25.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-02 00:00:00', 23.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-03 00:00:00', 26.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-04 00:00:00', 27.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-05 00:00:00', 26.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-06 00:00:00', 25.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-07 00:00:00', 26.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-08 00:00:00', 20.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-09 00:00:00', 13.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-10 00:00:00', 16.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-11 00:00:00', 17.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-12 00:00:00', 18.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-13 00:00:00', 22.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-14 00:00:00', 27.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-15 00:00:00', 21.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-16 00:00:00', 21.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-17 00:00:00', 25.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-18 00:00:00', 26.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-19 00:00:00', 24.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-20 00:00:00', 26.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-21 00:00:00', 27.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-22 00:00:00', 29.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-23 00:00:00', 31.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-24 00:00:00', 24.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-25 00:00:00', 27.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-26 00:00:00', 26.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-27 00:00:00', 30.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-28 00:00:00', 32.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-29 00:00:00', 30.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-30 00:00:00', 22.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-05-31 00:00:00', 26.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-01 00:00:00', 30.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-02 00:00:00', 28.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-03 00:00:00', 30.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-04 00:00:00', 32.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-05 00:00:00', 31.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-06 00:00:00', 31.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-07 00:00:00', 29.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-08 00:00:00', 30.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-09 00:00:00', 33.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-10 00:00:00', 36.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-11 00:00:00', 36.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-12 00:00:00', 35.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-13 00:00:00', 31.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-14 00:00:00', 33.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-15 00:00:00', 32.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-16 00:00:00', 32.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-17 00:00:00', 33.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-18 00:00:00', 34.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-19 00:00:00', 36.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-20 00:00:00', 37.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-21 00:00:00', 37.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-22 00:00:00', 38.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-23 00:00:00', 27.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-24 00:00:00', 30.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-25 00:00:00', 32.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-26 00:00:00', 28.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-27 00:00:00', 35.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-28 00:00:00', 34.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-29 00:00:00', 37.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-06-30 00:00:00', 39.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-01 00:00:00', 38.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-02 00:00:00', 39.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-03 00:00:00', 40.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-04 00:00:00', 40.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-05 00:00:00', 39.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-06 00:00:00', 39.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-07 00:00:00', 39.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-08 00:00:00', 38.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-09 00:00:00', 33.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-10 00:00:00', 33.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-11 00:00:00', 35.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-12 00:00:00', 35.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-13 00:00:00', 36.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-14 00:00:00', 38.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-15 00:00:00', 36.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-16 00:00:00', 37.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-17 00:00:00', 38.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-18 00:00:00', 37.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-19 00:00:00', 38.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-20 00:00:00', 38.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-21 00:00:00', 38.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-22 00:00:00', 29.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-23 00:00:00', 33.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-24 00:00:00', 30.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-25 00:00:00', 31.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-26 00:00:00', 34.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-27 00:00:00', 35.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-28 00:00:00', 36.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-29 00:00:00', 35.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-30 00:00:00', 35.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-07-31 00:00:00', 34.6220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-01 00:00:00', 35.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-02 00:00:00', 35.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-03 00:00:00', 35.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-04 00:00:00', 34.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-05 00:00:00', 34.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-06 00:00:00', 35.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-07 00:00:00', 35.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-08 00:00:00', 35.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-09 00:00:00', 34.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-10 00:00:00', 34.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-11 00:00:00', 31.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-12 00:00:00', 32.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-13 00:00:00', 34.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-14 00:00:00', 34.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-15 00:00:00', 35.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-16 00:00:00', 36.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-17 00:00:00', 35.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-18 00:00:00', 32.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-19 00:00:00', 30.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-20 00:00:00', 31.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-21 00:00:00', 32.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-22 00:00:00', 33.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-23 00:00:00', 33.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-24 00:00:00', 32.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-25 00:00:00', 30.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-26 00:00:00', 33.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-27 00:00:00', 36.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-28 00:00:00', 36.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-29 00:00:00', 36.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-30 00:00:00', 36.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-08-31 00:00:00', 37.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-01 00:00:00', 37.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-02 00:00:00', 35.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-03 00:00:00', 34.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-04 00:00:00', 34.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-05 00:00:00', 35.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-06 00:00:00', 33.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-07 00:00:00', 34.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-08 00:00:00', 35.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-09 00:00:00', 33.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-10 00:00:00', 34.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-11 00:00:00', 32.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-12 00:00:00', 33.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-13 00:00:00', 32.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-14 00:00:00', 33.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-15 00:00:00', 36.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-16 00:00:00', 26.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-17 00:00:00', 28.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-18 00:00:00', 31.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-19 00:00:00', 31.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-20 00:00:00', 33.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-21 00:00:00', 33.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-22 00:00:00', 31.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-23 00:00:00', 26.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-24 00:00:00', 26.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-25 00:00:00', 29.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-26 00:00:00', 28.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-27 00:00:00', 26.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-28 00:00:00', 24.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-29 00:00:00', 28.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-09-30 00:00:00', 31.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-01 00:00:00', 29.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-02 00:00:00', 32.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-03 00:00:00', 28.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-04 00:00:00', 25.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-05 00:00:00', 18.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-06 00:00:00', 15.6470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-07 00:00:00', 16.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-08 00:00:00', 7.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-09 00:00:00', 14.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-10 00:00:00', 16.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-11 00:00:00', 19.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-12 00:00:00', 22.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-13 00:00:00', 20.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-14 00:00:00', 21.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-15 00:00:00', 21.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-16 00:00:00', 20.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-17 00:00:00', 19.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-18 00:00:00', 19.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-19 00:00:00', 20.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-20 00:00:00', 20.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-21 00:00:00', 19.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-22 00:00:00', 18.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-23 00:00:00', 18.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-24 00:00:00', 18.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-25 00:00:00', 15.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-26 00:00:00', 18.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-27 00:00:00', 21.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-28 00:00:00', 23.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-29 00:00:00', 24.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-30 00:00:00', 21.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-10-31 00:00:00', 22.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-01 00:00:00', 24.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-02 00:00:00', 18.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-03 00:00:00', 15.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-04 00:00:00', 10.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-05 00:00:00', 12.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-06 00:00:00', 9.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-07 00:00:00', 15.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-08 00:00:00', 8.26299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-09 00:00:00', 13.6059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-10 00:00:00', 18.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-11 00:00:00', 19.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-12 00:00:00', 21.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-13 00:00:00', 18.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-14 00:00:00', 21.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-15 00:00:00', 15.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-16 00:00:00', 17.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-17 00:00:00', 11.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-18 00:00:00', 8.51799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-19 00:00:00', 16.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-20 00:00:00', 15.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-21 00:00:00', 8.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-22 00:00:00', 3.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-23 00:00:00', 8.18500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-24 00:00:00', 12.7650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-25 00:00:00', 13.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-26 00:00:00', 6.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-27 00:00:00', 7.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-28 00:00:00', 12.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-29 00:00:00', 11.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-11-30 00:00:00', 7.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-01 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-02 00:00:00', 5.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-03 00:00:00', 3.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-04 00:00:00', 3.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-05 00:00:00', 9.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-06 00:00:00', 8.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-07 00:00:00', 4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-08 00:00:00', 7.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-09 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-10 00:00:00', 6.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-11 00:00:00', 8.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-12 00:00:00', 7.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-13 00:00:00', 3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-14 00:00:00', 8.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-15 00:00:00', 11.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-16 00:00:00', 10.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-17 00:00:00', 9.73700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-18 00:00:00', 7.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-19 00:00:00', 11.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-20 00:00:00', 10.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-21 00:00:00', 5.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-22 00:00:00', 4.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-23 00:00:00', 8.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-24 00:00:00', 9.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-25 00:00:00', 10.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-26 00:00:00', 10.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-27 00:00:00', 7.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-28 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-29 00:00:00', 8.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-30 00:00:00', 8.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1993-12-31 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-01 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-02 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-03 00:00:00', 5.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-04 00:00:00', 7.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-05 00:00:00', 10.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-06 00:00:00', 8.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-07 00:00:00', 5.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-08 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-09 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-10 00:00:00', 1.3049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-11 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-12 00:00:00', 7.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-13 00:00:00', 8.21800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-14 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-15 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-16 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-17 00:00:00', 8.52999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-18 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-19 00:00:00', 2.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-20 00:00:00', 3.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-21 00:00:00', 7.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-22 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-23 00:00:00', 9.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-24 00:00:00', 6.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-25 00:00:00', 11.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-26 00:00:00', 8.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-27 00:00:00', 5.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-28 00:00:00', 6.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-29 00:00:00', 8.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-30 00:00:00', 9.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-01-31 00:00:00', 6.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-01 00:00:00', 11.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-02 00:00:00', 7.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-03 00:00:00', 10.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-04 00:00:00', 3.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-05 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-06 00:00:00', 6.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-07 00:00:00', 2.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-08 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-09 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-10 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-11 00:00:00', -0.690999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-12 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-13 00:00:00', 4.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-14 00:00:00', 6.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-15 00:00:00', 4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-16 00:00:00', 1.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-17 00:00:00', 2.19499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-18 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-19 00:00:00', 3.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-20 00:00:00', -2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-21 00:00:00', -1.63999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-22 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-23 00:00:00', 3.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-24 00:00:00', 6.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-25 00:00:00', 9.00300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-26 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-27 00:00:00', 7.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-02-28 00:00:00', 11.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-01 00:00:00', 12.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-02 00:00:00', 11.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-03 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-04 00:00:00', 9.93799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-05 00:00:00', 12.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-06 00:00:00', 13.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-07 00:00:00', 14.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-08 00:00:00', 17.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-09 00:00:00', 16.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-10 00:00:00', 14.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-11 00:00:00', 15.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-12 00:00:00', 17.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-13 00:00:00', 17.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-14 00:00:00', 10.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-15 00:00:00', 17.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-16 00:00:00', 14.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-17 00:00:00', 15.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-18 00:00:00', 14.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-19 00:00:00', 16.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-20 00:00:00', 17.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-21 00:00:00', 16.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-22 00:00:00', 18.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-23 00:00:00', 20.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-24 00:00:00', 20.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-25 00:00:00', 11.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-26 00:00:00', 16.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-27 00:00:00', 19.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-28 00:00:00', 20.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-29 00:00:00', 19.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-30 00:00:00', 20.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-03-31 00:00:00', 21.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-01 00:00:00', 19.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-02 00:00:00', 22.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-03 00:00:00', 13.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-04 00:00:00', 12.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-05 00:00:00', 6.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-06 00:00:00', 4.29799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-07 00:00:00', 10.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-08 00:00:00', 13.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-09 00:00:00', 10.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-10 00:00:00', 12.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-11 00:00:00', 17.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-12 00:00:00', 18.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-13 00:00:00', 17.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-14 00:00:00', 17.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-15 00:00:00', 17.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-16 00:00:00', 17.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-17 00:00:00', 18.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-18 00:00:00', 19.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-19 00:00:00', 21.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-20 00:00:00', 20.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-21 00:00:00', 18.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-22 00:00:00', 19.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-23 00:00:00', 20.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-24 00:00:00', 23.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-25 00:00:00', 27.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-26 00:00:00', 27.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-27 00:00:00', 28.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-28 00:00:00', 21.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-29 00:00:00', 23.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-04-30 00:00:00', 20.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-01 00:00:00', 24.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-02 00:00:00', 26.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-03 00:00:00', 26.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-04 00:00:00', 27.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-05 00:00:00', 28.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-06 00:00:00', 29.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-07 00:00:00', 29.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-08 00:00:00', 20.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-09 00:00:00', 21.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-10 00:00:00', 23.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-11 00:00:00', 27.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-12 00:00:00', 28.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-13 00:00:00', 28.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-14 00:00:00', 30.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-15 00:00:00', 31.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-16 00:00:00', 31.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-17 00:00:00', 32.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-18 00:00:00', 30.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-19 00:00:00', 24.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-20 00:00:00', 29.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-21 00:00:00', 31.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-22 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-23 00:00:00', 28.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-24 00:00:00', 25.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-25 00:00:00', 30.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-26 00:00:00', 29.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-27 00:00:00', 32.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-28 00:00:00', 33.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-29 00:00:00', 34.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-30 00:00:00', 33.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-05-31 00:00:00', 32.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-01 00:00:00', 32.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-02 00:00:00', 32.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-03 00:00:00', 32.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-04 00:00:00', 37.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-05 00:00:00', 34.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-06 00:00:00', 36.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-07 00:00:00', 35.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-08 00:00:00', 33.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-09 00:00:00', 31.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-10 00:00:00', 33.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-11 00:00:00', 30.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-12 00:00:00', 31.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-13 00:00:00', 31.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-14 00:00:00', 32.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-15 00:00:00', 34.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-16 00:00:00', 34.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-17 00:00:00', 37.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-18 00:00:00', 40.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-19 00:00:00', 37.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-20 00:00:00', 37.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-21 00:00:00', 38.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-22 00:00:00', 38.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-23 00:00:00', 40.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-24 00:00:00', 38.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-25 00:00:00', 37.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-26 00:00:00', 36.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-27 00:00:00', 36.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-28 00:00:00', 38.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-29 00:00:00', 39.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-06-30 00:00:00', 41.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-01 00:00:00', 41.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-02 00:00:00', 36.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-03 00:00:00', 37.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-04 00:00:00', 38.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-05 00:00:00', 39.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-06 00:00:00', 40.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-07 00:00:00', 42.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-08 00:00:00', 42.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-09 00:00:00', 41.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-10 00:00:00', 40.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-11 00:00:00', 37.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-12 00:00:00', 36.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-13 00:00:00', 34.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-14 00:00:00', 35.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-15 00:00:00', 36.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-16 00:00:00', 37.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-17 00:00:00', 38.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-18 00:00:00', 39.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-19 00:00:00', 38.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-20 00:00:00', 38.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-21 00:00:00', 39.3499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-22 00:00:00', 40.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-23 00:00:00', 39.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-24 00:00:00', 37.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-25 00:00:00', 38.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-26 00:00:00', 38.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-27 00:00:00', 39.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-28 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-29 00:00:00', 37.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-30 00:00:00', 37.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-07-31 00:00:00', 39.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-01 00:00:00', 40.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-02 00:00:00', 41.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-03 00:00:00', 42.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-04 00:00:00', 42.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-05 00:00:00', 41.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-06 00:00:00', 41.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-07 00:00:00', 39.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-08 00:00:00', 35.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-09 00:00:00', 33.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-10 00:00:00', 33.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-11 00:00:00', 36.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-12 00:00:00', 37.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-13 00:00:00', 40.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-14 00:00:00', 39.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-15 00:00:00', 36.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-16 00:00:00', 35.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-17 00:00:00', 35.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-18 00:00:00', 37.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-19 00:00:00', 38.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-20 00:00:00', 39.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-21 00:00:00', 39.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-22 00:00:00', 38.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-23 00:00:00', 38.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-24 00:00:00', 38.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-25 00:00:00', 39.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-26 00:00:00', 38.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-27 00:00:00', 37.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-28 00:00:00', 37.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-29 00:00:00', 36.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-30 00:00:00', 35.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-08-31 00:00:00', 34.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-01 00:00:00', 34.5309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-02 00:00:00', 33.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-03 00:00:00', 34.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-04 00:00:00', 31.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-05 00:00:00', 28.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-06 00:00:00', 28.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-07 00:00:00', 27.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-08 00:00:00', 28.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-09 00:00:00', 29.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-10 00:00:00', 28.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-11 00:00:00', 29.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-12 00:00:00', 29.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-13 00:00:00', 30.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-14 00:00:00', 27.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-15 00:00:00', 23.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-16 00:00:00', 25.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-17 00:00:00', 24.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-18 00:00:00', 19.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-19 00:00:00', 21.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-20 00:00:00', 20.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-21 00:00:00', 21.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-22 00:00:00', 21.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-23 00:00:00', 23.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-24 00:00:00', 24.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-25 00:00:00', 25.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-26 00:00:00', 28.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-27 00:00:00', 29.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-28 00:00:00', 29.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-29 00:00:00', 29.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-09-30 00:00:00', 28.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-01 00:00:00', 27.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-02 00:00:00', 27.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-03 00:00:00', 26.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-04 00:00:00', 26.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-05 00:00:00', 21.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-06 00:00:00', 22.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-07 00:00:00', 24.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-08 00:00:00', 24.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-09 00:00:00', 23.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-10 00:00:00', 22.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-11 00:00:00', 18.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-12 00:00:00', 18.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-13 00:00:00', 19.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-14 00:00:00', 22.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-15 00:00:00', 22.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-16 00:00:00', 24.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-17 00:00:00', 20.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-18 00:00:00', 24.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-19 00:00:00', 25.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-20 00:00:00', 26.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-21 00:00:00', 26.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-22 00:00:00', 25.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-23 00:00:00', 21.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-24 00:00:00', 13.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-25 00:00:00', 9.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-26 00:00:00', 6.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-27 00:00:00', 17.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-28 00:00:00', 18.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-29 00:00:00', 19.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-30 00:00:00', 19.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-10-31 00:00:00', 20.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-01 00:00:00', 19.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-02 00:00:00', 15.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-03 00:00:00', 19.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-04 00:00:00', 21.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-05 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-06 00:00:00', 21.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-07 00:00:00', 17.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-08 00:00:00', 21.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-09 00:00:00', 23.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-10 00:00:00', 17.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-11 00:00:00', 12.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-12 00:00:00', 17.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-13 00:00:00', 17.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-14 00:00:00', 17.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-15 00:00:00', 18.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-16 00:00:00', 18.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-17 00:00:00', 17.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-18 00:00:00', 19.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-19 00:00:00', 15.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-20 00:00:00', 17.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-21 00:00:00', 18.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-22 00:00:00', 17.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-23 00:00:00', 18.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-24 00:00:00', 18.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-25 00:00:00', 12.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-26 00:00:00', 17.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-27 00:00:00', 13.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-28 00:00:00', 16.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-29 00:00:00', 17.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-11-30 00:00:00', 16.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-01 00:00:00', 17.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-02 00:00:00', 11.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-03 00:00:00', 14.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-04 00:00:00', 15.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-05 00:00:00', 13.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-06 00:00:00', 7.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-07 00:00:00', 3.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-08 00:00:00', -0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-09 00:00:00', 1.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-10 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-11 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-12 00:00:00', 1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-13 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-14 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-15 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-16 00:00:00', 2.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-17 00:00:00', 4.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-18 00:00:00', 7.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-19 00:00:00', 10.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-20 00:00:00', 9.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-21 00:00:00', 8.99400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-22 00:00:00', 6.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-23 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-24 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-25 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-26 00:00:00', -0.115000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-27 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-28 00:00:00', 0.783999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-29 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-30 00:00:00', 5.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1994-12-31 00:00:00', 8.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-01 00:00:00', 11.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-02 00:00:00', 8.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-03 00:00:00', 7.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-04 00:00:00', 9.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-05 00:00:00', 10.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-06 00:00:00', 9.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-07 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-08 00:00:00', 3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-09 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-10 00:00:00', 5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-11 00:00:00', 7.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-12 00:00:00', 8.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-13 00:00:00', 6.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-14 00:00:00', 7.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-15 00:00:00', 4.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-16 00:00:00', 3.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-17 00:00:00', 8.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-18 00:00:00', 6.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-19 00:00:00', 3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-20 00:00:00', 5.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-21 00:00:00', 5.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-22 00:00:00', 7.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-23 00:00:00', 6.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-24 00:00:00', 7.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-25 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-26 00:00:00', 8.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-27 00:00:00', 8.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-28 00:00:00', 7.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-29 00:00:00', 10.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-30 00:00:00', 12.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-01-31 00:00:00', 12.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-01 00:00:00', 13.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-02 00:00:00', 14.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-03 00:00:00', 13.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-04 00:00:00', 13.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-05 00:00:00', 14.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-06 00:00:00', 8.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-07 00:00:00', 8.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-08 00:00:00', 9.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-09 00:00:00', 10.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-10 00:00:00', 9.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-11 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-12 00:00:00', 8.03899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-13 00:00:00', 9.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-14 00:00:00', 8.57199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-15 00:00:00', 8.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-16 00:00:00', 9.36699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-17 00:00:00', 3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-18 00:00:00', 1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-19 00:00:00', 2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-20 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-21 00:00:00', 8.55300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-22 00:00:00', 8.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-23 00:00:00', 9.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-24 00:00:00', 12.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-25 00:00:00', 6.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-26 00:00:00', 3.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-27 00:00:00', 0.828000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-02-28 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-01 00:00:00', 8.19499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-02 00:00:00', 10.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-03 00:00:00', 9.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-04 00:00:00', 6.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-05 00:00:00', 10.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-06 00:00:00', 9.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-07 00:00:00', 9.63300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-08 00:00:00', 8.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-09 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-10 00:00:00', 8.32400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-11 00:00:00', 10.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-12 00:00:00', 11.9709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-13 00:00:00', 13.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-14 00:00:00', 13.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-15 00:00:00', 15.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-16 00:00:00', 18.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-17 00:00:00', 18.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-18 00:00:00', 18.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-19 00:00:00', 16.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-20 00:00:00', 12.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-21 00:00:00', 12.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-22 00:00:00', 12.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-23 00:00:00', 12.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-24 00:00:00', 17.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-25 00:00:00', 17.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-26 00:00:00', 19.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-27 00:00:00', 19.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-28 00:00:00', 10.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-29 00:00:00', 12.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-30 00:00:00', 14.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-03-31 00:00:00', 16.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-01 00:00:00', 14.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-02 00:00:00', 17.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-03 00:00:00', 20.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-04 00:00:00', 21.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-05 00:00:00', 24.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-06 00:00:00', 22.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-07 00:00:00', 15.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-08 00:00:00', 11.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-09 00:00:00', 17.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-10 00:00:00', 19.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-11 00:00:00', 21.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-12 00:00:00', 23.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-13 00:00:00', 26.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-14 00:00:00', 24.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-15 00:00:00', 22.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-16 00:00:00', 24.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-17 00:00:00', 18.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-18 00:00:00', 22.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-19 00:00:00', 22.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-20 00:00:00', 22.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-21 00:00:00', 21.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-22 00:00:00', 24.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-23 00:00:00', 24.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-24 00:00:00', 23.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-25 00:00:00', 27.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-26 00:00:00', 25.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-27 00:00:00', 21.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-28 00:00:00', 23.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-29 00:00:00', 24.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-04-30 00:00:00', 25.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-01 00:00:00', 27.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-02 00:00:00', 28.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-03 00:00:00', 30.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-04 00:00:00', 32.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-05 00:00:00', 30.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-06 00:00:00', 33.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-07 00:00:00', 34.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-08 00:00:00', 36.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-09 00:00:00', 35.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-10 00:00:00', 31.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-11 00:00:00', 29.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-12 00:00:00', 31.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-13 00:00:00', 32.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-14 00:00:00', 33.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-15 00:00:00', 33.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-16 00:00:00', 30.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-17 00:00:00', 27.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-18 00:00:00', 28.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-19 00:00:00', 25.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-20 00:00:00', 26.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-21 00:00:00', 25.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-22 00:00:00', 27.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-23 00:00:00', 28.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-24 00:00:00', 25.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-25 00:00:00', 18.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-26 00:00:00', 24.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-27 00:00:00', 25.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-28 00:00:00', 26.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-29 00:00:00', 25.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-30 00:00:00', 27.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-05-31 00:00:00', 29.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-01 00:00:00', 30.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-02 00:00:00', 30.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-03 00:00:00', 28.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-04 00:00:00', 33.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-05 00:00:00', 37.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-06 00:00:00', 36.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-07 00:00:00', 34.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-08 00:00:00', 34.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-09 00:00:00', 34.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-10 00:00:00', 31.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-11 00:00:00', 32.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-12 00:00:00', 33.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-13 00:00:00', 28.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-14 00:00:00', 35.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-15 00:00:00', 39.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-16 00:00:00', 39.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-17 00:00:00', 38.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-18 00:00:00', 35.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-19 00:00:00', 34.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-20 00:00:00', 33.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-21 00:00:00', 32.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-22 00:00:00', 33.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-23 00:00:00', 33.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-24 00:00:00', 19.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-25 00:00:00', 33.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-26 00:00:00', 33.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-27 00:00:00', 34.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-28 00:00:00', 35.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-29 00:00:00', 35.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-06-30 00:00:00', 35.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-01 00:00:00', 38.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-02 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-03 00:00:00', 38.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-04 00:00:00', 38.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-05 00:00:00', 37.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-06 00:00:00', 38.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-07 00:00:00', 34.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-08 00:00:00', 35.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-09 00:00:00', 35.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-10 00:00:00', 36.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-11 00:00:00', 35.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-12 00:00:00', 37.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-13 00:00:00', 38.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-14 00:00:00', 38.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-15 00:00:00', 41.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-16 00:00:00', 42.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-17 00:00:00', 42.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-18 00:00:00', 44.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-19 00:00:00', 38.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-20 00:00:00', 35.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-21 00:00:00', 39.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-22 00:00:00', 40.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-23 00:00:00', 40.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-24 00:00:00', 37.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-25 00:00:00', 33.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-26 00:00:00', 35.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-27 00:00:00', 37.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-28 00:00:00', 37.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-29 00:00:00', 38.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-30 00:00:00', 38.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-07-31 00:00:00', 40.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-01 00:00:00', 40.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-02 00:00:00', 39.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-03 00:00:00', 39.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-04 00:00:00', 38.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-05 00:00:00', 36.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-06 00:00:00', 34.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-07 00:00:00', 34.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-08 00:00:00', 36.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-09 00:00:00', 38.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-10 00:00:00', 40.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-11 00:00:00', 38.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-12 00:00:00', 40.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-13 00:00:00', 40.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-14 00:00:00', 38.6969985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-15 00:00:00', 38.1370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-16 00:00:00', 37.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-17 00:00:00', 37.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-18 00:00:00', 37.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-19 00:00:00', 38.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-20 00:00:00', 38.1710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-21 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-22 00:00:00', 35.5449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-23 00:00:00', 39.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-24 00:00:00', 39.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-25 00:00:00', 35.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-26 00:00:00', 35.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-27 00:00:00', 36.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-28 00:00:00', 35.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-29 00:00:00', 31.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-30 00:00:00', 31.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-08-31 00:00:00', 20.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-01 00:00:00', 27.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-02 00:00:00', 27.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-03 00:00:00', 27.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-04 00:00:00', 27.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-05 00:00:00', 27.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-06 00:00:00', 29.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-07 00:00:00', 31.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-08 00:00:00', 31.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-09 00:00:00', 32.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-10 00:00:00', 33.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-11 00:00:00', 32.4410018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-12 00:00:00', 31.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-13 00:00:00', 31.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-14 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-15 00:00:00', 31.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-16 00:00:00', 31.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-17 00:00:00', 31.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-18 00:00:00', 33.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-19 00:00:00', 35.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-20 00:00:00', 35.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-21 00:00:00', 37.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-22 00:00:00', 27.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-23 00:00:00', 25.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-24 00:00:00', 30.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-25 00:00:00', 32.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-26 00:00:00', 33.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-27 00:00:00', 31.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-28 00:00:00', 21.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-29 00:00:00', 26.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-09-30 00:00:00', 28.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-01 00:00:00', 24.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-02 00:00:00', 17.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-03 00:00:00', 23.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-04 00:00:00', 16.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-05 00:00:00', 28.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-06 00:00:00', 29.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-07 00:00:00', 29.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-08 00:00:00', 30.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-09 00:00:00', 25.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-10 00:00:00', 15.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-11 00:00:00', 21.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-12 00:00:00', 24.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-13 00:00:00', 23.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-14 00:00:00', 13.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-15 00:00:00', 15.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-16 00:00:00', 14.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-17 00:00:00', 18.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-18 00:00:00', 8.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-19 00:00:00', 1.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-20 00:00:00', 5.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-21 00:00:00', 12.9049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-22 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-23 00:00:00', 20.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-24 00:00:00', 17.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-25 00:00:00', 9.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-26 00:00:00', 8.56200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-27 00:00:00', 7.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-28 00:00:00', 9.53400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-29 00:00:00', 9.00100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-30 00:00:00', 9.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-10-31 00:00:00', 7.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-01 00:00:00', 12.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-02 00:00:00', 8.72000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-03 00:00:00', 19.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-04 00:00:00', 20.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-05 00:00:00', 19.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-06 00:00:00', 17.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-07 00:00:00', 17.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-08 00:00:00', 19.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-09 00:00:00', 20.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-10 00:00:00', 20.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-11 00:00:00', 19.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-12 00:00:00', 19.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-13 00:00:00', 14.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-14 00:00:00', 15.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-15 00:00:00', 14.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-16 00:00:00', 10.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-17 00:00:00', 10.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-18 00:00:00', 13.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-19 00:00:00', 10.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-20 00:00:00', 11.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-21 00:00:00', 12.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-22 00:00:00', 13.1689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-23 00:00:00', 11.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-24 00:00:00', 13.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-25 00:00:00', 14.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-26 00:00:00', 11.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-27 00:00:00', 7.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-28 00:00:00', 0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-29 00:00:00', 0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-11-30 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-01 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-02 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-03 00:00:00', 1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-04 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-05 00:00:00', 2.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-06 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-07 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-08 00:00:00', 1.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-09 00:00:00', 1.63699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-10 00:00:00', -0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-11 00:00:00', -1.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-12 00:00:00', 0.720000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-13 00:00:00', -0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-14 00:00:00', -0.414999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-15 00:00:00', -0.356000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-16 00:00:00', 1.41900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-17 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-18 00:00:00', 1.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-19 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-20 00:00:00', 1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-21 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-22 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-23 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-24 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-25 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-26 00:00:00', 3.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-27 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-28 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-29 00:00:00', 3.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-30 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1995-12-31 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-01 00:00:00', 4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-02 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-03 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-04 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-05 00:00:00', 2.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-06 00:00:00', 2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-07 00:00:00', 6.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-08 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-09 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-10 00:00:00', -1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-11 00:00:00', -4.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-12 00:00:00', -0.580999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-13 00:00:00', -3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-14 00:00:00', -5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-15 00:00:00', -7.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-16 00:00:00', -5.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-17 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-18 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-19 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-20 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-21 00:00:00', -0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-22 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-23 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-24 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-25 00:00:00', -0.120999999344348907, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-26 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-27 00:00:00', 0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-28 00:00:00', 0.330000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-29 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-30 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-01-31 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-01 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-02 00:00:00', 3.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-03 00:00:00', 3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-04 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-05 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-06 00:00:00', 8.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-07 00:00:00', 7.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-08 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-09 00:00:00', 9.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-10 00:00:00', 10.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-11 00:00:00', 10.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-12 00:00:00', 6.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-13 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-14 00:00:00', -0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-15 00:00:00', -0.720000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-16 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-17 00:00:00', 6.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-18 00:00:00', 10.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-19 00:00:00', 12.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-20 00:00:00', 12.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-21 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-22 00:00:00', 7.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-23 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-24 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-25 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-26 00:00:00', 0.345999985933303833, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-27 00:00:00', -0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-28 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-02-29 00:00:00', 5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-01 00:00:00', 4.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-02 00:00:00', 7.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-03 00:00:00', 10.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-04 00:00:00', 12.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-05 00:00:00', 11.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-06 00:00:00', 10.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-07 00:00:00', 10.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-08 00:00:00', 12.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-09 00:00:00', 15.3660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-10 00:00:00', 13.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-11 00:00:00', 15.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-12 00:00:00', 8.58899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-13 00:00:00', 16.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-14 00:00:00', 14.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-15 00:00:00', 7.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-16 00:00:00', 8.50100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-17 00:00:00', 9.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-18 00:00:00', 6.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-19 00:00:00', 5.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-20 00:00:00', 6.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-21 00:00:00', 7.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-22 00:00:00', 11.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-23 00:00:00', 15.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-24 00:00:00', 11.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-25 00:00:00', 13.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-26 00:00:00', 18.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-27 00:00:00', 10.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-28 00:00:00', 10.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-29 00:00:00', 8.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-30 00:00:00', 8.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-03-31 00:00:00', 11.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-01 00:00:00', 14.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-02 00:00:00', 9.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-03 00:00:00', 14.1579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-04 00:00:00', 7.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-05 00:00:00', 7.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-06 00:00:00', 10.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-07 00:00:00', 12.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-08 00:00:00', 15.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-09 00:00:00', 15.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-10 00:00:00', 17.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-11 00:00:00', 17.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-12 00:00:00', 15.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-13 00:00:00', 21.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-14 00:00:00', 24.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-15 00:00:00', 26.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-16 00:00:00', 21.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-17 00:00:00', 14.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-18 00:00:00', 18.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-19 00:00:00', 25.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-20 00:00:00', 24.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-21 00:00:00', 20.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-22 00:00:00', 23.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-23 00:00:00', 24.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-24 00:00:00', 22.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-25 00:00:00', 24.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-26 00:00:00', 20.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-27 00:00:00', 19.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-28 00:00:00', 22.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-29 00:00:00', 18.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-04-30 00:00:00', 19.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-01 00:00:00', 20.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-02 00:00:00', 20.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-03 00:00:00', 19.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-04 00:00:00', 19.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-05 00:00:00', 17.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-06 00:00:00', 19.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-07 00:00:00', 22.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-08 00:00:00', 23.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-09 00:00:00', 21.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-10 00:00:00', 22.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-11 00:00:00', 22.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-12 00:00:00', 22.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-13 00:00:00', 25.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-14 00:00:00', 25.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-15 00:00:00', 26.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-16 00:00:00', 26.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-17 00:00:00', 27.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-18 00:00:00', 28.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-19 00:00:00', 29.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-20 00:00:00', 26.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-21 00:00:00', 28.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-22 00:00:00', 28.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-23 00:00:00', 28.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-24 00:00:00', 26.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-25 00:00:00', 33.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-26 00:00:00', 31.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-27 00:00:00', 27.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-28 00:00:00', 27.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-29 00:00:00', 26.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-30 00:00:00', 29.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-05-31 00:00:00', 30.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-01 00:00:00', 31.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-02 00:00:00', 32.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-03 00:00:00', 34.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-04 00:00:00', 32.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-05 00:00:00', 32.7179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-06 00:00:00', 34.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-07 00:00:00', 37.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-08 00:00:00', 36.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-09 00:00:00', 36.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-10 00:00:00', 38.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-11 00:00:00', 37.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-12 00:00:00', 34.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-13 00:00:00', 33.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-14 00:00:00', 32.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-15 00:00:00', 30.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-16 00:00:00', 28.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-17 00:00:00', 28.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-18 00:00:00', 28.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-19 00:00:00', 31.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-20 00:00:00', 32.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-21 00:00:00', 37.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-22 00:00:00', 38.8639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-23 00:00:00', 39.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-24 00:00:00', 38.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-25 00:00:00', 37.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-26 00:00:00', 36.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-27 00:00:00', 35.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-28 00:00:00', 35.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-29 00:00:00', 30.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-06-30 00:00:00', 33.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-01 00:00:00', 35.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-02 00:00:00', 35.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-03 00:00:00', 37.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-04 00:00:00', 33.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-05 00:00:00', 34.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-06 00:00:00', 36.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-07 00:00:00', 38.3779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-08 00:00:00', 38.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-09 00:00:00', 39.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-10 00:00:00', 38.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-11 00:00:00', 34.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-12 00:00:00', 35.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-13 00:00:00', 33.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-14 00:00:00', 29.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-15 00:00:00', 26.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-16 00:00:00', 30.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-17 00:00:00', 33.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-18 00:00:00', 37.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-19 00:00:00', 34.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-20 00:00:00', 33.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-21 00:00:00', 34.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-22 00:00:00', 35.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-23 00:00:00', 36.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-24 00:00:00', 37.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-25 00:00:00', 42.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-26 00:00:00', 39.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-27 00:00:00', 39.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-28 00:00:00', 40.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-29 00:00:00', 40.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-30 00:00:00', 42.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-07-31 00:00:00', 41.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-01 00:00:00', 40.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-02 00:00:00', 37.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-03 00:00:00', 38.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-04 00:00:00', 38.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-05 00:00:00', 38.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-06 00:00:00', 38.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-07 00:00:00', 38.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-08 00:00:00', 38.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-09 00:00:00', 39.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-10 00:00:00', 40.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-11 00:00:00', 41.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-12 00:00:00', 41.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-13 00:00:00', 39.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-14 00:00:00', 38.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-15 00:00:00', 35.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-16 00:00:00', 33.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-17 00:00:00', 34.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-18 00:00:00', 31.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-19 00:00:00', 32.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-20 00:00:00', 31.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-21 00:00:00', 33.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-22 00:00:00', 33.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-23 00:00:00', 33.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-24 00:00:00', 34.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-25 00:00:00', 34.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-26 00:00:00', 36.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-27 00:00:00', 36.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-28 00:00:00', 37.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-29 00:00:00', 33.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-30 00:00:00', 26.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-08-31 00:00:00', 30.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-01 00:00:00', 32.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-02 00:00:00', 31.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-03 00:00:00', 32.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-04 00:00:00', 30.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-05 00:00:00', 33.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-06 00:00:00', 34.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-07 00:00:00', 33.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-08 00:00:00', 35.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-09 00:00:00', 38.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-10 00:00:00', 38.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-11 00:00:00', 38.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-12 00:00:00', 37.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-13 00:00:00', 36.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-14 00:00:00', 36.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-15 00:00:00', 34.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-16 00:00:00', 33.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-17 00:00:00', 32.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-18 00:00:00', 31.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-19 00:00:00', 32.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-20 00:00:00', 32.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-21 00:00:00', 32.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-22 00:00:00', 35.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-23 00:00:00', 33.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-24 00:00:00', 30.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-25 00:00:00', 27.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-26 00:00:00', 27.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-27 00:00:00', 28.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-28 00:00:00', 28.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-29 00:00:00', 30.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-09-30 00:00:00', 31.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-01 00:00:00', 27.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-02 00:00:00', 19.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-03 00:00:00', 18.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-04 00:00:00', 19.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-05 00:00:00', 22.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-06 00:00:00', 23.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-07 00:00:00', 24.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-08 00:00:00', 22.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-09 00:00:00', 21.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-10 00:00:00', 23.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-11 00:00:00', 23.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-12 00:00:00', 24.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-13 00:00:00', 25.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-14 00:00:00', 26.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-15 00:00:00', 25.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-16 00:00:00', 19.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-17 00:00:00', 17.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-18 00:00:00', 17.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-19 00:00:00', 15.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-20 00:00:00', 16.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-21 00:00:00', 17.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-22 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-23 00:00:00', 21.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-24 00:00:00', 23.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-25 00:00:00', 21.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-26 00:00:00', 22.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-27 00:00:00', 22.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-28 00:00:00', 25.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-29 00:00:00', 20.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-30 00:00:00', 20.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-10-31 00:00:00', 23.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-01 00:00:00', 14.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-02 00:00:00', 16.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-03 00:00:00', 17.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-04 00:00:00', 14.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-05 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-06 00:00:00', 15.4840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-07 00:00:00', 18.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-08 00:00:00', 20.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-09 00:00:00', 20.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-10 00:00:00', 19.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-11 00:00:00', 15.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-12 00:00:00', 11.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-13 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-14 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-15 00:00:00', 2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-16 00:00:00', 7.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-17 00:00:00', 6.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-18 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-19 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-20 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-21 00:00:00', 6.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-22 00:00:00', 7.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-23 00:00:00', 9.52700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-24 00:00:00', 10.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-25 00:00:00', 9.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-26 00:00:00', 9.47000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-27 00:00:00', 10.133000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-28 00:00:00', 11.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-29 00:00:00', 12.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-11-30 00:00:00', 12.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-01 00:00:00', 10.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-02 00:00:00', 6.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-03 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-04 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-05 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-06 00:00:00', 4.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-07 00:00:00', 4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-08 00:00:00', 5.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-09 00:00:00', 5.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-10 00:00:00', 9.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-11 00:00:00', 10.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-12 00:00:00', 10.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-13 00:00:00', 10.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-14 00:00:00', 12.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-15 00:00:00', 13.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-16 00:00:00', 12.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-17 00:00:00', 11.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-18 00:00:00', 12.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-19 00:00:00', 13.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-20 00:00:00', 13.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-21 00:00:00', 12.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-22 00:00:00', 13.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-23 00:00:00', 13.9429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-24 00:00:00', 9.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-25 00:00:00', 10.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-26 00:00:00', 12.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-27 00:00:00', 12.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-28 00:00:00', 8.05799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-29 00:00:00', 12.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-30 00:00:00', 16.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1996-12-31 00:00:00', 15.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-01 00:00:00', 14.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-02 00:00:00', 16.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-03 00:00:00', 15.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-04 00:00:00', 8.26299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-05 00:00:00', 9.38599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-06 00:00:00', 10.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-07 00:00:00', 11.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-08 00:00:00', 9.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-09 00:00:00', 12.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-10 00:00:00', 13.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-11 00:00:00', 13.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-12 00:00:00', 9.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-13 00:00:00', 7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-14 00:00:00', 4.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-15 00:00:00', 7.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-16 00:00:00', 7.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-17 00:00:00', 9.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-18 00:00:00', 6.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-19 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-20 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-21 00:00:00', 2.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-22 00:00:00', 4.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-23 00:00:00', 2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-24 00:00:00', 2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-25 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-26 00:00:00', 7.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-27 00:00:00', 7.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-28 00:00:00', 10.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-29 00:00:00', 5.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-30 00:00:00', 7.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-01-31 00:00:00', 7.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-01 00:00:00', 7.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-02 00:00:00', 0.504999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-03 00:00:00', 4.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-04 00:00:00', 6.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-05 00:00:00', 7.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-06 00:00:00', 7.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-07 00:00:00', 6.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-08 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-09 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-10 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-11 00:00:00', 4.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-12 00:00:00', 7.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-13 00:00:00', 9.25800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-14 00:00:00', 9.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-15 00:00:00', 9.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-16 00:00:00', 10.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-17 00:00:00', 11.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-18 00:00:00', 11.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-19 00:00:00', 13.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-20 00:00:00', 9.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-21 00:00:00', 9.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-22 00:00:00', 10.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-23 00:00:00', 11.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-24 00:00:00', 9.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-25 00:00:00', 7.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-26 00:00:00', 10.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-27 00:00:00', 14.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-02-28 00:00:00', 12.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-01 00:00:00', 9.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-02 00:00:00', 5.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-03 00:00:00', 8.69200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-04 00:00:00', 14.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-05 00:00:00', 12.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-06 00:00:00', 12.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-07 00:00:00', 10.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-08 00:00:00', 18.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-09 00:00:00', 10.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-10 00:00:00', 8.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-11 00:00:00', 8.28699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-12 00:00:00', 10.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-13 00:00:00', 13.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-14 00:00:00', 8.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-15 00:00:00', 9.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-16 00:00:00', 12.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-17 00:00:00', 14.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-18 00:00:00', 14.255000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-19 00:00:00', 13.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-20 00:00:00', 15.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-21 00:00:00', 16.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-22 00:00:00', 14.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-23 00:00:00', 14.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-24 00:00:00', 20.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-25 00:00:00', 23.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-26 00:00:00', 25.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-27 00:00:00', 15.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-28 00:00:00', 15.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-29 00:00:00', 19.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-30 00:00:00', 24.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-03-31 00:00:00', 21.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-01 00:00:00', 16.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-02 00:00:00', 15.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-03 00:00:00', 17.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-04 00:00:00', 17.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-05 00:00:00', 20.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-06 00:00:00', 19.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-07 00:00:00', 21.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-08 00:00:00', 22.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-09 00:00:00', 22.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-10 00:00:00', 26.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-11 00:00:00', 25.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-12 00:00:00', 18.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-13 00:00:00', 14.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-14 00:00:00', 11.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-15 00:00:00', 9.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-16 00:00:00', 20.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-17 00:00:00', 24.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-18 00:00:00', 24.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-19 00:00:00', 24.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-20 00:00:00', 20.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-21 00:00:00', 23.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-22 00:00:00', 26.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-23 00:00:00', 28.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-24 00:00:00', 30.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-25 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-26 00:00:00', 31.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-27 00:00:00', 28.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-28 00:00:00', 28.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-29 00:00:00', 29.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-04-30 00:00:00', 27.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-01 00:00:00', 25.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-02 00:00:00', 25.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-03 00:00:00', 26.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-04 00:00:00', 27.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-05 00:00:00', 30.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-06 00:00:00', 24.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-07 00:00:00', 16.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-08 00:00:00', 18.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-09 00:00:00', 23.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-10 00:00:00', 24.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-11 00:00:00', 23.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-12 00:00:00', 17.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-13 00:00:00', 22.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-14 00:00:00', 26.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-15 00:00:00', 25.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-16 00:00:00', 17.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-17 00:00:00', 23.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-18 00:00:00', 26.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-19 00:00:00', 29.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-20 00:00:00', 31.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-21 00:00:00', 31.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-22 00:00:00', 30.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-23 00:00:00', 31.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-24 00:00:00', 32.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-25 00:00:00', 33.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-26 00:00:00', 35.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-27 00:00:00', 33.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-28 00:00:00', 31.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-29 00:00:00', 35.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-30 00:00:00', 34.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-05-31 00:00:00', 33.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-01 00:00:00', 35.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-02 00:00:00', 34.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-03 00:00:00', 34.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-04 00:00:00', 29.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-05 00:00:00', 33.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-06 00:00:00', 35.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-07 00:00:00', 35.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-08 00:00:00', 36.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-09 00:00:00', 36.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-10 00:00:00', 34.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-11 00:00:00', 32.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-12 00:00:00', 31.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-13 00:00:00', 33.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-14 00:00:00', 34.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-15 00:00:00', 37.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-16 00:00:00', 38.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-17 00:00:00', 36.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-18 00:00:00', 36.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-19 00:00:00', 32.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-20 00:00:00', 35.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-21 00:00:00', 35.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-22 00:00:00', 36.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-23 00:00:00', 37.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-24 00:00:00', 38.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-25 00:00:00', 38.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-26 00:00:00', 40.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-27 00:00:00', 38.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-28 00:00:00', 36.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-29 00:00:00', 36.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-06-30 00:00:00', 33.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-01 00:00:00', 35.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-02 00:00:00', 37.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-03 00:00:00', 38.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-04 00:00:00', 38.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-05 00:00:00', 38.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-06 00:00:00', 38.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-07 00:00:00', 40.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-08 00:00:00', 40.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-09 00:00:00', 36.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-10 00:00:00', 37.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-11 00:00:00', 37.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-12 00:00:00', 38.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-13 00:00:00', 39.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-14 00:00:00', 40.7260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-15 00:00:00', 41.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-16 00:00:00', 43.9760017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-17 00:00:00', 43.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-18 00:00:00', 45.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-19 00:00:00', 44.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-20 00:00:00', 42.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-21 00:00:00', 40.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-22 00:00:00', 38.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-23 00:00:00', 38.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-24 00:00:00', 38.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-25 00:00:00', 39.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-26 00:00:00', 41.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-27 00:00:00', 41.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-28 00:00:00', 41.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-29 00:00:00', 40.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-30 00:00:00', 38.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-07-31 00:00:00', 37.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-01 00:00:00', 35.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-02 00:00:00', 31.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-03 00:00:00', 32.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-04 00:00:00', 33.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-05 00:00:00', 36.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-06 00:00:00', 38.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-07 00:00:00', 40.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-08 00:00:00', 41.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-09 00:00:00', 40.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-10 00:00:00', 39.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-11 00:00:00', 37.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-12 00:00:00', 35.1500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-13 00:00:00', 36.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-14 00:00:00', 38.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-15 00:00:00', 40.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-16 00:00:00', 39.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-17 00:00:00', 40.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-18 00:00:00', 40.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-19 00:00:00', 41.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-20 00:00:00', 40.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-21 00:00:00', 40.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-22 00:00:00', 41.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-23 00:00:00', 38.5530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-24 00:00:00', 34.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-25 00:00:00', 32.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-26 00:00:00', 31.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-27 00:00:00', 32.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-28 00:00:00', 32.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-29 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-30 00:00:00', 34.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-08-31 00:00:00', 35.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-01 00:00:00', 38.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-02 00:00:00', 38.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-03 00:00:00', 39.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-04 00:00:00', 37.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-05 00:00:00', 36.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-06 00:00:00', 32.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-07 00:00:00', 28.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-08 00:00:00', 27.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-09 00:00:00', 28.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-10 00:00:00', 31.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-11 00:00:00', 33.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-12 00:00:00', 34.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-13 00:00:00', 34.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-14 00:00:00', 33.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-15 00:00:00', 31.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-16 00:00:00', 29.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-17 00:00:00', 30.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-18 00:00:00', 30.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-19 00:00:00', 29.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-20 00:00:00', 29.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-21 00:00:00', 29.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-22 00:00:00', 30.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-23 00:00:00', 30.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-24 00:00:00', 30.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-25 00:00:00', 30.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-26 00:00:00', 31.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-27 00:00:00', 31.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-28 00:00:00', 30.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-29 00:00:00', 29.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-09-30 00:00:00', 29.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-01 00:00:00', 30.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-02 00:00:00', 31.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-03 00:00:00', 30.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-04 00:00:00', 32.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-05 00:00:00', 31.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-06 00:00:00', 28.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-07 00:00:00', 28.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-08 00:00:00', 22.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-09 00:00:00', 24.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-10 00:00:00', 23.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-11 00:00:00', 25.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-12 00:00:00', 25.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-13 00:00:00', 27.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-14 00:00:00', 27.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-15 00:00:00', 25.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-16 00:00:00', 26.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-17 00:00:00', 25.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-18 00:00:00', 21.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-19 00:00:00', 24.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-20 00:00:00', 24.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-21 00:00:00', 23.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-22 00:00:00', 21.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-23 00:00:00', 23.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-24 00:00:00', 25.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-25 00:00:00', 24.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-26 00:00:00', 18.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-27 00:00:00', 21.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-28 00:00:00', 21.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-29 00:00:00', 20.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-30 00:00:00', 21.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-10-31 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-01 00:00:00', 22.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-02 00:00:00', 13.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-03 00:00:00', 19.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-04 00:00:00', 21.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-05 00:00:00', 24.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-06 00:00:00', 16.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-07 00:00:00', 10.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-08 00:00:00', 10.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-09 00:00:00', 10.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-10 00:00:00', 13.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-11 00:00:00', 16.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-12 00:00:00', 18.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-13 00:00:00', 19.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-14 00:00:00', 17.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-15 00:00:00', 10.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-16 00:00:00', 13.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-17 00:00:00', 14.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-18 00:00:00', 15.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-19 00:00:00', 15.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-20 00:00:00', 15.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-21 00:00:00', 16.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-22 00:00:00', 14.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-23 00:00:00', 13.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-24 00:00:00', 9.96599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-25 00:00:00', 7.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-26 00:00:00', 7.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-27 00:00:00', 9.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-28 00:00:00', 11.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-29 00:00:00', 10.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-11-30 00:00:00', 11.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-01 00:00:00', 14.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-02 00:00:00', 10.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-03 00:00:00', 9.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-04 00:00:00', 9.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-05 00:00:00', 11.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-06 00:00:00', 11.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-07 00:00:00', 14.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-08 00:00:00', 13.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-09 00:00:00', 13.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-10 00:00:00', 12.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-11 00:00:00', 15.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-12 00:00:00', 9.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-13 00:00:00', 9.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-14 00:00:00', 10.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-15 00:00:00', 11.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-16 00:00:00', 11.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-17 00:00:00', 11.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-18 00:00:00', 6.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-19 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-20 00:00:00', 6.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-21 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-22 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-23 00:00:00', 5.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-24 00:00:00', 7.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-25 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-26 00:00:00', 8.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-27 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-28 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-29 00:00:00', 2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-30 00:00:00', 7.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1997-12-31 00:00:00', 8.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-01 00:00:00', 9.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-02 00:00:00', 9.57199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-03 00:00:00', 8.57199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-04 00:00:00', 5.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-05 00:00:00', 6.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-06 00:00:00', 7.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-07 00:00:00', 6.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-08 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-09 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-10 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-11 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-12 00:00:00', 5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-13 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-14 00:00:00', 3.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-15 00:00:00', -0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-16 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-17 00:00:00', -0.0869999974966049194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-18 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-19 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-20 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-21 00:00:00', 2.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-22 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-23 00:00:00', -0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-24 00:00:00', 1.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-25 00:00:00', 2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-26 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-27 00:00:00', 8.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-28 00:00:00', 4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-29 00:00:00', 7.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-30 00:00:00', 7.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-01-31 00:00:00', 9.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-01 00:00:00', 5.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-02 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-03 00:00:00', 6.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-04 00:00:00', 8.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-05 00:00:00', 8.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-06 00:00:00', 9.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-07 00:00:00', 11.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-08 00:00:00', 9.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-09 00:00:00', 8.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-10 00:00:00', 9.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-11 00:00:00', 4.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-12 00:00:00', 9.88300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-13 00:00:00', 9.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-14 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-15 00:00:00', 7.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-16 00:00:00', 5.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-17 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-18 00:00:00', 1.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-19 00:00:00', 7.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-20 00:00:00', 3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-21 00:00:00', 4.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-22 00:00:00', 3.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-23 00:00:00', 0.537999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-24 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-25 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-26 00:00:00', 9.36400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-27 00:00:00', 5.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-02-28 00:00:00', 10.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-01 00:00:00', 4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-02 00:00:00', 8.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-03 00:00:00', 3.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-04 00:00:00', 4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-05 00:00:00', 6.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-06 00:00:00', 5.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-07 00:00:00', 3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-08 00:00:00', 7.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-09 00:00:00', 10.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-10 00:00:00', 12.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-11 00:00:00', 12.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-12 00:00:00', 11.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-13 00:00:00', 11.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-14 00:00:00', 10.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-15 00:00:00', 15.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-16 00:00:00', 15.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-17 00:00:00', 12.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-18 00:00:00', 16.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-19 00:00:00', 11.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-20 00:00:00', 13.1689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-21 00:00:00', 14.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-22 00:00:00', 12.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-23 00:00:00', 14.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-24 00:00:00', 15.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-25 00:00:00', 18.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-26 00:00:00', 17.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-27 00:00:00', 17.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-28 00:00:00', 18.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-29 00:00:00', 18.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-30 00:00:00', 22.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-03-31 00:00:00', 22.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-01 00:00:00', 22.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-02 00:00:00', 18.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-03 00:00:00', 16.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-04 00:00:00', 21.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-05 00:00:00', 24.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-06 00:00:00', 21.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-07 00:00:00', 24.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-08 00:00:00', 12.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-09 00:00:00', 18.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-10 00:00:00', 20.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-11 00:00:00', 21.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-12 00:00:00', 21.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-13 00:00:00', 23.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-14 00:00:00', 26.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-15 00:00:00', 27.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-16 00:00:00', 27.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-17 00:00:00', 28.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-18 00:00:00', 27.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-19 00:00:00', 29.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-20 00:00:00', 27.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-21 00:00:00', 24.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-22 00:00:00', 26.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-23 00:00:00', 29.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-24 00:00:00', 21.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-25 00:00:00', 15.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-26 00:00:00', 18.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-27 00:00:00', 20.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-28 00:00:00', 24.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-29 00:00:00', 26.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-04-30 00:00:00', 26.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-01 00:00:00', 24.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-02 00:00:00', 18.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-03 00:00:00', 14.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-04 00:00:00', 22.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-05 00:00:00', 19.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-06 00:00:00', 19.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-07 00:00:00', 23.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-08 00:00:00', 24.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-09 00:00:00', 24.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-10 00:00:00', 27.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-11 00:00:00', 24.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-12 00:00:00', 25.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-13 00:00:00', 25.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-14 00:00:00', 29.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-15 00:00:00', 31.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-16 00:00:00', 31.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-17 00:00:00', 30.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-18 00:00:00', 23.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-19 00:00:00', 26.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-20 00:00:00', 28.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-21 00:00:00', 30.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-22 00:00:00', 31.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-23 00:00:00', 33.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-24 00:00:00', 32.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-25 00:00:00', 32.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-26 00:00:00', 30.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-27 00:00:00', 29.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-28 00:00:00', 25.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-29 00:00:00', 28.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-30 00:00:00', 29.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-05-31 00:00:00', 26.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-01 00:00:00', 30.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-02 00:00:00', 31.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-03 00:00:00', 29.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-04 00:00:00', 30.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-05 00:00:00', 32.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-06 00:00:00', 29.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-07 00:00:00', 29.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-08 00:00:00', 31.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-09 00:00:00', 32.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-10 00:00:00', 30.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-11 00:00:00', 28.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-12 00:00:00', 26.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-13 00:00:00', 27.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-14 00:00:00', 27.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-15 00:00:00', 32.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-16 00:00:00', 33.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-17 00:00:00', 32.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-18 00:00:00', 32.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-19 00:00:00', 33.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-20 00:00:00', 34.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-21 00:00:00', 35.6570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-22 00:00:00', 32.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-23 00:00:00', 33.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-24 00:00:00', 36.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-25 00:00:00', 37.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-26 00:00:00', 36.7820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-27 00:00:00', 37.7340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-28 00:00:00', 36.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-29 00:00:00', 39.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-06-30 00:00:00', 36.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-01 00:00:00', 33.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-02 00:00:00', 34.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-03 00:00:00', 36.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-04 00:00:00', 36.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-05 00:00:00', 37.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-06 00:00:00', 39.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-07 00:00:00', 42.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-08 00:00:00', 43.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-09 00:00:00', 44.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-10 00:00:00', 44.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-11 00:00:00', 43.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-12 00:00:00', 39.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-13 00:00:00', 39.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-14 00:00:00', 39.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-15 00:00:00', 39.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-16 00:00:00', 38.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-17 00:00:00', 36.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-18 00:00:00', 37.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-19 00:00:00', 35.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-20 00:00:00', 36.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-21 00:00:00', 36.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-22 00:00:00', 36.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-23 00:00:00', 35.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-24 00:00:00', 36.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-25 00:00:00', 34.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-26 00:00:00', 32.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-27 00:00:00', 34.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-28 00:00:00', 36.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-29 00:00:00', 36.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-30 00:00:00', 36.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-07-31 00:00:00', 38.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-01 00:00:00', 38.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-02 00:00:00', 37.1559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-03 00:00:00', 39.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-04 00:00:00', 38.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-05 00:00:00', 32.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-06 00:00:00', 34.6759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-07 00:00:00', 36.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-08 00:00:00', 33.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-09 00:00:00', 37.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-10 00:00:00', 37.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-11 00:00:00', 38.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-12 00:00:00', 38.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-13 00:00:00', 39.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-14 00:00:00', 38.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-15 00:00:00', 36.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-16 00:00:00', 36.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-17 00:00:00', 36.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-18 00:00:00', 38.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-19 00:00:00', 37.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-20 00:00:00', 36.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-21 00:00:00', 34.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-22 00:00:00', 34.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-23 00:00:00', 34.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-24 00:00:00', 35.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-25 00:00:00', 35.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-26 00:00:00', 35.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-27 00:00:00', 36.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-28 00:00:00', 36.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-29 00:00:00', 36.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-30 00:00:00', 35.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-08-31 00:00:00', 35.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-01 00:00:00', 37.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-02 00:00:00', 37.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-03 00:00:00', 40.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-04 00:00:00', 39.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-05 00:00:00', 39.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-06 00:00:00', 38.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-07 00:00:00', 39.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-08 00:00:00', 36.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-09 00:00:00', 34.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-10 00:00:00', 32.6349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-11 00:00:00', 33.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-12 00:00:00', 29.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-13 00:00:00', 23.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-14 00:00:00', 16.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-15 00:00:00', 18.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-16 00:00:00', 22.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-17 00:00:00', 26.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-18 00:00:00', 28.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-19 00:00:00', 26.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-20 00:00:00', 26.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-21 00:00:00', 27.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-22 00:00:00', 27.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-23 00:00:00', 30.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-24 00:00:00', 31.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-25 00:00:00', 34.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-26 00:00:00', 34.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-27 00:00:00', 34.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-28 00:00:00', 31.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-29 00:00:00', 29.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-09-30 00:00:00', 28.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-01 00:00:00', 30.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-02 00:00:00', 30.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-03 00:00:00', 30.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-04 00:00:00', 28.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-05 00:00:00', 28.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-06 00:00:00', 27.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-07 00:00:00', 27.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-08 00:00:00', 29.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-09 00:00:00', 19.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-10 00:00:00', 15.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-11 00:00:00', 19.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-12 00:00:00', 24.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-13 00:00:00', 23.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-14 00:00:00', 20.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-15 00:00:00', 22.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-16 00:00:00', 23.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-17 00:00:00', 25.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-18 00:00:00', 25.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-19 00:00:00', 24.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-20 00:00:00', 24.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-21 00:00:00', 23.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-22 00:00:00', 22.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-23 00:00:00', 21.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-24 00:00:00', 19.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-25 00:00:00', 18.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-26 00:00:00', 16.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-27 00:00:00', 17.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-28 00:00:00', 15.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-29 00:00:00', 17.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-30 00:00:00', 21.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-10-31 00:00:00', 24.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-01 00:00:00', 26.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-02 00:00:00', 25.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-03 00:00:00', 24.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-04 00:00:00', 23.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-05 00:00:00', 22.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-06 00:00:00', 22.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-07 00:00:00', 21.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-08 00:00:00', 20.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-09 00:00:00', 21.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-10 00:00:00', 22.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-11 00:00:00', 23.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-12 00:00:00', 21.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-13 00:00:00', 16.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-14 00:00:00', 16.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-15 00:00:00', 21.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-16 00:00:00', 21.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-17 00:00:00', 18.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-18 00:00:00', 19.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-19 00:00:00', 19.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-20 00:00:00', 19.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-21 00:00:00', 16.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-22 00:00:00', 15.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-23 00:00:00', 14.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-24 00:00:00', 13.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-25 00:00:00', 14.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-26 00:00:00', 15.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-27 00:00:00', 14.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-28 00:00:00', 6.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-29 00:00:00', 5.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-11-30 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-01 00:00:00', 10.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-02 00:00:00', 7.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-03 00:00:00', 8.93000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-04 00:00:00', 9.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-05 00:00:00', 12.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-06 00:00:00', 9.99600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-07 00:00:00', 9.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-08 00:00:00', 13.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-09 00:00:00', 14.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-10 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-11 00:00:00', 18.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-12 00:00:00', 19.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-13 00:00:00', 19.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-14 00:00:00', 17.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-15 00:00:00', 13.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-16 00:00:00', 14.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-17 00:00:00', 15.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-18 00:00:00', 17.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-19 00:00:00', 16.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-20 00:00:00', 10.5819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-21 00:00:00', 13.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-22 00:00:00', 10.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-23 00:00:00', 12.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-24 00:00:00', 13.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-25 00:00:00', 9.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-26 00:00:00', 10.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-27 00:00:00', 12.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-28 00:00:00', 12.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-29 00:00:00', 7.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-30 00:00:00', 7.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1998-12-31 00:00:00', 11.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-02 00:00:00', 4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-04 00:00:00', 5.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-06 00:00:00', 9.50599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-08 00:00:00', 10.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-10 00:00:00', 7.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-12 00:00:00', 8.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-14 00:00:00', 6.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-16 00:00:00', 11.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-18 00:00:00', 9.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-20 00:00:00', 14.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-22 00:00:00', 13.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-24 00:00:00', 10.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-26 00:00:00', 13.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-28 00:00:00', 13.9189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-30 00:00:00', 11.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-01 00:00:00', 12.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-03 00:00:00', 12.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-05 00:00:00', 14.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-07 00:00:00', 14.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-09 00:00:00', 16.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-11 00:00:00', 12.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-13 00:00:00', 10.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-15 00:00:00', 10.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-17 00:00:00', 12.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-19 00:00:00', 11.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-21 00:00:00', 15.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-23 00:00:00', 15.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-25 00:00:00', 16.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-27 00:00:00', 9.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-01 00:00:00', 13.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-03 00:00:00', 10.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-04 00:00:00', 13.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-05 00:00:00', 7.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-06 00:00:00', 11.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-07 00:00:00', 6.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-08 00:00:00', 8.60299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-09 00:00:00', 12.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-10 00:00:00', 14.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-11 00:00:00', 15.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-12 00:00:00', 15.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-13 00:00:00', 17.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-14 00:00:00', 11.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-15 00:00:00', 15.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-16 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-17 00:00:00', 11.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-18 00:00:00', 12.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-19 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-20 00:00:00', 9.79599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-21 00:00:00', 14.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-22 00:00:00', 17.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-23 00:00:00', 17.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-24 00:00:00', 15.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-25 00:00:00', 16.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-26 00:00:00', 18.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-27 00:00:00', 19.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-28 00:00:00', 18.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-29 00:00:00', 12.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-30 00:00:00', 18.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-03-31 00:00:00', 14.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-01 00:00:00', 15.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-02 00:00:00', 17.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-03 00:00:00', 22.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-04 00:00:00', 20.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-05 00:00:00', 22.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-06 00:00:00', 19.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-07 00:00:00', 16.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-08 00:00:00', 17.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-09 00:00:00', 20.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-10 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-11 00:00:00', 11.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-12 00:00:00', 17.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-13 00:00:00', 18.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-14 00:00:00', 19.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-15 00:00:00', 23.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-16 00:00:00', 25.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-17 00:00:00', 25.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-18 00:00:00', 25.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-19 00:00:00', 22.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-20 00:00:00', 23.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-21 00:00:00', 23.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-22 00:00:00', 19.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-23 00:00:00', 17.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-24 00:00:00', 19.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-25 00:00:00', 22.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-26 00:00:00', 25.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-27 00:00:00', 26.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-28 00:00:00', 26.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-29 00:00:00', 26.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-04-30 00:00:00', 27.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-01 00:00:00', 26.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-02 00:00:00', 27.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-03 00:00:00', 28.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-04 00:00:00', 30.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-05 00:00:00', 29.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-06 00:00:00', 29.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-07 00:00:00', 31.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-08 00:00:00', 32.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-09 00:00:00', 31.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-10 00:00:00', 30.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-11 00:00:00', 30.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-12 00:00:00', 20.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-13 00:00:00', 25.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-14 00:00:00', 28.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-15 00:00:00', 32.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-16 00:00:00', 30.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-17 00:00:00', 33.6020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-18 00:00:00', 34.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-19 00:00:00', 35.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-20 00:00:00', 34.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-21 00:00:00', 37.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-22 00:00:00', 27.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-23 00:00:00', 24.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-24 00:00:00', 27.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-25 00:00:00', 26.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-26 00:00:00', 25.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-27 00:00:00', 28.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-28 00:00:00', 30.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-29 00:00:00', 30.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-30 00:00:00', 30.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-05-31 00:00:00', 31.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-01 00:00:00', 33.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-02 00:00:00', 30.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-03 00:00:00', 30.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-04 00:00:00', 31.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-05 00:00:00', 31.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-06 00:00:00', 35.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-07 00:00:00', 34.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-08 00:00:00', 36.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-09 00:00:00', 33.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-10 00:00:00', 31.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-11 00:00:00', 32.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-12 00:00:00', 32.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-13 00:00:00', 34.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-14 00:00:00', 36.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-15 00:00:00', 39.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-16 00:00:00', 36.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-17 00:00:00', 33.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-18 00:00:00', 34.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-19 00:00:00', 34.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-20 00:00:00', 34.3149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-21 00:00:00', 34.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-22 00:00:00', 34.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-23 00:00:00', 31.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-24 00:00:00', 30.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-25 00:00:00', 35.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-26 00:00:00', 41.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-27 00:00:00', 42.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-28 00:00:00', 40.1850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-29 00:00:00', 40.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-06-30 00:00:00', 39.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-01 00:00:00', 38.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-02 00:00:00', 36.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-03 00:00:00', 35.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-04 00:00:00', 36.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-05 00:00:00', 39.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-06 00:00:00', 37.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-07 00:00:00', 35.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-08 00:00:00', 36.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-09 00:00:00', 40.2519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-10 00:00:00', 37.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-11 00:00:00', 36.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-12 00:00:00', 32.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-13 00:00:00', 32.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-14 00:00:00', 34.4399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-15 00:00:00', 36.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-16 00:00:00', 38.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-17 00:00:00', 39.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-18 00:00:00', 38.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-19 00:00:00', 35.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-20 00:00:00', 36.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-21 00:00:00', 35.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-22 00:00:00', 36.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-23 00:00:00', 35.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-24 00:00:00', 35.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-25 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-26 00:00:00', 35.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-27 00:00:00', 33.9070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-28 00:00:00', 36.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-29 00:00:00', 35.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-30 00:00:00', 37.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-07-31 00:00:00', 37.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-01 00:00:00', 38.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-02 00:00:00', 38.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-03 00:00:00', 36.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-04 00:00:00', 40.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-05 00:00:00', 40.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-06 00:00:00', 40.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-07 00:00:00', 39.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-08 00:00:00', 39.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-09 00:00:00', 39.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-10 00:00:00', 38.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-11 00:00:00', 36.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-12 00:00:00', 33.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-13 00:00:00', 33.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-14 00:00:00', 34.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-15 00:00:00', 36.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-16 00:00:00', 36.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-17 00:00:00', 37.5159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-18 00:00:00', 37.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-19 00:00:00', 38.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-20 00:00:00', 39.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-21 00:00:00', 38.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-22 00:00:00', 38.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-23 00:00:00', 38.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-24 00:00:00', 38.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-25 00:00:00', 37.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-26 00:00:00', 38.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-27 00:00:00', 37.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-28 00:00:00', 38.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-29 00:00:00', 39.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-30 00:00:00', 40.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-08-31 00:00:00', 37.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-01 00:00:00', 34.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-02 00:00:00', 32.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-03 00:00:00', 33.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-04 00:00:00', 33.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-05 00:00:00', 32.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-06 00:00:00', 30.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-07 00:00:00', 32.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-08 00:00:00', 31.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-09 00:00:00', 32.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-10 00:00:00', 33.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-11 00:00:00', 33.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-12 00:00:00', 34.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-13 00:00:00', 36.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-14 00:00:00', 37.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-15 00:00:00', 36.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-16 00:00:00', 36.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-17 00:00:00', 36.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-18 00:00:00', 34.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-19 00:00:00', 33.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-20 00:00:00', 32.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-21 00:00:00', 33.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-22 00:00:00', 34.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-23 00:00:00', 34.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-24 00:00:00', 28.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-25 00:00:00', 26.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-26 00:00:00', 26.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-27 00:00:00', 29.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-28 00:00:00', 30.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-29 00:00:00', 16.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-09-30 00:00:00', 24.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-01 00:00:00', 24.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-02 00:00:00', 27.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-03 00:00:00', 27.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-04 00:00:00', 27.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-05 00:00:00', 27.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-06 00:00:00', 26.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-07 00:00:00', 24.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-08 00:00:00', 24.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-09 00:00:00', 24.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-10 00:00:00', 24.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-11 00:00:00', 25.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-12 00:00:00', 25.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-13 00:00:00', 26.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-14 00:00:00', 24.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-15 00:00:00', 25.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-16 00:00:00', 28.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-17 00:00:00', 27.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-18 00:00:00', 27.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-19 00:00:00', 27.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-20 00:00:00', 26.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-21 00:00:00', 24.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-22 00:00:00', 24.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-23 00:00:00', 25.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-24 00:00:00', 26.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-25 00:00:00', 27.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-26 00:00:00', 18.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-27 00:00:00', 18.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-28 00:00:00', 16.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-29 00:00:00', 22.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-30 00:00:00', 23.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-10-31 00:00:00', 22.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-01 00:00:00', 22.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-02 00:00:00', 20.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-03 00:00:00', 10.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-04 00:00:00', 13.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-05 00:00:00', 8.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-06 00:00:00', 13.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-07 00:00:00', 12.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-08 00:00:00', 15.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-09 00:00:00', 9.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-10 00:00:00', 13.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-11 00:00:00', 7.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-12 00:00:00', 12.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-13 00:00:00', 7.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-14 00:00:00', 11.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-15 00:00:00', 14.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-16 00:00:00', 15.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-17 00:00:00', 15.8079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-18 00:00:00', 14.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-19 00:00:00', 13.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-20 00:00:00', 10.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-21 00:00:00', 7.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-22 00:00:00', 8.11900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-23 00:00:00', 12.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-24 00:00:00', 8.84500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-25 00:00:00', 12.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-26 00:00:00', 13.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-27 00:00:00', 13.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-28 00:00:00', 14.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-29 00:00:00', 12.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-11-30 00:00:00', 7.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-01 00:00:00', 5.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-02 00:00:00', 10.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-03 00:00:00', 14.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-04 00:00:00', 11.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-05 00:00:00', 11.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-06 00:00:00', 6.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-07 00:00:00', 8.31700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-08 00:00:00', 10.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-09 00:00:00', 9.46800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-10 00:00:00', 12.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-11 00:00:00', 8.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-12 00:00:00', 10.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-13 00:00:00', 12.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-14 00:00:00', 13.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-15 00:00:00', 14.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-16 00:00:00', 16.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-17 00:00:00', 14.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-18 00:00:00', 7.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-19 00:00:00', 5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-20 00:00:00', 11.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-21 00:00:00', 12.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-22 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-23 00:00:00', 14.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-24 00:00:00', 12.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-25 00:00:00', 6.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-26 00:00:00', 9.33600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-27 00:00:00', 9.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-28 00:00:00', 11.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-29 00:00:00', 13.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-30 00:00:00', 14.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '1999-12-31 00:00:00', 15.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-01 00:00:00', 14.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-02 00:00:00', 15.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-03 00:00:00', 16.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-04 00:00:00', 16.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-05 00:00:00', 15.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-06 00:00:00', 14.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-07 00:00:00', 13.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-08 00:00:00', 8.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-09 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-10 00:00:00', 6.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-11 00:00:00', 5.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-12 00:00:00', -0.111000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-13 00:00:00', -3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-14 00:00:00', -0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-15 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-16 00:00:00', 5.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-17 00:00:00', 10.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-18 00:00:00', 6.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-19 00:00:00', 8.31499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-20 00:00:00', 12.5780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-21 00:00:00', 13.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-22 00:00:00', 8.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-23 00:00:00', 11.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-24 00:00:00', 9.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-25 00:00:00', 7.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-26 00:00:00', 8.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-27 00:00:00', 10.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-28 00:00:00', 13.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-29 00:00:00', 14.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-30 00:00:00', 12.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-01-31 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-01 00:00:00', 6.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-02 00:00:00', 8.93000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-03 00:00:00', 4.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-04 00:00:00', 6.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-05 00:00:00', 8.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-06 00:00:00', 8.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-07 00:00:00', 10.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-08 00:00:00', 9.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-09 00:00:00', 4.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-10 00:00:00', 3.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-11 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-12 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-13 00:00:00', 8.43500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-14 00:00:00', 10.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-15 00:00:00', 6.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-16 00:00:00', 5.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-17 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-18 00:00:00', 8.23499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-19 00:00:00', 8.56200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-20 00:00:00', 8.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-21 00:00:00', 10.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-22 00:00:00', 10.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-23 00:00:00', 10.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-24 00:00:00', 12.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-25 00:00:00', 12.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-26 00:00:00', 11.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-27 00:00:00', 6.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-28 00:00:00', 10.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-02-29 00:00:00', 9.05300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-01 00:00:00', 9.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-02 00:00:00', 9.00399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-03 00:00:00', 12.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-04 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-05 00:00:00', 7.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-06 00:00:00', 8.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-07 00:00:00', 11.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-08 00:00:00', 14.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-09 00:00:00', 16.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-10 00:00:00', 14.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-11 00:00:00', 12.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-12 00:00:00', 15.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-13 00:00:00', 15.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-14 00:00:00', 18.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-15 00:00:00', 19.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-16 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-17 00:00:00', 10.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-18 00:00:00', 12.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-19 00:00:00', 16.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-20 00:00:00', 18.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-21 00:00:00', 18.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-22 00:00:00', 19.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-23 00:00:00', 21.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-24 00:00:00', 22.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-25 00:00:00', 27.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-26 00:00:00', 24.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-27 00:00:00', 12.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-28 00:00:00', 12.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-29 00:00:00', 15.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-30 00:00:00', 17.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-03-31 00:00:00', 20.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-01 00:00:00', 20.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-02 00:00:00', 21.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-03 00:00:00', 17.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-04 00:00:00', 17.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-05 00:00:00', 19.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-06 00:00:00', 22.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-07 00:00:00', 24.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-08 00:00:00', 25.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-09 00:00:00', 28.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-10 00:00:00', 29.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-11 00:00:00', 32.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-12 00:00:00', 32.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-13 00:00:00', 26.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-14 00:00:00', 24.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-15 00:00:00', 25.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-16 00:00:00', 26.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-17 00:00:00', 30.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-18 00:00:00', 28.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-19 00:00:00', 28.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-20 00:00:00', 30.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-21 00:00:00', 30.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-22 00:00:00', 31.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-23 00:00:00', 29.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-24 00:00:00', 31.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-25 00:00:00', 28.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-26 00:00:00', 28.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-27 00:00:00', 27.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-28 00:00:00', 25.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-29 00:00:00', 25.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-04-30 00:00:00', 28.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-01 00:00:00', 32.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-02 00:00:00', 30.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-03 00:00:00', 32.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-04 00:00:00', 31.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-05 00:00:00', 33.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-06 00:00:00', 33.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-07 00:00:00', 35.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-08 00:00:00', 36.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-09 00:00:00', 38.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-10 00:00:00', 38.7540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-11 00:00:00', 32.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-12 00:00:00', 31.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-13 00:00:00', 33.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-14 00:00:00', 33.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-15 00:00:00', 32.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-16 00:00:00', 34.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-17 00:00:00', 35.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-18 00:00:00', 36.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-19 00:00:00', 36.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-20 00:00:00', 36.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-21 00:00:00', 36.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-22 00:00:00', 32.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-23 00:00:00', 31.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-24 00:00:00', 31.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-25 00:00:00', 32.5530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-26 00:00:00', 32.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-27 00:00:00', 33.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-28 00:00:00', 38.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-29 00:00:00', 34.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-30 00:00:00', 32.8989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-05-31 00:00:00', 33.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-01 00:00:00', 33.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-02 00:00:00', 32.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-03 00:00:00', 30.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-04 00:00:00', 31.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-05 00:00:00', 34.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-06 00:00:00', 35.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-07 00:00:00', 35.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-08 00:00:00', 36.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-09 00:00:00', 36.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-10 00:00:00', 34.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-11 00:00:00', 35.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-12 00:00:00', 36.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-13 00:00:00', 35.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-14 00:00:00', 29.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-15 00:00:00', 33.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-16 00:00:00', 32.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-17 00:00:00', 34.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-18 00:00:00', 36.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-19 00:00:00', 35.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-20 00:00:00', 35.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-21 00:00:00', 37.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-22 00:00:00', 36.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-23 00:00:00', 38.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-24 00:00:00', 40.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-25 00:00:00', 40.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-26 00:00:00', 40.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-27 00:00:00', 39.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-28 00:00:00', 38.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-29 00:00:00', 37.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-06-30 00:00:00', 37.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-01 00:00:00', 37.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-02 00:00:00', 37.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-03 00:00:00', 37.3790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-04 00:00:00', 37.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-05 00:00:00', 37.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-06 00:00:00', 38.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-07 00:00:00', 39.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-08 00:00:00', 39.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-09 00:00:00', 39.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-10 00:00:00', 39.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-11 00:00:00', 38.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-12 00:00:00', 38.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-13 00:00:00', 38.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-14 00:00:00', 36.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-15 00:00:00', 35.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-16 00:00:00', 34.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-17 00:00:00', 33.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-18 00:00:00', 32.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-19 00:00:00', 34.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-20 00:00:00', 35.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-21 00:00:00', 36.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-22 00:00:00', 36.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-23 00:00:00', 36.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-24 00:00:00', 35.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-25 00:00:00', 35.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-26 00:00:00', 35.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-27 00:00:00', 36.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-28 00:00:00', 39.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-29 00:00:00', 40.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-30 00:00:00', 39.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-07-31 00:00:00', 40.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-01 00:00:00', 39.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-02 00:00:00', 38.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-03 00:00:00', 38.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-04 00:00:00', 38.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-05 00:00:00', 38.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-06 00:00:00', 38.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-07 00:00:00', 39.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-08 00:00:00', 39.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-09 00:00:00', 37.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-10 00:00:00', 37.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-11 00:00:00', 38.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-12 00:00:00', 37.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-13 00:00:00', 37.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-14 00:00:00', 38.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-15 00:00:00', 37.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-16 00:00:00', 37.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-17 00:00:00', 36.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-18 00:00:00', 34.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-19 00:00:00', 34.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-20 00:00:00', 33.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-21 00:00:00', 34.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-22 00:00:00', 34.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-23 00:00:00', 35.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-24 00:00:00', 37.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-25 00:00:00', 38.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-26 00:00:00', 38.3030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-27 00:00:00', 38.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-28 00:00:00', 39.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-29 00:00:00', 39.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-30 00:00:00', 38.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-08-31 00:00:00', 37.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-01 00:00:00', 36.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-02 00:00:00', 36.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-03 00:00:00', 36.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-04 00:00:00', 36.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-05 00:00:00', 35.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-06 00:00:00', 34.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-07 00:00:00', 34.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-08 00:00:00', 33.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-09 00:00:00', 32.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-10 00:00:00', 31.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-11 00:00:00', 31.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-12 00:00:00', 32.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-13 00:00:00', 34.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-14 00:00:00', 34.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-15 00:00:00', 34.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-16 00:00:00', 35.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-17 00:00:00', 36.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-18 00:00:00', 35.345001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-19 00:00:00', 33.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-20 00:00:00', 30.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-21 00:00:00', 28.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-22 00:00:00', 27.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-23 00:00:00', 28.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-24 00:00:00', 30.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-25 00:00:00', 26.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-26 00:00:00', 22.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-27 00:00:00', 26.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-28 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-29 00:00:00', 30.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-09-30 00:00:00', 27.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-01 00:00:00', 27.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-02 00:00:00', 26.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-03 00:00:00', 27.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-04 00:00:00', 23.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-05 00:00:00', 16.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-06 00:00:00', 21.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-07 00:00:00', 19.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-08 00:00:00', 20.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-09 00:00:00', 20.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-10 00:00:00', 21.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-11 00:00:00', 22.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-12 00:00:00', 24.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-13 00:00:00', 25.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-14 00:00:00', 24.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-15 00:00:00', 20.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-16 00:00:00', 12.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-17 00:00:00', 21.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-18 00:00:00', 22.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-19 00:00:00', 20.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-20 00:00:00', 22.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-21 00:00:00', 21.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-22 00:00:00', 20.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-23 00:00:00', 18.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-24 00:00:00', 20.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-25 00:00:00', 20.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-26 00:00:00', 22.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-27 00:00:00', 26.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-28 00:00:00', 27.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-29 00:00:00', 26.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-30 00:00:00', 23.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-10-31 00:00:00', 23.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-01 00:00:00', 20.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-02 00:00:00', 20.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-03 00:00:00', 23.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-04 00:00:00', 24.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-05 00:00:00', 19.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-06 00:00:00', 19.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-07 00:00:00', 16.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-08 00:00:00', 7.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-09 00:00:00', 14.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-10 00:00:00', 17.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-11 00:00:00', 9.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-12 00:00:00', 5.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-13 00:00:00', 8.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-14 00:00:00', 12.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-15 00:00:00', 13.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-16 00:00:00', 9.05500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-17 00:00:00', 6.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-18 00:00:00', 4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-19 00:00:00', 12.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-20 00:00:00', 12.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-21 00:00:00', 12.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-22 00:00:00', 12.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-23 00:00:00', 10.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-24 00:00:00', 12.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-25 00:00:00', 12.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-26 00:00:00', 12.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-27 00:00:00', 11.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-28 00:00:00', 10.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-29 00:00:00', 6.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-11-30 00:00:00', 7.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-01 00:00:00', 10.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-02 00:00:00', 7.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-03 00:00:00', 7.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-04 00:00:00', 7.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-05 00:00:00', 7.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-06 00:00:00', 9.62800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-07 00:00:00', 9.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-08 00:00:00', 9.59599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-09 00:00:00', 9.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-10 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-11 00:00:00', 7.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-12 00:00:00', 10.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-13 00:00:00', 10.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-14 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-15 00:00:00', 11.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-16 00:00:00', 8.09099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-17 00:00:00', 5.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-18 00:00:00', 7.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-19 00:00:00', 9.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-20 00:00:00', 11.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-21 00:00:00', 12.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-22 00:00:00', 12.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-23 00:00:00', 12.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-24 00:00:00', 11.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-25 00:00:00', 10.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-26 00:00:00', 12.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-27 00:00:00', 11.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-28 00:00:00', 6.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-29 00:00:00', 9.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-30 00:00:00', 9.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2000-12-31 00:00:00', 9.16899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-01 00:00:00', 11.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-02 00:00:00', 8.92099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-03 00:00:00', 7.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-04 00:00:00', 9.92099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-05 00:00:00', 12.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-06 00:00:00', 7.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-07 00:00:00', 7.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-08 00:00:00', 7.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-09 00:00:00', 8.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-10 00:00:00', 8.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-11 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-12 00:00:00', 10.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-13 00:00:00', 11.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-14 00:00:00', 11.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-15 00:00:00', 10.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-16 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-17 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-18 00:00:00', 7.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-19 00:00:00', 7.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-20 00:00:00', 6.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-21 00:00:00', 2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-22 00:00:00', -0.425000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-23 00:00:00', 0.439999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-24 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-25 00:00:00', 0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-26 00:00:00', 1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-27 00:00:00', 2.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-28 00:00:00', 5.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-29 00:00:00', -4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-30 00:00:00', -4.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-01-31 00:00:00', 0.81800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-01 00:00:00', 3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-02 00:00:00', 3.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-03 00:00:00', 5.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-04 00:00:00', 4.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-05 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-06 00:00:00', 2.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-07 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-08 00:00:00', 6.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-09 00:00:00', 5.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-10 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-11 00:00:00', 2.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-12 00:00:00', 7.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-13 00:00:00', 8.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-14 00:00:00', 10.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-15 00:00:00', 14.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-16 00:00:00', 8.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-17 00:00:00', 10.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-18 00:00:00', 11.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-19 00:00:00', 14.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-20 00:00:00', 9.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-21 00:00:00', 12.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-22 00:00:00', 9.63799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-23 00:00:00', 10.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-24 00:00:00', 12.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-25 00:00:00', 12.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-26 00:00:00', 14.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-27 00:00:00', 13.9289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-02-28 00:00:00', 14.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-01 00:00:00', 15.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-02 00:00:00', 15.4420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-03 00:00:00', 14.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-04 00:00:00', 17.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-05 00:00:00', 17.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-06 00:00:00', 14.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-07 00:00:00', 15.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-08 00:00:00', 18.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-09 00:00:00', 19.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-10 00:00:00', 19.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-11 00:00:00', 15.4110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-12 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-13 00:00:00', 7.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-14 00:00:00', 1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-15 00:00:00', 15.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-16 00:00:00', 18.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-17 00:00:00', 18.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-18 00:00:00', 17.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-19 00:00:00', 10.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-20 00:00:00', 15.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-21 00:00:00', 17.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-22 00:00:00', 19.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-23 00:00:00', 20.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-24 00:00:00', 20.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-25 00:00:00', 22.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-26 00:00:00', 21.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-27 00:00:00', 14.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-28 00:00:00', 11.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-29 00:00:00', 14.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-30 00:00:00', 19.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-03-31 00:00:00', 20.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-01 00:00:00', 20.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-02 00:00:00', 14.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-03 00:00:00', 19.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-04 00:00:00', 24.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-05 00:00:00', 23.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-06 00:00:00', 25.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-07 00:00:00', 28.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-08 00:00:00', 31.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-09 00:00:00', 29.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-10 00:00:00', 28.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-11 00:00:00', 29.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-12 00:00:00', 28.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-13 00:00:00', 29.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-14 00:00:00', 27.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-15 00:00:00', 28.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-16 00:00:00', 27.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-17 00:00:00', 25.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-18 00:00:00', 24.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-19 00:00:00', 18.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-20 00:00:00', 23.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-21 00:00:00', 26.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-22 00:00:00', 28.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-23 00:00:00', 26.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-24 00:00:00', 27.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-25 00:00:00', 28.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-26 00:00:00', 26.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-27 00:00:00', 29.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-28 00:00:00', 29.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-29 00:00:00', 30.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-04-30 00:00:00', 30.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-01 00:00:00', 29.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-02 00:00:00', 28.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-03 00:00:00', 31.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-04 00:00:00', 33.5579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-05 00:00:00', 33.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-06 00:00:00', 34.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-07 00:00:00', 33.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-08 00:00:00', 32.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-09 00:00:00', 34.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-10 00:00:00', 36.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-11 00:00:00', 37.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-12 00:00:00', 37.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-13 00:00:00', 35.7729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-14 00:00:00', 36.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-15 00:00:00', 35.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-16 00:00:00', 39.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-17 00:00:00', 37.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-18 00:00:00', 36.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-19 00:00:00', 33.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-20 00:00:00', 30.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-21 00:00:00', 30.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-22 00:00:00', 32.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-23 00:00:00', 33.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-24 00:00:00', 33.0120010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-25 00:00:00', 33.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-26 00:00:00', 35.8370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-27 00:00:00', 37.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-28 00:00:00', 35.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-29 00:00:00', 33.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-30 00:00:00', 37.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-05-31 00:00:00', 39.0019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-01 00:00:00', 39.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-02 00:00:00', 36.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-03 00:00:00', 34.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-04 00:00:00', 34.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-05 00:00:00', 34.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-06 00:00:00', 35.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-07 00:00:00', 36.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-08 00:00:00', 37.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-09 00:00:00', 38.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-10 00:00:00', 39.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-11 00:00:00', 37.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-12 00:00:00', 37.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-13 00:00:00', 37.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-14 00:00:00', 35.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-15 00:00:00', 36.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-16 00:00:00', 35.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-17 00:00:00', 35.6360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-18 00:00:00', 37.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-19 00:00:00', 38.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-20 00:00:00', 39.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-21 00:00:00', 38.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-22 00:00:00', 35.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-23 00:00:00', 36.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-24 00:00:00', 37.6510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-25 00:00:00', 38.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-26 00:00:00', 39.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-27 00:00:00', 41.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-28 00:00:00', 43.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-29 00:00:00', 43.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-06-30 00:00:00', 42.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-01 00:00:00', 41.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-02 00:00:00', 37.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-03 00:00:00', 36.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-04 00:00:00', 36.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-05 00:00:00', 36.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-06 00:00:00', 35.4560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-07 00:00:00', 36.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-08 00:00:00', 38.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-09 00:00:00', 38.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-10 00:00:00', 40.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-11 00:00:00', 42.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-12 00:00:00', 42.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-13 00:00:00', 41.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-14 00:00:00', 40.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-15 00:00:00', 36.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-16 00:00:00', 34.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-17 00:00:00', 35.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-18 00:00:00', 36.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-19 00:00:00', 40.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-20 00:00:00', 38.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-21 00:00:00', 37.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-22 00:00:00', 36.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-23 00:00:00', 36.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-24 00:00:00', 35.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-25 00:00:00', 39.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-26 00:00:00', 38.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-27 00:00:00', 38.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-28 00:00:00', 35.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-29 00:00:00', 32.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-30 00:00:00', 31.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-07-31 00:00:00', 34.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-01 00:00:00', 36.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-02 00:00:00', 36.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-03 00:00:00', 37.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-04 00:00:00', 39.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-05 00:00:00', 39.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-06 00:00:00', 37.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-07 00:00:00', 37.8849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-08 00:00:00', 37.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-09 00:00:00', 37.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-10 00:00:00', 37.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-11 00:00:00', 36.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-12 00:00:00', 35.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-13 00:00:00', 35.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-14 00:00:00', 32.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-15 00:00:00', 32.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-16 00:00:00', 34.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-17 00:00:00', 34.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-18 00:00:00', 35.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-19 00:00:00', 34.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-20 00:00:00', 35.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-21 00:00:00', 35.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-22 00:00:00', 35.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-23 00:00:00', 35.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-24 00:00:00', 37.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-25 00:00:00', 36.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-26 00:00:00', 32.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-27 00:00:00', 34.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-28 00:00:00', 32.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-29 00:00:00', 31.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-30 00:00:00', 32.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-08-31 00:00:00', 34.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-01 00:00:00', 39.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-02 00:00:00', 37.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-03 00:00:00', 33.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-04 00:00:00', 32.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-05 00:00:00', 33.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-06 00:00:00', 35.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-07 00:00:00', 36.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-08 00:00:00', 38.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-09 00:00:00', 37.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-10 00:00:00', 34.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-11 00:00:00', 33.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-12 00:00:00', 31.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-13 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-14 00:00:00', 28.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-15 00:00:00', 29.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-16 00:00:00', 30.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-17 00:00:00', 30.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-18 00:00:00', 28.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-19 00:00:00', 25.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-20 00:00:00', 23.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-21 00:00:00', 25.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-22 00:00:00', 23.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-23 00:00:00', 24.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-24 00:00:00', 26.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-25 00:00:00', 26.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-26 00:00:00', 27.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-27 00:00:00', 31.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-28 00:00:00', 31.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-29 00:00:00', 31.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-09-30 00:00:00', 32.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-01 00:00:00', 32.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-02 00:00:00', 30.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-03 00:00:00', 24.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-04 00:00:00', 23.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-05 00:00:00', 23.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-06 00:00:00', 26.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-07 00:00:00', 30.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-08 00:00:00', 30.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-09 00:00:00', 25.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-10 00:00:00', 19.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-11 00:00:00', 16.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-12 00:00:00', 23.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-13 00:00:00', 23.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-14 00:00:00', 25.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-15 00:00:00', 25.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-16 00:00:00', 24.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-17 00:00:00', 24.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-18 00:00:00', 21.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-19 00:00:00', 21.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-20 00:00:00', 27.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-21 00:00:00', 25.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-22 00:00:00', 25.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-23 00:00:00', 18.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-24 00:00:00', 22.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-25 00:00:00', 26.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-26 00:00:00', 28.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-27 00:00:00', 19.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-28 00:00:00', 17.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-29 00:00:00', 19.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-30 00:00:00', 18.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-10-31 00:00:00', 20.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-01 00:00:00', 18.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-02 00:00:00', 15.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-03 00:00:00', 11.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-04 00:00:00', 17.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-05 00:00:00', 16.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-06 00:00:00', 16.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-07 00:00:00', 18.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-08 00:00:00', 20.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-09 00:00:00', 15.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-10 00:00:00', 16.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-11 00:00:00', 17.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-12 00:00:00', 20.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-13 00:00:00', 23.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-14 00:00:00', 23.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-15 00:00:00', 19.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-16 00:00:00', 21.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-17 00:00:00', 23.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-18 00:00:00', 23.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-19 00:00:00', 23.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-20 00:00:00', 14.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-21 00:00:00', 17.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-22 00:00:00', 19.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-23 00:00:00', 22.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-24 00:00:00', 18.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-25 00:00:00', 16.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-26 00:00:00', 15.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-27 00:00:00', 14.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-28 00:00:00', 14.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-29 00:00:00', 8.67800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-11-30 00:00:00', 10.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-01 00:00:00', 9.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-02 00:00:00', 7.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-03 00:00:00', 5.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-04 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-05 00:00:00', 8.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-06 00:00:00', 10.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-07 00:00:00', 11.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-08 00:00:00', 10.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-09 00:00:00', 10.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-10 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-11 00:00:00', 7.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-12 00:00:00', 8.96399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-13 00:00:00', 8.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-14 00:00:00', 10.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-15 00:00:00', 11.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-16 00:00:00', 9.71599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-17 00:00:00', 9.20600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-18 00:00:00', 7.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-19 00:00:00', 10.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-20 00:00:00', 12.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-21 00:00:00', 13.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-22 00:00:00', 7.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-23 00:00:00', 7.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-24 00:00:00', 10.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-25 00:00:00', 11.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-26 00:00:00', 12.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-27 00:00:00', 13.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-28 00:00:00', 12.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-29 00:00:00', 13.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-30 00:00:00', 14.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2001-12-31 00:00:00', 13.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-01 00:00:00', 13.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-02 00:00:00', 15.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-03 00:00:00', 18.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-04 00:00:00', 15.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-05 00:00:00', 14.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-06 00:00:00', 13.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-07 00:00:00', 14.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-08 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-09 00:00:00', 10.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-10 00:00:00', 10.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-11 00:00:00', 9.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-12 00:00:00', 8.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-13 00:00:00', 5.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-14 00:00:00', 2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-15 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-16 00:00:00', 1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-17 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-18 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-19 00:00:00', 4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-20 00:00:00', 7.43699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-21 00:00:00', 7.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-22 00:00:00', 8.52700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-23 00:00:00', 6.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-24 00:00:00', 7.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-25 00:00:00', 5.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-26 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-27 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-28 00:00:00', 6.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-29 00:00:00', 10.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-30 00:00:00', 11.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-01-31 00:00:00', 8.64299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-01 00:00:00', 6.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-02 00:00:00', 3.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-03 00:00:00', 6.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-04 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-05 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-06 00:00:00', -0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-07 00:00:00', 1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-08 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-09 00:00:00', 8.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-10 00:00:00', 10.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-11 00:00:00', 10.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-12 00:00:00', 7.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-13 00:00:00', 12.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-14 00:00:00', 15.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-15 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-16 00:00:00', 12.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-17 00:00:00', 7.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-18 00:00:00', 11.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-19 00:00:00', 9.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-20 00:00:00', 12.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-21 00:00:00', 14.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-22 00:00:00', 9.59300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-23 00:00:00', 10.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-24 00:00:00', 12.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-25 00:00:00', 13.560999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-26 00:00:00', 13.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-27 00:00:00', 15.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-02-28 00:00:00', 16.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-01 00:00:00', 9.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-02 00:00:00', 10.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-03 00:00:00', 13.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-04 00:00:00', 15.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-05 00:00:00', 18.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-06 00:00:00', 19.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-07 00:00:00', 8.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-08 00:00:00', 11.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-09 00:00:00', 10.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-10 00:00:00', 11.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-11 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-12 00:00:00', 7.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-13 00:00:00', 9.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-14 00:00:00', 13.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-15 00:00:00', 17.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-16 00:00:00', 19.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-17 00:00:00', 21.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-18 00:00:00', 22.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-19 00:00:00', 25.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-20 00:00:00', 18.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-21 00:00:00', 20.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-22 00:00:00', 20.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-23 00:00:00', 18.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-24 00:00:00', 10.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-25 00:00:00', 16.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-26 00:00:00', 19.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-27 00:00:00', 23.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-28 00:00:00', 24.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-29 00:00:00', 25.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-30 00:00:00', 15.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-03-31 00:00:00', 16.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-01 00:00:00', 14.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-02 00:00:00', 17.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-03 00:00:00', 21.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-04 00:00:00', 20.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-05 00:00:00', 15.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-06 00:00:00', 20.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-07 00:00:00', 20.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-08 00:00:00', 23.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-09 00:00:00', 26.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-10 00:00:00', 26.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-11 00:00:00', 27.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-12 00:00:00', 24.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-13 00:00:00', 25.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-14 00:00:00', 23.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-15 00:00:00', 15.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-16 00:00:00', 21.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-17 00:00:00', 24.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-18 00:00:00', 26.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-19 00:00:00', 29.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-20 00:00:00', 31.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-21 00:00:00', 31.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-22 00:00:00', 23.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-23 00:00:00', 15.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-24 00:00:00', 19.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-25 00:00:00', 19.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-26 00:00:00', 16.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-27 00:00:00', 15.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-28 00:00:00', 19.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-29 00:00:00', 21.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-04-30 00:00:00', 19.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-01 00:00:00', 22.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-02 00:00:00', 22.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-03 00:00:00', 25.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-04 00:00:00', 26.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-05 00:00:00', 25.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-06 00:00:00', 27.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-07 00:00:00', 27.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-08 00:00:00', 30.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-09 00:00:00', 30.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-10 00:00:00', 29.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-11 00:00:00', 32.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-12 00:00:00', 34.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-13 00:00:00', 30.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-14 00:00:00', 18.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-15 00:00:00', 26.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-16 00:00:00', 29.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-17 00:00:00', 28.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-18 00:00:00', 26.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-19 00:00:00', 25.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-20 00:00:00', 25.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-21 00:00:00', 28.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-22 00:00:00', 30.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-23 00:00:00', 30.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-24 00:00:00', 32.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-25 00:00:00', 34.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-26 00:00:00', 35.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-27 00:00:00', 31.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-28 00:00:00', 30.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-29 00:00:00', 31.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-30 00:00:00', 33.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-05-31 00:00:00', 36.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-01 00:00:00', 35.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-02 00:00:00', 37.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-03 00:00:00', 36.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-04 00:00:00', 36.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-05 00:00:00', 33.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-06 00:00:00', 31.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-07 00:00:00', 36.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-08 00:00:00', 34.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-09 00:00:00', 31.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-10 00:00:00', 31.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-11 00:00:00', 34.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-12 00:00:00', 35.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-13 00:00:00', 38.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-14 00:00:00', 40.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-15 00:00:00', 35.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-16 00:00:00', 33.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-17 00:00:00', 32.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-18 00:00:00', 34.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-19 00:00:00', 34.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-20 00:00:00', 35.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-21 00:00:00', 38.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-22 00:00:00', 38.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-23 00:00:00', 33.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-24 00:00:00', 33.7960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-25 00:00:00', 33.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-26 00:00:00', 36.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-27 00:00:00', 40.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-28 00:00:00', 38.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-29 00:00:00', 37.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-06-30 00:00:00', 37.8009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-01 00:00:00', 36.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-02 00:00:00', 34.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-03 00:00:00', 35.1269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-04 00:00:00', 35.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-05 00:00:00', 34.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-06 00:00:00', 33.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-07 00:00:00', 34.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-08 00:00:00', 34.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-09 00:00:00', 33.1220016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-10 00:00:00', 34.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-11 00:00:00', 35.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-12 00:00:00', 36.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-13 00:00:00', 37.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-14 00:00:00', 37.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-15 00:00:00', 37.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-16 00:00:00', 39.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-17 00:00:00', 40.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-18 00:00:00', 39.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-19 00:00:00', 40.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-20 00:00:00', 41.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-21 00:00:00', 37.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-22 00:00:00', 33.1990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-23 00:00:00', 35.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-24 00:00:00', 38.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-25 00:00:00', 38.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-26 00:00:00', 40.5519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-27 00:00:00', 37.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-28 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-29 00:00:00', 36.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-30 00:00:00', 35.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-07-31 00:00:00', 36.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-01 00:00:00', 37.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-02 00:00:00', 36.9879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-03 00:00:00', 37.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-04 00:00:00', 38.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-05 00:00:00', 41.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-06 00:00:00', 40.6570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-07 00:00:00', 40.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-08 00:00:00', 42.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-09 00:00:00', 43.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-10 00:00:00', 42.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-11 00:00:00', 43.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-12 00:00:00', 39.96099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-13 00:00:00', 34.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-14 00:00:00', 31.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-15 00:00:00', 33.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-16 00:00:00', 35.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-17 00:00:00', 37.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-18 00:00:00', 38.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-19 00:00:00', 38.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-20 00:00:00', 39.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-21 00:00:00', 35.9980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-22 00:00:00', 37.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-23 00:00:00', 39.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-24 00:00:00', 39.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-25 00:00:00', 39.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-26 00:00:00', 37.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-27 00:00:00', 38.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-28 00:00:00', 38.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-29 00:00:00', 38.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-30 00:00:00', 38.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-08-31 00:00:00', 36.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-01 00:00:00', 34.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-02 00:00:00', 31.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-03 00:00:00', 30.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-04 00:00:00', 31.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-05 00:00:00', 30.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-06 00:00:00', 31.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-07 00:00:00', 31.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-08 00:00:00', 31.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-09 00:00:00', 31.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-10 00:00:00', 32.1839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-11 00:00:00', 34.3489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-12 00:00:00', 34.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-13 00:00:00', 35.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-14 00:00:00', 35.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-15 00:00:00', 35.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-16 00:00:00', 35.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-17 00:00:00', 32.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-18 00:00:00', 32.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-19 00:00:00', 33.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-20 00:00:00', 35.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-21 00:00:00', 32.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-22 00:00:00', 31.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-23 00:00:00', 32.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-24 00:00:00', 28.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-25 00:00:00', 29.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-26 00:00:00', 29.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-27 00:00:00', 29.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-28 00:00:00', 29.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-29 00:00:00', 30.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-09-30 00:00:00', 29.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-01 00:00:00', 30.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-02 00:00:00', 31.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-03 00:00:00', 32.0449981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-04 00:00:00', 33.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-05 00:00:00', 31.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-06 00:00:00', 30.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-07 00:00:00', 30.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-08 00:00:00', 31.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-09 00:00:00', 30.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-10 00:00:00', 29.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-11 00:00:00', 29.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-12 00:00:00', 29.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-13 00:00:00', 28.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-14 00:00:00', 28.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-15 00:00:00', 26.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-16 00:00:00', 24.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-17 00:00:00', 25.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-18 00:00:00', 25.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-19 00:00:00', 24.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-20 00:00:00', 24.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-21 00:00:00', 25.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-22 00:00:00', 26.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-23 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-24 00:00:00', 20.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-25 00:00:00', 23.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-26 00:00:00', 23.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-27 00:00:00', 23.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-28 00:00:00', 23.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-29 00:00:00', 24.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-30 00:00:00', 24.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-10-31 00:00:00', 25.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-01 00:00:00', 24.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-02 00:00:00', 25.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-03 00:00:00', 24.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-04 00:00:00', 22.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-05 00:00:00', 16.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-06 00:00:00', 19.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-07 00:00:00', 21.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-08 00:00:00', 19.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-09 00:00:00', 18.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-10 00:00:00', 18.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-11 00:00:00', 19.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-12 00:00:00', 20.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-13 00:00:00', 21.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-14 00:00:00', 18.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-15 00:00:00', 17.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-16 00:00:00', 12.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-17 00:00:00', 15.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-18 00:00:00', 11.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-19 00:00:00', 14.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-20 00:00:00', 17.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-21 00:00:00', 16.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-22 00:00:00', 17.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-23 00:00:00', 16.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-24 00:00:00', 18.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-25 00:00:00', 19.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-26 00:00:00', 18.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-27 00:00:00', 14.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-28 00:00:00', 13.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-29 00:00:00', 13.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-11-30 00:00:00', 9.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-01 00:00:00', 12.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-02 00:00:00', 8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-03 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-04 00:00:00', -4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-05 00:00:00', -3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-06 00:00:00', 1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-07 00:00:00', 2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-08 00:00:00', 2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-09 00:00:00', 6.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-10 00:00:00', 8.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-11 00:00:00', 7.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-12 00:00:00', 7.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-13 00:00:00', 9.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-14 00:00:00', 11.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-15 00:00:00', 6.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-16 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-17 00:00:00', 6.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-18 00:00:00', 2.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-19 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-20 00:00:00', 3.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-21 00:00:00', 7.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-22 00:00:00', 11.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-23 00:00:00', 8.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-24 00:00:00', 4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-25 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-26 00:00:00', 8.40699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-27 00:00:00', 6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-28 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-29 00:00:00', 7.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-30 00:00:00', 4.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2002-12-31 00:00:00', 8.45400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-01 00:00:00', 12.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-02 00:00:00', 11.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-03 00:00:00', 12.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-04 00:00:00', 13.1689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-05 00:00:00', 14.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-06 00:00:00', 10.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-07 00:00:00', 9.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-08 00:00:00', 9.04399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-09 00:00:00', 9.86200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-10 00:00:00', 12.2440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-11 00:00:00', 9.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-12 00:00:00', 9.97000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-13 00:00:00', 12.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-14 00:00:00', 14.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-15 00:00:00', 14.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-16 00:00:00', 14.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-17 00:00:00', 15.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-18 00:00:00', 16.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-19 00:00:00', 9.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-20 00:00:00', 15.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-21 00:00:00', 11.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-22 00:00:00', 9.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-23 00:00:00', 7.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-24 00:00:00', 9.08100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-25 00:00:00', 8.75599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-26 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-27 00:00:00', 9.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-28 00:00:00', 10.5819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-29 00:00:00', 8.14299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-30 00:00:00', 7.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-01-31 00:00:00', 7.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-01 00:00:00', 8.14299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-02 00:00:00', 11.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-03 00:00:00', 14.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-04 00:00:00', 15.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-05 00:00:00', 16.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-06 00:00:00', 10.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-07 00:00:00', 5.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-08 00:00:00', 9.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-09 00:00:00', 11.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-10 00:00:00', 13.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-11 00:00:00', 15.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-12 00:00:00', 10.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-13 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-14 00:00:00', 10.4329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-15 00:00:00', 10.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-16 00:00:00', 7.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-17 00:00:00', 5.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-18 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-19 00:00:00', 4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-20 00:00:00', 6.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-21 00:00:00', 9.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-22 00:00:00', 8.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-23 00:00:00', 10.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-24 00:00:00', 10.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-25 00:00:00', 10.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-26 00:00:00', 11.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-27 00:00:00', 9.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-02-28 00:00:00', 7.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-01 00:00:00', 6.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-02 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-03 00:00:00', 1.4989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-04 00:00:00', 2.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-05 00:00:00', 6.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-06 00:00:00', 9.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-07 00:00:00', 11.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-08 00:00:00', 15.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-09 00:00:00', 7.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-10 00:00:00', 10.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-11 00:00:00', 13.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-12 00:00:00', 14.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-13 00:00:00', 17.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-14 00:00:00', 13.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-15 00:00:00', 10.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-16 00:00:00', 11.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-17 00:00:00', 15.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-18 00:00:00', 15.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-19 00:00:00', 14.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-20 00:00:00', 18.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-21 00:00:00', 22.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-22 00:00:00', 17.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-23 00:00:00', 20.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-24 00:00:00', 18.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-25 00:00:00', 19.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-26 00:00:00', 22.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-27 00:00:00', 16.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-28 00:00:00', 13.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-29 00:00:00', 16.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-30 00:00:00', 18.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-03-31 00:00:00', 10.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-01 00:00:00', 12.8730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-02 00:00:00', 14.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-03 00:00:00', 14.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-04 00:00:00', 15.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-05 00:00:00', 17.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-06 00:00:00', 21.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-07 00:00:00', 26.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-08 00:00:00', 28.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-09 00:00:00', 28.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-10 00:00:00', 28.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-11 00:00:00', 27.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-12 00:00:00', 28.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-13 00:00:00', 27.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-14 00:00:00', 24.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-15 00:00:00', 14.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-16 00:00:00', 12.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-17 00:00:00', 18.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-18 00:00:00', 16.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-19 00:00:00', 4.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-20 00:00:00', 13.9049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-21 00:00:00', 20.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-22 00:00:00', 25.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-23 00:00:00', 27.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-24 00:00:00', 17.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-25 00:00:00', 22.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-26 00:00:00', 25.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-27 00:00:00', 28.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-28 00:00:00', 30.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-29 00:00:00', 28.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-04-30 00:00:00', 21.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-01 00:00:00', 18.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-02 00:00:00', 14.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-03 00:00:00', 16.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-04 00:00:00', 19.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-05 00:00:00', 20.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-06 00:00:00', 24.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-07 00:00:00', 27.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-08 00:00:00', 29.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-09 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-10 00:00:00', 21.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-11 00:00:00', 22.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-12 00:00:00', 23.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-13 00:00:00', 24.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-14 00:00:00', 22.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-15 00:00:00', 25.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-16 00:00:00', 27.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-17 00:00:00', 28.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-18 00:00:00', 29.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-19 00:00:00', 29.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-20 00:00:00', 30.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-21 00:00:00', 31.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-22 00:00:00', 30.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-23 00:00:00', 30.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-24 00:00:00', 31.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-25 00:00:00', 30.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-26 00:00:00', 25.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-27 00:00:00', 21.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-28 00:00:00', 26.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-29 00:00:00', 27.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-30 00:00:00', 31.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-05-31 00:00:00', 32.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-01 00:00:00', 32.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-02 00:00:00', 34.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-03 00:00:00', 33.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-04 00:00:00', 32.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-05 00:00:00', 34.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-06 00:00:00', 35.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-07 00:00:00', 30.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-08 00:00:00', 29.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-09 00:00:00', 31.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-10 00:00:00', 32.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-11 00:00:00', 31.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-12 00:00:00', 27.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-13 00:00:00', 32.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-14 00:00:00', 33.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-15 00:00:00', 33.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-16 00:00:00', 35.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-17 00:00:00', 36.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-18 00:00:00', 36.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-19 00:00:00', 36.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-20 00:00:00', 35.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-21 00:00:00', 33.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-22 00:00:00', 33.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-23 00:00:00', 35.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-24 00:00:00', 36.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-25 00:00:00', 38.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-26 00:00:00', 34.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-27 00:00:00', 35.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-28 00:00:00', 35.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-29 00:00:00', 35.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-06-30 00:00:00', 35.8709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-01 00:00:00', 37.7319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-02 00:00:00', 39.0870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-03 00:00:00', 42.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-04 00:00:00', 39.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-05 00:00:00', 36.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-06 00:00:00', 37.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-07 00:00:00', 37.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-08 00:00:00', 38.6129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-09 00:00:00', 39.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-10 00:00:00', 38.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-11 00:00:00', 39.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-12 00:00:00', 38.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-13 00:00:00', 36.6780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-14 00:00:00', 37.4959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-15 00:00:00', 38.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-16 00:00:00', 38.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-17 00:00:00', 38.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-18 00:00:00', 43.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-19 00:00:00', 42.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-20 00:00:00', 43.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-21 00:00:00', 43.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-22 00:00:00', 40.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-23 00:00:00', 37.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-24 00:00:00', 36.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-25 00:00:00', 37.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-26 00:00:00', 37.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-27 00:00:00', 39.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-28 00:00:00', 40.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-29 00:00:00', 39.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-30 00:00:00', 38.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-07-31 00:00:00', 41.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-01 00:00:00', 41.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-02 00:00:00', 39.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-03 00:00:00', 36.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-04 00:00:00', 34.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-05 00:00:00', 32.7739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-06 00:00:00', 33.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-07 00:00:00', 34.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-08 00:00:00', 35.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-09 00:00:00', 35.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-10 00:00:00', 36.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-11 00:00:00', 36.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-12 00:00:00', 36.358001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-13 00:00:00', 37.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-14 00:00:00', 37.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-15 00:00:00', 39.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-16 00:00:00', 40.8170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-17 00:00:00', 40.6710014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-18 00:00:00', 39.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-19 00:00:00', 37.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-20 00:00:00', 35.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-21 00:00:00', 34.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-22 00:00:00', 34.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-23 00:00:00', 34.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-24 00:00:00', 35.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-25 00:00:00', 35.641998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-26 00:00:00', 35.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-27 00:00:00', 36.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-28 00:00:00', 36.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-29 00:00:00', 36.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-30 00:00:00', 34.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-08-31 00:00:00', 35.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-01 00:00:00', 35.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-02 00:00:00', 35.9840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-03 00:00:00', 36.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-04 00:00:00', 35.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-05 00:00:00', 34.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-06 00:00:00', 34.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-07 00:00:00', 34.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-08 00:00:00', 35.8790016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-09 00:00:00', 38.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-10 00:00:00', 36.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-11 00:00:00', 35.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-12 00:00:00', 36.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-13 00:00:00', 33.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-14 00:00:00', 33.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-15 00:00:00', 32.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-16 00:00:00', 28.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-17 00:00:00', 30.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-18 00:00:00', 33.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-19 00:00:00', 34.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-20 00:00:00', 36.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-21 00:00:00', 33.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-22 00:00:00', 30.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-23 00:00:00', 27.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-24 00:00:00', 25.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-25 00:00:00', 25.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-26 00:00:00', 24.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-27 00:00:00', 24.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-28 00:00:00', 23.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-29 00:00:00', 23.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-09-30 00:00:00', 24.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-01 00:00:00', 25.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-02 00:00:00', 27.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-03 00:00:00', 29.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-04 00:00:00', 30.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-05 00:00:00', 31.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-06 00:00:00', 27.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-07 00:00:00', 22.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-08 00:00:00', 21.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-09 00:00:00', 22.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-10 00:00:00', 23.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-11 00:00:00', 23.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-12 00:00:00', 22.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-13 00:00:00', 22.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-14 00:00:00', 23.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-15 00:00:00', 23.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-16 00:00:00', 21.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-17 00:00:00', 24.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-18 00:00:00', 26.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-19 00:00:00', 26.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-20 00:00:00', 26.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-21 00:00:00', 24.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-22 00:00:00', 24.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-23 00:00:00', 25.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-24 00:00:00', 25.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-25 00:00:00', 26.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-26 00:00:00', 27.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-27 00:00:00', 27.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-28 00:00:00', 29.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-29 00:00:00', 29.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-30 00:00:00', 29.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-10-31 00:00:00', 28.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-01 00:00:00', 27.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-02 00:00:00', 26.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-03 00:00:00', 26.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-04 00:00:00', 20.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-05 00:00:00', 12.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-06 00:00:00', 12.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-07 00:00:00', 10.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-08 00:00:00', 9.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-09 00:00:00', 14.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-10 00:00:00', 19.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-11 00:00:00', 20.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-12 00:00:00', 19.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-13 00:00:00', 14.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-14 00:00:00', 15.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-15 00:00:00', 14.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-16 00:00:00', 8.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-17 00:00:00', 5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-18 00:00:00', 7.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-19 00:00:00', 9.34300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-20 00:00:00', 12.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-21 00:00:00', 14.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-22 00:00:00', 13.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-23 00:00:00', 6.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-24 00:00:00', 9.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-25 00:00:00', 13.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-26 00:00:00', 12.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-27 00:00:00', 13.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-28 00:00:00', 15.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-29 00:00:00', 13.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-11-30 00:00:00', 12.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-01 00:00:00', 12.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-02 00:00:00', 11.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-03 00:00:00', 12.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-04 00:00:00', 12.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-05 00:00:00', 9.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-06 00:00:00', 13.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-07 00:00:00', 12.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-08 00:00:00', 11.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-09 00:00:00', 11.7100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-10 00:00:00', 11.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-11 00:00:00', 10.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-12 00:00:00', 2.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-13 00:00:00', -3.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-14 00:00:00', 0.535000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-15 00:00:00', 2.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-16 00:00:00', 4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-17 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-18 00:00:00', 8.57400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-19 00:00:00', 10.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-20 00:00:00', 10.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-21 00:00:00', 11.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-22 00:00:00', 6.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-23 00:00:00', 0.384000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-24 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-25 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-26 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-27 00:00:00', 4.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-28 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-29 00:00:00', 6.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-30 00:00:00', 3.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2003-12-31 00:00:00', 2.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-01 00:00:00', 0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-02 00:00:00', 1.39300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-03 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-04 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-05 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-06 00:00:00', 6.49900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-07 00:00:00', 6.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-08 00:00:00', 6.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-09 00:00:00', 11.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-10 00:00:00', 11.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-11 00:00:00', 10.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-12 00:00:00', 7.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-13 00:00:00', 7.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-14 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-15 00:00:00', 12.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-16 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-17 00:00:00', 8.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-18 00:00:00', 11.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-19 00:00:00', 11.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-20 00:00:00', 8.67099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-21 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-22 00:00:00', 6.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-23 00:00:00', 8.78400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-24 00:00:00', 10.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-25 00:00:00', 10.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-26 00:00:00', 10.5819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-27 00:00:00', 10.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-28 00:00:00', 6.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-29 00:00:00', 6.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-30 00:00:00', 4.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-01-31 00:00:00', 3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-01 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-02 00:00:00', 7.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-03 00:00:00', 11.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-04 00:00:00', 7.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-05 00:00:00', 9.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-06 00:00:00', 9.88799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-07 00:00:00', 8.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-08 00:00:00', 9.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-09 00:00:00', 8.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-10 00:00:00', 12.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-11 00:00:00', 16.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-12 00:00:00', 18.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-13 00:00:00', 14.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-14 00:00:00', 16.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-15 00:00:00', 17.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-16 00:00:00', 19.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-17 00:00:00', 9.52900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-18 00:00:00', 11.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-19 00:00:00', 10.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-20 00:00:00', 13.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-21 00:00:00', 10.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-22 00:00:00', 15.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-23 00:00:00', 16.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-24 00:00:00', 17.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-25 00:00:00', 14.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-26 00:00:00', 12.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-27 00:00:00', 13.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-28 00:00:00', 15.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-02-29 00:00:00', 14.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-01 00:00:00', 12.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-02 00:00:00', 16.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-03 00:00:00', 16.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-04 00:00:00', 16.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-05 00:00:00', 17.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-06 00:00:00', 23.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-07 00:00:00', 27.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-08 00:00:00', 24.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-09 00:00:00', 16.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-10 00:00:00', 16.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-11 00:00:00', 18.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-12 00:00:00', 22.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-13 00:00:00', 22.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-14 00:00:00', 16.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-15 00:00:00', 19.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-16 00:00:00', 21.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-17 00:00:00', 10.6029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-18 00:00:00', 15.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-19 00:00:00', 17.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-20 00:00:00', 16.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-21 00:00:00', 9.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-22 00:00:00', 12.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-23 00:00:00', 14.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-24 00:00:00', 16.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-25 00:00:00', 18.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-26 00:00:00', 20.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-27 00:00:00', 22.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-28 00:00:00', 23.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-29 00:00:00', 24.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-30 00:00:00', 26.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-03-31 00:00:00', 27.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-01 00:00:00', 24.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-02 00:00:00', 24.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-03 00:00:00', 20.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-04 00:00:00', 27.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-05 00:00:00', 29.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-06 00:00:00', 17.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-07 00:00:00', 17.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-08 00:00:00', 19.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-09 00:00:00', 18.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-10 00:00:00', 19.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-11 00:00:00', 22.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-12 00:00:00', 23.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-13 00:00:00', 23.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-14 00:00:00', 25.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-15 00:00:00', 27.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-16 00:00:00', 25.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-17 00:00:00', 26.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-18 00:00:00', 27.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-19 00:00:00', 21.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-20 00:00:00', 26.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-21 00:00:00', 30.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-22 00:00:00', 19.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-23 00:00:00', 24.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-24 00:00:00', 30.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-25 00:00:00', 31.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-26 00:00:00', 27.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-27 00:00:00', 25.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-28 00:00:00', 24.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-29 00:00:00', 16.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-04-30 00:00:00', 19.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-01 00:00:00', 22.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-02 00:00:00', 25.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-03 00:00:00', 27.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-04 00:00:00', 30.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-05 00:00:00', 32.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-06 00:00:00', 31.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-07 00:00:00', 17.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-08 00:00:00', 26.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-09 00:00:00', 27.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-10 00:00:00', 30.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-11 00:00:00', 31.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-12 00:00:00', 32.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-13 00:00:00', 35.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-14 00:00:00', 37.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-15 00:00:00', 38.5670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-16 00:00:00', 35.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-17 00:00:00', 36.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-18 00:00:00', 36.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-19 00:00:00', 30.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-20 00:00:00', 29.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-21 00:00:00', 31.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-22 00:00:00', 23.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-23 00:00:00', 26.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-24 00:00:00', 30.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-25 00:00:00', 32.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-26 00:00:00', 30.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-27 00:00:00', 29.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-28 00:00:00', 29.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-29 00:00:00', 31.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-30 00:00:00', 31.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-05-31 00:00:00', 31.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-01 00:00:00', 32.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-02 00:00:00', 32.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-03 00:00:00', 35.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-04 00:00:00', 37.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-05 00:00:00', 37.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-06 00:00:00', 35.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-07 00:00:00', 31.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-08 00:00:00', 32.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-09 00:00:00', 33.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-10 00:00:00', 36.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-11 00:00:00', 37.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-12 00:00:00', 38.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-13 00:00:00', 38.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-14 00:00:00', 32.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-15 00:00:00', 36.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-16 00:00:00', 37.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-17 00:00:00', 37.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-18 00:00:00', 38.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-19 00:00:00', 38.4879989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-20 00:00:00', 39.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-21 00:00:00', 39.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-22 00:00:00', 38.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-23 00:00:00', 38.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-24 00:00:00', 36.4819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-25 00:00:00', 35.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-26 00:00:00', 36.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-27 00:00:00', 36.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-28 00:00:00', 36.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-29 00:00:00', 38.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-06-30 00:00:00', 40.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-01 00:00:00', 38.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-02 00:00:00', 39.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-03 00:00:00', 40.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-04 00:00:00', 40.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-05 00:00:00', 37.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-06 00:00:00', 34.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-07 00:00:00', 36.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-08 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-09 00:00:00', 35.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-10 00:00:00', 36.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-11 00:00:00', 38.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-12 00:00:00', 36.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-13 00:00:00', 34.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-14 00:00:00', 35.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-15 00:00:00', 35.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-16 00:00:00', 32.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-17 00:00:00', 32.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-18 00:00:00', 32.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-19 00:00:00', 28.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-20 00:00:00', 32.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-21 00:00:00', 34.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-22 00:00:00', 34.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-23 00:00:00', 35.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-24 00:00:00', 39.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-25 00:00:00', 39.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-26 00:00:00', 40.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-27 00:00:00', 39.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-28 00:00:00', 39.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-29 00:00:00', 40.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-30 00:00:00', 37.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-07-31 00:00:00', 36.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-01 00:00:00', 33.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-02 00:00:00', 33.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-03 00:00:00', 33.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-04 00:00:00', 36.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-05 00:00:00', 39.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-06 00:00:00', 39.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-07 00:00:00', 34.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-08 00:00:00', 33.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-09 00:00:00', 34.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-10 00:00:00', 34.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-11 00:00:00', 34.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-12 00:00:00', 36.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-13 00:00:00', 42.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-14 00:00:00', 40.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-15 00:00:00', 39.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-16 00:00:00', 39.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-17 00:00:00', 37.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-18 00:00:00', 36.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-19 00:00:00', 36.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-20 00:00:00', 35.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-21 00:00:00', 35.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-22 00:00:00', 37.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-23 00:00:00', 38.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-24 00:00:00', 38.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-25 00:00:00', 36.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-26 00:00:00', 34.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-27 00:00:00', 34.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-28 00:00:00', 35.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-29 00:00:00', 34.7480010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-30 00:00:00', 33.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-08-31 00:00:00', 33.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-01 00:00:00', 32.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-02 00:00:00', 32.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-03 00:00:00', 32.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-04 00:00:00', 33.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-05 00:00:00', 33.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-06 00:00:00', 36.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-07 00:00:00', 38.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-08 00:00:00', 35.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-09 00:00:00', 36.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-10 00:00:00', 35.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-11 00:00:00', 37.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-12 00:00:00', 35.5089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-13 00:00:00', 35.5589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-14 00:00:00', 32.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-15 00:00:00', 29.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-16 00:00:00', 28.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-17 00:00:00', 28.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-18 00:00:00', 32.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-19 00:00:00', 31.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-20 00:00:00', 29.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-21 00:00:00', 26.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-22 00:00:00', 27.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-23 00:00:00', 29.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-24 00:00:00', 29.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-25 00:00:00', 30.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-26 00:00:00', 30.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-27 00:00:00', 30.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-28 00:00:00', 29.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-29 00:00:00', 30.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-09-30 00:00:00', 30.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-01 00:00:00', 29.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-02 00:00:00', 26.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-03 00:00:00', 28.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-04 00:00:00', 30.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-05 00:00:00', 29.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-06 00:00:00', 26.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-07 00:00:00', 18.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-08 00:00:00', 17.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-09 00:00:00', 15.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-10 00:00:00', 16.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-11 00:00:00', 22.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-12 00:00:00', 24.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-13 00:00:00', 24.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-14 00:00:00', 25.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-15 00:00:00', 19.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-16 00:00:00', 18.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-17 00:00:00', 20.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-18 00:00:00', 19.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-19 00:00:00', 18.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-20 00:00:00', 19.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-21 00:00:00', 22.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-22 00:00:00', 25.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-23 00:00:00', 26.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-24 00:00:00', 20.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-25 00:00:00', 18.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-26 00:00:00', 20.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-27 00:00:00', 16.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-28 00:00:00', 18.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-29 00:00:00', 21.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-30 00:00:00', 22.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-10-31 00:00:00', 21.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-01 00:00:00', 20.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-02 00:00:00', 20.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-03 00:00:00', 22.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-04 00:00:00', 24.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-05 00:00:00', 21.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-06 00:00:00', 21.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-07 00:00:00', 21.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-08 00:00:00', 20.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-09 00:00:00', 19.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-10 00:00:00', 16.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-11 00:00:00', 17.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-12 00:00:00', 17.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-13 00:00:00', 16.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-14 00:00:00', 18.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-15 00:00:00', 19.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-16 00:00:00', 16.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-17 00:00:00', 19.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-18 00:00:00', 21.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-19 00:00:00', 14.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-20 00:00:00', 16.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-21 00:00:00', 15.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-22 00:00:00', 14.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-23 00:00:00', 18.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-24 00:00:00', 20.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-25 00:00:00', 14.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-26 00:00:00', 16.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-27 00:00:00', 18.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-28 00:00:00', 20.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-29 00:00:00', 11.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-11-30 00:00:00', 8.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-01 00:00:00', 10.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-02 00:00:00', 14.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-03 00:00:00', 8.50599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-04 00:00:00', 7.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-05 00:00:00', 10.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-06 00:00:00', 11.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-07 00:00:00', 9.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-08 00:00:00', 10.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-09 00:00:00', 14.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-10 00:00:00', 15.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-11 00:00:00', 15.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-12 00:00:00', 14.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-13 00:00:00', 15.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-14 00:00:00', 11.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-15 00:00:00', 12.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-16 00:00:00', 12.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-17 00:00:00', 16.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-18 00:00:00', 10.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-19 00:00:00', 2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-20 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-21 00:00:00', 6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-22 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-23 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-24 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-25 00:00:00', 5.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-26 00:00:00', 6.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-27 00:00:00', 8.72099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-28 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-29 00:00:00', 0.720000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-30 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2004-12-31 00:00:00', 8.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-01 00:00:00', 5.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-02 00:00:00', 6.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-03 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-04 00:00:00', 8.65400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-05 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-06 00:00:00', 8.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-07 00:00:00', 8.42099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-08 00:00:00', 4.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-09 00:00:00', 6.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-10 00:00:00', 5.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-11 00:00:00', 11.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-12 00:00:00', 6.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-13 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-14 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-15 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-16 00:00:00', 6.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-17 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-18 00:00:00', 4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-19 00:00:00', 6.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-20 00:00:00', 8.83100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-21 00:00:00', 6.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-22 00:00:00', 4.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-23 00:00:00', 6.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-24 00:00:00', 5.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-25 00:00:00', 8.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-26 00:00:00', 5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-27 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-28 00:00:00', 0.465999990701675415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-29 00:00:00', 3.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-30 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-01-31 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-01 00:00:00', 7.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-02 00:00:00', 7.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-03 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-04 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-05 00:00:00', 5.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-06 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-07 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-08 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-09 00:00:00', 8.89000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-10 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-11 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-12 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-13 00:00:00', 0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-14 00:00:00', 1.62999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-15 00:00:00', 0.574999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-16 00:00:00', -0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-17 00:00:00', -0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-18 00:00:00', -0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-19 00:00:00', 0.368999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-20 00:00:00', 5.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-21 00:00:00', 7.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-22 00:00:00', 10.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-23 00:00:00', 5.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-24 00:00:00', 4.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-25 00:00:00', 7.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-26 00:00:00', 10.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-27 00:00:00', 13.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-02-28 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-01 00:00:00', 15.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-02 00:00:00', 18.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-03 00:00:00', 19.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-04 00:00:00', 19.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-05 00:00:00', 20.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-06 00:00:00', 21.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-07 00:00:00', 19.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-08 00:00:00', 18.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-09 00:00:00', 16.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-10 00:00:00', 17.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-11 00:00:00', 20.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-12 00:00:00', 25.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-13 00:00:00', 23.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-14 00:00:00', 15.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-15 00:00:00', 17.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-16 00:00:00', 14.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-17 00:00:00', 14.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-18 00:00:00', 16.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-19 00:00:00', 14.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-20 00:00:00', 17.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-21 00:00:00', 16.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-22 00:00:00', 18.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-23 00:00:00', 18.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-24 00:00:00', 20.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-25 00:00:00', 14.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-26 00:00:00', 16.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-27 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-28 00:00:00', 13.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-29 00:00:00', 16.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-30 00:00:00', 18.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-03-31 00:00:00', 20.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-01 00:00:00', 23.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-02 00:00:00', 24.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-03 00:00:00', 25.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-04 00:00:00', 22.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-05 00:00:00', 14.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-06 00:00:00', 11.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-07 00:00:00', 10.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-08 00:00:00', 10.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-09 00:00:00', 11.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-10 00:00:00', 14.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-11 00:00:00', 16.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-12 00:00:00', 17.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-13 00:00:00', 19.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-14 00:00:00', 20.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-15 00:00:00', 22.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-16 00:00:00', 24.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-17 00:00:00', 27.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-18 00:00:00', 29.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-19 00:00:00', 27.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-20 00:00:00', 27.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-21 00:00:00', 30.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-22 00:00:00', 29.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-23 00:00:00', 28.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-24 00:00:00', 25.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-25 00:00:00', 24.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-26 00:00:00', 24.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-27 00:00:00', 25.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-28 00:00:00', 28.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-29 00:00:00', 28.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-04-30 00:00:00', 30.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-01 00:00:00', 30.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-02 00:00:00', 30.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-03 00:00:00', 29.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-04 00:00:00', 29.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-05 00:00:00', 30.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-06 00:00:00', 29.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-07 00:00:00', 26.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-08 00:00:00', 17.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-09 00:00:00', 21.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-10 00:00:00', 26.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-11 00:00:00', 26.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-12 00:00:00', 26.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-13 00:00:00', 23.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-14 00:00:00', 23.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-15 00:00:00', 25.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-16 00:00:00', 26.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-17 00:00:00', 27.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-18 00:00:00', 26.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-19 00:00:00', 22.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-20 00:00:00', 21.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-21 00:00:00', 24.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-22 00:00:00', 26.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-23 00:00:00', 27.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-24 00:00:00', 24.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-25 00:00:00', 25.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-26 00:00:00', 27.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-27 00:00:00', 27.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-28 00:00:00', 29.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-29 00:00:00', 31.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-30 00:00:00', 32.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-05-31 00:00:00', 31.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-01 00:00:00', 32.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-02 00:00:00', 33.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-03 00:00:00', 35.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-04 00:00:00', 34.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-05 00:00:00', 33.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-06 00:00:00', 33.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-07 00:00:00', 34.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-08 00:00:00', 36.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-09 00:00:00', 31.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-10 00:00:00', 27.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-11 00:00:00', 27.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-12 00:00:00', 30.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-13 00:00:00', 31.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-14 00:00:00', 34.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-15 00:00:00', 36.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-16 00:00:00', 38.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-17 00:00:00', 38.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-18 00:00:00', 38.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-19 00:00:00', 38.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-20 00:00:00', 38.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-21 00:00:00', 39.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-22 00:00:00', 43.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-23 00:00:00', 43.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-24 00:00:00', 40.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-25 00:00:00', 35.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-26 00:00:00', 35.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-27 00:00:00', 38.53900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-28 00:00:00', 37.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-29 00:00:00', 36.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-06-30 00:00:00', 37.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-01 00:00:00', 37.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-02 00:00:00', 37.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-03 00:00:00', 37.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-04 00:00:00', 37.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-05 00:00:00', 37.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-06 00:00:00', 38.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-07 00:00:00', 39.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-08 00:00:00', 42.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-09 00:00:00', 43.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-10 00:00:00', 40.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-11 00:00:00', 39.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-12 00:00:00', 38.6689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-13 00:00:00', 38.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-14 00:00:00', 37.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-15 00:00:00', 36.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-16 00:00:00', 34.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-17 00:00:00', 35.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-18 00:00:00', 36.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-19 00:00:00', 37.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-20 00:00:00', 38.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-21 00:00:00', 38.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-22 00:00:00', 38.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-23 00:00:00', 37.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-24 00:00:00', 37.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-25 00:00:00', 37.5250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-26 00:00:00', 37.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-27 00:00:00', 37.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-28 00:00:00', 37.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-29 00:00:00', 36.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-30 00:00:00', 36.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-07-31 00:00:00', 38.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-01 00:00:00', 34.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-02 00:00:00', 34.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-03 00:00:00', 35.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-04 00:00:00', 36.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-05 00:00:00', 37.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-06 00:00:00', 37.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-07 00:00:00', 38.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-08 00:00:00', 38.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-09 00:00:00', 37.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-10 00:00:00', 36.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-11 00:00:00', 35.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-12 00:00:00', 33.1759986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-13 00:00:00', 34.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-14 00:00:00', 36.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-15 00:00:00', 36.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-16 00:00:00', 35.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-17 00:00:00', 34.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-18 00:00:00', 35.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-19 00:00:00', 35.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-20 00:00:00', 36.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-21 00:00:00', 36.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-22 00:00:00', 36.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-23 00:00:00', 37.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-24 00:00:00', 33.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-25 00:00:00', 32.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-26 00:00:00', 31.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-27 00:00:00', 28.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-28 00:00:00', 28.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-29 00:00:00', 29.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-30 00:00:00', 30.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-08-31 00:00:00', 31.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-01 00:00:00', 33.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-02 00:00:00', 35.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-03 00:00:00', 35.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-04 00:00:00', 37.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-05 00:00:00', 39.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-06 00:00:00', 39.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-07 00:00:00', 37.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-08 00:00:00', 35.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-09 00:00:00', 33.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-10 00:00:00', 30.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-11 00:00:00', 31.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-12 00:00:00', 32.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-13 00:00:00', 34.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-14 00:00:00', 34.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-15 00:00:00', 34.7610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-16 00:00:00', 35.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-17 00:00:00', 33.9959983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-18 00:00:00', 31.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-19 00:00:00', 31.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-20 00:00:00', 32.220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-21 00:00:00', 32.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-22 00:00:00', 32.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-23 00:00:00', 31.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-24 00:00:00', 31.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-25 00:00:00', 29.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-26 00:00:00', 30.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-27 00:00:00', 28.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-28 00:00:00', 28.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-29 00:00:00', 30.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-09-30 00:00:00', 31.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-01 00:00:00', 33.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-02 00:00:00', 31.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-03 00:00:00', 27.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-04 00:00:00', 26.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-05 00:00:00', 27.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-06 00:00:00', 31.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-07 00:00:00', 31.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-08 00:00:00', 30.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-09 00:00:00', 29.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-10 00:00:00', 28.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-11 00:00:00', 26.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-12 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-13 00:00:00', 21.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-14 00:00:00', 19.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-15 00:00:00', 19.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-16 00:00:00', 19.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-17 00:00:00', 22.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-18 00:00:00', 25.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-19 00:00:00', 26.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-20 00:00:00', 27.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-21 00:00:00', 27.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-22 00:00:00', 28.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-23 00:00:00', 21.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-24 00:00:00', 14.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-25 00:00:00', 17.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-26 00:00:00', 21.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-27 00:00:00', 19.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-28 00:00:00', 23.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-29 00:00:00', 24.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-30 00:00:00', 24.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-10-31 00:00:00', 20.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-01 00:00:00', 17.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-02 00:00:00', 18.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-03 00:00:00', 19.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-04 00:00:00', 20.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-05 00:00:00', 20.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-06 00:00:00', 21.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-07 00:00:00', 16.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-08 00:00:00', 17.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-09 00:00:00', 21.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-10 00:00:00', 14.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-11 00:00:00', 9.88099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-12 00:00:00', 14.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-13 00:00:00', 14.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-14 00:00:00', 10.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-15 00:00:00', 11.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-16 00:00:00', 10.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-17 00:00:00', 15.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-18 00:00:00', 18.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-19 00:00:00', 21.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-20 00:00:00', 21.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-21 00:00:00', 16.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-22 00:00:00', 17.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-23 00:00:00', 16.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-24 00:00:00', 13.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-25 00:00:00', 10.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-26 00:00:00', 9.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-27 00:00:00', 8.55099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-28 00:00:00', 9.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-29 00:00:00', 10.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-11-30 00:00:00', 10.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-01 00:00:00', 13.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-02 00:00:00', 13.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-03 00:00:00', 12.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-04 00:00:00', 12.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-05 00:00:00', 9.18700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-06 00:00:00', 14.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-07 00:00:00', 14.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-08 00:00:00', 8.74699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-09 00:00:00', 9.44699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-10 00:00:00', 11.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-11 00:00:00', 12.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-12 00:00:00', 10.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-13 00:00:00', 12.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-14 00:00:00', 9.84599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-15 00:00:00', 12.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-16 00:00:00', 14.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-17 00:00:00', 16.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-18 00:00:00', 17.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-19 00:00:00', 13.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-20 00:00:00', 14.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-21 00:00:00', 14.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-22 00:00:00', 12.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-23 00:00:00', 13.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-24 00:00:00', 15.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-25 00:00:00', 14.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-26 00:00:00', 15.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-27 00:00:00', 10.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-28 00:00:00', 6.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-29 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-30 00:00:00', 4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2005-12-31 00:00:00', 1.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-01 00:00:00', -0.804000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-02 00:00:00', -2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-03 00:00:00', -3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-04 00:00:00', -3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-05 00:00:00', -2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-06 00:00:00', 0.825999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-07 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-08 00:00:00', 5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-09 00:00:00', 6.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-10 00:00:00', 3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-11 00:00:00', 6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-12 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-13 00:00:00', 4.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-14 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-15 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-16 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-17 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-18 00:00:00', 3.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-19 00:00:00', 4.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-20 00:00:00', 2.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-21 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-22 00:00:00', 5.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-23 00:00:00', 3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-24 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-25 00:00:00', 4.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-26 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-27 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-28 00:00:00', 3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-29 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-30 00:00:00', 3.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-01-31 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-01 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-02 00:00:00', 6.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-03 00:00:00', 6.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-04 00:00:00', 15.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-05 00:00:00', 16.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-06 00:00:00', 13.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-07 00:00:00', 16.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-08 00:00:00', 16.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-09 00:00:00', 17.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-10 00:00:00', 13.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-11 00:00:00', 13.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-12 00:00:00', 15.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-13 00:00:00', 14.9049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-14 00:00:00', 17.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-15 00:00:00', 13.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-16 00:00:00', 15.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-17 00:00:00', 11.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-18 00:00:00', 14.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-19 00:00:00', 10.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-20 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-21 00:00:00', 12.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-22 00:00:00', 11.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-23 00:00:00', 7.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-24 00:00:00', 7.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-25 00:00:00', 5.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-26 00:00:00', 12.1549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-27 00:00:00', 13.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-02-28 00:00:00', 16.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-01 00:00:00', 16.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-02 00:00:00', 16.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-03 00:00:00', 17.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-04 00:00:00', 14.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-05 00:00:00', 17.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-06 00:00:00', 14.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-07 00:00:00', 14.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-08 00:00:00', 17.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-09 00:00:00', 19.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-10 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-11 00:00:00', 23.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-12 00:00:00', 21.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-13 00:00:00', 12.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-14 00:00:00', 11.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-15 00:00:00', 10.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-16 00:00:00', 13.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-17 00:00:00', 17.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-18 00:00:00', 17.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-19 00:00:00', 17.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-20 00:00:00', 19.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-21 00:00:00', 19.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-22 00:00:00', 15.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-23 00:00:00', 18.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-24 00:00:00', 18.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-25 00:00:00', 21.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-26 00:00:00', 13.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-27 00:00:00', 17.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-28 00:00:00', 21.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-29 00:00:00', 21.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-30 00:00:00', 22.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-03-31 00:00:00', 15.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-01 00:00:00', 13.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-02 00:00:00', 19.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-03 00:00:00', 22.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-04 00:00:00', 24.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-05 00:00:00', 25.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-06 00:00:00', 23.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-07 00:00:00', 26.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-08 00:00:00', 24.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-09 00:00:00', 11.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-10 00:00:00', 13.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-11 00:00:00', 15.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-12 00:00:00', 17.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-13 00:00:00', 19.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-14 00:00:00', 19.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-15 00:00:00', 20.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-16 00:00:00', 22.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-17 00:00:00', 22.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-18 00:00:00', 24.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-19 00:00:00', 26.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-20 00:00:00', 25.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-21 00:00:00', 21.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-22 00:00:00', 24.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-23 00:00:00', 26.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-24 00:00:00', 30.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-25 00:00:00', 32.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-26 00:00:00', 33.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-27 00:00:00', 34.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-28 00:00:00', 31.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-29 00:00:00', 28.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-04-30 00:00:00', 26.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-01 00:00:00', 27.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-02 00:00:00', 28.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-03 00:00:00', 29.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-04 00:00:00', 29.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-05 00:00:00', 29.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-06 00:00:00', 30.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-07 00:00:00', 28.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-08 00:00:00', 29.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-09 00:00:00', 31.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-10 00:00:00', 33.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-11 00:00:00', 33.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-12 00:00:00', 36.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-13 00:00:00', 35.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-14 00:00:00', 36.6300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-15 00:00:00', 38.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-16 00:00:00', 38.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-17 00:00:00', 34.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-18 00:00:00', 33.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-19 00:00:00', 34.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-20 00:00:00', 35.9679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-21 00:00:00', 33.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-22 00:00:00', 33.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-23 00:00:00', 34.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-24 00:00:00', 33.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-25 00:00:00', 33.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-26 00:00:00', 33.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-27 00:00:00', 33.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-28 00:00:00', 32.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-29 00:00:00', 32.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-30 00:00:00', 34.0050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-05-31 00:00:00', 30.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-01 00:00:00', 30.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-02 00:00:00', 33.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-03 00:00:00', 33.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-04 00:00:00', 32.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-05 00:00:00', 34.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-06 00:00:00', 33.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-07 00:00:00', 31.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-08 00:00:00', 31.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-09 00:00:00', 31.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-10 00:00:00', 31.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-11 00:00:00', 32.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-12 00:00:00', 33.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-13 00:00:00', 35.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-14 00:00:00', 38.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-15 00:00:00', 36.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-16 00:00:00', 35.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-17 00:00:00', 36.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-18 00:00:00', 38.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-19 00:00:00', 38.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-20 00:00:00', 39.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-21 00:00:00', 39.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-22 00:00:00', 38.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-23 00:00:00', 38.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-24 00:00:00', 39, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-25 00:00:00', 38.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-26 00:00:00', 39.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-27 00:00:00', 38.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-28 00:00:00', 38.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-29 00:00:00', 38.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-06-30 00:00:00', 37.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-01 00:00:00', 34.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-02 00:00:00', 34.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-03 00:00:00', 36.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-04 00:00:00', 37.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-05 00:00:00', 38.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-06 00:00:00', 40.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-07 00:00:00', 39.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-08 00:00:00', 39.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-09 00:00:00', 41.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-10 00:00:00', 39.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-11 00:00:00', 36.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-12 00:00:00', 33.5019989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-13 00:00:00', 30.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-14 00:00:00', 30.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-15 00:00:00', 32.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-16 00:00:00', 34.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-17 00:00:00', 36.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-18 00:00:00', 35.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-19 00:00:00', 36.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-20 00:00:00', 38.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-21 00:00:00', 39.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-22 00:00:00', 41.83599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-23 00:00:00', 42.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-24 00:00:00', 40.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-25 00:00:00', 40.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-26 00:00:00', 40.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-27 00:00:00', 39.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-28 00:00:00', 37.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-29 00:00:00', 39.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-30 00:00:00', 42.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-07-31 00:00:00', 41.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-01 00:00:00', 41.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-02 00:00:00', 40.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-03 00:00:00', 39.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-04 00:00:00', 39.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-05 00:00:00', 38.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-06 00:00:00', 37.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-07 00:00:00', 38.970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-08 00:00:00', 38.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-09 00:00:00', 39.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-10 00:00:00', 39.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-11 00:00:00', 39.2309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-12 00:00:00', 39.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-13 00:00:00', 40.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-14 00:00:00', 40.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-15 00:00:00', 36.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-16 00:00:00', 35.279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-17 00:00:00', 34.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-18 00:00:00', 37.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-19 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-20 00:00:00', 36.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-21 00:00:00', 37.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-22 00:00:00', 37.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-23 00:00:00', 37.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-24 00:00:00', 38.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-25 00:00:00', 38.5789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-26 00:00:00', 36.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-27 00:00:00', 35.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-28 00:00:00', 34.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-29 00:00:00', 33.8559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-30 00:00:00', 35.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-08-31 00:00:00', 36.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-01 00:00:00', 34.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-02 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-03 00:00:00', 32.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-04 00:00:00', 29.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-05 00:00:00', 29.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-06 00:00:00', 32.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-07 00:00:00', 34.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-08 00:00:00', 34.6069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-09 00:00:00', 34.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-10 00:00:00', 33.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-11 00:00:00', 32.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-12 00:00:00', 31.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-13 00:00:00', 32.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-14 00:00:00', 31.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-15 00:00:00', 31.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-16 00:00:00', 34.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-17 00:00:00', 35.3170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-18 00:00:00', 29.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-19 00:00:00', 23.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-20 00:00:00', 25.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-21 00:00:00', 27.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-22 00:00:00', 28.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-23 00:00:00', 29.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-24 00:00:00', 28.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-25 00:00:00', 27.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-26 00:00:00', 29.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-27 00:00:00', 31.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-28 00:00:00', 32.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-29 00:00:00', 26.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-09-30 00:00:00', 28.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-01 00:00:00', 29.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-02 00:00:00', 29.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-03 00:00:00', 30.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-04 00:00:00', 30.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-05 00:00:00', 31.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-06 00:00:00', 29.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-07 00:00:00', 29.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-08 00:00:00', 29.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-09 00:00:00', 31.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-10 00:00:00', 31.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-11 00:00:00', 30.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-12 00:00:00', 29.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-13 00:00:00', 27.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-14 00:00:00', 25.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-15 00:00:00', 24.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-16 00:00:00', 28.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-17 00:00:00', 29.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-18 00:00:00', 27.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-19 00:00:00', 25.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-20 00:00:00', 25.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-21 00:00:00', 22.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-22 00:00:00', 24.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-23 00:00:00', 26.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-24 00:00:00', 22.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-25 00:00:00', 19.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-26 00:00:00', 22.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-27 00:00:00', 22.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-28 00:00:00', 23.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-29 00:00:00', 24.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-30 00:00:00', 25.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-10-31 00:00:00', 27.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-01 00:00:00', 27.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-02 00:00:00', 24.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-03 00:00:00', 26.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-04 00:00:00', 27.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-05 00:00:00', 28.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-06 00:00:00', 26.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-07 00:00:00', 26.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-08 00:00:00', 26.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-09 00:00:00', 20.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-10 00:00:00', 14.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-11 00:00:00', 18.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-12 00:00:00', 18.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-13 00:00:00', 17.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-14 00:00:00', 17.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-15 00:00:00', 17.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-16 00:00:00', 13.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-17 00:00:00', 11.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-18 00:00:00', 16.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-19 00:00:00', 18.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-20 00:00:00', 14.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-21 00:00:00', 7.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-22 00:00:00', 2.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-23 00:00:00', 3.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-24 00:00:00', 8.62199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-25 00:00:00', 8.13099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-26 00:00:00', 7.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-27 00:00:00', 7.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-28 00:00:00', 10.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-29 00:00:00', 9.76299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-11-30 00:00:00', 8.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-01 00:00:00', 5.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-02 00:00:00', 7.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-03 00:00:00', 9.62600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-04 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-05 00:00:00', 0.518999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-06 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-07 00:00:00', 1.26199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-08 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-09 00:00:00', 8.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-10 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-11 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-12 00:00:00', 3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-13 00:00:00', 6.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-14 00:00:00', 7.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-15 00:00:00', 6.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-16 00:00:00', 7.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-17 00:00:00', 10.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-18 00:00:00', 13.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-19 00:00:00', 13.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-20 00:00:00', 9.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-21 00:00:00', 14.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-22 00:00:00', 13.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-23 00:00:00', 13.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-24 00:00:00', 7.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-25 00:00:00', 6.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-26 00:00:00', 9.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-27 00:00:00', 8.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-28 00:00:00', 12.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-29 00:00:00', 10.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-30 00:00:00', 5.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2006-12-31 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-01 00:00:00', -0.848999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-02 00:00:00', -0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-03 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-04 00:00:00', 2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-05 00:00:00', 2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-06 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-07 00:00:00', 9.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-08 00:00:00', 10.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-09 00:00:00', 6.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-10 00:00:00', 7.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-11 00:00:00', 6.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-12 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-13 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-14 00:00:00', 5.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-15 00:00:00', 4.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-16 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-17 00:00:00', 7.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-18 00:00:00', 3.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-19 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-20 00:00:00', 8.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-21 00:00:00', 8.39700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-22 00:00:00', 11.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-23 00:00:00', 12.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-24 00:00:00', 6.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-25 00:00:00', 9.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-26 00:00:00', 13.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-27 00:00:00', 14.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-28 00:00:00', 15.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-29 00:00:00', 16.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-30 00:00:00', 18.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-01-31 00:00:00', 18.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-01 00:00:00', 17.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-02 00:00:00', 10.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-03 00:00:00', 15.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-04 00:00:00', 10.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-05 00:00:00', 11.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-06 00:00:00', 11.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-07 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-08 00:00:00', 16.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-09 00:00:00', 10.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-10 00:00:00', 10.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-11 00:00:00', 7.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-12 00:00:00', 7.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-13 00:00:00', 9.48700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-14 00:00:00', 11.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-15 00:00:00', 12.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-16 00:00:00', 12.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-17 00:00:00', 11.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-18 00:00:00', 10.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-19 00:00:00', 5.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-20 00:00:00', 12.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-21 00:00:00', 7.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-22 00:00:00', 10.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-23 00:00:00', 13.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-24 00:00:00', 14.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-25 00:00:00', 13.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-26 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-27 00:00:00', 2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-02-28 00:00:00', 4.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-01 00:00:00', 0.781000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-02 00:00:00', 2.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-03 00:00:00', 8.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-04 00:00:00', 7.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-05 00:00:00', 12.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-06 00:00:00', 13.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-07 00:00:00', 16.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-08 00:00:00', 19.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-09 00:00:00', 9.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-10 00:00:00', 12.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-11 00:00:00', 9.49600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-12 00:00:00', 4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-13 00:00:00', 10.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-14 00:00:00', 13.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-15 00:00:00', 16.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-16 00:00:00', 16.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-17 00:00:00', 16.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-18 00:00:00', 11.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-19 00:00:00', 11.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-20 00:00:00', 17.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-21 00:00:00', 16.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-22 00:00:00', 18.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-23 00:00:00', 18.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-24 00:00:00', 18.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-25 00:00:00', 19.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-26 00:00:00', 17.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-27 00:00:00', 23.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-28 00:00:00', 20.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-29 00:00:00', 17.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-30 00:00:00', 11.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-03-31 00:00:00', 8.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-01 00:00:00', 9.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-02 00:00:00', 15.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-03 00:00:00', 19.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-04 00:00:00', 19.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-05 00:00:00', 20.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-06 00:00:00', 19.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-07 00:00:00', 22.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-08 00:00:00', 24.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-09 00:00:00', 25.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-10 00:00:00', 29.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-11 00:00:00', 29.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-12 00:00:00', 30.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-13 00:00:00', 32.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-14 00:00:00', 28.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-15 00:00:00', 32.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-16 00:00:00', 30.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-17 00:00:00', 27.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-18 00:00:00', 27.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-19 00:00:00', 28.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-20 00:00:00', 30.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-21 00:00:00', 31.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-22 00:00:00', 25.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-23 00:00:00', 26.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-24 00:00:00', 27.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-25 00:00:00', 30.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-26 00:00:00', 32.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-27 00:00:00', 28.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-28 00:00:00', 30.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-29 00:00:00', 31.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-04-30 00:00:00', 32.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-01 00:00:00', 33.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-02 00:00:00', 31.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-03 00:00:00', 32.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-04 00:00:00', 32.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-05 00:00:00', 32.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-06 00:00:00', 32.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-07 00:00:00', 24.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-08 00:00:00', 26.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-09 00:00:00', 28.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-10 00:00:00', 32.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-11 00:00:00', 33.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-12 00:00:00', 33.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-13 00:00:00', 33.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-14 00:00:00', 35.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-15 00:00:00', 37.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-16 00:00:00', 25.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-17 00:00:00', 22.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-18 00:00:00', 19.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-19 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-20 00:00:00', 24.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-21 00:00:00', 27.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-22 00:00:00', 29.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-23 00:00:00', 30.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-24 00:00:00', 30.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-25 00:00:00', 29.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-26 00:00:00', 30.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-27 00:00:00', 32.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-28 00:00:00', 33.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-29 00:00:00', 34.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-30 00:00:00', 34.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-05-31 00:00:00', 33.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-01 00:00:00', 34.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-02 00:00:00', 34.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-03 00:00:00', 33.016998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-04 00:00:00', 32.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-05 00:00:00', 26.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-06 00:00:00', 31.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-07 00:00:00', 33.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-08 00:00:00', 34.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-09 00:00:00', 37.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-10 00:00:00', 38.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-11 00:00:00', 40.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-12 00:00:00', 38.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-13 00:00:00', 37.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-14 00:00:00', 38.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-15 00:00:00', 35.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-16 00:00:00', 33.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-17 00:00:00', 34.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-18 00:00:00', 35.5989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-19 00:00:00', 36.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-20 00:00:00', 38.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-21 00:00:00', 42.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-22 00:00:00', 41.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-23 00:00:00', 43.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-24 00:00:00', 41.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-25 00:00:00', 40.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-26 00:00:00', 41.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-27 00:00:00', 39.9949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-28 00:00:00', 38.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-29 00:00:00', 37.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-06-30 00:00:00', 38.8650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-01 00:00:00', 38.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-02 00:00:00', 37.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-03 00:00:00', 40.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-04 00:00:00', 39.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-05 00:00:00', 38.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-06 00:00:00', 38.9350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-07 00:00:00', 36.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-08 00:00:00', 36.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-09 00:00:00', 38.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-10 00:00:00', 39.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-11 00:00:00', 39.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-12 00:00:00', 38.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-13 00:00:00', 37.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-14 00:00:00', 36.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-15 00:00:00', 36.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-16 00:00:00', 37.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-17 00:00:00', 39.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-18 00:00:00', 39.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-19 00:00:00', 41.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-20 00:00:00', 40.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-21 00:00:00', 30.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-22 00:00:00', 35.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-23 00:00:00', 36.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-24 00:00:00', 38.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-25 00:00:00', 38.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-26 00:00:00', 37.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-27 00:00:00', 35.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-28 00:00:00', 36.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-29 00:00:00', 37.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-30 00:00:00', 39.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-07-31 00:00:00', 39.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-01 00:00:00', 38.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-02 00:00:00', 36.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-03 00:00:00', 35.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-04 00:00:00', 36.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-05 00:00:00', 37.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-06 00:00:00', 36.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-07 00:00:00', 37.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-08 00:00:00', 38.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-09 00:00:00', 39.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-10 00:00:00', 40.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-11 00:00:00', 41.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-12 00:00:00', 34.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-13 00:00:00', 34.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-14 00:00:00', 35.7120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-15 00:00:00', 34.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-16 00:00:00', 34.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-17 00:00:00', 34.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-18 00:00:00', 36.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-19 00:00:00', 37.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-20 00:00:00', 37.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-21 00:00:00', 36.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-22 00:00:00', 35.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-23 00:00:00', 36.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-24 00:00:00', 36.5600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-25 00:00:00', 36.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-26 00:00:00', 35.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-27 00:00:00', 35.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-28 00:00:00', 35.8100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-29 00:00:00', 37.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-30 00:00:00', 37.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-08-31 00:00:00', 38.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-01 00:00:00', 37.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-02 00:00:00', 38.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-03 00:00:00', 37.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-04 00:00:00', 34.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-05 00:00:00', 33.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-06 00:00:00', 34.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-07 00:00:00', 34.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-08 00:00:00', 33.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-09 00:00:00', 35.3009986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-10 00:00:00', 34.9469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-11 00:00:00', 35.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-12 00:00:00', 35.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-13 00:00:00', 34.7239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-14 00:00:00', 35.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-15 00:00:00', 34.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-16 00:00:00', 33.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-17 00:00:00', 34.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-18 00:00:00', 34.0369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-19 00:00:00', 32.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-20 00:00:00', 30.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-21 00:00:00', 28.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-22 00:00:00', 27.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-23 00:00:00', 25.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-24 00:00:00', 26.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-25 00:00:00', 27.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-26 00:00:00', 27.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-27 00:00:00', 25.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-28 00:00:00', 23.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-29 00:00:00', 24.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-09-30 00:00:00', 25.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-01 00:00:00', 23.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-02 00:00:00', 23.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-03 00:00:00', 22.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-04 00:00:00', 20.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-05 00:00:00', 19.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-06 00:00:00', 20.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-07 00:00:00', 21.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-08 00:00:00', 22.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-09 00:00:00', 22.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-10 00:00:00', 21.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-11 00:00:00', 21.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-12 00:00:00', 23.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-13 00:00:00', 24.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-14 00:00:00', 25.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-15 00:00:00', 26.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-16 00:00:00', 25.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-17 00:00:00', 26.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-18 00:00:00', 27.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-19 00:00:00', 21.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-20 00:00:00', 21.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-21 00:00:00', 22.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-22 00:00:00', 23.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-23 00:00:00', 22.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-24 00:00:00', 21.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-25 00:00:00', 19.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-26 00:00:00', 18.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-27 00:00:00', 20.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-28 00:00:00', 21.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-29 00:00:00', 19.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-30 00:00:00', 21.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-10-31 00:00:00', 23.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-01 00:00:00', 25.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-02 00:00:00', 25.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-03 00:00:00', 24.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-04 00:00:00', 27.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-05 00:00:00', 23.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-06 00:00:00', 26.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-07 00:00:00', 25.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-08 00:00:00', 24.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-09 00:00:00', 19.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-10 00:00:00', 22.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-11 00:00:00', 22.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-12 00:00:00', 23.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-13 00:00:00', 21.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-14 00:00:00', 17.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-15 00:00:00', 18.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-16 00:00:00', 18.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-17 00:00:00', 19.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-18 00:00:00', 19.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-19 00:00:00', 20.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-20 00:00:00', 17.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-21 00:00:00', 19.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-22 00:00:00', 22.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-23 00:00:00', 17.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-24 00:00:00', 15.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-25 00:00:00', 19.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-26 00:00:00', 19.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-27 00:00:00', 17.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-28 00:00:00', 13.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-29 00:00:00', 15.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-11-30 00:00:00', 10.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-01 00:00:00', 6.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-02 00:00:00', 11.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-03 00:00:00', 13.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-04 00:00:00', 14.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-05 00:00:00', 11.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-06 00:00:00', 13.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-07 00:00:00', 10.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-08 00:00:00', 12.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-09 00:00:00', 8.02000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-10 00:00:00', 5.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-11 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-12 00:00:00', 6.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-13 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-14 00:00:00', 6.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-15 00:00:00', 10.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-16 00:00:00', 9.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-17 00:00:00', 8.99600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-18 00:00:00', 7.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-19 00:00:00', 5.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-20 00:00:00', 8.80500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-21 00:00:00', 6.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-22 00:00:00', 8.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-23 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-24 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-25 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-26 00:00:00', 1.76499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-27 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-28 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-29 00:00:00', -0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-30 00:00:00', 4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2007-12-31 00:00:00', 5.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-01 00:00:00', 6.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-02 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-03 00:00:00', 6.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-04 00:00:00', 3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-05 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-06 00:00:00', 5.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-07 00:00:00', 4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-08 00:00:00', -3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-09 00:00:00', 1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-10 00:00:00', -1.14900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-11 00:00:00', 0.629000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-12 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-13 00:00:00', -2.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-14 00:00:00', -1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-15 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-16 00:00:00', -1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-17 00:00:00', -2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-18 00:00:00', -2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-19 00:00:00', -4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-20 00:00:00', -5.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-21 00:00:00', -4.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-22 00:00:00', -4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-23 00:00:00', -4.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-24 00:00:00', -3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-25 00:00:00', -3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-26 00:00:00', -1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-27 00:00:00', 2.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-28 00:00:00', 0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-29 00:00:00', 2.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-30 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-01-31 00:00:00', 8.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-01 00:00:00', 7.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-02 00:00:00', 2.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-03 00:00:00', -1.42200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-04 00:00:00', -2.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-05 00:00:00', -4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-06 00:00:00', -5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-07 00:00:00', -5.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-08 00:00:00', -1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-09 00:00:00', -0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-10 00:00:00', -2.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-11 00:00:00', -1.84700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-12 00:00:00', 1.67299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-13 00:00:00', 5.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-14 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-15 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-16 00:00:00', 4.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-17 00:00:00', 7.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-18 00:00:00', 10.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-19 00:00:00', 11.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-20 00:00:00', 13.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-21 00:00:00', 7.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-22 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-23 00:00:00', 5.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-24 00:00:00', 8.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-25 00:00:00', 9.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-26 00:00:00', 12.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-27 00:00:00', 17.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-28 00:00:00', 15.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-02-29 00:00:00', 18.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-01 00:00:00', 14.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-02 00:00:00', 16.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-03 00:00:00', 16.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-04 00:00:00', 18.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-05 00:00:00', 17.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-06 00:00:00', 9.03899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-07 00:00:00', 14.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-08 00:00:00', 19.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-09 00:00:00', 16.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-10 00:00:00', 18.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-11 00:00:00', 20.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-12 00:00:00', 19.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-13 00:00:00', 21.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-14 00:00:00', 23.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-15 00:00:00', 25.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-16 00:00:00', 26.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-17 00:00:00', 20.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-18 00:00:00', 18.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-19 00:00:00', 21.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-20 00:00:00', 23.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-21 00:00:00', 23.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-22 00:00:00', 25.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-23 00:00:00', 26.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-24 00:00:00', 26.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-25 00:00:00', 26.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-26 00:00:00', 24.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-27 00:00:00', 27.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-28 00:00:00', 28.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-29 00:00:00', 26.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-30 00:00:00', 26.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-03-31 00:00:00', 25.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-01 00:00:00', 25.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-02 00:00:00', 26.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-03 00:00:00', 28.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-04 00:00:00', 20.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-05 00:00:00', 22.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-06 00:00:00', 23.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-07 00:00:00', 15.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-08 00:00:00', 21.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-09 00:00:00', 24.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-10 00:00:00', 24.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-11 00:00:00', 23.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-12 00:00:00', 23.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-13 00:00:00', 21.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-14 00:00:00', 17.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-15 00:00:00', 11.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-16 00:00:00', 21.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-17 00:00:00', 21.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-18 00:00:00', 23.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-19 00:00:00', 23.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-20 00:00:00', 28.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-21 00:00:00', 28.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-22 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-23 00:00:00', 24.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-24 00:00:00', 26.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-25 00:00:00', 30.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-26 00:00:00', 30.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-27 00:00:00', 31.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-28 00:00:00', 32.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-29 00:00:00', 33.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-04-30 00:00:00', 33.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-01 00:00:00', 33.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-02 00:00:00', 34.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-03 00:00:00', 33.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-04 00:00:00', 26.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-05 00:00:00', 25.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-06 00:00:00', 28.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-07 00:00:00', 33.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-08 00:00:00', 35.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-09 00:00:00', 31.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-10 00:00:00', 33.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-11 00:00:00', 36.0089988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-12 00:00:00', 35.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-13 00:00:00', 33.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-14 00:00:00', 35.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-15 00:00:00', 35.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-16 00:00:00', 31.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-17 00:00:00', 34.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-18 00:00:00', 33.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-19 00:00:00', 34.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-20 00:00:00', 35.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-21 00:00:00', 37.7690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-22 00:00:00', 35.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-23 00:00:00', 32.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-24 00:00:00', 31.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-25 00:00:00', 29.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-26 00:00:00', 28.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-27 00:00:00', 29.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-28 00:00:00', 32.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-29 00:00:00', 35.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-30 00:00:00', 37.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-05-31 00:00:00', 36.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-01 00:00:00', 36.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-02 00:00:00', 36.9889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-03 00:00:00', 36.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-04 00:00:00', 38.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-05 00:00:00', 38.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-06 00:00:00', 38.6629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-07 00:00:00', 37.8800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-08 00:00:00', 37.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-09 00:00:00', 40.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-10 00:00:00', 40.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-11 00:00:00', 38.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-12 00:00:00', 40.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-13 00:00:00', 42.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-14 00:00:00', 42.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-15 00:00:00', 37.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-16 00:00:00', 37.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-17 00:00:00', 37.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-18 00:00:00', 37.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-19 00:00:00', 38.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-20 00:00:00', 38.5800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-21 00:00:00', 38.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-22 00:00:00', 39.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-23 00:00:00', 38.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-24 00:00:00', 39.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-25 00:00:00', 38.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-26 00:00:00', 38.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-27 00:00:00', 37.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-28 00:00:00', 36.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-29 00:00:00', 35.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-06-30 00:00:00', 34.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-01 00:00:00', 36.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-02 00:00:00', 41.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-03 00:00:00', 39.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-04 00:00:00', 39.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-05 00:00:00', 40.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-06 00:00:00', 39.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-07 00:00:00', 39.2739982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-08 00:00:00', 38.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-09 00:00:00', 38.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-10 00:00:00', 38.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-11 00:00:00', 39.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-12 00:00:00', 39.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-13 00:00:00', 39.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-14 00:00:00', 39.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-15 00:00:00', 39.8230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-16 00:00:00', 40.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-17 00:00:00', 38.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-18 00:00:00', 38.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-19 00:00:00', 38.5870018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-20 00:00:00', 37.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-21 00:00:00', 36.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-22 00:00:00', 37.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-23 00:00:00', 35.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-24 00:00:00', 36.516998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-25 00:00:00', 35.71099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-26 00:00:00', 35.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-27 00:00:00', 36.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-28 00:00:00', 38.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-29 00:00:00', 41.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-30 00:00:00', 41.4339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-07-31 00:00:00', 42.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-01 00:00:00', 44.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-02 00:00:00', 43.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-03 00:00:00', 43.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-04 00:00:00', 38.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-05 00:00:00', 38.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-06 00:00:00', 39.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-07 00:00:00', 40.5180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-08 00:00:00', 40.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-09 00:00:00', 41.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-10 00:00:00', 37.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-11 00:00:00', 35.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-12 00:00:00', 35.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-13 00:00:00', 36.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-14 00:00:00', 37.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-15 00:00:00', 36.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-16 00:00:00', 33.6500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-17 00:00:00', 33.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-18 00:00:00', 35.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-19 00:00:00', 36.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-20 00:00:00', 36.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-21 00:00:00', 36.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-22 00:00:00', 36.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-23 00:00:00', 37.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-24 00:00:00', 37.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-25 00:00:00', 37.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-26 00:00:00', 37.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-27 00:00:00', 37.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-28 00:00:00', 35.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-29 00:00:00', 35.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-30 00:00:00', 34.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-08-31 00:00:00', 34.9010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-01 00:00:00', 35.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-02 00:00:00', 35.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-03 00:00:00', 34.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-04 00:00:00', 34.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-05 00:00:00', 30.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-06 00:00:00', 28.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-07 00:00:00', 29.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-08 00:00:00', 31.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-09 00:00:00', 32.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-10 00:00:00', 32.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-11 00:00:00', 33.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-12 00:00:00', 36.6209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-13 00:00:00', 36.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-14 00:00:00', 35.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-15 00:00:00', 34.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-16 00:00:00', 33.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-17 00:00:00', 33.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-18 00:00:00', 31.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-19 00:00:00', 30.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-20 00:00:00', 29.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-21 00:00:00', 28.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-22 00:00:00', 28.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-23 00:00:00', 27.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-24 00:00:00', 27.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-25 00:00:00', 30.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-26 00:00:00', 33.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-27 00:00:00', 31.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-28 00:00:00', 30.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-29 00:00:00', 33.5649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-09-30 00:00:00', 26.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-01 00:00:00', 28.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-02 00:00:00', 33.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-03 00:00:00', 32.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-04 00:00:00', 27.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-05 00:00:00', 27.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-06 00:00:00', 27.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-07 00:00:00', 26.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-08 00:00:00', 26.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-09 00:00:00', 26.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-10 00:00:00', 28.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-11 00:00:00', 23.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-12 00:00:00', 25.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-13 00:00:00', 23.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-14 00:00:00', 22.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-15 00:00:00', 23.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-16 00:00:00', 23.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-17 00:00:00', 27.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-18 00:00:00', 26.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-19 00:00:00', 19.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-20 00:00:00', 24.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-21 00:00:00', 23.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-22 00:00:00', 22.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-23 00:00:00', 24.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-24 00:00:00', 16.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-25 00:00:00', 19.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-26 00:00:00', 22.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-27 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-28 00:00:00', 12.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-29 00:00:00', 11.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-30 00:00:00', 13.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-10-31 00:00:00', 15.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-01 00:00:00', 12.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-02 00:00:00', 15.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-03 00:00:00', 17.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-04 00:00:00', 21.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-05 00:00:00', 22.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-06 00:00:00', 20.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-07 00:00:00', 22.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-08 00:00:00', 18.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-09 00:00:00', 13.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-10 00:00:00', 10.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-11 00:00:00', 10.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-12 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-13 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-14 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-15 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-16 00:00:00', 11.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-17 00:00:00', 8.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-18 00:00:00', 14.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-19 00:00:00', 9.98499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-20 00:00:00', 12.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-21 00:00:00', 15.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-22 00:00:00', 16.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-23 00:00:00', 18.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-24 00:00:00', 18.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-25 00:00:00', 17.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-26 00:00:00', 19.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-27 00:00:00', 19.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-28 00:00:00', 21.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-29 00:00:00', 21.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-11-30 00:00:00', 20.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-01 00:00:00', 19.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-02 00:00:00', 19.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-03 00:00:00', 17.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-04 00:00:00', 15.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-05 00:00:00', 13.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-06 00:00:00', 13.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-07 00:00:00', 15.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-08 00:00:00', 6.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-09 00:00:00', 12.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-10 00:00:00', 13.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-11 00:00:00', 13.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-12 00:00:00', 15.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-13 00:00:00', 15.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-14 00:00:00', 12.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-15 00:00:00', 15.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-16 00:00:00', 10.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-17 00:00:00', 6.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-18 00:00:00', 0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-19 00:00:00', 0.656000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-20 00:00:00', -0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-21 00:00:00', 1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-22 00:00:00', 3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-23 00:00:00', 2.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-24 00:00:00', 7.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-25 00:00:00', 13.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-26 00:00:00', 15.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-27 00:00:00', 11.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-28 00:00:00', 10.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-29 00:00:00', 6.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-30 00:00:00', 10.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2008-12-31 00:00:00', 11.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-01 00:00:00', 12.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-02 00:00:00', 9.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-03 00:00:00', 6.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-04 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-05 00:00:00', 8.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-06 00:00:00', 9.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-07 00:00:00', 9.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-08 00:00:00', 12.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-09 00:00:00', 12.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-10 00:00:00', 10.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-11 00:00:00', 9.49600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-12 00:00:00', 10.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-13 00:00:00', 6.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-14 00:00:00', 8.09599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-15 00:00:00', 9.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-16 00:00:00', 6.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-17 00:00:00', 7.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-18 00:00:00', 9.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-19 00:00:00', 10.3900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-20 00:00:00', 15.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-21 00:00:00', 13.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-22 00:00:00', 14.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-23 00:00:00', 13.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-24 00:00:00', 14.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-25 00:00:00', 8.22999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-26 00:00:00', 10.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-27 00:00:00', 10.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-28 00:00:00', 12.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-29 00:00:00', 10.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-30 00:00:00', 10.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-01-31 00:00:00', 14.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-01 00:00:00', 14.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-02 00:00:00', 13.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-03 00:00:00', 7.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-04 00:00:00', 7.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-05 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-06 00:00:00', 7.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-07 00:00:00', 13.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-08 00:00:00', 16.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-09 00:00:00', 13.2899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-10 00:00:00', 9.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-11 00:00:00', 9.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-12 00:00:00', 11.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-13 00:00:00', 9.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-14 00:00:00', 8.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-15 00:00:00', 12.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-16 00:00:00', 14.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-17 00:00:00', 12.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-18 00:00:00', 14.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-19 00:00:00', 14.1920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-20 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-21 00:00:00', 13.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-22 00:00:00', 13.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-23 00:00:00', 9.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-24 00:00:00', 9.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-25 00:00:00', 10.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-26 00:00:00', 11.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-27 00:00:00', 13.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-02-28 00:00:00', 16.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-01 00:00:00', 15.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-02 00:00:00', 17.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-03 00:00:00', 12.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-04 00:00:00', 14.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-05 00:00:00', 13.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-06 00:00:00', 9.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-07 00:00:00', 11.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-08 00:00:00', 13.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-09 00:00:00', 15.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-10 00:00:00', 18.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-11 00:00:00', 24.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-12 00:00:00', 22.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-13 00:00:00', 23.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-14 00:00:00', 24.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-15 00:00:00', 26.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-16 00:00:00', 23.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-17 00:00:00', 23.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-18 00:00:00', 14.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-19 00:00:00', 14.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-20 00:00:00', 18.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-21 00:00:00', 20.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-22 00:00:00', 21.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-23 00:00:00', 18.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-24 00:00:00', 18.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-25 00:00:00', 22.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-26 00:00:00', 23.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-27 00:00:00', 19.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-28 00:00:00', 21.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-29 00:00:00', 21.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-30 00:00:00', 22.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-03-31 00:00:00', 24.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-01 00:00:00', 23.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-02 00:00:00', 16.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-03 00:00:00', 15.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-04 00:00:00', 22.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-05 00:00:00', 16.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-06 00:00:00', 11.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-07 00:00:00', 11.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-08 00:00:00', 17.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-09 00:00:00', 21.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-10 00:00:00', 21.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-11 00:00:00', 14.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-12 00:00:00', 22.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-13 00:00:00', 22.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-14 00:00:00', 19.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-15 00:00:00', 10.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-16 00:00:00', 18.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-17 00:00:00', 22.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-18 00:00:00', 25.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-19 00:00:00', 26.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-20 00:00:00', 24.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-21 00:00:00', 15.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-22 00:00:00', 19.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-23 00:00:00', 21.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-24 00:00:00', 25.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-25 00:00:00', 24.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-26 00:00:00', 19.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-27 00:00:00', 14.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-28 00:00:00', 17.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-29 00:00:00', 23.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-04-30 00:00:00', 27.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-01 00:00:00', 29.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-02 00:00:00', 27.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-03 00:00:00', 26.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-04 00:00:00', 15.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-05 00:00:00', 21.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-06 00:00:00', 24.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-07 00:00:00', 29.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-08 00:00:00', 26.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-09 00:00:00', 23.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-10 00:00:00', 23.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-11 00:00:00', 25.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-12 00:00:00', 28.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-13 00:00:00', 28.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-14 00:00:00', 27.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-15 00:00:00', 27.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-16 00:00:00', 27.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-17 00:00:00', 33.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-18 00:00:00', 33.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-19 00:00:00', 29.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-20 00:00:00', 30.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-21 00:00:00', 29.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-22 00:00:00', 29.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-23 00:00:00', 31.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-24 00:00:00', 31.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-25 00:00:00', 30.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-26 00:00:00', 32.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-27 00:00:00', 33.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-28 00:00:00', 34.4970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-29 00:00:00', 35.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-30 00:00:00', 36.3839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-05-31 00:00:00', 33.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-01 00:00:00', 28.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-02 00:00:00', 26.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-03 00:00:00', 29.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-04 00:00:00', 28.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-05 00:00:00', 29.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-06 00:00:00', 28.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-07 00:00:00', 28.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-08 00:00:00', 30.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-09 00:00:00', 31.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-10 00:00:00', 33.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-11 00:00:00', 33.8310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-12 00:00:00', 33.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-13 00:00:00', 33.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-14 00:00:00', 33.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-15 00:00:00', 32.3160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-16 00:00:00', 33.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-17 00:00:00', 33.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-18 00:00:00', 33.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-19 00:00:00', 34.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-20 00:00:00', 36.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-21 00:00:00', 35.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-22 00:00:00', 35.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-23 00:00:00', 34.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-24 00:00:00', 33.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-25 00:00:00', 36.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-26 00:00:00', 36.9059982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-27 00:00:00', 37.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-28 00:00:00', 37.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-29 00:00:00', 35.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-06-30 00:00:00', 33.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-01 00:00:00', 33.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-02 00:00:00', 35.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-03 00:00:00', 31.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-04 00:00:00', 31.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-05 00:00:00', 34.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-06 00:00:00', 36.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-07 00:00:00', 38.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-08 00:00:00', 39.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-09 00:00:00', 38.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-10 00:00:00', 38.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-11 00:00:00', 37.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-12 00:00:00', 38.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-13 00:00:00', 35.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-14 00:00:00', 36.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-15 00:00:00', 37.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-16 00:00:00', 37.8720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-17 00:00:00', 38.4269981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-18 00:00:00', 38.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-19 00:00:00', 38.858001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-20 00:00:00', 38.2249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-21 00:00:00', 39.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-22 00:00:00', 38.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-23 00:00:00', 38.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-24 00:00:00', 39.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-25 00:00:00', 40.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-26 00:00:00', 42.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-27 00:00:00', 42.2239990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-28 00:00:00', 40.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-29 00:00:00', 39.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-30 00:00:00', 37.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-07-31 00:00:00', 38.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-01 00:00:00', 39.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-02 00:00:00', 40.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-03 00:00:00', 39.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-04 00:00:00', 37.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-05 00:00:00', 36.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-06 00:00:00', 36.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-07 00:00:00', 36.5789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-08 00:00:00', 38.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-09 00:00:00', 37.9280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-10 00:00:00', 39.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-11 00:00:00', 40.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-12 00:00:00', 42.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-13 00:00:00', 42.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-14 00:00:00', 40.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-15 00:00:00', 40.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-16 00:00:00', 37.2949981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-17 00:00:00', 37.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-18 00:00:00', 36.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-19 00:00:00', 34.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-20 00:00:00', 33.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-21 00:00:00', 32.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-22 00:00:00', 34.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-23 00:00:00', 35.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-24 00:00:00', 37.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-25 00:00:00', 31.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-26 00:00:00', 33.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-27 00:00:00', 34.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-28 00:00:00', 37.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-29 00:00:00', 36.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-30 00:00:00', 33.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-08-31 00:00:00', 34.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-01 00:00:00', 33.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-02 00:00:00', 32.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-03 00:00:00', 29.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-04 00:00:00', 30.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-05 00:00:00', 29.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-06 00:00:00', 28.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-07 00:00:00', 28.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-08 00:00:00', 27.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-09 00:00:00', 27.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-10 00:00:00', 28.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-11 00:00:00', 31.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-12 00:00:00', 31.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-13 00:00:00', 35.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-14 00:00:00', 34.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-15 00:00:00', 35.4679985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-16 00:00:00', 31.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-17 00:00:00', 31.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-18 00:00:00', 34.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-19 00:00:00', 35.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-20 00:00:00', 35.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-21 00:00:00', 34.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-22 00:00:00', 32.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-23 00:00:00', 30.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-24 00:00:00', 33.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-25 00:00:00', 36.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-26 00:00:00', 29.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-27 00:00:00', 29.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-28 00:00:00', 31.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-29 00:00:00', 31.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-09-30 00:00:00', 34.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-01 00:00:00', 35.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-02 00:00:00', 30.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-03 00:00:00', 27.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-04 00:00:00', 26.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-05 00:00:00', 26.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-06 00:00:00', 28.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-07 00:00:00', 26.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-08 00:00:00', 24.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-09 00:00:00', 21.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-10 00:00:00', 21.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-11 00:00:00', 23.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-12 00:00:00', 24.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-13 00:00:00', 24.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-14 00:00:00', 25.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-15 00:00:00', 25.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-16 00:00:00', 25.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-17 00:00:00', 23.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-18 00:00:00', 22.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-19 00:00:00', 23.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-20 00:00:00', 22.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-21 00:00:00', 22.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-22 00:00:00', 21.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-23 00:00:00', 21.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-24 00:00:00', 20.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-25 00:00:00', 22.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-26 00:00:00', 21.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-27 00:00:00', 21.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-28 00:00:00', 15.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-29 00:00:00', 21.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-30 00:00:00', 22.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-10-31 00:00:00', 24.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-01 00:00:00', 25.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-02 00:00:00', 18.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-03 00:00:00', 25.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-04 00:00:00', 25.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-05 00:00:00', 23.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-06 00:00:00', 23.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-07 00:00:00', 15.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-08 00:00:00', 9.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-09 00:00:00', 8.71300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-10 00:00:00', 10.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-11 00:00:00', 18.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-12 00:00:00', 18.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-13 00:00:00', 18.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-14 00:00:00', 15.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-15 00:00:00', 12.7030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-16 00:00:00', 12.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-17 00:00:00', 11.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-18 00:00:00', 14.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-19 00:00:00', 17.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-20 00:00:00', 19.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-21 00:00:00', 16.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-22 00:00:00', 18.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-23 00:00:00', 9.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-24 00:00:00', 14.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-25 00:00:00', 9.33100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-26 00:00:00', 11.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-27 00:00:00', 13.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-28 00:00:00', 8.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-29 00:00:00', 12.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-11-30 00:00:00', 14.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-01 00:00:00', 11.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-02 00:00:00', 13.5819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-03 00:00:00', 11.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-04 00:00:00', 4.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-05 00:00:00', 7.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-06 00:00:00', 9.22299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-07 00:00:00', 10.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-08 00:00:00', 12.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-09 00:00:00', 7.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-10 00:00:00', 4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-11 00:00:00', 8.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-12 00:00:00', 5.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-13 00:00:00', 9.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-14 00:00:00', 12.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-15 00:00:00', 12.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-16 00:00:00', 7.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-17 00:00:00', 11.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-18 00:00:00', 14.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-19 00:00:00', 16.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-20 00:00:00', 10.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-21 00:00:00', 9.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-22 00:00:00', 11.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-23 00:00:00', 10.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-24 00:00:00', 11.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-25 00:00:00', 13.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-26 00:00:00', 12.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-27 00:00:00', 11.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-28 00:00:00', 10.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-29 00:00:00', 11.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-30 00:00:00', 14.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2009-12-31 00:00:00', 15.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-01 00:00:00', 17.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-02 00:00:00', 17.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-03 00:00:00', 14.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-04 00:00:00', 15.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-05 00:00:00', 15.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-06 00:00:00', 14.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-07 00:00:00', 6.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-08 00:00:00', 6.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-09 00:00:00', 5.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-10 00:00:00', 6.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-11 00:00:00', 8.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-12 00:00:00', 13.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-13 00:00:00', 11.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-14 00:00:00', 13.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-15 00:00:00', 13.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-16 00:00:00', 16.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-17 00:00:00', 12.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-18 00:00:00', 6.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-19 00:00:00', 9.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-20 00:00:00', 14.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-21 00:00:00', 15.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-22 00:00:00', 11.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-23 00:00:00', 10.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-24 00:00:00', 12.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-25 00:00:00', 14.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-26 00:00:00', 16.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-27 00:00:00', 9.24899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-28 00:00:00', 6.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-29 00:00:00', 7.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-30 00:00:00', 12.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-01-31 00:00:00', 8.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-01 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-02 00:00:00', 11.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-03 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-04 00:00:00', 12.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-05 00:00:00', 8.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-06 00:00:00', 12.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-07 00:00:00', 6.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-08 00:00:00', 0.976999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-09 00:00:00', -0.913999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-10 00:00:00', 6.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-11 00:00:00', 6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-12 00:00:00', 2.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-13 00:00:00', 0.583000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-14 00:00:00', 0.331999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-15 00:00:00', -0.164000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-16 00:00:00', 7.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-17 00:00:00', 12.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-18 00:00:00', 10.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-19 00:00:00', 8.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-20 00:00:00', 11.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-21 00:00:00', 19.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-22 00:00:00', 13.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-23 00:00:00', 18.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-24 00:00:00', 12.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-25 00:00:00', 16.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-26 00:00:00', 9.18700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-27 00:00:00', 13.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-02-28 00:00:00', 10.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-01 00:00:00', 9.99600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-02 00:00:00', 16.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-03 00:00:00', 20.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-04 00:00:00', 12.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-05 00:00:00', 16.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-06 00:00:00', 15.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-07 00:00:00', 18.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-08 00:00:00', 20.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-09 00:00:00', 18.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-10 00:00:00', 22.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-11 00:00:00', 21.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-12 00:00:00', 12.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-13 00:00:00', 18.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-14 00:00:00', 22.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-15 00:00:00', 24.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-16 00:00:00', 28.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-17 00:00:00', 29.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-18 00:00:00', 26.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-19 00:00:00', 31.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-20 00:00:00', 19.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-21 00:00:00', 13.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-22 00:00:00', 13.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-23 00:00:00', 16.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-24 00:00:00', 18.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-25 00:00:00', 21.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-26 00:00:00', 17.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-27 00:00:00', 18.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-28 00:00:00', 21.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-29 00:00:00', 21.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-30 00:00:00', 16.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-03-31 00:00:00', 20.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-01 00:00:00', 22.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-02 00:00:00', 23.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-03 00:00:00', 16.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-04 00:00:00', 21.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-05 00:00:00', 21.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-06 00:00:00', 24.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-07 00:00:00', 20.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-08 00:00:00', 26.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-09 00:00:00', 28.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-10 00:00:00', 23.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-11 00:00:00', 26.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-12 00:00:00', 18.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-13 00:00:00', 25.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-14 00:00:00', 31.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-15 00:00:00', 24.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-16 00:00:00', 26.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-17 00:00:00', 27.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-18 00:00:00', 25.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-19 00:00:00', 28.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-20 00:00:00', 26.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-21 00:00:00', 18.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-22 00:00:00', 23.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-23 00:00:00', 27.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-24 00:00:00', 28.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-25 00:00:00', 28.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-26 00:00:00', 28.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-27 00:00:00', 27.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-28 00:00:00', 30.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-29 00:00:00', 28.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-04-30 00:00:00', 31.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-01 00:00:00', 27.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-02 00:00:00', 26.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-03 00:00:00', 32.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-04 00:00:00', 21.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-05 00:00:00', 25.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-06 00:00:00', 28.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-07 00:00:00', 22.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-08 00:00:00', 28.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-09 00:00:00', 29.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-10 00:00:00', 27.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-11 00:00:00', 27.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-12 00:00:00', 28.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-13 00:00:00', 27.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-14 00:00:00', 28.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-15 00:00:00', 31.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-16 00:00:00', 23.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-17 00:00:00', 25.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-18 00:00:00', 29.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-19 00:00:00', 29.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-20 00:00:00', 32.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-21 00:00:00', 27.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-22 00:00:00', 31.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-23 00:00:00', 30.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-24 00:00:00', 29.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-25 00:00:00', 35.2529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-26 00:00:00', 28.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-27 00:00:00', 29.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-28 00:00:00', 29.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-29 00:00:00', 31.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-30 00:00:00', 33.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-05-31 00:00:00', 34.4259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-01 00:00:00', 35.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-02 00:00:00', 28.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-03 00:00:00', 28.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-04 00:00:00', 27.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-05 00:00:00', 28.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-06 00:00:00', 28.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-07 00:00:00', 30.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-08 00:00:00', 31.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-09 00:00:00', 33.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-10 00:00:00', 34.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-11 00:00:00', 36.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-12 00:00:00', 35.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-13 00:00:00', 35.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-14 00:00:00', 34.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-15 00:00:00', 33.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-16 00:00:00', 34.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-17 00:00:00', 34.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-18 00:00:00', 35.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-19 00:00:00', 36.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-20 00:00:00', 38.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-21 00:00:00', 39.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-22 00:00:00', 38.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-23 00:00:00', 38.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-24 00:00:00', 37.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-25 00:00:00', 31.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-26 00:00:00', 36.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-27 00:00:00', 36.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-28 00:00:00', 35.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-29 00:00:00', 36.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-06-30 00:00:00', 36.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-01 00:00:00', 35.8219985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-02 00:00:00', 36.4539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-03 00:00:00', 38.2260017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-04 00:00:00', 37.766998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-05 00:00:00', 36.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-06 00:00:00', 37.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-07 00:00:00', 38.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-08 00:00:00', 39.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-09 00:00:00', 39.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-10 00:00:00', 41.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-11 00:00:00', 38.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-12 00:00:00', 35.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-13 00:00:00', 35.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-14 00:00:00', 37.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-15 00:00:00', 40.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-16 00:00:00', 43.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-17 00:00:00', 42.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-18 00:00:00', 41.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-19 00:00:00', 38.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-20 00:00:00', 37.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-21 00:00:00', 35.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-22 00:00:00', 31.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-23 00:00:00', 34.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-24 00:00:00', 35.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-25 00:00:00', 36.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-26 00:00:00', 36.6980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-27 00:00:00', 35.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-28 00:00:00', 37.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-29 00:00:00', 35.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-30 00:00:00', 36.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-07-31 00:00:00', 35.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-01 00:00:00', 36.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-02 00:00:00', 37.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-03 00:00:00', 31.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-04 00:00:00', 29.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-05 00:00:00', 37.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-06 00:00:00', 35.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-07 00:00:00', 36.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-08 00:00:00', 38.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-09 00:00:00', 39.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-10 00:00:00', 37.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-11 00:00:00', 38.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-12 00:00:00', 37.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-13 00:00:00', 37.6479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-14 00:00:00', 36.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-15 00:00:00', 36.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-16 00:00:00', 37.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-17 00:00:00', 37.6290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-18 00:00:00', 38.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-19 00:00:00', 37.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-20 00:00:00', 38.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-21 00:00:00', 40.3699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-22 00:00:00', 40.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-23 00:00:00', 33.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-24 00:00:00', 30.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-25 00:00:00', 31.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-26 00:00:00', 33.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-27 00:00:00', 35.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-28 00:00:00', 35.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-29 00:00:00', 36.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-30 00:00:00', 36.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-08-31 00:00:00', 37.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-01 00:00:00', 37.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-02 00:00:00', 37.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-03 00:00:00', 37.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-04 00:00:00', 36.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-05 00:00:00', 36.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-06 00:00:00', 34.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-07 00:00:00', 34.7410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-08 00:00:00', 34.8300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-09 00:00:00', 35.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-10 00:00:00', 34.7589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-11 00:00:00', 33.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-12 00:00:00', 29.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-13 00:00:00', 26.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-14 00:00:00', 29.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-15 00:00:00', 31.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-16 00:00:00', 20.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-17 00:00:00', 21.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-18 00:00:00', 22.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-19 00:00:00', 24.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-20 00:00:00', 27.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-21 00:00:00', 29.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-22 00:00:00', 27.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-23 00:00:00', 27.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-24 00:00:00', 28.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-25 00:00:00', 27.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-26 00:00:00', 27.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-27 00:00:00', 26.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-28 00:00:00', 24.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-29 00:00:00', 27.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-09-30 00:00:00', 26.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-01 00:00:00', 29.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-02 00:00:00', 31.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-03 00:00:00', 33.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-04 00:00:00', 31.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-05 00:00:00', 32.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-06 00:00:00', 31.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-07 00:00:00', 31.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-08 00:00:00', 25.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-09 00:00:00', 25.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-10 00:00:00', 24.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-11 00:00:00', 26.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-12 00:00:00', 29.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-13 00:00:00', 21.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-14 00:00:00', 26.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-15 00:00:00', 28.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-16 00:00:00', 30.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-17 00:00:00', 31.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-18 00:00:00', 30.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-19 00:00:00', 29.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-20 00:00:00', 27.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-21 00:00:00', 22.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-22 00:00:00', 16.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-23 00:00:00', 18.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-24 00:00:00', 20.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-25 00:00:00', 20.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-26 00:00:00', 20.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-27 00:00:00', 22.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-28 00:00:00', 21.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-29 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-30 00:00:00', 20.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-10-31 00:00:00', 23.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-01 00:00:00', 25.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-02 00:00:00', 22.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-03 00:00:00', 15.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-04 00:00:00', 17.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-05 00:00:00', 11.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-06 00:00:00', 16.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-07 00:00:00', 20.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-08 00:00:00', 23.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-09 00:00:00', 24.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-10 00:00:00', 24.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-11 00:00:00', 22.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-12 00:00:00', 19.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-13 00:00:00', 18.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-14 00:00:00', 19.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-15 00:00:00', 17.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-16 00:00:00', 15.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-17 00:00:00', 15.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-18 00:00:00', 16.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-19 00:00:00', 16.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-20 00:00:00', 15.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-21 00:00:00', 14.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-22 00:00:00', 16.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-23 00:00:00', 17.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-24 00:00:00', 18.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-25 00:00:00', 16.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-26 00:00:00', 15.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-27 00:00:00', 17.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-28 00:00:00', 18.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-29 00:00:00', 18.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-11-30 00:00:00', 16.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-01 00:00:00', 15.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-02 00:00:00', 17.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-03 00:00:00', 17.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-04 00:00:00', 9.18799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-05 00:00:00', 9.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-06 00:00:00', 6.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-07 00:00:00', 11.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-08 00:00:00', 11.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-09 00:00:00', 13.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-10 00:00:00', 14.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-11 00:00:00', 16.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-12 00:00:00', 18.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-13 00:00:00', 18.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-14 00:00:00', 20.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-15 00:00:00', 12.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-16 00:00:00', 9.65699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-17 00:00:00', 12.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-18 00:00:00', 13.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-19 00:00:00', 15.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-20 00:00:00', 16.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-21 00:00:00', 12.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-22 00:00:00', 5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-23 00:00:00', 6.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-24 00:00:00', 10.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-25 00:00:00', 9.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-26 00:00:00', 8.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-27 00:00:00', 8.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-28 00:00:00', 8.42800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-29 00:00:00', 8.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-30 00:00:00', 7.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2010-12-31 00:00:00', 8.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-01 00:00:00', 12.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-02 00:00:00', 14.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-03 00:00:00', 11.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-04 00:00:00', 6.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-05 00:00:00', 9.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-06 00:00:00', 8.81700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-07 00:00:00', 6.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-08 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-09 00:00:00', 7.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-10 00:00:00', 9.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-11 00:00:00', 4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-12 00:00:00', 6.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-13 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-14 00:00:00', -2.62299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-15 00:00:00', -0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-16 00:00:00', 2.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-17 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-18 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-19 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-20 00:00:00', 8.02999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-21 00:00:00', 4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-22 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-23 00:00:00', 4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-24 00:00:00', 7.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-25 00:00:00', 7.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-26 00:00:00', 10.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-27 00:00:00', 12.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-28 00:00:00', 9.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-29 00:00:00', 10.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-30 00:00:00', 9.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-01-31 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-01 00:00:00', 11.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-02 00:00:00', 12.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-03 00:00:00', 13.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-04 00:00:00', 8.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-05 00:00:00', 6.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-06 00:00:00', 2.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-07 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-08 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-09 00:00:00', 1.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-10 00:00:00', 8.27999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-11 00:00:00', 11.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-12 00:00:00', 6.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-13 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-14 00:00:00', 8.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-15 00:00:00', 9.99699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-16 00:00:00', 9.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-17 00:00:00', 11.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-18 00:00:00', 8.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-19 00:00:00', 3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-20 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-21 00:00:00', 9.64000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-22 00:00:00', 7.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-23 00:00:00', 4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-24 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-25 00:00:00', -1.79700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-26 00:00:00', -4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-27 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-02-28 00:00:00', -0.634000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-01 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-02 00:00:00', 3.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-03 00:00:00', 5.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-04 00:00:00', 0.377000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-05 00:00:00', 6.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-06 00:00:00', 8.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-07 00:00:00', 7.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-08 00:00:00', 13.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-09 00:00:00', 15.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-10 00:00:00', 17.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-11 00:00:00', 18.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-12 00:00:00', 18.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-13 00:00:00', 21.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-14 00:00:00', 24.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-15 00:00:00', 14.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-16 00:00:00', 13.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-17 00:00:00', 7.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-18 00:00:00', 14.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-19 00:00:00', 12.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-20 00:00:00', 13.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-21 00:00:00', 16.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-22 00:00:00', 18.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-23 00:00:00', 20.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-24 00:00:00', 22.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-25 00:00:00', 18.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-26 00:00:00', 17.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-27 00:00:00', 12.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-28 00:00:00', 13.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-29 00:00:00', 17.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-30 00:00:00', 14.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-03-31 00:00:00', 16.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-01 00:00:00', 16.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-02 00:00:00', 16.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-03 00:00:00', 9.61699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-04 00:00:00', 10.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-05 00:00:00', 15.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-06 00:00:00', 19.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-07 00:00:00', 21.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-08 00:00:00', 16.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-09 00:00:00', 16.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-10 00:00:00', 21.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-11 00:00:00', 21.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-12 00:00:00', 24.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-13 00:00:00', 25.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-14 00:00:00', 25.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-15 00:00:00', 15.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-16 00:00:00', 19.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-17 00:00:00', 22.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-18 00:00:00', 22.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-19 00:00:00', 23.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-20 00:00:00', 23.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-21 00:00:00', 28.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-22 00:00:00', 31.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-23 00:00:00', 31.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-24 00:00:00', 34.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-25 00:00:00', 31.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-26 00:00:00', 31.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-27 00:00:00', 31.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-28 00:00:00', 29.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-29 00:00:00', 24.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-04-30 00:00:00', 26.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-01 00:00:00', 31.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-02 00:00:00', 34.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-03 00:00:00', 34.0229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-04 00:00:00', 32.9809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-05 00:00:00', 25.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-06 00:00:00', 20.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-07 00:00:00', 25.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-08 00:00:00', 22.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-09 00:00:00', 25.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-10 00:00:00', 25.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-11 00:00:00', 23.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-12 00:00:00', 25.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-13 00:00:00', 28.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-14 00:00:00', 33.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-15 00:00:00', 36.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-16 00:00:00', 37.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-17 00:00:00', 37.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-18 00:00:00', 32.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-19 00:00:00', 30.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-20 00:00:00', 28.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-21 00:00:00', 29.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-22 00:00:00', 30.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-23 00:00:00', 31.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-24 00:00:00', 32.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-25 00:00:00', 29.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-26 00:00:00', 31.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-27 00:00:00', 29.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-28 00:00:00', 30.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-29 00:00:00', 30.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-30 00:00:00', 30.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-05-31 00:00:00', 31.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-01 00:00:00', 31.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-02 00:00:00', 28.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-03 00:00:00', 30.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-04 00:00:00', 28.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-05 00:00:00', 30.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-06 00:00:00', 32.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-07 00:00:00', 35.8380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-08 00:00:00', 37.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-09 00:00:00', 36.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-10 00:00:00', 35.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-11 00:00:00', 33.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-12 00:00:00', 32.3650016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-13 00:00:00', 31.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-14 00:00:00', 34.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-15 00:00:00', 36.8839988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-16 00:00:00', 37.3520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-17 00:00:00', 33.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-18 00:00:00', 33.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-19 00:00:00', 34.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-20 00:00:00', 34.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-21 00:00:00', 36.391998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-22 00:00:00', 36.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-23 00:00:00', 36.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-24 00:00:00', 37.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-25 00:00:00', 35.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-26 00:00:00', 32.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-27 00:00:00', 35.2459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-28 00:00:00', 35.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-29 00:00:00', 35.470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-06-30 00:00:00', 34.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-01 00:00:00', 34.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-02 00:00:00', 34.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-03 00:00:00', 35.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-04 00:00:00', 36.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-05 00:00:00', 37.0460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-06 00:00:00', 37.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-07 00:00:00', 37.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-08 00:00:00', 37.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-09 00:00:00', 36.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-10 00:00:00', 36.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-11 00:00:00', 38.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-12 00:00:00', 39.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-13 00:00:00', 40.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-14 00:00:00', 37.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-15 00:00:00', 33.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-16 00:00:00', 34.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-17 00:00:00', 34.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-18 00:00:00', 35.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-19 00:00:00', 33.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-20 00:00:00', 34.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-21 00:00:00', 36.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-22 00:00:00', 35.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-23 00:00:00', 35.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-24 00:00:00', 35.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-25 00:00:00', 35.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-26 00:00:00', 35.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-27 00:00:00', 35.6850013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-28 00:00:00', 36.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-29 00:00:00', 35.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-30 00:00:00', 35.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-07-31 00:00:00', 36.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-01 00:00:00', 37.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-02 00:00:00', 39.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-03 00:00:00', 41.2550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-04 00:00:00', 41.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-05 00:00:00', 41.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-06 00:00:00', 41.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-07 00:00:00', 41.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-08 00:00:00', 39.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-09 00:00:00', 35.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-10 00:00:00', 34.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-11 00:00:00', 35.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-12 00:00:00', 35.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-13 00:00:00', 35.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-14 00:00:00', 37.2960014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-15 00:00:00', 37.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-16 00:00:00', 36.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-17 00:00:00', 35.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-18 00:00:00', 35.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-19 00:00:00', 35.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-20 00:00:00', 37.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-21 00:00:00', 38.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-22 00:00:00', 38.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-23 00:00:00', 39.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-24 00:00:00', 39.0029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-25 00:00:00', 37.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-26 00:00:00', 34.6090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-27 00:00:00', 31.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-28 00:00:00', 30.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-29 00:00:00', 29.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-30 00:00:00', 28.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-08-31 00:00:00', 32.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-01 00:00:00', 33.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-02 00:00:00', 33.4129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-03 00:00:00', 32.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-04 00:00:00', 35.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-05 00:00:00', 36.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-06 00:00:00', 35.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-07 00:00:00', 34.4749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-08 00:00:00', 33.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-09 00:00:00', 33.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-10 00:00:00', 33.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-11 00:00:00', 33.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-12 00:00:00', 34.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-13 00:00:00', 35.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-14 00:00:00', 34.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-15 00:00:00', 31.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-16 00:00:00', 26.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-17 00:00:00', 29.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-18 00:00:00', 27.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-19 00:00:00', 27.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-20 00:00:00', 27.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-21 00:00:00', 25.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-22 00:00:00', 26.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-23 00:00:00', 26.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-24 00:00:00', 28.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-25 00:00:00', 28.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-26 00:00:00', 28.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-27 00:00:00', 29.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-28 00:00:00', 26.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-29 00:00:00', 25.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-09-30 00:00:00', 26.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-01 00:00:00', 28.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-02 00:00:00', 30.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-03 00:00:00', 31.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-04 00:00:00', 29.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-05 00:00:00', 23.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-06 00:00:00', 23.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-07 00:00:00', 21.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-08 00:00:00', 22.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-09 00:00:00', 24.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-10 00:00:00', 24.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-11 00:00:00', 23.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-12 00:00:00', 21.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-13 00:00:00', 20.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-14 00:00:00', 21.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-15 00:00:00', 25.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-16 00:00:00', 24.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-17 00:00:00', 23.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-18 00:00:00', 23.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-19 00:00:00', 22.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-20 00:00:00', 23.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-21 00:00:00', 20.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-22 00:00:00', 19.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-23 00:00:00', 10.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-24 00:00:00', 15.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-25 00:00:00', 17.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-26 00:00:00', 20.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-27 00:00:00', 21.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-28 00:00:00', 12.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-29 00:00:00', 10.5780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-30 00:00:00', 12.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-10-31 00:00:00', 13.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-01 00:00:00', 9.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-02 00:00:00', 13.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-03 00:00:00', 14.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-04 00:00:00', 12.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-05 00:00:00', 15.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-06 00:00:00', 16.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-07 00:00:00', 20.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-08 00:00:00', 9.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-09 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-10 00:00:00', 13.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-11 00:00:00', 15.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-12 00:00:00', 15.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-13 00:00:00', 17.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-14 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-15 00:00:00', 8.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-16 00:00:00', 12.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-17 00:00:00', 13.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-18 00:00:00', 12.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-19 00:00:00', 11.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-20 00:00:00', 14.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-21 00:00:00', 16.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-22 00:00:00', 15.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-23 00:00:00', 13.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-24 00:00:00', 9.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-25 00:00:00', 11.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-26 00:00:00', 6.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-27 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-28 00:00:00', 6.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-29 00:00:00', 10.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-11-30 00:00:00', 15.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-01 00:00:00', 9.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-02 00:00:00', 10.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-03 00:00:00', 9.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-04 00:00:00', 7.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-05 00:00:00', 1.76199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-06 00:00:00', 2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-07 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-08 00:00:00', 5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-09 00:00:00', 6.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-10 00:00:00', 8.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-11 00:00:00', 10.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-12 00:00:00', 3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-13 00:00:00', 6.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-14 00:00:00', 8.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-15 00:00:00', 5.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-16 00:00:00', 6.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-17 00:00:00', 10.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-18 00:00:00', 8.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-19 00:00:00', 2.38599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-20 00:00:00', -4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-21 00:00:00', -3.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-22 00:00:00', -3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-23 00:00:00', 2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-24 00:00:00', 5.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-25 00:00:00', 8.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-26 00:00:00', 7.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-27 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-28 00:00:00', 1.00499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-29 00:00:00', 4.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-30 00:00:00', 3.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2011-12-31 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-01 00:00:00', 6.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-02 00:00:00', 4.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-03 00:00:00', 5.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-04 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-05 00:00:00', 0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-06 00:00:00', -4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-07 00:00:00', -1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-08 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-09 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-10 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-11 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-12 00:00:00', 7.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-13 00:00:00', 3.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-14 00:00:00', 7.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-15 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-16 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-17 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-18 00:00:00', 2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-19 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-20 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-21 00:00:00', 2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-22 00:00:00', -0.246000006794929504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-23 00:00:00', 1.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-24 00:00:00', 5.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-25 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-26 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-27 00:00:00', 4.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-28 00:00:00', 5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-29 00:00:00', 8.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-30 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-01-31 00:00:00', 2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-01 00:00:00', 5.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-02 00:00:00', 7.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-03 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-04 00:00:00', -1.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-05 00:00:00', -7.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-06 00:00:00', -5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-07 00:00:00', -2.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-08 00:00:00', 0.825999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-09 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-10 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-11 00:00:00', 4.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-12 00:00:00', 0.587000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-13 00:00:00', -2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-14 00:00:00', -2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-15 00:00:00', 0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-16 00:00:00', 3.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-17 00:00:00', 3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-18 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-19 00:00:00', 7.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-20 00:00:00', 4.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-21 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-22 00:00:00', -3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-23 00:00:00', -1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-24 00:00:00', 1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-25 00:00:00', 6.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-26 00:00:00', 8.27700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-27 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-28 00:00:00', 7.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-02-29 00:00:00', 9.13300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-01 00:00:00', 10.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-02 00:00:00', 12.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-03 00:00:00', 13.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-04 00:00:00', 7.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-05 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-06 00:00:00', 4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-07 00:00:00', 4.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-08 00:00:00', 7.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-09 00:00:00', 7.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-10 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-11 00:00:00', 2.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-12 00:00:00', -0.197999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-13 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-14 00:00:00', 6.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-15 00:00:00', 11.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-16 00:00:00', 9.04800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-17 00:00:00', 15.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-18 00:00:00', 12.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-19 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-20 00:00:00', -0.365000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-21 00:00:00', 6.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-22 00:00:00', 11.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-23 00:00:00', 13.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-24 00:00:00', 13.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-25 00:00:00', 14.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-26 00:00:00', 14.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-27 00:00:00', 17.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-28 00:00:00', 21.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-29 00:00:00', 17.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-30 00:00:00', 20.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-03-31 00:00:00', 19.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-01 00:00:00', 17.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-02 00:00:00', 21.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-03 00:00:00', 22.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-04 00:00:00', 23.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-05 00:00:00', 22.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-06 00:00:00', 20.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-07 00:00:00', 21.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-08 00:00:00', 23.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-09 00:00:00', 20.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-10 00:00:00', 22.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-11 00:00:00', 21.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-12 00:00:00', 20.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-13 00:00:00', 22.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-14 00:00:00', 23.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-15 00:00:00', 24.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-16 00:00:00', 25.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-17 00:00:00', 25.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-18 00:00:00', 27.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-19 00:00:00', 28.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-20 00:00:00', 25.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-21 00:00:00', 19.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-22 00:00:00', 20.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-23 00:00:00', 20.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-24 00:00:00', 22.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-25 00:00:00', 20.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-26 00:00:00', 20.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-27 00:00:00', 21.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-28 00:00:00', 15.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-29 00:00:00', 19.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-04-30 00:00:00', 18.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-01 00:00:00', 20.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-02 00:00:00', 19.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-03 00:00:00', 21.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-04 00:00:00', 24.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-05 00:00:00', 25.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-06 00:00:00', 24.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-07 00:00:00', 23.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-08 00:00:00', 23.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-09 00:00:00', 28.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-10 00:00:00', 24.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-11 00:00:00', 24.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-12 00:00:00', 22.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-13 00:00:00', 25.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-14 00:00:00', 25.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-15 00:00:00', 25.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-16 00:00:00', 26.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-17 00:00:00', 25.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-18 00:00:00', 22.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-19 00:00:00', 26.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-20 00:00:00', 25.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-21 00:00:00', 24.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-22 00:00:00', 26.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-23 00:00:00', 27.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-24 00:00:00', 30.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-25 00:00:00', 23.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-26 00:00:00', 25.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-27 00:00:00', 28.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-28 00:00:00', 33.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-29 00:00:00', 29.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-30 00:00:00', 31.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-05-31 00:00:00', 30.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-01 00:00:00', 30.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-02 00:00:00', 31.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-03 00:00:00', 32.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-04 00:00:00', 33.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-05 00:00:00', 30.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-06 00:00:00', 29.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-07 00:00:00', 30.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-08 00:00:00', 31.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-09 00:00:00', 32.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-10 00:00:00', 33.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-11 00:00:00', 30.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-12 00:00:00', 30.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-13 00:00:00', 31.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-14 00:00:00', 31.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-15 00:00:00', 33.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-16 00:00:00', 34.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-17 00:00:00', 34.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-18 00:00:00', 35.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-19 00:00:00', 35.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-20 00:00:00', 34.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-21 00:00:00', 33.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-22 00:00:00', 29.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-23 00:00:00', 32.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-24 00:00:00', 31.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-25 00:00:00', 30.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-26 00:00:00', 29.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-27 00:00:00', 30.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-28 00:00:00', 32.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-29 00:00:00', 34.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-06-30 00:00:00', 35.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-01 00:00:00', 36.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-02 00:00:00', 37.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-03 00:00:00', 38.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-04 00:00:00', 37.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-05 00:00:00', 36.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-06 00:00:00', 36.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-07 00:00:00', 35.9630012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-08 00:00:00', 36.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-09 00:00:00', 36.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-10 00:00:00', 38.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-11 00:00:00', 39.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-12 00:00:00', 38.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-13 00:00:00', 38.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-14 00:00:00', 34.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-15 00:00:00', 33.9339981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-16 00:00:00', 34.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-17 00:00:00', 35.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-18 00:00:00', 35.8860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-19 00:00:00', 35.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-20 00:00:00', 35.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-21 00:00:00', 36.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-22 00:00:00', 37.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-23 00:00:00', 36.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-24 00:00:00', 35.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-25 00:00:00', 34.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-26 00:00:00', 34.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-27 00:00:00', 30.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-28 00:00:00', 32.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-29 00:00:00', 34.6150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-30 00:00:00', 36.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-07-31 00:00:00', 36.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-01 00:00:00', 36.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-02 00:00:00', 34.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-03 00:00:00', 33.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-04 00:00:00', 33.2939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-05 00:00:00', 34.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-06 00:00:00', 35.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-07 00:00:00', 35.7529983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-08 00:00:00', 35.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-09 00:00:00', 36.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-10 00:00:00', 35.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-11 00:00:00', 35.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-12 00:00:00', 33.8769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-13 00:00:00', 34.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-14 00:00:00', 35.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-15 00:00:00', 36.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-16 00:00:00', 36.91400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-17 00:00:00', 38.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-18 00:00:00', 38.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-19 00:00:00', 38.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-20 00:00:00', 38.2879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-21 00:00:00', 38.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-22 00:00:00', 38.46099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-23 00:00:00', 37.1290016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-24 00:00:00', 35.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-25 00:00:00', 33.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-26 00:00:00', 33, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-27 00:00:00', 32.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-28 00:00:00', 34.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-29 00:00:00', 35.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-30 00:00:00', 35.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-08-31 00:00:00', 35.7659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-01 00:00:00', 35.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-02 00:00:00', 35.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-03 00:00:00', 34.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-04 00:00:00', 31.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-05 00:00:00', 28.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-06 00:00:00', 32.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-07 00:00:00', 29.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-08 00:00:00', 31.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-09 00:00:00', 32.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-10 00:00:00', 34.3569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-11 00:00:00', 34.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-12 00:00:00', 32.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-13 00:00:00', 31.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-14 00:00:00', 28.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-15 00:00:00', 29.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-16 00:00:00', 28.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-17 00:00:00', 27.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-18 00:00:00', 26.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-19 00:00:00', 28.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-20 00:00:00', 27.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-21 00:00:00', 26.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-22 00:00:00', 27.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-23 00:00:00', 27.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-24 00:00:00', 28.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-25 00:00:00', 27.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-26 00:00:00', 26.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-27 00:00:00', 28.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-28 00:00:00', 27.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-29 00:00:00', 25.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-09-30 00:00:00', 21.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-01 00:00:00', 25.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-02 00:00:00', 24.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-03 00:00:00', 23.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-04 00:00:00', 22.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-05 00:00:00', 23.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-06 00:00:00', 24.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-07 00:00:00', 26.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-08 00:00:00', 25.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-09 00:00:00', 25.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-10 00:00:00', 25.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-11 00:00:00', 25.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-12 00:00:00', 25.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-13 00:00:00', 25.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-14 00:00:00', 17.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-15 00:00:00', 19.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-16 00:00:00', 20.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-17 00:00:00', 17.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-18 00:00:00', 18.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-19 00:00:00', 17.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-20 00:00:00', 14.9469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-21 00:00:00', 16.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-22 00:00:00', 19.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-23 00:00:00', 19.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-24 00:00:00', 20.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-25 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-26 00:00:00', 17.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-27 00:00:00', 20.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-28 00:00:00', 21.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-29 00:00:00', 22.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-30 00:00:00', 25.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-10-31 00:00:00', 23.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-01 00:00:00', 16.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-02 00:00:00', 18.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-03 00:00:00', 19.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-04 00:00:00', 13.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-05 00:00:00', 14.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-06 00:00:00', 18.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-07 00:00:00', 18.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-08 00:00:00', 19.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-09 00:00:00', 20.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-10 00:00:00', 19.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-11 00:00:00', 20.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-12 00:00:00', 17.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-13 00:00:00', 11.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-14 00:00:00', 16.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-15 00:00:00', 18.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-16 00:00:00', 9.68700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-17 00:00:00', 12.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-18 00:00:00', 10.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-19 00:00:00', 9.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-20 00:00:00', 7.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-21 00:00:00', 10.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-22 00:00:00', 9.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-23 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-24 00:00:00', 7.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-25 00:00:00', 11.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-26 00:00:00', 8.01099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-27 00:00:00', 13.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-28 00:00:00', 7.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-29 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-11-30 00:00:00', 9.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-01 00:00:00', 11.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-02 00:00:00', 12.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-03 00:00:00', 13.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-04 00:00:00', 16.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-05 00:00:00', 16.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-06 00:00:00', 16.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-07 00:00:00', 15.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-08 00:00:00', 10.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-09 00:00:00', 14.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-10 00:00:00', 11.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-11 00:00:00', 8.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-12 00:00:00', 7.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-13 00:00:00', 6.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-14 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-15 00:00:00', 4.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-16 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-17 00:00:00', 6.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-18 00:00:00', 0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-19 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-20 00:00:00', 5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-21 00:00:00', 10.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-22 00:00:00', 15.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-23 00:00:00', 9.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-24 00:00:00', 8.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-25 00:00:00', 10.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-26 00:00:00', 5.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-27 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-28 00:00:00', -9.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-29 00:00:00', -3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-30 00:00:00', 3.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2012-12-31 00:00:00', 4.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-01 00:00:00', -4.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-02 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-03 00:00:00', 0.246000006794929504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-04 00:00:00', -0.499000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-05 00:00:00', 2.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-06 00:00:00', 3.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-07 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-08 00:00:00', 4.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-09 00:00:00', 5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-10 00:00:00', 5.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-11 00:00:00', 10.2100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-12 00:00:00', 4.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-13 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-14 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-15 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-16 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-17 00:00:00', -0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-18 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-19 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-20 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-21 00:00:00', 7.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-22 00:00:00', 3.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-23 00:00:00', 5.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-24 00:00:00', 10.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-25 00:00:00', 9.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-26 00:00:00', 10.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-27 00:00:00', 8.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-28 00:00:00', 11.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-29 00:00:00', 11.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-30 00:00:00', 15.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-01-31 00:00:00', 11.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-01 00:00:00', 14.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-02 00:00:00', 9.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-03 00:00:00', 10.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-04 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-05 00:00:00', 2.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-06 00:00:00', 6.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-07 00:00:00', 9.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-08 00:00:00', 13.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-09 00:00:00', 7.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-10 00:00:00', 8.51799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-11 00:00:00', 8.81999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-12 00:00:00', 9.39299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-13 00:00:00', 9.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-14 00:00:00', 12.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-15 00:00:00', 7.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-16 00:00:00', 8.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-17 00:00:00', 13.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-18 00:00:00', 7.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-19 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-20 00:00:00', 12.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-21 00:00:00', 11.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-22 00:00:00', 10.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-23 00:00:00', 9.57900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-24 00:00:00', 12.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-25 00:00:00', 12.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-26 00:00:00', 7.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-27 00:00:00', 0.521000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-02-28 00:00:00', 7.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-01 00:00:00', 14.1549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-02 00:00:00', 18.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-03 00:00:00', 16.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-04 00:00:00', 14.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-05 00:00:00', 20.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-06 00:00:00', 23.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-07 00:00:00', 13.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-08 00:00:00', 10.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-09 00:00:00', 5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-10 00:00:00', 12.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-11 00:00:00', 16.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-12 00:00:00', 16.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-13 00:00:00', 12.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-14 00:00:00', 17.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-15 00:00:00', 17.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-16 00:00:00', 11.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-17 00:00:00', 14.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-18 00:00:00', 14.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-19 00:00:00', 20.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-20 00:00:00', 20.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-21 00:00:00', 14.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-22 00:00:00', 16.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-23 00:00:00', 14.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-24 00:00:00', 12.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-25 00:00:00', 19.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-26 00:00:00', 15.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-27 00:00:00', 19.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-28 00:00:00', 22.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-29 00:00:00', 20.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-30 00:00:00', 21.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-03-31 00:00:00', 12.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-01 00:00:00', 9.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-02 00:00:00', 15.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-03 00:00:00', 16.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-04 00:00:00', 18.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-05 00:00:00', 13.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-06 00:00:00', 16.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-07 00:00:00', 19.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-08 00:00:00', 22.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-09 00:00:00', 25.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-10 00:00:00', 24.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-11 00:00:00', 25.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-12 00:00:00', 25.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-13 00:00:00', 21.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-14 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-15 00:00:00', 14.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-16 00:00:00', 12.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-17 00:00:00', 17.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-18 00:00:00', 19.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-19 00:00:00', 21.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-20 00:00:00', 21.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-21 00:00:00', 22.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-22 00:00:00', 27.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-23 00:00:00', 23.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-24 00:00:00', 20.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-25 00:00:00', 18.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-26 00:00:00', 14.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-27 00:00:00', 21.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-28 00:00:00', 17.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-29 00:00:00', 10.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-04-30 00:00:00', 14.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-01 00:00:00', 19.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-02 00:00:00', 22.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-03 00:00:00', 21.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-04 00:00:00', 23.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-05 00:00:00', 23.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-06 00:00:00', 26.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-07 00:00:00', 26.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-08 00:00:00', 27.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-09 00:00:00', 26.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-10 00:00:00', 28.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-11 00:00:00', 26.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-12 00:00:00', 23.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-13 00:00:00', 25.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-14 00:00:00', 27.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-15 00:00:00', 28.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-16 00:00:00', 30.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-17 00:00:00', 31.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-18 00:00:00', 33.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-19 00:00:00', 25.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-20 00:00:00', 28.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-21 00:00:00', 26.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-22 00:00:00', 28.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-23 00:00:00', 29.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-24 00:00:00', 27.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-25 00:00:00', 24.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-26 00:00:00', 21.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-27 00:00:00', 22.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-28 00:00:00', 27.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-29 00:00:00', 30.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-30 00:00:00', 32.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-05-31 00:00:00', 35.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-01 00:00:00', 35.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-02 00:00:00', 32.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-03 00:00:00', 33.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-04 00:00:00', 31.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-05 00:00:00', 31.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-06 00:00:00', 33.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-07 00:00:00', 33.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-08 00:00:00', 40.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-09 00:00:00', 37.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-10 00:00:00', 36.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-11 00:00:00', 36.108001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-12 00:00:00', 34.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-13 00:00:00', 34.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-14 00:00:00', 33.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-15 00:00:00', 32.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-16 00:00:00', 30.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-17 00:00:00', 29.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-18 00:00:00', 32.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-19 00:00:00', 35.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-20 00:00:00', 36.3240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-21 00:00:00', 37.9490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-22 00:00:00', 38.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-23 00:00:00', 38.2869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-24 00:00:00', 37.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-25 00:00:00', 38.1090011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-26 00:00:00', 39.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-27 00:00:00', 34.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-28 00:00:00', 30.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-29 00:00:00', 30.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-06-30 00:00:00', 31.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-01 00:00:00', 31.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-02 00:00:00', 32.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-03 00:00:00', 35.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-04 00:00:00', 38.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-05 00:00:00', 36.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-06 00:00:00', 33.779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-07 00:00:00', 32.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-08 00:00:00', 33.5260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-09 00:00:00', 31.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-10 00:00:00', 32.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-11 00:00:00', 32.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-12 00:00:00', 34.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-13 00:00:00', 37.1209983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-14 00:00:00', 35.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-15 00:00:00', 35.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-16 00:00:00', 35.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-17 00:00:00', 36.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-18 00:00:00', 38.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-19 00:00:00', 38.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-20 00:00:00', 38.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-21 00:00:00', 38.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-22 00:00:00', 36.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-23 00:00:00', 35.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-24 00:00:00', 36.6990013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-25 00:00:00', 36.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-26 00:00:00', 37.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-27 00:00:00', 40.6279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-28 00:00:00', 42.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-29 00:00:00', 42.904998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-30 00:00:00', 41.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-07-31 00:00:00', 40.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-01 00:00:00', 39.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-02 00:00:00', 39.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-03 00:00:00', 38.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-04 00:00:00', 38.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-05 00:00:00', 37.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-06 00:00:00', 39.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-07 00:00:00', 36.8160018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-08 00:00:00', 32.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-09 00:00:00', 33.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-10 00:00:00', 34.5229988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-11 00:00:00', 33.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-12 00:00:00', 32.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-13 00:00:00', 31.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-14 00:00:00', 32.1409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-15 00:00:00', 34.0579986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-16 00:00:00', 33.7039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-17 00:00:00', 33.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-18 00:00:00', 34.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-19 00:00:00', 33.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-20 00:00:00', 34.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-21 00:00:00', 34.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-22 00:00:00', 35.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-23 00:00:00', 36.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-24 00:00:00', 33.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-25 00:00:00', 33.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-26 00:00:00', 35.5029983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-27 00:00:00', 34.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-28 00:00:00', 35.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-29 00:00:00', 35.3660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-30 00:00:00', 32.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-08-31 00:00:00', 32.1910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-01 00:00:00', 32.7620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-02 00:00:00', 32.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-03 00:00:00', 33.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-04 00:00:00', 32.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-05 00:00:00', 34.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-06 00:00:00', 36.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-07 00:00:00', 35.4469985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-08 00:00:00', 36.1339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-09 00:00:00', 36.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-10 00:00:00', 36.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-11 00:00:00', 34.8590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-12 00:00:00', 33.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-13 00:00:00', 30.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-14 00:00:00', 27.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-15 00:00:00', 27.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-16 00:00:00', 25.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-17 00:00:00', 29.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-18 00:00:00', 30.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-19 00:00:00', 33.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-20 00:00:00', 35.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-21 00:00:00', 35.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-22 00:00:00', 33.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-23 00:00:00', 32.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-24 00:00:00', 33.4129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-25 00:00:00', 34.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-26 00:00:00', 36.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-27 00:00:00', 30.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-28 00:00:00', 30.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-29 00:00:00', 30.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-09-30 00:00:00', 30.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-01 00:00:00', 30.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-02 00:00:00', 30.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-03 00:00:00', 31.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-04 00:00:00', 31.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-05 00:00:00', 33.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-06 00:00:00', 33.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-07 00:00:00', 32.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-08 00:00:00', 30.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-09 00:00:00', 26.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-10 00:00:00', 22.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-11 00:00:00', 21.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-12 00:00:00', 24.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-13 00:00:00', 23.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-14 00:00:00', 24.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-15 00:00:00', 22.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-16 00:00:00', 22.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-17 00:00:00', 22.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-18 00:00:00', 24.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-19 00:00:00', 25.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-20 00:00:00', 26.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-21 00:00:00', 26.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-22 00:00:00', 21.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-23 00:00:00', 15.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-24 00:00:00', 21.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-25 00:00:00', 19.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-26 00:00:00', 11.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-27 00:00:00', 12.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-28 00:00:00', 18.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-29 00:00:00', 21.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-30 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-10-31 00:00:00', 12.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-01 00:00:00', 10.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-02 00:00:00', 15.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-03 00:00:00', 17.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-04 00:00:00', 15.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-05 00:00:00', 14.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-06 00:00:00', 12.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-07 00:00:00', 10.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-08 00:00:00', 16.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-09 00:00:00', 17.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-10 00:00:00', 15.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-11 00:00:00', 15.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-12 00:00:00', 12.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-13 00:00:00', 14.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-14 00:00:00', 16.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-15 00:00:00', 19.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-16 00:00:00', 17.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-17 00:00:00', 16.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-18 00:00:00', 18.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-19 00:00:00', 12.9530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-20 00:00:00', 7.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-21 00:00:00', 10.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-22 00:00:00', 16.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-23 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-24 00:00:00', 12.2489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-25 00:00:00', 15.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-26 00:00:00', 13.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-27 00:00:00', 14.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-28 00:00:00', 15.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-29 00:00:00', 16.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-11-30 00:00:00', 18.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-01 00:00:00', 15.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-02 00:00:00', 8.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-03 00:00:00', 13.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-04 00:00:00', 13.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-05 00:00:00', 9.78199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-06 00:00:00', 8.62100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-07 00:00:00', 8.23700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-08 00:00:00', 11.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-09 00:00:00', 11.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-10 00:00:00', 13.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-11 00:00:00', 8.58100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-12 00:00:00', 10.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-13 00:00:00', 13.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-14 00:00:00', 17.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-15 00:00:00', 17.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-16 00:00:00', 10.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-17 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-18 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-19 00:00:00', 2.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-20 00:00:00', 6.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-21 00:00:00', -0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-22 00:00:00', -0.0920000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-23 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-24 00:00:00', 0.605000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-25 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-26 00:00:00', 2.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-27 00:00:00', -1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-28 00:00:00', -4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-29 00:00:00', -6.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-30 00:00:00', -6.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2013-12-31 00:00:00', -2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-01 00:00:00', 1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-02 00:00:00', 4.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-03 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-04 00:00:00', 1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-05 00:00:00', -0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-06 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-07 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-08 00:00:00', -1.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-09 00:00:00', -0.425000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-10 00:00:00', -0.349000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-11 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-12 00:00:00', 7.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-13 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-14 00:00:00', 7.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-15 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-16 00:00:00', 4.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-17 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-18 00:00:00', 9.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-19 00:00:00', 10.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-20 00:00:00', 11.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-21 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-22 00:00:00', 4.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-23 00:00:00', 4.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-24 00:00:00', 6.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-25 00:00:00', 5.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-26 00:00:00', 8.99400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-27 00:00:00', 9.49600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-28 00:00:00', 12.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-29 00:00:00', 14.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-30 00:00:00', 8.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-01-31 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-01 00:00:00', 3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-02 00:00:00', -6.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-03 00:00:00', -10.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-04 00:00:00', -4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-05 00:00:00', -2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-06 00:00:00', -0.783999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-07 00:00:00', -3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-08 00:00:00', -1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-09 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-10 00:00:00', -0.635999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-11 00:00:00', 1.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-12 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-13 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-14 00:00:00', 0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-15 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-16 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-17 00:00:00', 10.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-18 00:00:00', 9.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-19 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-20 00:00:00', 6.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-21 00:00:00', 9.69900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-22 00:00:00', 11.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-23 00:00:00', 5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-24 00:00:00', 6.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-25 00:00:00', 9.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-26 00:00:00', 7.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-27 00:00:00', 9.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-02-28 00:00:00', 10.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-01 00:00:00', 12.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-02 00:00:00', 13.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-03 00:00:00', 10.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-04 00:00:00', 10.560999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-05 00:00:00', 13.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-06 00:00:00', 11.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-07 00:00:00', 8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-08 00:00:00', 10.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-09 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-10 00:00:00', 7.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-11 00:00:00', 8.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-12 00:00:00', 14.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-13 00:00:00', 18.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-14 00:00:00', 10.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-15 00:00:00', 8.50800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-16 00:00:00', 13.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-17 00:00:00', 9.94900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-18 00:00:00', 11.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-19 00:00:00', 16.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-20 00:00:00', 14.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-21 00:00:00', 11.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-22 00:00:00', 15.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-23 00:00:00', 9.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-24 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-25 00:00:00', 8.02700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-26 00:00:00', 12.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-27 00:00:00', 12.2829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-28 00:00:00', 15.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-29 00:00:00', 17.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-30 00:00:00', 19.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-03-31 00:00:00', 21.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-01 00:00:00', 21.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-02 00:00:00', 17.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-03 00:00:00', 19.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-04 00:00:00', 12.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-05 00:00:00', 11.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-06 00:00:00', 11.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-07 00:00:00', 12.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-08 00:00:00', 15.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-09 00:00:00', 19.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-10 00:00:00', 18.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-11 00:00:00', 16.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-12 00:00:00', 13.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-13 00:00:00', 13.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-14 00:00:00', 18.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-15 00:00:00', 21.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-16 00:00:00', 18.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-17 00:00:00', 19.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-18 00:00:00', 18.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-19 00:00:00', 20.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-20 00:00:00', 21.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-21 00:00:00', 21.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-22 00:00:00', 23.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-23 00:00:00', 22.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-24 00:00:00', 17.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-25 00:00:00', 18.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-26 00:00:00', 18.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-27 00:00:00', 24.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-28 00:00:00', 25.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-29 00:00:00', 23.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-04-30 00:00:00', 26.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-01 00:00:00', 26.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-02 00:00:00', 29.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-03 00:00:00', 28.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-04 00:00:00', 23.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-05 00:00:00', 24.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-06 00:00:00', 24.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-07 00:00:00', 27.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-08 00:00:00', 19.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-09 00:00:00', 19.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-10 00:00:00', 24.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-11 00:00:00', 24.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-12 00:00:00', 24.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-13 00:00:00', 24.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-14 00:00:00', 25.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-15 00:00:00', 27.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-16 00:00:00', 28.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-17 00:00:00', 30.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-18 00:00:00', 19.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-19 00:00:00', 23.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-20 00:00:00', 27.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-21 00:00:00', 25.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-22 00:00:00', 25.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-23 00:00:00', 25.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-24 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-25 00:00:00', 28.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-26 00:00:00', 27.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-27 00:00:00', 29.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-28 00:00:00', 30.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-29 00:00:00', 30.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-30 00:00:00', 21.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-05-31 00:00:00', 25.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-01 00:00:00', 24.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-02 00:00:00', 25.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-03 00:00:00', 26.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-04 00:00:00', 27.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-05 00:00:00', 30.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-06 00:00:00', 29.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-07 00:00:00', 29.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-08 00:00:00', 29.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-09 00:00:00', 30.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-10 00:00:00', 32.1069984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-11 00:00:00', 30.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-12 00:00:00', 34.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-13 00:00:00', 35.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-14 00:00:00', 36.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-15 00:00:00', 32.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-16 00:00:00', 30.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-17 00:00:00', 32.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-18 00:00:00', 31.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-19 00:00:00', 32.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-20 00:00:00', 33.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-21 00:00:00', 35.1010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-22 00:00:00', 35.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-23 00:00:00', 36.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-24 00:00:00', 35.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-25 00:00:00', 35.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-26 00:00:00', 35.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-27 00:00:00', 37.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-28 00:00:00', 39.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-29 00:00:00', 38.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-06-30 00:00:00', 39.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-01 00:00:00', 38.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-02 00:00:00', 35.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-03 00:00:00', 34.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-04 00:00:00', 31.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-05 00:00:00', 31.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-06 00:00:00', 32.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-07 00:00:00', 34.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-08 00:00:00', 35.0600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-09 00:00:00', 35.9550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-10 00:00:00', 36.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-11 00:00:00', 37.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-12 00:00:00', 37.8940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-13 00:00:00', 35.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-14 00:00:00', 35.4690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-15 00:00:00', 35.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-16 00:00:00', 34.2540016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-17 00:00:00', 33.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-18 00:00:00', 32.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-19 00:00:00', 32.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-20 00:00:00', 34.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-21 00:00:00', 37.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-22 00:00:00', 40.0180015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-23 00:00:00', 41.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-24 00:00:00', 36.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-25 00:00:00', 36.4550018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-26 00:00:00', 36.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-27 00:00:00', 39.3720016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-28 00:00:00', 39.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-29 00:00:00', 35.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-30 00:00:00', 34.4949989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (39, '2014-07-31 00:00:00', 33.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-01 00:00:00', 5.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-02 00:00:00', 7.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-03 00:00:00', 6.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-04 00:00:00', 7.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-05 00:00:00', 9.52900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-06 00:00:00', 3.8469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-07 00:00:00', 6.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-08 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-09 00:00:00', 1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-10 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-11 00:00:00', 6.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-12 00:00:00', 11.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-13 00:00:00', 5.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-14 00:00:00', 0.0710000023245811462, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-15 00:00:00', 2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-16 00:00:00', 1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-17 00:00:00', 0.404000014066696167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-18 00:00:00', -3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-19 00:00:00', -2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-20 00:00:00', -1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-21 00:00:00', -0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-22 00:00:00', 2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-23 00:00:00', 3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-24 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-25 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-26 00:00:00', -1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-27 00:00:00', -3.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-28 00:00:00', -1.62000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-29 00:00:00', -4.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-30 00:00:00', -1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-01-31 00:00:00', -0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-01 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-02 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-03 00:00:00', 5.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-04 00:00:00', 5.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-05 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-06 00:00:00', 4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-07 00:00:00', 6.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-08 00:00:00', 5.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-09 00:00:00', 8.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-10 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-11 00:00:00', 3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-12 00:00:00', 3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-13 00:00:00', 4.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-14 00:00:00', 4.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-15 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-16 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-17 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-18 00:00:00', 2.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-19 00:00:00', -1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-20 00:00:00', -6.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-21 00:00:00', -1.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-22 00:00:00', -1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-23 00:00:00', -0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-24 00:00:00', 2.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-25 00:00:00', 1.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-26 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-27 00:00:00', 0.521000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-02-28 00:00:00', -0.291000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-01 00:00:00', 1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-02 00:00:00', -1.2489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-03 00:00:00', -2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-04 00:00:00', -0.763000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-05 00:00:00', -2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-06 00:00:00', -4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-07 00:00:00', -4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-08 00:00:00', -2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-09 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-10 00:00:00', 4.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-11 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-12 00:00:00', 5.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-13 00:00:00', 6.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-14 00:00:00', 6.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-15 00:00:00', 8.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-16 00:00:00', 6.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-17 00:00:00', 7.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-18 00:00:00', 8.47500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-19 00:00:00', 7.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-20 00:00:00', 9.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-21 00:00:00', 13.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-22 00:00:00', 9.17300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-23 00:00:00', 13.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-24 00:00:00', 10.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-25 00:00:00', 9.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-26 00:00:00', 8.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-27 00:00:00', 10.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-28 00:00:00', 10.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-29 00:00:00', 11.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-30 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-03-31 00:00:00', 6.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-01 00:00:00', 9.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-02 00:00:00', 8.49199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-03 00:00:00', 8.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-04 00:00:00', 4.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-05 00:00:00', 9.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-06 00:00:00', 7.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-07 00:00:00', 7.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-08 00:00:00', 8.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-09 00:00:00', 8.93999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-10 00:00:00', 15.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-11 00:00:00', 9.28400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-12 00:00:00', 7.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-13 00:00:00', 8.43299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-14 00:00:00', 6.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-15 00:00:00', 6.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-16 00:00:00', 7.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-17 00:00:00', 7.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-18 00:00:00', 5.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-19 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-20 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-21 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-22 00:00:00', 5.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-23 00:00:00', 10.3559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-24 00:00:00', 10.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-25 00:00:00', 9.04399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-26 00:00:00', 10.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-27 00:00:00', 7.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-28 00:00:00', 7.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-29 00:00:00', 12.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-04-30 00:00:00', 8.76500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-01 00:00:00', 9.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-02 00:00:00', 18.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-03 00:00:00', 13.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-04 00:00:00', 19.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-05 00:00:00', 16.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-06 00:00:00', 15.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-07 00:00:00', 19.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-08 00:00:00', 12.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-09 00:00:00', 10.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-10 00:00:00', 13.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-11 00:00:00', 17.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-12 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-13 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-14 00:00:00', 11.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-15 00:00:00', 13.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-16 00:00:00', 9.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-17 00:00:00', 12.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-18 00:00:00', 12.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-19 00:00:00', 14.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-20 00:00:00', 13.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-21 00:00:00', 12.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-22 00:00:00', 17.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-23 00:00:00', 17.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-24 00:00:00', 12.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-25 00:00:00', 10.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-26 00:00:00', 14.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-27 00:00:00', 12.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-28 00:00:00', 11.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-29 00:00:00', 16.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-30 00:00:00', 16.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-05-31 00:00:00', 20.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-01 00:00:00', 21.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-02 00:00:00', 19.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-03 00:00:00', 20.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-04 00:00:00', 20.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-05 00:00:00', 22.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-06 00:00:00', 22.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-07 00:00:00', 22.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-08 00:00:00', 25.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-09 00:00:00', 24.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-10 00:00:00', 28.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-11 00:00:00', 21.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-12 00:00:00', 22.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-13 00:00:00', 22.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-14 00:00:00', 23.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-15 00:00:00', 26.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-16 00:00:00', 26.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-17 00:00:00', 26.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-18 00:00:00', 26.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-19 00:00:00', 26.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-20 00:00:00', 27.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-21 00:00:00', 27.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-22 00:00:00', 29.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-23 00:00:00', 30.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-24 00:00:00', 33.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-25 00:00:00', 31.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-26 00:00:00', 30.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-27 00:00:00', 28.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-28 00:00:00', 25.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-29 00:00:00', 27.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-06-30 00:00:00', 28.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-01 00:00:00', 27.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-02 00:00:00', 27.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-03 00:00:00', 28.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-04 00:00:00', 28.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-05 00:00:00', 29.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-06 00:00:00', 31.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-07 00:00:00', 32.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-08 00:00:00', 34.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-09 00:00:00', 37.9539985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-10 00:00:00', 38.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-11 00:00:00', 35.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-12 00:00:00', 33.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-13 00:00:00', 31.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-14 00:00:00', 32.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-15 00:00:00', 34.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-16 00:00:00', 34.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-17 00:00:00', 34.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-18 00:00:00', 34.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-19 00:00:00', 35.5730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-20 00:00:00', 33.9329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-21 00:00:00', 28.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-22 00:00:00', 28.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-23 00:00:00', 28.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-24 00:00:00', 29.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-25 00:00:00', 30.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-26 00:00:00', 31.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-27 00:00:00', 30.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-28 00:00:00', 31.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-29 00:00:00', 33.3370018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-30 00:00:00', 34.891998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-07-31 00:00:00', 36.2449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-01 00:00:00', 36.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-02 00:00:00', 36.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-03 00:00:00', 33.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-04 00:00:00', 30.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-05 00:00:00', 25.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-06 00:00:00', 28.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-07 00:00:00', 26.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-08 00:00:00', 28.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-09 00:00:00', 28.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-10 00:00:00', 29.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-11 00:00:00', 29.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-12 00:00:00', 30.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-13 00:00:00', 29.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-14 00:00:00', 30.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-15 00:00:00', 31.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-16 00:00:00', 31.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-17 00:00:00', 30.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-18 00:00:00', 34.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-19 00:00:00', 32.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-20 00:00:00', 26.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-21 00:00:00', 25.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-22 00:00:00', 24.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-23 00:00:00', 24.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-24 00:00:00', 25.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-25 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-26 00:00:00', 27.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-27 00:00:00', 26.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-28 00:00:00', 23.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-29 00:00:00', 23.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-30 00:00:00', 23.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-08-31 00:00:00', 25.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-01 00:00:00', 26.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-02 00:00:00', 24.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-03 00:00:00', 27.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-04 00:00:00', 29.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-05 00:00:00', 29.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-06 00:00:00', 29.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-07 00:00:00', 29.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-08 00:00:00', 29.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-09 00:00:00', 27.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-10 00:00:00', 27.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-11 00:00:00', 28.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-12 00:00:00', 28.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-13 00:00:00', 26.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-14 00:00:00', 25.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-15 00:00:00', 23.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-16 00:00:00', 23.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-17 00:00:00', 24.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-18 00:00:00', 24.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-19 00:00:00', 23.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-20 00:00:00', 24.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-21 00:00:00', 24.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-22 00:00:00', 22.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-23 00:00:00', 18.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-24 00:00:00', 19.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-25 00:00:00', 22.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-26 00:00:00', 23.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-27 00:00:00', 22.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-28 00:00:00', 21.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-29 00:00:00', 21.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-09-30 00:00:00', 22.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-01 00:00:00', 22.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-02 00:00:00', 22.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-03 00:00:00', 21.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-04 00:00:00', 22.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-05 00:00:00', 23.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-06 00:00:00', 23.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-07 00:00:00', 23.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-08 00:00:00', 21.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-09 00:00:00', 17.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-10 00:00:00', 16.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-11 00:00:00', 16.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-12 00:00:00', 16.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-13 00:00:00', 18.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-14 00:00:00', 19.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-15 00:00:00', 19.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-16 00:00:00', 20.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-17 00:00:00', 20.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-18 00:00:00', 20.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-19 00:00:00', 20.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-20 00:00:00', 16.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-21 00:00:00', 18.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-22 00:00:00', 19.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-23 00:00:00', 21.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-24 00:00:00', 22.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-25 00:00:00', 22.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-26 00:00:00', 22.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-27 00:00:00', 21.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-28 00:00:00', 16.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-29 00:00:00', 18.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-30 00:00:00', 14.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-10-31 00:00:00', 14.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-01 00:00:00', 14.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-02 00:00:00', 18.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-03 00:00:00', 18.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-04 00:00:00', 18.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-05 00:00:00', 10.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-06 00:00:00', 5.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-07 00:00:00', 6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-08 00:00:00', 6.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-09 00:00:00', 11.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-10 00:00:00', 10.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-11 00:00:00', 6.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-12 00:00:00', 8.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-13 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-14 00:00:00', 8.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-15 00:00:00', 10.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-16 00:00:00', 9.69699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-17 00:00:00', 10.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-18 00:00:00', 10.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-19 00:00:00', 9.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-20 00:00:00', 6.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-21 00:00:00', 5.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-22 00:00:00', 4.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-23 00:00:00', 7.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-24 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-25 00:00:00', 9.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-26 00:00:00', 11.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-27 00:00:00', 12.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-28 00:00:00', 12.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-29 00:00:00', 12.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-11-30 00:00:00', 14.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-01 00:00:00', 12.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-02 00:00:00', 8.85999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-03 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-04 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-05 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-06 00:00:00', 7.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-07 00:00:00', 8.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-08 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-09 00:00:00', 7.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-10 00:00:00', 6.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-11 00:00:00', 3.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-12 00:00:00', 4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-13 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-14 00:00:00', 3.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-15 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-16 00:00:00', 8.88799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-17 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-18 00:00:00', 0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-19 00:00:00', 1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-20 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-21 00:00:00', 6.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-22 00:00:00', 0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-23 00:00:00', -4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-24 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-25 00:00:00', 6.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-26 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-27 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-28 00:00:00', 2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-29 00:00:00', 2.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-30 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1979-12-31 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-01 00:00:00', 1.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-02 00:00:00', 0.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-03 00:00:00', 2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-04 00:00:00', 2.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-05 00:00:00', 2.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-06 00:00:00', 5.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-07 00:00:00', 7.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-08 00:00:00', 2.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-09 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-10 00:00:00', -2.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-11 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-12 00:00:00', 0.671000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-13 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-14 00:00:00', 3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-15 00:00:00', 0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-16 00:00:00', -2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-17 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-18 00:00:00', 1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-19 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-20 00:00:00', 0.679000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-21 00:00:00', -0.634000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-22 00:00:00', -0.945999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-23 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-24 00:00:00', -0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-25 00:00:00', -1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-26 00:00:00', -1.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-27 00:00:00', -3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-28 00:00:00', -5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-29 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-30 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-01-31 00:00:00', 0.252999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-01 00:00:00', -4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-02 00:00:00', -7.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-03 00:00:00', -8.23700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-04 00:00:00', -8.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-05 00:00:00', -6.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-06 00:00:00', -2.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-07 00:00:00', -0.272000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-08 00:00:00', -0.435000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-09 00:00:00', 2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-10 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-11 00:00:00', 4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-12 00:00:00', 7.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-13 00:00:00', 4.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-14 00:00:00', 2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-15 00:00:00', 5.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-16 00:00:00', 7.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-17 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-18 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-19 00:00:00', 5.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-20 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-21 00:00:00', 3.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-22 00:00:00', -0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-23 00:00:00', 1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-24 00:00:00', -0.755999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-25 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-26 00:00:00', 2.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-27 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-28 00:00:00', -0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-02-29 00:00:00', 0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-01 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-02 00:00:00', 4.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-03 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-04 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-05 00:00:00', 0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-06 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-07 00:00:00', 5.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-08 00:00:00', 0.653999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-09 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-10 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-11 00:00:00', 2.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-12 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-13 00:00:00', 7.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-14 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-15 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-16 00:00:00', 4.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-17 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-18 00:00:00', 5.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-19 00:00:00', 10.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-20 00:00:00', 6.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-21 00:00:00', 8.34099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-22 00:00:00', 8.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-23 00:00:00', 12.2100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-24 00:00:00', 9.08899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-25 00:00:00', 11.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-26 00:00:00', 10.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-27 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-28 00:00:00', 5.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-29 00:00:00', 11.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-30 00:00:00', 15.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-03-31 00:00:00', 13.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-01 00:00:00', 9.63799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-02 00:00:00', 9.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-03 00:00:00', 9.75800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-04 00:00:00', 12.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-05 00:00:00', 9.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-06 00:00:00', 9.77999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-07 00:00:00', 12.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-08 00:00:00', 17.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-09 00:00:00', 18.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-10 00:00:00', 19.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-11 00:00:00', 18.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-12 00:00:00', 19.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-13 00:00:00', 15.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-14 00:00:00', 21.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-15 00:00:00', 9.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-16 00:00:00', 10.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-17 00:00:00', 13.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-18 00:00:00', 6.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-19 00:00:00', 8.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-20 00:00:00', 12.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-21 00:00:00', 7.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-22 00:00:00', 11.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-23 00:00:00', 14.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-24 00:00:00', 17.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-25 00:00:00', 14.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-26 00:00:00', 16.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-27 00:00:00', 14.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-28 00:00:00', 11.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-29 00:00:00', 13.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-04-30 00:00:00', 17.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-01 00:00:00', 21.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-02 00:00:00', 20.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-03 00:00:00', 21.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-04 00:00:00', 22.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-05 00:00:00', 23.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-06 00:00:00', 25.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-07 00:00:00', 25.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-08 00:00:00', 16.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-09 00:00:00', 18.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-10 00:00:00', 25.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-11 00:00:00', 13.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-12 00:00:00', 15.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-13 00:00:00', 16.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-14 00:00:00', 22.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-15 00:00:00', 18.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-16 00:00:00', 20.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-17 00:00:00', 17.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-18 00:00:00', 18.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-19 00:00:00', 21.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-20 00:00:00', 20.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-21 00:00:00', 22.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-22 00:00:00', 20.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-23 00:00:00', 23.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-24 00:00:00', 26.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-25 00:00:00', 26.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-26 00:00:00', 26.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-27 00:00:00', 25.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-28 00:00:00', 26.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-29 00:00:00', 25.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-30 00:00:00', 26.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-05-31 00:00:00', 25.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-01 00:00:00', 22.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-02 00:00:00', 21.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-03 00:00:00', 24.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-04 00:00:00', 26.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-05 00:00:00', 27.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-06 00:00:00', 29.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-07 00:00:00', 29.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-08 00:00:00', 29.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-09 00:00:00', 31.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-10 00:00:00', 33.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-11 00:00:00', 32.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-12 00:00:00', 23.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-13 00:00:00', 22.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-14 00:00:00', 25.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-15 00:00:00', 26.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-16 00:00:00', 27.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-17 00:00:00', 30.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-18 00:00:00', 33.3089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-19 00:00:00', 32.2050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-20 00:00:00', 29.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-21 00:00:00', 30.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-22 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-23 00:00:00', 32.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-24 00:00:00', 28.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-25 00:00:00', 25.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-26 00:00:00', 26.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-27 00:00:00', 27.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-28 00:00:00', 29.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-29 00:00:00', 30.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-06-30 00:00:00', 30.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-01 00:00:00', 31.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-02 00:00:00', 34.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-03 00:00:00', 34.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-04 00:00:00', 31.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-05 00:00:00', 31.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-06 00:00:00', 32.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-07 00:00:00', 33.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-08 00:00:00', 33.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-09 00:00:00', 34.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-10 00:00:00', 35.7379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-11 00:00:00', 34.608001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-12 00:00:00', 31.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-13 00:00:00', 29.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-14 00:00:00', 31.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-15 00:00:00', 32.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-16 00:00:00', 34.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-17 00:00:00', 33.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-18 00:00:00', 32.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-19 00:00:00', 26.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-20 00:00:00', 29.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-21 00:00:00', 31.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-22 00:00:00', 30.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-23 00:00:00', 30.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-24 00:00:00', 31.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-25 00:00:00', 32.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-26 00:00:00', 32.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-27 00:00:00', 32.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-28 00:00:00', 32.8510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-29 00:00:00', 31.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-30 00:00:00', 31.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-07-31 00:00:00', 32.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-01 00:00:00', 33.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-02 00:00:00', 34.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-03 00:00:00', 29.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-04 00:00:00', 29.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-05 00:00:00', 31.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-06 00:00:00', 32.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-07 00:00:00', 30.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-08 00:00:00', 25.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-09 00:00:00', 26.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-10 00:00:00', 25.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-11 00:00:00', 27.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-12 00:00:00', 26.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-13 00:00:00', 27.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-14 00:00:00', 27.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-15 00:00:00', 27.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-16 00:00:00', 28.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-17 00:00:00', 26.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-18 00:00:00', 27.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-19 00:00:00', 29.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-20 00:00:00', 32.4210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-21 00:00:00', 32.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-22 00:00:00', 33.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-23 00:00:00', 29.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-24 00:00:00', 29.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-25 00:00:00', 29.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-26 00:00:00', 29.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-27 00:00:00', 29.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-28 00:00:00', 30.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-29 00:00:00', 30.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-30 00:00:00', 29.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-08-31 00:00:00', 25.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-01 00:00:00', 25.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-02 00:00:00', 25.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-03 00:00:00', 26.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-04 00:00:00', 24.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-05 00:00:00', 26.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-06 00:00:00', 27.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-07 00:00:00', 29.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-08 00:00:00', 28.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-09 00:00:00', 26.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-10 00:00:00', 20.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-11 00:00:00', 22.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-12 00:00:00', 23.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-13 00:00:00', 23.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-14 00:00:00', 24.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-15 00:00:00', 23.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-16 00:00:00', 26.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-17 00:00:00', 27.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-18 00:00:00', 26.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-19 00:00:00', 26.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-20 00:00:00', 26.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-21 00:00:00', 27.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-22 00:00:00', 29.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-23 00:00:00', 25.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-24 00:00:00', 23.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-25 00:00:00', 21.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-26 00:00:00', 22.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-27 00:00:00', 20.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-28 00:00:00', 21.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-29 00:00:00', 23.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-09-30 00:00:00', 22.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-01 00:00:00', 21.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-02 00:00:00', 22.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-03 00:00:00', 25.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-04 00:00:00', 24.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-05 00:00:00', 21.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-06 00:00:00', 23.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-07 00:00:00', 19.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-08 00:00:00', 17.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-09 00:00:00', 17.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-10 00:00:00', 9.96100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-11 00:00:00', 7.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-12 00:00:00', 13.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-13 00:00:00', 15.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-14 00:00:00', 17.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-15 00:00:00', 14.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-16 00:00:00', 15.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-17 00:00:00', 14.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-18 00:00:00', 15.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-19 00:00:00', 15.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-20 00:00:00', 18.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-21 00:00:00', 14.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-22 00:00:00', 9.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-23 00:00:00', 7.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-24 00:00:00', 13.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-25 00:00:00', 17.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-26 00:00:00', 16.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-27 00:00:00', 17.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-28 00:00:00', 15.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-29 00:00:00', 14.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-30 00:00:00', 13.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-10-31 00:00:00', 13.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-01 00:00:00', 14.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-02 00:00:00', 13.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-03 00:00:00', 11.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-04 00:00:00', 7.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-05 00:00:00', 7.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-06 00:00:00', 7.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-07 00:00:00', 13.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-08 00:00:00', 12.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-09 00:00:00', 15.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-10 00:00:00', 16.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-11 00:00:00', 16.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-12 00:00:00', 15.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-13 00:00:00', 15.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-14 00:00:00', 15.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-15 00:00:00', 14.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-16 00:00:00', 10.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-17 00:00:00', 14.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-18 00:00:00', 11.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-19 00:00:00', 7.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-20 00:00:00', 10.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-21 00:00:00', 10.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-22 00:00:00', 10.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-23 00:00:00', 11.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-24 00:00:00', 7.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-25 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-26 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-27 00:00:00', 7.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-28 00:00:00', 10.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-29 00:00:00', 13.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-11-30 00:00:00', 13.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-01 00:00:00', 11.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-02 00:00:00', 8.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-03 00:00:00', 7.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-04 00:00:00', 8.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-05 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-06 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-07 00:00:00', 11.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-08 00:00:00', 12.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-09 00:00:00', 11.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-10 00:00:00', 9.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-11 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-12 00:00:00', 5.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-13 00:00:00', 4.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-14 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-15 00:00:00', 4.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-16 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-17 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-18 00:00:00', 2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-19 00:00:00', 6.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-20 00:00:00', 3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-21 00:00:00', 2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-22 00:00:00', 6.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-23 00:00:00', 7.71799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-24 00:00:00', 5.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-25 00:00:00', 6.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-26 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-27 00:00:00', 0.880999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-28 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-29 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-30 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1980-12-31 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-01 00:00:00', 2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-02 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-03 00:00:00', -1.02100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-04 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-05 00:00:00', -0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-06 00:00:00', 1.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-07 00:00:00', 3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-08 00:00:00', 4.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-09 00:00:00', 2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-10 00:00:00', 2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-11 00:00:00', 5.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-12 00:00:00', 7.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-13 00:00:00', 6.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-14 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-15 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-16 00:00:00', 0.486999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-17 00:00:00', 1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-18 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-19 00:00:00', 7.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-20 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-21 00:00:00', 4.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-22 00:00:00', 5.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-23 00:00:00', 2.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-24 00:00:00', -2.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-25 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-26 00:00:00', 0.570999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-27 00:00:00', 3.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-28 00:00:00', 2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-29 00:00:00', 2.18600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-30 00:00:00', -0.629000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-01-31 00:00:00', -1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-01 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-02 00:00:00', 0.203999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-03 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-04 00:00:00', -2.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-05 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-06 00:00:00', 6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-07 00:00:00', 6.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-08 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-09 00:00:00', 6.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-10 00:00:00', 4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-11 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-12 00:00:00', 4.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-13 00:00:00', 1.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-14 00:00:00', 2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-15 00:00:00', 4.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-16 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-17 00:00:00', 1.99100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-18 00:00:00', 5.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-19 00:00:00', 5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-20 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-21 00:00:00', 8.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-22 00:00:00', 7.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-23 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-24 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-25 00:00:00', 4.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-26 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-27 00:00:00', 4.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-02-28 00:00:00', 2.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-01 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-02 00:00:00', 5.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-03 00:00:00', 8.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-04 00:00:00', 9.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-05 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-06 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-07 00:00:00', 6.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-08 00:00:00', 7.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-09 00:00:00', 4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-10 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-11 00:00:00', 6.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-12 00:00:00', 7.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-13 00:00:00', 9.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-14 00:00:00', 9.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-15 00:00:00', 8.82900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-16 00:00:00', 5.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-17 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-18 00:00:00', 2.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-19 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-20 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-21 00:00:00', 6.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-22 00:00:00', 9.04800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-23 00:00:00', 14.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-24 00:00:00', 8.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-25 00:00:00', 11.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-26 00:00:00', 11.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-27 00:00:00', 5.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-28 00:00:00', 10.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-29 00:00:00', 4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-30 00:00:00', 3.81399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-03-31 00:00:00', 6.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-01 00:00:00', 6.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-02 00:00:00', 4.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-03 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-04 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-05 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-06 00:00:00', 4.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-07 00:00:00', 4.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-08 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-09 00:00:00', 6.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-10 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-11 00:00:00', 4.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-12 00:00:00', 4.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-13 00:00:00', 4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-14 00:00:00', 3.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-15 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-16 00:00:00', 18.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-17 00:00:00', 15.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-18 00:00:00', 18.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-19 00:00:00', 12.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-20 00:00:00', 9.31700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-21 00:00:00', 12.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-22 00:00:00', 19.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-23 00:00:00', 16.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-24 00:00:00', 25.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-25 00:00:00', 20.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-26 00:00:00', 20.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-27 00:00:00', 26.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-28 00:00:00', 19.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-29 00:00:00', 20.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-04-30 00:00:00', 15.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-01 00:00:00', 20.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-02 00:00:00', 23.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-03 00:00:00', 24.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-04 00:00:00', 16.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-05 00:00:00', 18.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-06 00:00:00', 20.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-07 00:00:00', 21.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-08 00:00:00', 16.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-09 00:00:00', 19.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-10 00:00:00', 19.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-11 00:00:00', 18.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-12 00:00:00', 22.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-13 00:00:00', 22.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-14 00:00:00', 18.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-15 00:00:00', 21.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-16 00:00:00', 24.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-17 00:00:00', 26.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-18 00:00:00', 21.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-19 00:00:00', 15.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-20 00:00:00', 17.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-21 00:00:00', 20.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-22 00:00:00', 20.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-23 00:00:00', 22.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-24 00:00:00', 25.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-25 00:00:00', 24.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-26 00:00:00', 24.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-27 00:00:00', 24.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-28 00:00:00', 25.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-29 00:00:00', 25.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-30 00:00:00', 17.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-05-31 00:00:00', 17.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-01 00:00:00', 17.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-02 00:00:00', 17.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-03 00:00:00', 20.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-04 00:00:00', 22.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-05 00:00:00', 25.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-06 00:00:00', 26.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-07 00:00:00', 22.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-08 00:00:00', 20.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-09 00:00:00', 20.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-10 00:00:00', 20.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-11 00:00:00', 20.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-12 00:00:00', 22.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-13 00:00:00', 23.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-14 00:00:00', 22.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-15 00:00:00', 25.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-16 00:00:00', 27.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-17 00:00:00', 29.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-18 00:00:00', 28.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-19 00:00:00', 29.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-20 00:00:00', 29.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-21 00:00:00', 28.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-22 00:00:00', 29.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-23 00:00:00', 28.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-24 00:00:00', 29.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-25 00:00:00', 29.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-26 00:00:00', 30.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-27 00:00:00', 30.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-28 00:00:00', 30.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-29 00:00:00', 31.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-06-30 00:00:00', 28.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-01 00:00:00', 27.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-02 00:00:00', 27.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-03 00:00:00', 27.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-04 00:00:00', 29.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-05 00:00:00', 29.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-06 00:00:00', 31.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-07 00:00:00', 32.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-08 00:00:00', 26.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-09 00:00:00', 28.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-10 00:00:00', 29.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-11 00:00:00', 31.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-12 00:00:00', 33.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-13 00:00:00', 38.0519981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-14 00:00:00', 37.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-15 00:00:00', 34.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-16 00:00:00', 30.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-17 00:00:00', 29.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-18 00:00:00', 27.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-19 00:00:00', 28.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-20 00:00:00', 31.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-21 00:00:00', 33.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-22 00:00:00', 29.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-23 00:00:00', 22.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-24 00:00:00', 22.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-25 00:00:00', 26.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-26 00:00:00', 27.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-27 00:00:00', 28.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-28 00:00:00', 28.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-29 00:00:00', 27.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-30 00:00:00', 26.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-07-31 00:00:00', 25.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-01 00:00:00', 25.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-02 00:00:00', 26.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-03 00:00:00', 27.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-04 00:00:00', 28.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-05 00:00:00', 28.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-06 00:00:00', 31.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-07 00:00:00', 30.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-08 00:00:00', 30.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-09 00:00:00', 29.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-10 00:00:00', 31.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-11 00:00:00', 30.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-12 00:00:00', 27.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-13 00:00:00', 28.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-14 00:00:00', 27.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-15 00:00:00', 27.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-16 00:00:00', 28.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-17 00:00:00', 29.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-18 00:00:00', 29.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-19 00:00:00', 25.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-20 00:00:00', 24.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-21 00:00:00', 24.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-22 00:00:00', 23.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-23 00:00:00', 25.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-24 00:00:00', 24.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-25 00:00:00', 26.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-26 00:00:00', 26.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-27 00:00:00', 25.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-28 00:00:00', 25.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-29 00:00:00', 23.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-30 00:00:00', 25.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-08-31 00:00:00', 27.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-01 00:00:00', 27.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-02 00:00:00', 25.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-03 00:00:00', 24.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-04 00:00:00', 25.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-05 00:00:00', 24.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-06 00:00:00', 24.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-07 00:00:00', 24.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-08 00:00:00', 25.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-09 00:00:00', 24.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-10 00:00:00', 22.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-11 00:00:00', 20.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-12 00:00:00', 25.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-13 00:00:00', 27.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-14 00:00:00', 29.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-15 00:00:00', 29.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-16 00:00:00', 29.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-17 00:00:00', 28.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-18 00:00:00', 28.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-19 00:00:00', 27.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-20 00:00:00', 27.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-21 00:00:00', 26.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-22 00:00:00', 24.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-23 00:00:00', 16.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-24 00:00:00', 15.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-25 00:00:00', 18.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-26 00:00:00', 21.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-27 00:00:00', 21.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-28 00:00:00', 21.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-29 00:00:00', 19.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-09-30 00:00:00', 18.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-01 00:00:00', 16.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-02 00:00:00', 16.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-03 00:00:00', 16.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-04 00:00:00', 17.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-05 00:00:00', 16.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-06 00:00:00', 14.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-07 00:00:00', 15.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-08 00:00:00', 16.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-09 00:00:00', 17.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-10 00:00:00', 14.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-11 00:00:00', 14.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-12 00:00:00', 15.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-13 00:00:00', 16.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-14 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-15 00:00:00', 14.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-16 00:00:00', 12.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-17 00:00:00', 15.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-18 00:00:00', 16.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-19 00:00:00', 10.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-20 00:00:00', 8.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-21 00:00:00', 12.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-22 00:00:00', 14.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-23 00:00:00', 12.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-24 00:00:00', 10.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-25 00:00:00', 13.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-26 00:00:00', 12.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-27 00:00:00', 11.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-28 00:00:00', 9.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-29 00:00:00', 9.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-30 00:00:00', 9.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-10-31 00:00:00', 11.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-01 00:00:00', 13.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-02 00:00:00', 13.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-03 00:00:00', 13.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-04 00:00:00', 12.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-05 00:00:00', 15.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-06 00:00:00', 17.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-07 00:00:00', 14.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-08 00:00:00', 10.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-09 00:00:00', 11.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-10 00:00:00', 10.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-11 00:00:00', 11.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-12 00:00:00', 11.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-13 00:00:00', 12.9709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-14 00:00:00', 15.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-15 00:00:00', 12.8590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-16 00:00:00', 8.26799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-17 00:00:00', 8.68500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-18 00:00:00', 9.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-19 00:00:00', 10.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-20 00:00:00', 9.37199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-21 00:00:00', 9.62899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-22 00:00:00', 8.57400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-23 00:00:00', 6.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-24 00:00:00', 3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-25 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-26 00:00:00', 5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-27 00:00:00', 6.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-28 00:00:00', 8.92300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-29 00:00:00', 7.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-11-30 00:00:00', 8.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-01 00:00:00', 8.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-02 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-03 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-04 00:00:00', 1.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-05 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-06 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-07 00:00:00', 4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-08 00:00:00', 3.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-09 00:00:00', 5.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-10 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-11 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-12 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-13 00:00:00', 6.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-14 00:00:00', 5.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-15 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-16 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-17 00:00:00', 6.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-18 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-19 00:00:00', 8.14500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-20 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-21 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-22 00:00:00', 1.75899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-23 00:00:00', 3.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-24 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-25 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-26 00:00:00', 4.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-27 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-28 00:00:00', -0.123000003397464752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-29 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-30 00:00:00', 0.691999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1981-12-31 00:00:00', 0.671000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-01 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-02 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-03 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-04 00:00:00', 4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-05 00:00:00', 5.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-06 00:00:00', 7.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-07 00:00:00', 10.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-08 00:00:00', 10.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-09 00:00:00', 8.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-10 00:00:00', 7.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-11 00:00:00', 6.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-12 00:00:00', 3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-13 00:00:00', -0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-14 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-15 00:00:00', 5.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-16 00:00:00', 4.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-17 00:00:00', 5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-18 00:00:00', 3.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-19 00:00:00', -6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-20 00:00:00', -3.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-21 00:00:00', -5.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-22 00:00:00', -8.78600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-23 00:00:00', -4.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-24 00:00:00', -2.83999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-25 00:00:00', -1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-26 00:00:00', -2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-27 00:00:00', -0.0299999993294477463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-28 00:00:00', -1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-29 00:00:00', 0.477999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-30 00:00:00', -0.254999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-01-31 00:00:00', -0.405999988317489624, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-01 00:00:00', 1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-02 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-03 00:00:00', 0.902000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-04 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-05 00:00:00', 3.98200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-06 00:00:00', 0.671999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-07 00:00:00', -3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-08 00:00:00', -1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-09 00:00:00', 1.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-10 00:00:00', 1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-11 00:00:00', -2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-12 00:00:00', -0.55699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-13 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-14 00:00:00', 6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-15 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-16 00:00:00', -0.870000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-17 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-18 00:00:00', 4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-19 00:00:00', -0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-20 00:00:00', -4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-21 00:00:00', -2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-22 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-23 00:00:00', -1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-24 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-25 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-26 00:00:00', 3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-27 00:00:00', 6.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-02-28 00:00:00', 6.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-01 00:00:00', 4.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-02 00:00:00', 4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-03 00:00:00', 6.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-04 00:00:00', 4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-05 00:00:00', 2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-06 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-07 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-08 00:00:00', 5.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-09 00:00:00', 4.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-10 00:00:00', 6.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-11 00:00:00', 5.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-12 00:00:00', 8.76299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-13 00:00:00', 6.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-14 00:00:00', 7.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-15 00:00:00', 8.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-16 00:00:00', 7.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-17 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-18 00:00:00', 7.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-19 00:00:00', 8.50800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-20 00:00:00', 7.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-21 00:00:00', 3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-22 00:00:00', 6.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-23 00:00:00', 9.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-24 00:00:00', 10.1549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-25 00:00:00', 9.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-26 00:00:00', 7.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-27 00:00:00', 8.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-28 00:00:00', 7.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-29 00:00:00', 8.47799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-30 00:00:00', 5.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-03-31 00:00:00', 7.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-01 00:00:00', 10.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-02 00:00:00', 12.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-03 00:00:00', 7.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-04 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-05 00:00:00', 7.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-06 00:00:00', 11.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-07 00:00:00', 15.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-08 00:00:00', 16.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-09 00:00:00', 18.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-10 00:00:00', 18.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-11 00:00:00', 15.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-12 00:00:00', 17.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-13 00:00:00', 18.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-14 00:00:00', 18.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-15 00:00:00', 16.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-16 00:00:00', 13.7899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-17 00:00:00', 16.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-18 00:00:00', 18.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-19 00:00:00', 20.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-20 00:00:00', 21.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-21 00:00:00', 20.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-22 00:00:00', 21.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-23 00:00:00', 21.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-24 00:00:00', 20.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-25 00:00:00', 19.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-26 00:00:00', 17.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-27 00:00:00', 17.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-28 00:00:00', 18.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-29 00:00:00', 18.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-04-30 00:00:00', 21.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-01 00:00:00', 22.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-02 00:00:00', 24.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-03 00:00:00', 24.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-04 00:00:00', 25.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-05 00:00:00', 24.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-06 00:00:00', 21.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-07 00:00:00', 23.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-08 00:00:00', 23.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-09 00:00:00', 21.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-10 00:00:00', 17.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-11 00:00:00', 18.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-12 00:00:00', 17.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-13 00:00:00', 18.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-14 00:00:00', 18.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-15 00:00:00', 18.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-16 00:00:00', 22.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-17 00:00:00', 22.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-18 00:00:00', 24.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-19 00:00:00', 25.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-20 00:00:00', 26.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-21 00:00:00', 26.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-22 00:00:00', 24.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-23 00:00:00', 24.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-24 00:00:00', 24.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-25 00:00:00', 22.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-26 00:00:00', 19.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-27 00:00:00', 21.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-28 00:00:00', 20.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-29 00:00:00', 15.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-30 00:00:00', 20.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-05-31 00:00:00', 22.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-01 00:00:00', 23.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-02 00:00:00', 25.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-03 00:00:00', 25.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-04 00:00:00', 23.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-05 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-06 00:00:00', 28.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-07 00:00:00', 28.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-08 00:00:00', 27.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-09 00:00:00', 29.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-10 00:00:00', 31.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-11 00:00:00', 30.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-12 00:00:00', 29.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-13 00:00:00', 30.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-14 00:00:00', 27.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-15 00:00:00', 27.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-16 00:00:00', 28.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-17 00:00:00', 25.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-18 00:00:00', 24.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-19 00:00:00', 25.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-20 00:00:00', 26.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-21 00:00:00', 27.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-22 00:00:00', 29.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-23 00:00:00', 29.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-24 00:00:00', 30.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-25 00:00:00', 31.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-26 00:00:00', 29.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-27 00:00:00', 29.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-28 00:00:00', 28.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-29 00:00:00', 30.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-06-30 00:00:00', 19.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-01 00:00:00', 20.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-02 00:00:00', 25.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-03 00:00:00', 25.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-04 00:00:00', 26.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-05 00:00:00', 27.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-06 00:00:00', 25.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-07 00:00:00', 27.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-08 00:00:00', 27.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-09 00:00:00', 28.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-10 00:00:00', 28.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-11 00:00:00', 28.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-12 00:00:00', 25.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-13 00:00:00', 28.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-14 00:00:00', 28.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-15 00:00:00', 28.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-16 00:00:00', 31.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-17 00:00:00', 31.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-18 00:00:00', 32.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-19 00:00:00', 33.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-20 00:00:00', 32.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-21 00:00:00', 32.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-22 00:00:00', 32.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-23 00:00:00', 32.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-24 00:00:00', 32.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-25 00:00:00', 31.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-26 00:00:00', 32.2270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-27 00:00:00', 34.3860015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-28 00:00:00', 33.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-29 00:00:00', 32.4889984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-30 00:00:00', 34.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-07-31 00:00:00', 35.8170013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-01 00:00:00', 37.8240013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-02 00:00:00', 37.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-03 00:00:00', 36.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-04 00:00:00', 35.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-05 00:00:00', 36.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-06 00:00:00', 36.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-07 00:00:00', 36.0670013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-08 00:00:00', 35.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-09 00:00:00', 34.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-10 00:00:00', 33.7050018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-11 00:00:00', 24.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-12 00:00:00', 25.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-13 00:00:00', 29.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-14 00:00:00', 30.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-15 00:00:00', 29.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-16 00:00:00', 26.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-17 00:00:00', 28.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-18 00:00:00', 29.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-19 00:00:00', 28.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-20 00:00:00', 27.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-21 00:00:00', 28.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-22 00:00:00', 26.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-23 00:00:00', 23.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-24 00:00:00', 20.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-25 00:00:00', 20.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-26 00:00:00', 21.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-27 00:00:00', 23.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-28 00:00:00', 26.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-29 00:00:00', 25.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-30 00:00:00', 24.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-08-31 00:00:00', 26.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-01 00:00:00', 27.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-02 00:00:00', 26.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-03 00:00:00', 25.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-04 00:00:00', 25.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-05 00:00:00', 26.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-06 00:00:00', 24.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-07 00:00:00', 24.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-08 00:00:00', 24.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-09 00:00:00', 25.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-10 00:00:00', 25.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-11 00:00:00', 25.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-12 00:00:00', 25.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-13 00:00:00', 24.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-14 00:00:00', 24.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-15 00:00:00', 24.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-16 00:00:00', 23.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-17 00:00:00', 21.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-18 00:00:00', 21.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-19 00:00:00', 19.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-20 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-21 00:00:00', 16.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-22 00:00:00', 18.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-23 00:00:00', 17.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-24 00:00:00', 18.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-25 00:00:00', 18.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-26 00:00:00', 17.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-27 00:00:00', 19.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-28 00:00:00', 18.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-29 00:00:00', 17.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-09-30 00:00:00', 15.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-01 00:00:00', 18.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-02 00:00:00', 21.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-03 00:00:00', 21.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-04 00:00:00', 16.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-05 00:00:00', 18.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-06 00:00:00', 17.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-07 00:00:00', 11.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-08 00:00:00', 11.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-09 00:00:00', 15.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-10 00:00:00', 19.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-11 00:00:00', 14.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-12 00:00:00', 15.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-13 00:00:00', 17.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-14 00:00:00', 18.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-15 00:00:00', 20.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-16 00:00:00', 19.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-17 00:00:00', 18.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-18 00:00:00', 17.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-19 00:00:00', 17.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-20 00:00:00', 17.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-21 00:00:00', 18.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-22 00:00:00', 16.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-23 00:00:00', 13.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-24 00:00:00', 10.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-25 00:00:00', 7.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-26 00:00:00', -1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-27 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-28 00:00:00', 10.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-29 00:00:00', 13.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-30 00:00:00', 14.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-10-31 00:00:00', 8.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-01 00:00:00', 7.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-02 00:00:00', 8.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-03 00:00:00', 6.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-04 00:00:00', 9.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-05 00:00:00', 9.46399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-06 00:00:00', 12.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-07 00:00:00', 14.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-08 00:00:00', 14.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-09 00:00:00', 13.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-10 00:00:00', 6.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-11 00:00:00', 4.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-12 00:00:00', 8.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-13 00:00:00', 9.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-14 00:00:00', 5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-15 00:00:00', 1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-16 00:00:00', 2.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-17 00:00:00', 5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-18 00:00:00', 2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-19 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-20 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-21 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-22 00:00:00', 4.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-23 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-24 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-25 00:00:00', 3.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-26 00:00:00', 4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-27 00:00:00', 5.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-28 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-29 00:00:00', 1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-11-30 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-01 00:00:00', -1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-02 00:00:00', -0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-03 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-04 00:00:00', 4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-05 00:00:00', 4.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-06 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-07 00:00:00', -1.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-08 00:00:00', 4.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-09 00:00:00', -4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-10 00:00:00', -0.527999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-11 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-12 00:00:00', 3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-13 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-14 00:00:00', 4.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-15 00:00:00', 5.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-16 00:00:00', 5.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-17 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-18 00:00:00', 5.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-19 00:00:00', 5.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-20 00:00:00', 6.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-21 00:00:00', 7.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-22 00:00:00', 5.54400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-23 00:00:00', 4.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-24 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-25 00:00:00', 6.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-26 00:00:00', 6.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-27 00:00:00', 4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-28 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-29 00:00:00', 0.509000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-30 00:00:00', 1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1982-12-31 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-01 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-02 00:00:00', 5.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-03 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-04 00:00:00', 4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-05 00:00:00', 0.488999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-06 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-07 00:00:00', -0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-08 00:00:00', -2.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-09 00:00:00', -3.85700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-10 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-11 00:00:00', -3.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-12 00:00:00', -1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-13 00:00:00', 0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-14 00:00:00', -2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-15 00:00:00', -3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-16 00:00:00', 4.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-17 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-18 00:00:00', 6.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-19 00:00:00', 6.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-20 00:00:00', 8.06700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-21 00:00:00', 11.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-22 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-23 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-24 00:00:00', 9.81000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-25 00:00:00', 7.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-26 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-27 00:00:00', -0.745999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-28 00:00:00', -2.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-29 00:00:00', -0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-30 00:00:00', -0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-01-31 00:00:00', 1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-01 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-02 00:00:00', 3.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-03 00:00:00', 3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-04 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-05 00:00:00', 5.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-06 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-07 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-08 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-09 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-10 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-11 00:00:00', 3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-12 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-13 00:00:00', 2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-14 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-15 00:00:00', 7.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-16 00:00:00', 5.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-17 00:00:00', 6.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-18 00:00:00', 7.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-19 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-20 00:00:00', 4.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-21 00:00:00', 4.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-22 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-23 00:00:00', 2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-24 00:00:00', -1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-25 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-26 00:00:00', 2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-27 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-02-28 00:00:00', 4.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-01 00:00:00', 0.791999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-02 00:00:00', 2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-03 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-04 00:00:00', 4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-05 00:00:00', 7.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-06 00:00:00', 7.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-07 00:00:00', 5.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-08 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-09 00:00:00', 6.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-10 00:00:00', 7.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-11 00:00:00', 5.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-12 00:00:00', 7.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-13 00:00:00', 10.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-14 00:00:00', 7.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-15 00:00:00', 6.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-16 00:00:00', 7.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-17 00:00:00', 2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-18 00:00:00', 4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-19 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-20 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-21 00:00:00', 5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-22 00:00:00', 7.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-23 00:00:00', 7.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-24 00:00:00', 10.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-25 00:00:00', 4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-26 00:00:00', 3.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-27 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-28 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-29 00:00:00', 8.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-30 00:00:00', 10.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-03-31 00:00:00', 12.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-01 00:00:00', 14.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-02 00:00:00', 15.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-03 00:00:00', 16.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-04 00:00:00', 14.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-05 00:00:00', 13.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-06 00:00:00', 15.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-07 00:00:00', 11.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-08 00:00:00', 12.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-09 00:00:00', 11.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-10 00:00:00', 11.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-11 00:00:00', 14.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-12 00:00:00', 10.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-13 00:00:00', 8.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-14 00:00:00', 11.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-15 00:00:00', 12.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-16 00:00:00', 10.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-17 00:00:00', 12.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-18 00:00:00', 15.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-19 00:00:00', 15.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-20 00:00:00', 16.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-21 00:00:00', 18.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-22 00:00:00', 14.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-23 00:00:00', 17.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-24 00:00:00', 16.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-25 00:00:00', 19.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-26 00:00:00', 18.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-27 00:00:00', 12.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-28 00:00:00', 16.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-29 00:00:00', 9.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-04-30 00:00:00', 9.29199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-01 00:00:00', 13.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-02 00:00:00', 17.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-03 00:00:00', 16.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-04 00:00:00', 14.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-05 00:00:00', 19.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-06 00:00:00', 22.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-07 00:00:00', 24.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-08 00:00:00', 19.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-09 00:00:00', 22.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-10 00:00:00', 21.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-11 00:00:00', 18.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-12 00:00:00', 22.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-13 00:00:00', 20.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-14 00:00:00', 23.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-15 00:00:00', 23.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-16 00:00:00', 23.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-17 00:00:00', 22.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-18 00:00:00', 24.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-19 00:00:00', 21.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-20 00:00:00', 23.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-21 00:00:00', 23.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-22 00:00:00', 21.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-23 00:00:00', 22.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-24 00:00:00', 23.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-25 00:00:00', 25.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-26 00:00:00', 25.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-27 00:00:00', 25.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-28 00:00:00', 23.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-29 00:00:00', 23.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-30 00:00:00', 20.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-05-31 00:00:00', 17.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-01 00:00:00', 18.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-02 00:00:00', 20.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-03 00:00:00', 22.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-04 00:00:00', 23.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-05 00:00:00', 23.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-06 00:00:00', 24.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-07 00:00:00', 22.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-08 00:00:00', 23.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-09 00:00:00', 21.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-10 00:00:00', 23.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-11 00:00:00', 26.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-12 00:00:00', 27.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-13 00:00:00', 29.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-14 00:00:00', 27.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-15 00:00:00', 25.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-16 00:00:00', 25.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-17 00:00:00', 24.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-18 00:00:00', 24.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-19 00:00:00', 27.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-20 00:00:00', 27.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-21 00:00:00', 28.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-22 00:00:00', 30.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-23 00:00:00', 31.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-24 00:00:00', 32.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-25 00:00:00', 32.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-26 00:00:00', 33.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-27 00:00:00', 31.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-28 00:00:00', 32.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-29 00:00:00', 32.9199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-06-30 00:00:00', 33.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-01 00:00:00', 31.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-02 00:00:00', 27.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-03 00:00:00', 25.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-04 00:00:00', 26.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-05 00:00:00', 27.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-06 00:00:00', 26.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-07 00:00:00', 24.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-08 00:00:00', 27.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-09 00:00:00', 28.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-10 00:00:00', 29.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-11 00:00:00', 29.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-12 00:00:00', 30.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-13 00:00:00', 30.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-14 00:00:00', 30.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-15 00:00:00', 32.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-16 00:00:00', 31.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-17 00:00:00', 32.28900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-18 00:00:00', 30.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-19 00:00:00', 27.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-20 00:00:00', 30.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-21 00:00:00', 33.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-22 00:00:00', 37.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-23 00:00:00', 35.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-24 00:00:00', 36.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-25 00:00:00', 35.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-26 00:00:00', 31.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-27 00:00:00', 31.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-28 00:00:00', 37.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-29 00:00:00', 38.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-30 00:00:00', 38.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-07-31 00:00:00', 38.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-01 00:00:00', 36.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-02 00:00:00', 33.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-03 00:00:00', 34.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-04 00:00:00', 35.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-05 00:00:00', 34.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-06 00:00:00', 33.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-07 00:00:00', 30.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-08 00:00:00', 29.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-09 00:00:00', 28.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-10 00:00:00', 28.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-11 00:00:00', 29.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-12 00:00:00', 29.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-13 00:00:00', 31.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-14 00:00:00', 31.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-15 00:00:00', 33.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-16 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-17 00:00:00', 33.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-18 00:00:00', 32.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-19 00:00:00', 33.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-20 00:00:00', 32.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-21 00:00:00', 32.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-22 00:00:00', 31.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-23 00:00:00', 33.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-24 00:00:00', 33.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-25 00:00:00', 32.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-26 00:00:00', 29.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-27 00:00:00', 26.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-28 00:00:00', 29.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-29 00:00:00', 32.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-30 00:00:00', 34.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-08-31 00:00:00', 34.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-01 00:00:00', 22.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-03 00:00:00', 19.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-05 00:00:00', 21.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-07 00:00:00', 21.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-09 00:00:00', 21.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-11 00:00:00', 24.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-13 00:00:00', 21.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-15 00:00:00', 18.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-17 00:00:00', 17.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-19 00:00:00', 18.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-21 00:00:00', 20.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-23 00:00:00', 20.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-25 00:00:00', 18.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-27 00:00:00', 11.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-29 00:00:00', 14.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-01 00:00:00', 17.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-03 00:00:00', 9.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-05 00:00:00', 13.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-07 00:00:00', 14.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-09 00:00:00', 11.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-11 00:00:00', 9.81999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-13 00:00:00', 14.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-15 00:00:00', 15.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-17 00:00:00', 14.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-19 00:00:00', 13.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-21 00:00:00', 14.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-23 00:00:00', 11.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-25 00:00:00', 16.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-27 00:00:00', 17.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-29 00:00:00', 13.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-30 00:00:00', 15.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-10-31 00:00:00', 16.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-01 00:00:00', 17.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-02 00:00:00', 15.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-03 00:00:00', 11.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-04 00:00:00', 8.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-05 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-06 00:00:00', 7.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-07 00:00:00', 12.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-08 00:00:00', 12.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-09 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-10 00:00:00', 11.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-11 00:00:00', 13.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-12 00:00:00', 13.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-13 00:00:00', 15.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-14 00:00:00', 15.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-15 00:00:00', 15.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-16 00:00:00', 13.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-17 00:00:00', 9.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-18 00:00:00', 11.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-19 00:00:00', 13.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-20 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-21 00:00:00', 12.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-22 00:00:00', 13.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-23 00:00:00', 14.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-24 00:00:00', 13.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-25 00:00:00', 12.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-26 00:00:00', 6.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-27 00:00:00', 7.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-28 00:00:00', 9.72099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-29 00:00:00', 12.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-11-30 00:00:00', 11.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-01 00:00:00', 11.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-02 00:00:00', 10.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-03 00:00:00', 8.01299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-04 00:00:00', 3.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-05 00:00:00', 5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-06 00:00:00', 5.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-07 00:00:00', 7.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-08 00:00:00', 8.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-09 00:00:00', 9.47799968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-10 00:00:00', 6.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-11 00:00:00', 8.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-12 00:00:00', 8.98700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-13 00:00:00', 10.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-14 00:00:00', 5.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-15 00:00:00', 6.10699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-16 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-17 00:00:00', -2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-18 00:00:00', -3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-19 00:00:00', -0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-20 00:00:00', -0.666000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-21 00:00:00', -0.972999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-22 00:00:00', -2.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-23 00:00:00', -0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-24 00:00:00', -0.888000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-25 00:00:00', -2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-26 00:00:00', -1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-27 00:00:00', 3.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-28 00:00:00', 4.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-29 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-30 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1983-12-31 00:00:00', -0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-01 00:00:00', -2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-02 00:00:00', 4.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-03 00:00:00', 0.00600000005215406418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-04 00:00:00', 0.115999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-05 00:00:00', -3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-06 00:00:00', -0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-07 00:00:00', 2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-08 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-09 00:00:00', 2.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-10 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-11 00:00:00', 2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-12 00:00:00', 1.06799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-13 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-14 00:00:00', 2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-15 00:00:00', -0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-16 00:00:00', -0.856999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-17 00:00:00', -0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-18 00:00:00', -2.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-19 00:00:00', -2.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-20 00:00:00', -0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-21 00:00:00', -3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-22 00:00:00', -3.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-23 00:00:00', -1.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-24 00:00:00', -0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-25 00:00:00', -2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-26 00:00:00', -0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-27 00:00:00', -3.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-28 00:00:00', -0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-29 00:00:00', 1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-30 00:00:00', 5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-01-31 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-01 00:00:00', -3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-02 00:00:00', -0.758000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-03 00:00:00', -4.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-04 00:00:00', -6.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-05 00:00:00', -3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-06 00:00:00', -5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-07 00:00:00', -8.53199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-08 00:00:00', -3.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-09 00:00:00', 0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-10 00:00:00', -2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-11 00:00:00', -3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-12 00:00:00', -2.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-13 00:00:00', 0.967000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-14 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-15 00:00:00', -0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-16 00:00:00', -3.56100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-17 00:00:00', -5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-18 00:00:00', -8.13099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-19 00:00:00', -9.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-20 00:00:00', -10.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-21 00:00:00', -9.00100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-22 00:00:00', -5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-23 00:00:00', -4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-24 00:00:00', -0.500999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-25 00:00:00', -1.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-26 00:00:00', -3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-27 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-28 00:00:00', 0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-02-29 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-01 00:00:00', 0.864000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-02 00:00:00', 5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-03 00:00:00', 4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-04 00:00:00', 1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-05 00:00:00', -1.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-06 00:00:00', 2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-07 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-08 00:00:00', 3.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-09 00:00:00', 3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-10 00:00:00', 0.804000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-11 00:00:00', -0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-12 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-13 00:00:00', 9.36400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-14 00:00:00', 8.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-15 00:00:00', 9.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-16 00:00:00', 8.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-17 00:00:00', 9.67300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-18 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-19 00:00:00', 9.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-20 00:00:00', 11.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-21 00:00:00', 12.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-22 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-23 00:00:00', 15.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-24 00:00:00', 15.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-25 00:00:00', 10.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-26 00:00:00', 13.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-27 00:00:00', 9.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-28 00:00:00', 8.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-29 00:00:00', 9.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-30 00:00:00', 11.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-03-31 00:00:00', 9.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-01 00:00:00', 11.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-02 00:00:00', 10.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-03 00:00:00', 9.59099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-04 00:00:00', 8.74899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-05 00:00:00', 9.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-06 00:00:00', 10.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-07 00:00:00', 9.64299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-08 00:00:00', 9.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-09 00:00:00', 10.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-10 00:00:00', 13.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-11 00:00:00', 16.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-12 00:00:00', 17.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-13 00:00:00', 12.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-14 00:00:00', 11.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-15 00:00:00', 13.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-16 00:00:00', 17.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-17 00:00:00', 19.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-18 00:00:00', 20.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-19 00:00:00', 11.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-20 00:00:00', 12.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-21 00:00:00', 15.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-22 00:00:00', 19.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-23 00:00:00', 22.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-24 00:00:00', 21.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-25 00:00:00', 22.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-26 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-27 00:00:00', 14.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-28 00:00:00', 15.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-29 00:00:00', 15.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-04-30 00:00:00', 17.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-01 00:00:00', 17.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-02 00:00:00', 22.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-03 00:00:00', 13.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-04 00:00:00', 17.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-05 00:00:00', 21.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-06 00:00:00', 19.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-07 00:00:00', 17.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-08 00:00:00', 14.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-09 00:00:00', 18.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-10 00:00:00', 20.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-11 00:00:00', 18.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-12 00:00:00', 15.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-13 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-14 00:00:00', 15.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-15 00:00:00', 16.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-16 00:00:00', 15.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-17 00:00:00', 19.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-18 00:00:00', 20.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-19 00:00:00', 19.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-20 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-21 00:00:00', 21.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-22 00:00:00', 23.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-23 00:00:00', 20.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-24 00:00:00', 22.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-25 00:00:00', 23.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-26 00:00:00', 26.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-27 00:00:00', 26.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-28 00:00:00', 25.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-29 00:00:00', 28.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-30 00:00:00', 30.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-05-31 00:00:00', 31.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-01 00:00:00', 27.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-02 00:00:00', 26.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-03 00:00:00', 25.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-04 00:00:00', 27.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-05 00:00:00', 27.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-06 00:00:00', 26.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-07 00:00:00', 27.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-08 00:00:00', 28.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-09 00:00:00', 28.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-10 00:00:00', 28.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-11 00:00:00', 25.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-12 00:00:00', 29.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-13 00:00:00', 30.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-14 00:00:00', 28.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-15 00:00:00', 31.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-16 00:00:00', 28.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-17 00:00:00', 25.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-18 00:00:00', 24.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-19 00:00:00', 25.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-20 00:00:00', 25.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-21 00:00:00', 28.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-22 00:00:00', 32.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-23 00:00:00', 33.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-24 00:00:00', 34.9480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-25 00:00:00', 34.3289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-26 00:00:00', 33.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-27 00:00:00', 31.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-28 00:00:00', 28.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-29 00:00:00', 28.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-06-30 00:00:00', 28.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-01 00:00:00', 26.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-02 00:00:00', 30.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-03 00:00:00', 29.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-04 00:00:00', 31.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-05 00:00:00', 33.3429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-06 00:00:00', 32.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-07 00:00:00', 32.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-08 00:00:00', 30.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-09 00:00:00', 33.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-10 00:00:00', 32.3440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-11 00:00:00', 33.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-12 00:00:00', 34.1780014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-13 00:00:00', 35.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-14 00:00:00', 34.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-15 00:00:00', 34.4280014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-16 00:00:00', 32.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-17 00:00:00', 33.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-18 00:00:00', 33.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-19 00:00:00', 32.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-20 00:00:00', 32.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-21 00:00:00', 30.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-22 00:00:00', 31.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-23 00:00:00', 33.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-24 00:00:00', 33.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-25 00:00:00', 31.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-26 00:00:00', 33.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-27 00:00:00', 32.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-28 00:00:00', 33.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-29 00:00:00', 33.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-30 00:00:00', 32.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-07-31 00:00:00', 32.1020011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-01 00:00:00', 35.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-02 00:00:00', 35.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-03 00:00:00', 34.983001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-04 00:00:00', 35.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-05 00:00:00', 34.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-06 00:00:00', 32.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-07 00:00:00', 33.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-08 00:00:00', 34.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-09 00:00:00', 35.08599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-10 00:00:00', 33.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-11 00:00:00', 34.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-12 00:00:00', 32.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-13 00:00:00', 30.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-14 00:00:00', 32.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-15 00:00:00', 31.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-16 00:00:00', 33.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-17 00:00:00', 34.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-18 00:00:00', 35.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-19 00:00:00', 36.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-20 00:00:00', 37.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-21 00:00:00', 34.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-22 00:00:00', 32.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-23 00:00:00', 33.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-24 00:00:00', 34.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-25 00:00:00', 32.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-26 00:00:00', 31.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-27 00:00:00', 32.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-28 00:00:00', 32.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-29 00:00:00', 33.4739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-30 00:00:00', 33.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-08-31 00:00:00', 32.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-01 00:00:00', 29.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-02 00:00:00', 27.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-03 00:00:00', 27.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-04 00:00:00', 27.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-05 00:00:00', 25.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-06 00:00:00', 22.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-07 00:00:00', 20.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-08 00:00:00', 22.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-09 00:00:00', 24.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-10 00:00:00', 26.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-11 00:00:00', 26.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-12 00:00:00', 26.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-13 00:00:00', 25.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-14 00:00:00', 24.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-15 00:00:00', 24.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-16 00:00:00', 25.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-17 00:00:00', 24.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-18 00:00:00', 22.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-19 00:00:00', 17.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-20 00:00:00', 19.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-21 00:00:00', 21.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-22 00:00:00', 19.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-23 00:00:00', 20.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-24 00:00:00', 20.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-25 00:00:00', 21.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-26 00:00:00', 21.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-27 00:00:00', 20.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-28 00:00:00', 22.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-29 00:00:00', 23.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-09-30 00:00:00', 21.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-01 00:00:00', 20.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-02 00:00:00', 19.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-03 00:00:00', 19.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-04 00:00:00', 18.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-05 00:00:00', 18.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-06 00:00:00', 18.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-07 00:00:00', 18.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-08 00:00:00', 12.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-09 00:00:00', 8.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-10 00:00:00', 14.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-11 00:00:00', 15.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-12 00:00:00', 13.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-13 00:00:00', 11.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-14 00:00:00', 15.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-15 00:00:00', 16.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-16 00:00:00', 17.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-17 00:00:00', 18.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-18 00:00:00', 17.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-19 00:00:00', 20.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-20 00:00:00', 23.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-21 00:00:00', 13.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-22 00:00:00', 6.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-23 00:00:00', 12.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-24 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-25 00:00:00', 12.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-26 00:00:00', 11.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-27 00:00:00', 10.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-28 00:00:00', 9.79199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-29 00:00:00', 8.50100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-30 00:00:00', 10.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-10-31 00:00:00', 13.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-01 00:00:00', 12.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-02 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-03 00:00:00', 14.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-04 00:00:00', 10.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-05 00:00:00', 15.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-06 00:00:00', 13.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-07 00:00:00', 13.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-08 00:00:00', 10.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-09 00:00:00', 7.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-10 00:00:00', 9.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-11 00:00:00', 8.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-12 00:00:00', 10.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-13 00:00:00', 7.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-14 00:00:00', 8.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-15 00:00:00', 6.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-16 00:00:00', 6.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-17 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-18 00:00:00', 5.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-19 00:00:00', 5.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-20 00:00:00', 5.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-21 00:00:00', 5.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-22 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-23 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-24 00:00:00', 6.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-25 00:00:00', 7.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-26 00:00:00', 8.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-27 00:00:00', 4.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-28 00:00:00', 8.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-29 00:00:00', 8.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-11-30 00:00:00', 6.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-01 00:00:00', 0.612999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-02 00:00:00', -2.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-03 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-04 00:00:00', 3.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-05 00:00:00', -0.472999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-06 00:00:00', -0.753000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-07 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-08 00:00:00', 0.973999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-09 00:00:00', -0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-10 00:00:00', 0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-11 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-12 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-13 00:00:00', -0.453999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-14 00:00:00', 2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-15 00:00:00', 1.79799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-16 00:00:00', -0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-17 00:00:00', -0.995000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-18 00:00:00', -1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-19 00:00:00', -3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-20 00:00:00', -2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-21 00:00:00', -7.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-22 00:00:00', -6.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-23 00:00:00', -3.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-24 00:00:00', -4.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-25 00:00:00', -4.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-26 00:00:00', -5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-27 00:00:00', -2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-28 00:00:00', -2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-29 00:00:00', -2.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-30 00:00:00', -4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1984-12-31 00:00:00', -3.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-01 00:00:00', -5.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-02 00:00:00', -2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-03 00:00:00', -0.902000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-04 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-05 00:00:00', -0.763999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-06 00:00:00', -1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-07 00:00:00', 1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-08 00:00:00', 1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-09 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-10 00:00:00', 3.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-11 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-12 00:00:00', 4.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-13 00:00:00', 3.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-14 00:00:00', -0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-15 00:00:00', -0.861000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-16 00:00:00', -1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-17 00:00:00', -0.194000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-18 00:00:00', -0.973999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-19 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-20 00:00:00', -0.601999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-21 00:00:00', 1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-22 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-23 00:00:00', 4.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-24 00:00:00', 4.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-25 00:00:00', 0.317000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-26 00:00:00', 0.586000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-27 00:00:00', 3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-28 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-29 00:00:00', 2.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-30 00:00:00', 5.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-01-31 00:00:00', 6.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-01 00:00:00', 1.78199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-02 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-03 00:00:00', 4.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-04 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-05 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-06 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-07 00:00:00', 1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-08 00:00:00', -2.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-09 00:00:00', 2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-10 00:00:00', 2.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-11 00:00:00', 0.728999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-12 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-13 00:00:00', 8.56999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-14 00:00:00', 8.34799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-15 00:00:00', 8.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-16 00:00:00', 10.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-17 00:00:00', 12.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-18 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-19 00:00:00', 6.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-20 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-21 00:00:00', 8.63300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-22 00:00:00', 10.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-23 00:00:00', 5.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-24 00:00:00', 1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-25 00:00:00', 4.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-26 00:00:00', 9.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-27 00:00:00', 12.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-02-28 00:00:00', 3.00200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-01 00:00:00', 5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-02 00:00:00', 6.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-03 00:00:00', 4.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-04 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-05 00:00:00', -0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-06 00:00:00', -2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-07 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-08 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-09 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-10 00:00:00', -0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-11 00:00:00', -0.876999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-12 00:00:00', -0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-13 00:00:00', 4.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-14 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-15 00:00:00', 2.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-16 00:00:00', 6.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-17 00:00:00', 6.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-18 00:00:00', 8.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-19 00:00:00', 11.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-20 00:00:00', 12.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-21 00:00:00', 11.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-22 00:00:00', 14.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-23 00:00:00', 11.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-24 00:00:00', 10.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-25 00:00:00', 9.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-26 00:00:00', 6.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-27 00:00:00', 9.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-28 00:00:00', 12.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-29 00:00:00', 10.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-30 00:00:00', 11.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-03-31 00:00:00', 15.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-01 00:00:00', 18.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-02 00:00:00', 12.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-03 00:00:00', 11.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-04 00:00:00', 11.508000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-05 00:00:00', 10.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-06 00:00:00', 10.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-07 00:00:00', 7.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-08 00:00:00', 10.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-09 00:00:00', 10.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-10 00:00:00', 12.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-11 00:00:00', 15.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-12 00:00:00', 13.3660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-13 00:00:00', 13.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-14 00:00:00', 14.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-15 00:00:00', 17.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-16 00:00:00', 18.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-17 00:00:00', 8.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-18 00:00:00', 12.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-19 00:00:00', 18.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-20 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-21 00:00:00', 19.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-22 00:00:00', 22.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-23 00:00:00', 20.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-24 00:00:00', 22.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-25 00:00:00', 23.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-26 00:00:00', 24.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-27 00:00:00', 23.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-28 00:00:00', 21.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-29 00:00:00', 22.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-04-30 00:00:00', 15.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-01 00:00:00', 14.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-02 00:00:00', 13.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-03 00:00:00', 17.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-04 00:00:00', 18.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-05 00:00:00', 20.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-06 00:00:00', 21.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-07 00:00:00', 19.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-08 00:00:00', 17.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-09 00:00:00', 18.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-10 00:00:00', 17.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-11 00:00:00', 17.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-12 00:00:00', 18.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-13 00:00:00', 17.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-14 00:00:00', 18.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-15 00:00:00', 19.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-16 00:00:00', 21.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-17 00:00:00', 23.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-18 00:00:00', 25.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-19 00:00:00', 27.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-20 00:00:00', 23.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-21 00:00:00', 24.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-22 00:00:00', 26.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-23 00:00:00', 23.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-24 00:00:00', 19.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-25 00:00:00', 18.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-26 00:00:00', 20.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-27 00:00:00', 23.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-28 00:00:00', 24.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-29 00:00:00', 25.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-30 00:00:00', 23.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-05-31 00:00:00', 25.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-01 00:00:00', 25.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-02 00:00:00', 25.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-03 00:00:00', 25.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-04 00:00:00', 29.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-05 00:00:00', 28.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-06 00:00:00', 27.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-07 00:00:00', 26.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-08 00:00:00', 27.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-09 00:00:00', 27.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-10 00:00:00', 25.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-11 00:00:00', 24.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-12 00:00:00', 27.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-13 00:00:00', 28.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-14 00:00:00', 27.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-15 00:00:00', 30.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-16 00:00:00', 30.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-17 00:00:00', 29.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-18 00:00:00', 28.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-19 00:00:00', 28.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-20 00:00:00', 29.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-21 00:00:00', 29.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-22 00:00:00', 30.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-23 00:00:00', 32.5050010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-24 00:00:00', 30.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-25 00:00:00', 31.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-26 00:00:00', 32.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-27 00:00:00', 32.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-28 00:00:00', 30.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-29 00:00:00', 30.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-06-30 00:00:00', 30.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-01 00:00:00', 29.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-02 00:00:00', 31.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-03 00:00:00', 32.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-04 00:00:00', 34.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-05 00:00:00', 34.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-06 00:00:00', 34.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-07 00:00:00', 31.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-08 00:00:00', 31.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-09 00:00:00', 34.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-10 00:00:00', 36.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-11 00:00:00', 34.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-12 00:00:00', 33.7400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-13 00:00:00', 31.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-14 00:00:00', 31.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-15 00:00:00', 34.4199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-16 00:00:00', 35.6339988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-17 00:00:00', 33.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-18 00:00:00', 28.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-19 00:00:00', 28.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-20 00:00:00', 32.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-21 00:00:00', 33.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-22 00:00:00', 34.4910011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-23 00:00:00', 34.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-24 00:00:00', 33.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-25 00:00:00', 32.4329986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-26 00:00:00', 33.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-27 00:00:00', 33.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-28 00:00:00', 35.1619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-29 00:00:00', 35.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-30 00:00:00', 31.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-07-31 00:00:00', 29.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-01 00:00:00', 30.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-02 00:00:00', 26.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-03 00:00:00', 30.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-04 00:00:00', 31.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-05 00:00:00', 30.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-06 00:00:00', 31.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-07 00:00:00', 30.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-08 00:00:00', 30.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-09 00:00:00', 28.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-10 00:00:00', 28.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-11 00:00:00', 27.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-12 00:00:00', 27.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-13 00:00:00', 29.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-14 00:00:00', 29.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-15 00:00:00', 27.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-16 00:00:00', 28.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-17 00:00:00', 28.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-18 00:00:00', 28.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-19 00:00:00', 27.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-20 00:00:00', 28.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-21 00:00:00', 28.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-22 00:00:00', 28.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-23 00:00:00', 29.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-24 00:00:00', 28.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-25 00:00:00', 27.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-26 00:00:00', 26.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-27 00:00:00', 25.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-28 00:00:00', 25.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-29 00:00:00', 23.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-30 00:00:00', 23.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-08-31 00:00:00', 24.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-01 00:00:00', 26.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-02 00:00:00', 28.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-03 00:00:00', 28.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-04 00:00:00', 26.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-05 00:00:00', 24.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-06 00:00:00', 24.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-07 00:00:00', 25.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-08 00:00:00', 25.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-09 00:00:00', 25.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-10 00:00:00', 26.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-11 00:00:00', 26.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-12 00:00:00', 26.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-13 00:00:00', 25.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-14 00:00:00', 26.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-15 00:00:00', 26.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-16 00:00:00', 26.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-17 00:00:00', 26.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-18 00:00:00', 22.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-19 00:00:00', 23.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-20 00:00:00', 26.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-21 00:00:00', 26.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-22 00:00:00', 23.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-23 00:00:00', 23.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-24 00:00:00', 24.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-25 00:00:00', 24.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-26 00:00:00', 24.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-27 00:00:00', 23.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-28 00:00:00', 25.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-29 00:00:00', 24.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-09-30 00:00:00', 26.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-01 00:00:00', 27.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-02 00:00:00', 23.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-03 00:00:00', 19.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-04 00:00:00', 21.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-05 00:00:00', 14.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-06 00:00:00', 16.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-07 00:00:00', 16.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-08 00:00:00', 18.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-09 00:00:00', 15.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-10 00:00:00', 16.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-11 00:00:00', 16.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-12 00:00:00', 9.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-13 00:00:00', 12.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-14 00:00:00', 11.324000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-15 00:00:00', 11.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-16 00:00:00', 12.9429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-17 00:00:00', 13.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-18 00:00:00', 15.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-19 00:00:00', 17.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-20 00:00:00', 17.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-21 00:00:00', 19.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-22 00:00:00', 14.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-23 00:00:00', 8.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-24 00:00:00', 12.7650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-25 00:00:00', 9.96300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-26 00:00:00', 11.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-27 00:00:00', 12.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-28 00:00:00', 14.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-29 00:00:00', 12.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-30 00:00:00', 14.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-10-31 00:00:00', 9.77499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-01 00:00:00', 7.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-02 00:00:00', 12.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-03 00:00:00', 14.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-04 00:00:00', 13.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-05 00:00:00', 12.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-06 00:00:00', 11.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-07 00:00:00', 12.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-08 00:00:00', 11.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-09 00:00:00', 9.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-10 00:00:00', 8.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-11 00:00:00', 9.75599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-12 00:00:00', 10.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-13 00:00:00', 13.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-14 00:00:00', 13.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-15 00:00:00', 13.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-16 00:00:00', 11.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-17 00:00:00', 10.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-18 00:00:00', 8.71800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-19 00:00:00', 4.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-20 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-21 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-22 00:00:00', 5.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-23 00:00:00', 6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-24 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-25 00:00:00', 3.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-26 00:00:00', 5.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-27 00:00:00', 7.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-28 00:00:00', 7.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-29 00:00:00', 7.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-11-30 00:00:00', 9.37899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-01 00:00:00', 8.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-02 00:00:00', 11.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-03 00:00:00', 12.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-04 00:00:00', 9.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-05 00:00:00', 10.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-06 00:00:00', 4.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-07 00:00:00', -1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-08 00:00:00', -2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-09 00:00:00', -2.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-10 00:00:00', 1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-11 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-12 00:00:00', 7.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-13 00:00:00', 6.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-14 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-15 00:00:00', 0.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-16 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-17 00:00:00', 4.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-18 00:00:00', 2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-19 00:00:00', 5.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-20 00:00:00', 9.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-21 00:00:00', 8.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-22 00:00:00', 7.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-23 00:00:00', 4.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-24 00:00:00', 4.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-25 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-26 00:00:00', 1.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-27 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-28 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-29 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-30 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1985-12-31 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-01 00:00:00', 0.980000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-02 00:00:00', 2.47600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-03 00:00:00', 3.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-04 00:00:00', 5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-05 00:00:00', 7.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-06 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-07 00:00:00', 6.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-08 00:00:00', 6.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-09 00:00:00', 5.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-10 00:00:00', 6.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-11 00:00:00', 3.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-12 00:00:00', 4.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-13 00:00:00', 3.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-14 00:00:00', 3.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-15 00:00:00', 5.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-16 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-17 00:00:00', 2.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-18 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-19 00:00:00', 6.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-20 00:00:00', 6.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-21 00:00:00', 8.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-22 00:00:00', 4.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-23 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-24 00:00:00', -0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-25 00:00:00', -3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-26 00:00:00', -1.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-27 00:00:00', -0.523000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-28 00:00:00', -1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-29 00:00:00', -3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-30 00:00:00', -1.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-01-31 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-01 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-02 00:00:00', 6.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-03 00:00:00', -0.193000003695487976, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-04 00:00:00', 2.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-05 00:00:00', 6.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-06 00:00:00', 5.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-07 00:00:00', 9.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-08 00:00:00', 6.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-09 00:00:00', 4.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-10 00:00:00', 5.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-11 00:00:00', 8.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-12 00:00:00', 2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-13 00:00:00', -0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-14 00:00:00', -0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-15 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-16 00:00:00', 3.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-17 00:00:00', 1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-18 00:00:00', -0.42300000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-19 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-20 00:00:00', 3.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-21 00:00:00', 5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-22 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-23 00:00:00', 5.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-24 00:00:00', 7.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-25 00:00:00', 7.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-26 00:00:00', 9.96800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-27 00:00:00', 11.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-02-28 00:00:00', 11.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-01 00:00:00', 10.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-02 00:00:00', 12.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-03 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-04 00:00:00', 6.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-05 00:00:00', 5.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-06 00:00:00', 9.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-07 00:00:00', 14.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-08 00:00:00', 14.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-09 00:00:00', 15.4110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-10 00:00:00', 10.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-11 00:00:00', 7.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-12 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-13 00:00:00', 3.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-14 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-15 00:00:00', 0.566999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-16 00:00:00', -0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-17 00:00:00', -0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-18 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-19 00:00:00', 5.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-20 00:00:00', 5.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-21 00:00:00', 6.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-22 00:00:00', 7.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-23 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-24 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-25 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-26 00:00:00', 5.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-27 00:00:00', 8.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-28 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-29 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-30 00:00:00', 1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-03-31 00:00:00', 2.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-01 00:00:00', 7.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-02 00:00:00', 10.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-03 00:00:00', 12.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-04 00:00:00', 15.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-05 00:00:00', 14.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-06 00:00:00', 15.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-07 00:00:00', 14.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-08 00:00:00', 15.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-09 00:00:00', 16.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-10 00:00:00', 16.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-11 00:00:00', 18.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-12 00:00:00', 15.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-13 00:00:00', 18.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-14 00:00:00', 15.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-15 00:00:00', 16.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-16 00:00:00', 15.9289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-17 00:00:00', 19.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-18 00:00:00', 20.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-19 00:00:00', 18.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-20 00:00:00', 20.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-21 00:00:00', 19.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-22 00:00:00', 10.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-23 00:00:00', 11.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-24 00:00:00', 14.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-25 00:00:00', 12.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-26 00:00:00', 12.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-27 00:00:00', 12.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-28 00:00:00', 13.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-29 00:00:00', 13.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-04-30 00:00:00', 14.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-01 00:00:00', 20.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-02 00:00:00', 18.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-03 00:00:00', 21.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-04 00:00:00', 22.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-05 00:00:00', 29.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-06 00:00:00', 28.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-07 00:00:00', 24.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-08 00:00:00', 24.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-09 00:00:00', 22.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-10 00:00:00', 25.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-11 00:00:00', 26.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-12 00:00:00', 22.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-13 00:00:00', 23.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-14 00:00:00', 26.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-15 00:00:00', 24.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-16 00:00:00', 21.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-17 00:00:00', 18.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-18 00:00:00', 15.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-19 00:00:00', 15.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-20 00:00:00', 17.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-21 00:00:00', 18.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-22 00:00:00', 19.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-23 00:00:00', 23.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-24 00:00:00', 26.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-25 00:00:00', 25.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-26 00:00:00', 22.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-27 00:00:00', 23.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-28 00:00:00', 23.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-29 00:00:00', 21.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-30 00:00:00', 12.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-01 00:00:00', 22.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-02 00:00:00', 22.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-03 00:00:00', 23.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-04 00:00:00', 21.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-05 00:00:00', 23.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-06 00:00:00', 25.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-07 00:00:00', 25.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-08 00:00:00', 27.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-09 00:00:00', 26.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-10 00:00:00', 27.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-11 00:00:00', 24.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-12 00:00:00', 26.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-13 00:00:00', 25.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-14 00:00:00', 26.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-15 00:00:00', 25.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-16 00:00:00', 25.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-17 00:00:00', 27.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-18 00:00:00', 31.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-19 00:00:00', 33.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-20 00:00:00', 29.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-21 00:00:00', 31.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-22 00:00:00', 31.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-23 00:00:00', 31.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-24 00:00:00', 30.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-25 00:00:00', 29.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-26 00:00:00', 29.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-27 00:00:00', 29.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-28 00:00:00', 29.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-29 00:00:00', 30.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-06-30 00:00:00', 31.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-01 00:00:00', 32.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-02 00:00:00', 34.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-03 00:00:00', 35.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-04 00:00:00', 33.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-05 00:00:00', 32.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-06 00:00:00', 32.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-07 00:00:00', 31.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-08 00:00:00', 29.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-09 00:00:00', 28.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-10 00:00:00', 30.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-11 00:00:00', 30.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-12 00:00:00', 31.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-13 00:00:00', 31.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-14 00:00:00', 33.5810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-15 00:00:00', 34.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-16 00:00:00', 34.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-17 00:00:00', 33.9970016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-18 00:00:00', 34.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-19 00:00:00', 32.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-20 00:00:00', 31.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-21 00:00:00', 30.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-22 00:00:00', 24.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-23 00:00:00', 26.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-24 00:00:00', 26.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-25 00:00:00', 29.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-26 00:00:00', 30.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-27 00:00:00', 31.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-28 00:00:00', 32.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-29 00:00:00', 32.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-30 00:00:00', 33.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-07-31 00:00:00', 34.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-01 00:00:00', 35.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-02 00:00:00', 34.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-03 00:00:00', 35.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-04 00:00:00', 33.8629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-05 00:00:00', 28.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-06 00:00:00', 27.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-07 00:00:00', 29.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-08 00:00:00', 24.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-09 00:00:00', 27.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-10 00:00:00', 27.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-11 00:00:00', 28.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-12 00:00:00', 30.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-13 00:00:00', 29.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-14 00:00:00', 31.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-15 00:00:00', 33.6559982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-16 00:00:00', 33.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-17 00:00:00', 31.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-18 00:00:00', 31.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-19 00:00:00', 29.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-20 00:00:00', 27.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-21 00:00:00', 26.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-22 00:00:00', 26.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-23 00:00:00', 27.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-24 00:00:00', 28.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-25 00:00:00', 28.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-26 00:00:00', 28.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-27 00:00:00', 27.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-28 00:00:00', 27.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-29 00:00:00', 26.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-30 00:00:00', 26.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-08-31 00:00:00', 23.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-01 00:00:00', 27.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-02 00:00:00', 29.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-03 00:00:00', 27.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-04 00:00:00', 26.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-05 00:00:00', 26.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-06 00:00:00', 26.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-07 00:00:00', 27.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-08 00:00:00', 26.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-09 00:00:00', 26.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-10 00:00:00', 25.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-11 00:00:00', 25.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-12 00:00:00', 25.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-13 00:00:00', 24.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-14 00:00:00', 23.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-15 00:00:00', 24.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-16 00:00:00', 25.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-17 00:00:00', 26.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-18 00:00:00', 25.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-19 00:00:00', 25.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-20 00:00:00', 22.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-21 00:00:00', 22.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-22 00:00:00', 24.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-23 00:00:00', 25.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-24 00:00:00', 27.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-25 00:00:00', 28.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-26 00:00:00', 27.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-27 00:00:00', 26.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-28 00:00:00', 25.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-29 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-09-30 00:00:00', 19.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-01 00:00:00', 19.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-02 00:00:00', 22.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-03 00:00:00', 23.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-04 00:00:00', 21.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-05 00:00:00', 24.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-06 00:00:00', 25.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-07 00:00:00', 24.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-08 00:00:00', 19.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-09 00:00:00', 19.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-10 00:00:00', 20.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-11 00:00:00', 22.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-12 00:00:00', 20.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-13 00:00:00', 17.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-14 00:00:00', 15.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-15 00:00:00', 9.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-16 00:00:00', 8.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-17 00:00:00', 10.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-18 00:00:00', 10.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-19 00:00:00', 12.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-20 00:00:00', 14.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-21 00:00:00', 16.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-22 00:00:00', 16.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-23 00:00:00', 18.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-24 00:00:00', 18.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-25 00:00:00', 20.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-26 00:00:00', 20.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-27 00:00:00', 19.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-28 00:00:00', 17.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-29 00:00:00', 16.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-30 00:00:00', 13.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-10-31 00:00:00', 15.9469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-01 00:00:00', 15.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-02 00:00:00', 15.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-03 00:00:00', 17.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-04 00:00:00', 17.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-05 00:00:00', 18.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-06 00:00:00', 17.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-07 00:00:00', 15.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-08 00:00:00', 16.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-09 00:00:00', 15.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-10 00:00:00', 13.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-11 00:00:00', 11.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-12 00:00:00', 8.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-13 00:00:00', 3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-14 00:00:00', 5.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-15 00:00:00', 3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-16 00:00:00', 2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-17 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-18 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-19 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-20 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-21 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-22 00:00:00', -2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-23 00:00:00', 3.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-24 00:00:00', 6.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-25 00:00:00', 3.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-26 00:00:00', 2.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-27 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-28 00:00:00', 5.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-29 00:00:00', 5.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-11-30 00:00:00', 7.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-01 00:00:00', 8.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-02 00:00:00', 8.60999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-03 00:00:00', 8.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-04 00:00:00', 6.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-05 00:00:00', 5.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-06 00:00:00', 4.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-07 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-08 00:00:00', 9.06999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-09 00:00:00', 7.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-10 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-11 00:00:00', -5.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-12 00:00:00', -6.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-13 00:00:00', -7.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-14 00:00:00', -1.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-15 00:00:00', -2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-16 00:00:00', -0.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-17 00:00:00', 0.101000003516674042, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-18 00:00:00', -0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-19 00:00:00', 0.898000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-20 00:00:00', -0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-21 00:00:00', 4.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-22 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-23 00:00:00', 1.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-24 00:00:00', -2.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-01 00:00:00', 0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-02 00:00:00', 4.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-03 00:00:00', 7.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-04 00:00:00', 6.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-05 00:00:00', 7.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-06 00:00:00', 7.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-07 00:00:00', 8.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-08 00:00:00', 4.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-09 00:00:00', 6.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-10 00:00:00', 7.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-11 00:00:00', 8.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-12 00:00:00', 5.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-13 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-14 00:00:00', 5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-15 00:00:00', 2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-16 00:00:00', 0.897000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-17 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-18 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-19 00:00:00', 0.140000000596046448, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-20 00:00:00', -0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-21 00:00:00', -2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-22 00:00:00', -1.28199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-23 00:00:00', 4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-24 00:00:00', 8.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-25 00:00:00', 9.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-26 00:00:00', 8.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-27 00:00:00', 9.98200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-28 00:00:00', 8.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-29 00:00:00', 7.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-30 00:00:00', 9.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-01-31 00:00:00', 8.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-01 00:00:00', 5.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-02 00:00:00', 5.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-03 00:00:00', 5.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-04 00:00:00', 9.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-05 00:00:00', 11.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-06 00:00:00', 4.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-07 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-08 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-09 00:00:00', 7.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-10 00:00:00', 9.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-11 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-12 00:00:00', 4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-13 00:00:00', 4.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-14 00:00:00', 4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-15 00:00:00', 1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-16 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-17 00:00:00', -3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-18 00:00:00', -0.0900000035762786865, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-19 00:00:00', 6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-20 00:00:00', 7.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-21 00:00:00', 6.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-22 00:00:00', 3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-23 00:00:00', 6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-24 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-25 00:00:00', 8.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-26 00:00:00', 10.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-27 00:00:00', 10.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-02-28 00:00:00', 11.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-01 00:00:00', 10.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-02 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-03 00:00:00', 12.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-04 00:00:00', 14.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-05 00:00:00', 10.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-06 00:00:00', 8.11900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-07 00:00:00', 9.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-08 00:00:00', 10.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-09 00:00:00', 10.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-10 00:00:00', 13.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-11 00:00:00', 9.86200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-12 00:00:00', 6.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-13 00:00:00', 4.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-14 00:00:00', 11.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-15 00:00:00', 7.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-16 00:00:00', 6.05000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-17 00:00:00', 9.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-18 00:00:00', 8.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-19 00:00:00', 9.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-20 00:00:00', 10.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-21 00:00:00', 7.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-22 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-23 00:00:00', 5.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-24 00:00:00', 9.29399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-25 00:00:00', 12.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-26 00:00:00', 12.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-27 00:00:00', 10.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-28 00:00:00', 10.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-29 00:00:00', 12.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-30 00:00:00', 14.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-03-31 00:00:00', 17.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-01 00:00:00', 9.14000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-02 00:00:00', 7.07000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-03 00:00:00', 8.41399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-04 00:00:00', 11.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-05 00:00:00', 13.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-06 00:00:00', 7.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-07 00:00:00', 11.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-08 00:00:00', 5.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-09 00:00:00', 9.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-10 00:00:00', 12.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-11 00:00:00', 11.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-12 00:00:00', 14.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-13 00:00:00', 14.7650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-14 00:00:00', 12.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-15 00:00:00', 14.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-16 00:00:00', 14.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-17 00:00:00', 16.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-18 00:00:00', 16.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-19 00:00:00', 19.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-20 00:00:00', 18.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-21 00:00:00', 12.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-22 00:00:00', 10.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-23 00:00:00', 15.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-24 00:00:00', 17.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-25 00:00:00', 18.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-26 00:00:00', 20.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-27 00:00:00', 22.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-28 00:00:00', 15.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-29 00:00:00', 17.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-04-30 00:00:00', 12.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-01 00:00:00', 14.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-02 00:00:00', 16.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-03 00:00:00', 19.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-04 00:00:00', 20.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-05 00:00:00', 19.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-06 00:00:00', 19.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-07 00:00:00', 16.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-08 00:00:00', 17.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-09 00:00:00', 18.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-10 00:00:00', 20.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-11 00:00:00', 21.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-12 00:00:00', 24.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-13 00:00:00', 23.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-14 00:00:00', 25.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-15 00:00:00', 25.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-16 00:00:00', 27.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-17 00:00:00', 25.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-18 00:00:00', 21.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-19 00:00:00', 21.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-20 00:00:00', 18.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-21 00:00:00', 21.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-22 00:00:00', 19.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-23 00:00:00', 21.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-24 00:00:00', 25.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-25 00:00:00', 26.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-26 00:00:00', 28.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-27 00:00:00', 27.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-28 00:00:00', 28.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-29 00:00:00', 26.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-30 00:00:00', 24.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-05-31 00:00:00', 24.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-01 00:00:00', 25.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-02 00:00:00', 23.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-03 00:00:00', 26.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-04 00:00:00', 27.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-05 00:00:00', 29.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-06 00:00:00', 28.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-07 00:00:00', 26.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-08 00:00:00', 26.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-09 00:00:00', 21.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-10 00:00:00', 25.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-11 00:00:00', 25.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-12 00:00:00', 24.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-13 00:00:00', 24.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-14 00:00:00', 26.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-15 00:00:00', 23.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-16 00:00:00', 24.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-17 00:00:00', 26.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-18 00:00:00', 27.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-19 00:00:00', 29.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-20 00:00:00', 23.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-21 00:00:00', 21.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-22 00:00:00', 25.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-23 00:00:00', 26.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-24 00:00:00', 26.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-25 00:00:00', 28.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-26 00:00:00', 29.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-27 00:00:00', 29.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-28 00:00:00', 30.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-29 00:00:00', 30.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-06-30 00:00:00', 31.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-01 00:00:00', 30.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-02 00:00:00', 31.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-03 00:00:00', 31.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-04 00:00:00', 31.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-05 00:00:00', 24.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-06 00:00:00', 28.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-07 00:00:00', 27.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-08 00:00:00', 28.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-09 00:00:00', 29.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-10 00:00:00', 31.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-11 00:00:00', 22.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-12 00:00:00', 21.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-13 00:00:00', 21.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-14 00:00:00', 19.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-15 00:00:00', 23.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-16 00:00:00', 24.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-17 00:00:00', 27.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-18 00:00:00', 26.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-19 00:00:00', 26.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-20 00:00:00', 29.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-21 00:00:00', 30.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-22 00:00:00', 33.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-23 00:00:00', 33.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-24 00:00:00', 35.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-25 00:00:00', 28.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-26 00:00:00', 25.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-27 00:00:00', 26.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-28 00:00:00', 27.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-29 00:00:00', 26.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-30 00:00:00', 29.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-07-31 00:00:00', 22.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-01 00:00:00', 25.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-02 00:00:00', 27.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-03 00:00:00', 28.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-04 00:00:00', 30.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-05 00:00:00', 30.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-06 00:00:00', 30.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-07 00:00:00', 31.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-08 00:00:00', 30.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-09 00:00:00', 30.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-10 00:00:00', 30.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-11 00:00:00', 29.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-12 00:00:00', 31.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-13 00:00:00', 33.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-14 00:00:00', 33.0099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-15 00:00:00', 32.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-16 00:00:00', 32.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-17 00:00:00', 31.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-18 00:00:00', 32.0530014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-19 00:00:00', 32.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-20 00:00:00', 32.6269989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-21 00:00:00', 32.8930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-22 00:00:00', 32.9620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-23 00:00:00', 31.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-24 00:00:00', 31.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-25 00:00:00', 29.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-26 00:00:00', 31.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-27 00:00:00', 30.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-28 00:00:00', 30.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-29 00:00:00', 30.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-30 00:00:00', 32.8030014038085938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-08-31 00:00:00', 26.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-01 00:00:00', 27.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-02 00:00:00', 25.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-03 00:00:00', 26.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-04 00:00:00', 28.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-05 00:00:00', 30.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-06 00:00:00', 32.5460014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-07 00:00:00', 30.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-08 00:00:00', 23.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-09 00:00:00', 22.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-10 00:00:00', 21.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-11 00:00:00', 22.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-12 00:00:00', 24.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-13 00:00:00', 25.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-14 00:00:00', 27.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-15 00:00:00', 26.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-16 00:00:00', 25.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-17 00:00:00', 28.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-18 00:00:00', 26.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-19 00:00:00', 26.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-20 00:00:00', 20.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-21 00:00:00', 19.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-22 00:00:00', 23.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-23 00:00:00', 24.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-24 00:00:00', 18.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-25 00:00:00', 22.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-26 00:00:00', 22.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-27 00:00:00', 22.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-28 00:00:00', 21.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-29 00:00:00', 23.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-09-30 00:00:00', 24.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-01 00:00:00', 19.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-02 00:00:00', 20.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-03 00:00:00', 22.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-04 00:00:00', 21.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-05 00:00:00', 24.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-06 00:00:00', 21.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-07 00:00:00', 20.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-08 00:00:00', 16.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-09 00:00:00', 14.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-10 00:00:00', 9.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-11 00:00:00', 7.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-12 00:00:00', 8.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-13 00:00:00', 7.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-14 00:00:00', 8.55799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-15 00:00:00', 7.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-16 00:00:00', 10.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-17 00:00:00', 9.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-18 00:00:00', 9.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-19 00:00:00', 9.90699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-20 00:00:00', 12.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-21 00:00:00', 13.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-22 00:00:00', 14.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-23 00:00:00', 15.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-24 00:00:00', 10.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-25 00:00:00', 14.8730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-26 00:00:00', 10.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-27 00:00:00', 6.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-28 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-29 00:00:00', 0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-30 00:00:00', 6.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-10-31 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-01 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-02 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-03 00:00:00', 4.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-04 00:00:00', 9.61900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-05 00:00:00', 7.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-06 00:00:00', 9.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-07 00:00:00', 12.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-08 00:00:00', 15.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-09 00:00:00', 10.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-10 00:00:00', 10.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-11 00:00:00', 9.70400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-12 00:00:00', 9.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-13 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-14 00:00:00', 12.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-15 00:00:00', 13.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-16 00:00:00', 9.32199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-17 00:00:00', 8.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-18 00:00:00', 6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-19 00:00:00', 5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-20 00:00:00', 7.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-21 00:00:00', 7.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-22 00:00:00', 8.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-23 00:00:00', 9.48700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-24 00:00:00', 6.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-25 00:00:00', 6.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-26 00:00:00', 6.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-27 00:00:00', 1.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-28 00:00:00', 2.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-29 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-11-30 00:00:00', -2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-01 00:00:00', -2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-02 00:00:00', -3.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-03 00:00:00', -1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-04 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-05 00:00:00', 2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-06 00:00:00', 2.73900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-07 00:00:00', 3.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-08 00:00:00', 3.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-09 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-10 00:00:00', 7.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-11 00:00:00', 4.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-12 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-13 00:00:00', 6.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-14 00:00:00', 7.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-15 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-16 00:00:00', 4.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-17 00:00:00', 5.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-18 00:00:00', 6.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-19 00:00:00', 8.83600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-20 00:00:00', 8.56200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-21 00:00:00', 10.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-22 00:00:00', 7.53399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-23 00:00:00', 7.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-24 00:00:00', 9.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-25 00:00:00', 7.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-26 00:00:00', 5.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-27 00:00:00', 5.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-28 00:00:00', 7.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-29 00:00:00', 2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-30 00:00:00', 2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1987-12-31 00:00:00', 4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-01 00:00:00', 3.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-02 00:00:00', 7.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-03 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-04 00:00:00', 6.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-05 00:00:00', 6.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-06 00:00:00', 7.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-07 00:00:00', 4.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-08 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-09 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-10 00:00:00', 5.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-11 00:00:00', 4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-12 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-13 00:00:00', 6.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-14 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-15 00:00:00', 0.0160000007599592209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-16 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-17 00:00:00', 1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-18 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-19 00:00:00', 4.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-20 00:00:00', 3.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-21 00:00:00', -3.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-22 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-23 00:00:00', 0.370000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-24 00:00:00', -0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-25 00:00:00', 0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-26 00:00:00', 1.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-27 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-28 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-29 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-30 00:00:00', 2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-01-31 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-01 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-02 00:00:00', 7.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-03 00:00:00', 11.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-04 00:00:00', 5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-05 00:00:00', 2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-06 00:00:00', 2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-07 00:00:00', -3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-08 00:00:00', -3.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-09 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-10 00:00:00', 7.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-11 00:00:00', 6.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-12 00:00:00', 5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-13 00:00:00', 5.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-14 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-15 00:00:00', 5.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-16 00:00:00', 0.0680000036954879761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-17 00:00:00', 6.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-18 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-19 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-20 00:00:00', 6.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-21 00:00:00', 1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-22 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-23 00:00:00', 3.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-24 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-25 00:00:00', 8.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-26 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-27 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-28 00:00:00', 2.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-02-29 00:00:00', 3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-01 00:00:00', 6.12099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-02 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-03 00:00:00', 10.1750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-04 00:00:00', 12.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-05 00:00:00', 13.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-06 00:00:00', 7.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-07 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-08 00:00:00', 8.31299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-09 00:00:00', 7.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-10 00:00:00', 5.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-11 00:00:00', 6.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-12 00:00:00', 6.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-13 00:00:00', 3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-14 00:00:00', 6.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-15 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-16 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-17 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-18 00:00:00', 4.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-19 00:00:00', 7.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-20 00:00:00', 7.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-21 00:00:00', 7.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-22 00:00:00', 7.56199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-23 00:00:00', 4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-24 00:00:00', 8.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-25 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-26 00:00:00', 3.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-27 00:00:00', 7.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-28 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-29 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-30 00:00:00', 3.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-03-31 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-01 00:00:00', 6.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-02 00:00:00', 6.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-03 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-04 00:00:00', 4.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-05 00:00:00', 8.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-06 00:00:00', 11.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-07 00:00:00', 10.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-08 00:00:00', 11.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-09 00:00:00', 7.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-10 00:00:00', 9.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-11 00:00:00', 14.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-12 00:00:00', 15.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-13 00:00:00', 19.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-14 00:00:00', 20.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-15 00:00:00', 21.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-16 00:00:00', 21.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-17 00:00:00', 13.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-18 00:00:00', 15.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-19 00:00:00', 17.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-20 00:00:00', 19.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-21 00:00:00', 20.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-22 00:00:00', 22.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-23 00:00:00', 18.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-24 00:00:00', 20.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-25 00:00:00', 25.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-26 00:00:00', 23.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-27 00:00:00', 25.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-28 00:00:00', 24.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-29 00:00:00', 18.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-04-30 00:00:00', 17.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-01 00:00:00', 17.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-02 00:00:00', 15.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-03 00:00:00', 18.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-04 00:00:00', 13.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-05 00:00:00', 11.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-06 00:00:00', 14.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-07 00:00:00', 15.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-08 00:00:00', 16.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-09 00:00:00', 18.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-10 00:00:00', 18.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-11 00:00:00', 21.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-12 00:00:00', 22.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-13 00:00:00', 22.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-14 00:00:00', 16.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-15 00:00:00', 19.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-16 00:00:00', 15.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-17 00:00:00', 16.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-18 00:00:00', 15.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-19 00:00:00', 19.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-20 00:00:00', 22.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-21 00:00:00', 25.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-22 00:00:00', 20.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-23 00:00:00', 20.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-24 00:00:00', 21.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-25 00:00:00', 21.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-26 00:00:00', 25.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-27 00:00:00', 25.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-28 00:00:00', 24.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-29 00:00:00', 27.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-30 00:00:00', 27.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-05-31 00:00:00', 22.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-01 00:00:00', 21.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-02 00:00:00', 23.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-03 00:00:00', 24.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-04 00:00:00', 19.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-05 00:00:00', 22.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-06 00:00:00', 22.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-07 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-08 00:00:00', 24.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-09 00:00:00', 23.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-10 00:00:00', 21.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-11 00:00:00', 25.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-12 00:00:00', 28.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-13 00:00:00', 29.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-14 00:00:00', 29.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-15 00:00:00', 29.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-16 00:00:00', 31.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-17 00:00:00', 33.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-18 00:00:00', 33.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-19 00:00:00', 32.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-20 00:00:00', 34.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-21 00:00:00', 32.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-22 00:00:00', 30.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-23 00:00:00', 31.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-24 00:00:00', 33.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-25 00:00:00', 36.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-26 00:00:00', 33.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-27 00:00:00', 28.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-28 00:00:00', 24.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-29 00:00:00', 25.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-06-30 00:00:00', 28.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-01 00:00:00', 32.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-02 00:00:00', 35.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-03 00:00:00', 32.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-04 00:00:00', 32.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-05 00:00:00', 30.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-06 00:00:00', 29.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-07 00:00:00', 28.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-08 00:00:00', 29.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-09 00:00:00', 30.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-10 00:00:00', 33.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-11 00:00:00', 34.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-12 00:00:00', 35.3870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-13 00:00:00', 33.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-14 00:00:00', 32.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-15 00:00:00', 30.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-16 00:00:00', 32.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-17 00:00:00', 31.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-18 00:00:00', 32.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-19 00:00:00', 33.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-20 00:00:00', 34.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-21 00:00:00', 31.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-22 00:00:00', 28.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-23 00:00:00', 28.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-24 00:00:00', 28.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-25 00:00:00', 31.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-26 00:00:00', 30.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-27 00:00:00', 33.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-28 00:00:00', 36.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-29 00:00:00', 34.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-30 00:00:00', 33.5929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-07-31 00:00:00', 29.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-01 00:00:00', 28.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-02 00:00:00', 27.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-03 00:00:00', 28.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-04 00:00:00', 28.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-05 00:00:00', 31.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-06 00:00:00', 32.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-07 00:00:00', 32.4480018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-08 00:00:00', 31.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-09 00:00:00', 30.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-10 00:00:00', 31.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-11 00:00:00', 31.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-12 00:00:00', 31.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-13 00:00:00', 31.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-14 00:00:00', 32.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-15 00:00:00', 28.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-16 00:00:00', 29.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-17 00:00:00', 29.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-18 00:00:00', 28.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-19 00:00:00', 29.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-20 00:00:00', 30.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-21 00:00:00', 30.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-22 00:00:00', 27.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-23 00:00:00', 25.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-24 00:00:00', 24.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-25 00:00:00', 25.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-26 00:00:00', 23.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-27 00:00:00', 21.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-28 00:00:00', 25.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-29 00:00:00', 26.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-30 00:00:00', 26.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-08-31 00:00:00', 28.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-01 00:00:00', 27.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-02 00:00:00', 25.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-03 00:00:00', 27.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-04 00:00:00', 27.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-05 00:00:00', 29.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-06 00:00:00', 31.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-07 00:00:00', 30.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-08 00:00:00', 27.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-09 00:00:00', 25.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-10 00:00:00', 28.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-11 00:00:00', 30.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-12 00:00:00', 29.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-13 00:00:00', 30.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-14 00:00:00', 26.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-15 00:00:00', 25.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-16 00:00:00', 23.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-17 00:00:00', 21.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-18 00:00:00', 23.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-19 00:00:00', 25.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-20 00:00:00', 25.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-21 00:00:00', 25.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-22 00:00:00', 18.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-23 00:00:00', 21.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-24 00:00:00', 19.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-25 00:00:00', 18.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-26 00:00:00', 19.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-27 00:00:00', 19.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-28 00:00:00', 17.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-29 00:00:00', 17.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-09-30 00:00:00', 17.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-01 00:00:00', 17.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-02 00:00:00', 18.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-03 00:00:00', 13.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-04 00:00:00', 15.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-05 00:00:00', 17.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-06 00:00:00', 16.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-07 00:00:00', 15.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-08 00:00:00', 15.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-09 00:00:00', 16.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-10 00:00:00', 18.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-11 00:00:00', 16.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-12 00:00:00', 14.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-13 00:00:00', 14.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-14 00:00:00', 12.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-15 00:00:00', 15.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-16 00:00:00', 12.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-17 00:00:00', 13.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-18 00:00:00', 14.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-19 00:00:00', 13.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-20 00:00:00', 14.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-21 00:00:00', 16.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-22 00:00:00', 15.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-23 00:00:00', 11.6129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-24 00:00:00', 13.7559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-25 00:00:00', 12.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-26 00:00:00', 13.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-27 00:00:00', 18.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-28 00:00:00', 18.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-29 00:00:00', 13.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-30 00:00:00', 14.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-10-31 00:00:00', 16.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-01 00:00:00', 16.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-02 00:00:00', 17.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-03 00:00:00', 16.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-04 00:00:00', 17.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-05 00:00:00', 17.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-06 00:00:00', 15.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-07 00:00:00', 15.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-08 00:00:00', 15.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-09 00:00:00', 16.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-10 00:00:00', 18.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-11 00:00:00', 19.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-12 00:00:00', 20.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-13 00:00:00', 18.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-14 00:00:00', 19.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-15 00:00:00', 13.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-16 00:00:00', 9.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-17 00:00:00', 15.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-18 00:00:00', 14.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-19 00:00:00', 13.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-20 00:00:00', 17.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-21 00:00:00', 10.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-22 00:00:00', 10.508000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-23 00:00:00', 8.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-24 00:00:00', 7.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-25 00:00:00', 7.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-26 00:00:00', 7.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-27 00:00:00', 9.69900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-28 00:00:00', 10.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-29 00:00:00', 10.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-11-30 00:00:00', 10.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-01 00:00:00', 10.9110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-02 00:00:00', 10.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-03 00:00:00', 11.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-04 00:00:00', 11.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-05 00:00:00', 8.22999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-06 00:00:00', 9.34599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-07 00:00:00', 8.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-08 00:00:00', 12.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-09 00:00:00', 11.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-10 00:00:00', 13.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-11 00:00:00', 11.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-12 00:00:00', 11.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-13 00:00:00', 10.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-14 00:00:00', 7.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-15 00:00:00', 6.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-16 00:00:00', 4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-17 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-18 00:00:00', 6.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-19 00:00:00', 7.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-20 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-21 00:00:00', 3.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-22 00:00:00', 1.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-23 00:00:00', 2.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-24 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-25 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-26 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-27 00:00:00', 6.49599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-28 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-29 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-30 00:00:00', -0.00600000005215406418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1988-12-31 00:00:00', 4.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-01 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-02 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-03 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-04 00:00:00', -1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-05 00:00:00', -2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-06 00:00:00', -6.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-07 00:00:00', -4.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-08 00:00:00', -3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-09 00:00:00', 1.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-10 00:00:00', -0.218999996781349182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-11 00:00:00', 1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-12 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-13 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-14 00:00:00', 0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-15 00:00:00', -0.679000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-16 00:00:00', -2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-17 00:00:00', 1.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-18 00:00:00', -1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-19 00:00:00', -3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-20 00:00:00', -1.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-21 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-22 00:00:00', -0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-23 00:00:00', 1.75499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-24 00:00:00', 4.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-25 00:00:00', -0.527999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-26 00:00:00', 0.643000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-27 00:00:00', -2.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-28 00:00:00', -1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-29 00:00:00', -0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-30 00:00:00', -0.615000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-01-31 00:00:00', -5.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-01 00:00:00', -0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-02 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-03 00:00:00', -0.324000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-04 00:00:00', -1.22500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-05 00:00:00', -2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-06 00:00:00', -5.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-07 00:00:00', -2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-08 00:00:00', -1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-09 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-10 00:00:00', 3.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-11 00:00:00', 2.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-12 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-13 00:00:00', -4.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-14 00:00:00', -2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-15 00:00:00', 0.197999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-16 00:00:00', -5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-17 00:00:00', -1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-18 00:00:00', -2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-19 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-20 00:00:00', -0.630999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-21 00:00:00', -1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-22 00:00:00', 0.804000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-23 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-24 00:00:00', 0.760999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-25 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-26 00:00:00', 0.384000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-27 00:00:00', -2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-02-28 00:00:00', 3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-01 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-02 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-03 00:00:00', 6.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-04 00:00:00', 6.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-05 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-06 00:00:00', 8.27900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-07 00:00:00', 7.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-08 00:00:00', 4.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-09 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-10 00:00:00', 7.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-11 00:00:00', 10.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-12 00:00:00', 10.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-13 00:00:00', 7.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-14 00:00:00', 6.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-15 00:00:00', 10.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-16 00:00:00', 14.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-17 00:00:00', 10.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-18 00:00:00', 8.71300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-19 00:00:00', 12.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-20 00:00:00', 5.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-21 00:00:00', 12.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-22 00:00:00', 4.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-23 00:00:00', 6.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-24 00:00:00', 8.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-25 00:00:00', 11.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-26 00:00:00', 13.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-27 00:00:00', 15.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-28 00:00:00', 15.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-29 00:00:00', 9.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-30 00:00:00', 12.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-03-31 00:00:00', 6.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-01 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-02 00:00:00', 5.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-03 00:00:00', 7.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-04 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-05 00:00:00', 10.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-06 00:00:00', 12.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-07 00:00:00', 11.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-08 00:00:00', 8.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-09 00:00:00', 7.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-10 00:00:00', 8.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-11 00:00:00', 9.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-12 00:00:00', 10.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-13 00:00:00', 14.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-14 00:00:00', 17.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-15 00:00:00', 16.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-16 00:00:00', 14.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-17 00:00:00', 13.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-18 00:00:00', 13.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-19 00:00:00', 16.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-20 00:00:00', 18.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-21 00:00:00', 17.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-22 00:00:00', 15.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-23 00:00:00', 17.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-24 00:00:00', 15.1190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-25 00:00:00', 15.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-26 00:00:00', 17.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-27 00:00:00', 18.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-28 00:00:00', 18.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-29 00:00:00', 19.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-04-30 00:00:00', 12.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-01 00:00:00', 5.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-02 00:00:00', 7.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-03 00:00:00', 7.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-04 00:00:00', 9.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-05 00:00:00', 8.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-06 00:00:00', 15.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-07 00:00:00', 18.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-08 00:00:00', 10.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-09 00:00:00', 10.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-10 00:00:00', 17.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-11 00:00:00', 19.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-12 00:00:00', 19.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-13 00:00:00', 21.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-14 00:00:00', 18.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-15 00:00:00', 16.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-16 00:00:00', 19.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-17 00:00:00', 19.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-18 00:00:00', 17.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-19 00:00:00', 22.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-20 00:00:00', 22.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-21 00:00:00', 18.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-22 00:00:00', 20.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-23 00:00:00', 16.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-24 00:00:00', 20.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-25 00:00:00', 21.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-26 00:00:00', 25.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-27 00:00:00', 25.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-28 00:00:00', 28.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-29 00:00:00', 28.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-30 00:00:00', 28.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-05-31 00:00:00', 27.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-01 00:00:00', 29.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-02 00:00:00', 28.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-03 00:00:00', 27.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-04 00:00:00', 27.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-05 00:00:00', 25.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-06 00:00:00', 24.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-07 00:00:00', 22.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-08 00:00:00', 24.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-09 00:00:00', 22.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-10 00:00:00', 23.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-11 00:00:00', 25.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-12 00:00:00', 28.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-13 00:00:00', 27.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-14 00:00:00', 25.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-15 00:00:00', 25.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-16 00:00:00', 25.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-17 00:00:00', 25.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-18 00:00:00', 24.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-19 00:00:00', 21.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-20 00:00:00', 20.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-21 00:00:00', 21.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-22 00:00:00', 26.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-23 00:00:00', 27.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-24 00:00:00', 29.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-25 00:00:00', 30.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-26 00:00:00', 31.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-27 00:00:00', 30.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-28 00:00:00', 29.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-29 00:00:00', 29.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-06-30 00:00:00', 29.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-01 00:00:00', 28.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-02 00:00:00', 29.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-03 00:00:00', 28.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-04 00:00:00', 28.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-05 00:00:00', 28.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-06 00:00:00', 27.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-07 00:00:00', 31.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-08 00:00:00', 33.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-09 00:00:00', 35.1699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-10 00:00:00', 35.7550010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-11 00:00:00', 35.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-12 00:00:00', 34.1829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-13 00:00:00', 29.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-14 00:00:00', 27.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-15 00:00:00', 27.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-16 00:00:00', 27.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-17 00:00:00', 28.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-18 00:00:00', 27.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-19 00:00:00', 27.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-20 00:00:00', 29.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-21 00:00:00', 30.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-22 00:00:00', 29.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-23 00:00:00', 26.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-24 00:00:00', 27.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-25 00:00:00', 28.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-26 00:00:00', 28.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-27 00:00:00', 31.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-28 00:00:00', 32.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-29 00:00:00', 31.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-30 00:00:00', 30.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-07-31 00:00:00', 25.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-01 00:00:00', 28.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-02 00:00:00', 31.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-03 00:00:00', 31.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-04 00:00:00', 30.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-05 00:00:00', 30.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-06 00:00:00', 30.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-07 00:00:00', 31.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-08 00:00:00', 31.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-09 00:00:00', 31.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-10 00:00:00', 32.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-11 00:00:00', 34.41400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-12 00:00:00', 33.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-13 00:00:00', 30.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-14 00:00:00', 29.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-15 00:00:00', 28.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-16 00:00:00', 29.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-17 00:00:00', 31.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-18 00:00:00', 32.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-19 00:00:00', 28.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-20 00:00:00', 26.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-21 00:00:00', 27.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-22 00:00:00', 28.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-23 00:00:00', 27.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-24 00:00:00', 27.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-25 00:00:00', 27.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-26 00:00:00', 26.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-27 00:00:00', 24.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-28 00:00:00', 24.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-29 00:00:00', 25.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-30 00:00:00', 26.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-08-31 00:00:00', 25.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-01 00:00:00', 26.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-02 00:00:00', 28.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-03 00:00:00', 28.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-04 00:00:00', 24.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-05 00:00:00', 22.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-06 00:00:00', 22.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-07 00:00:00', 25.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-08 00:00:00', 25.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-09 00:00:00', 26.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-10 00:00:00', 27.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-11 00:00:00', 27.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-12 00:00:00', 26.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-13 00:00:00', 27.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-14 00:00:00', 31.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-15 00:00:00', 32.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-16 00:00:00', 30.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-17 00:00:00', 27.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-18 00:00:00', 28.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-19 00:00:00', 27.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-20 00:00:00', 20.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-21 00:00:00', 18.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-22 00:00:00', 13.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-23 00:00:00', 14.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-24 00:00:00', 17.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-25 00:00:00', 21.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-26 00:00:00', 21.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-27 00:00:00', 20.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-28 00:00:00', 22.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-29 00:00:00', 21.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-09-30 00:00:00', 19.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-01 00:00:00', 20.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-02 00:00:00', 23.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-03 00:00:00', 24.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-04 00:00:00', 24.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-05 00:00:00', 25.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-06 00:00:00', 24.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-07 00:00:00', 25.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-08 00:00:00', 26.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-09 00:00:00', 24.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-10 00:00:00', 21.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-11 00:00:00', 15.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-12 00:00:00', 13.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-13 00:00:00', 14.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-14 00:00:00', 13.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-15 00:00:00', 16.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-16 00:00:00', 17.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-17 00:00:00', 19.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-18 00:00:00', 20.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-19 00:00:00', 18.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-20 00:00:00', 22.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-21 00:00:00', 21.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-22 00:00:00', 19.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-23 00:00:00', 14.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-24 00:00:00', 8.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-25 00:00:00', 14.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-26 00:00:00', 14.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-27 00:00:00', 11.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-28 00:00:00', 15.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-29 00:00:00', 15.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-30 00:00:00', 13.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-10-31 00:00:00', 16.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-01 00:00:00', 10.1789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-02 00:00:00', 5.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-03 00:00:00', 8.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-04 00:00:00', 8.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-05 00:00:00', 7.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-06 00:00:00', 8.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-07 00:00:00', 7.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-08 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-09 00:00:00', 7.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-10 00:00:00', 5.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-11 00:00:00', 5.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-12 00:00:00', 8.21100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-13 00:00:00', 10.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-14 00:00:00', 10.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-15 00:00:00', 6.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-16 00:00:00', 8.37600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-17 00:00:00', 6.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-18 00:00:00', 6.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-19 00:00:00', 8.99699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-20 00:00:00', 10.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-21 00:00:00', 8.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-22 00:00:00', 4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-23 00:00:00', 5.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-24 00:00:00', 6.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-25 00:00:00', 6.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-26 00:00:00', 9.81299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-27 00:00:00', 10.1579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-28 00:00:00', 11.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-29 00:00:00', 12.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-11-30 00:00:00', 14.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-01 00:00:00', 13.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-02 00:00:00', 11.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-03 00:00:00', 7.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-04 00:00:00', 7.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-05 00:00:00', 9.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-06 00:00:00', 7.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-07 00:00:00', 4.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-08 00:00:00', 4.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-09 00:00:00', 8.34500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-10 00:00:00', 7.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-11 00:00:00', 7.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-12 00:00:00', 5.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-13 00:00:00', 6.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-14 00:00:00', 6.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-15 00:00:00', 6.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-16 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-17 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-18 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-19 00:00:00', 5.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-20 00:00:00', 4.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-21 00:00:00', 5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-22 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-23 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-24 00:00:00', 2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-25 00:00:00', 1.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-26 00:00:00', 2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-27 00:00:00', 3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-28 00:00:00', 2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-29 00:00:00', 2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-30 00:00:00', 3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1989-12-31 00:00:00', -0.358000010251998901, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-01 00:00:00', 0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-02 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-03 00:00:00', 1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-04 00:00:00', 1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-05 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-06 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-07 00:00:00', -1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-08 00:00:00', -1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-09 00:00:00', -1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-10 00:00:00', 0.579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-11 00:00:00', -1.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-12 00:00:00', -1.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-13 00:00:00', -3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-14 00:00:00', -0.497000008821487427, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-15 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-16 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-17 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-18 00:00:00', 4.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-19 00:00:00', 5.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-20 00:00:00', 2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-21 00:00:00', 6.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-22 00:00:00', 5.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-23 00:00:00', 6.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-24 00:00:00', 7.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-25 00:00:00', 5.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-26 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-27 00:00:00', -2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-28 00:00:00', -1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-29 00:00:00', 4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-30 00:00:00', 2.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-01-31 00:00:00', -2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-01 00:00:00', -3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-02 00:00:00', 0.611999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-03 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-04 00:00:00', 1.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-05 00:00:00', 3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-06 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-07 00:00:00', -0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-08 00:00:00', 0.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-09 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-10 00:00:00', 2.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-11 00:00:00', 4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-12 00:00:00', 2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-13 00:00:00', 1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-14 00:00:00', 0.665000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-15 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-16 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-17 00:00:00', 2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-18 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-19 00:00:00', 6.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-20 00:00:00', 5.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-21 00:00:00', 6.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-22 00:00:00', 3.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-23 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-24 00:00:00', -0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-25 00:00:00', 1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-26 00:00:00', 2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-27 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-02-28 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-01 00:00:00', 4.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-02 00:00:00', 6.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-03 00:00:00', 8.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-04 00:00:00', 7.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-05 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-06 00:00:00', 5.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-07 00:00:00', 7.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-08 00:00:00', 9.59599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-09 00:00:00', 6.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-10 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-11 00:00:00', 8.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-12 00:00:00', 9.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-13 00:00:00', 12.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-14 00:00:00', 11.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-15 00:00:00', 10.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-16 00:00:00', 9.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-17 00:00:00', 4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-18 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-19 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-20 00:00:00', 3.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-21 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-22 00:00:00', -0.370000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-23 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-24 00:00:00', 5.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-25 00:00:00', 9.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-26 00:00:00', 9.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-27 00:00:00', 8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-28 00:00:00', 10.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-29 00:00:00', 11.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-30 00:00:00', 9.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-03-31 00:00:00', 8.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-01 00:00:00', 10.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-02 00:00:00', 14.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-03 00:00:00', 14.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-04 00:00:00', 13.5159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-05 00:00:00', 14.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-06 00:00:00', 11.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-07 00:00:00', 12.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-08 00:00:00', 6.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-09 00:00:00', 10.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-10 00:00:00', 12.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-11 00:00:00', 13.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-12 00:00:00', 10.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-13 00:00:00', 12.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-14 00:00:00', 8.64000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-15 00:00:00', 10.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-16 00:00:00', 12.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-17 00:00:00', 9.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-18 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-19 00:00:00', 13.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-20 00:00:00', 10.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-21 00:00:00', 11.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-22 00:00:00', 17.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-23 00:00:00', 17.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-24 00:00:00', 15.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-25 00:00:00', 16.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-26 00:00:00', 15.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-27 00:00:00', 16.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-28 00:00:00', 18.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-29 00:00:00', 21.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-04-30 00:00:00', 16.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-01 00:00:00', 17.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-02 00:00:00', 17.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-03 00:00:00', 22.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-04 00:00:00', 24.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-05 00:00:00', 24.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-06 00:00:00', 22.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-07 00:00:00', 25.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-08 00:00:00', 23.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-09 00:00:00', 22.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-10 00:00:00', 24.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-11 00:00:00', 27.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-12 00:00:00', 28.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-13 00:00:00', 31.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-14 00:00:00', 27.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-15 00:00:00', 17.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-16 00:00:00', 22.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-17 00:00:00', 21.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-18 00:00:00', 21.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-19 00:00:00', 23.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-20 00:00:00', 24.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-21 00:00:00', 25.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-22 00:00:00', 25.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-23 00:00:00', 25.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-24 00:00:00', 25.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-25 00:00:00', 24.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-26 00:00:00', 25.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-27 00:00:00', 28.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-28 00:00:00', 24.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-29 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-30 00:00:00', 21.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-05-31 00:00:00', 22.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-01 00:00:00', 25.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-02 00:00:00', 27.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-03 00:00:00', 26.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-04 00:00:00', 25.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-05 00:00:00', 25.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-06 00:00:00', 25.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-07 00:00:00', 29.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-08 00:00:00', 26.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-09 00:00:00', 22.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-10 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-11 00:00:00', 27.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-12 00:00:00', 26.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-13 00:00:00', 26.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-14 00:00:00', 29.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-15 00:00:00', 31.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-16 00:00:00', 33.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-17 00:00:00', 32.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-18 00:00:00', 35.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-19 00:00:00', 36.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-20 00:00:00', 35.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-21 00:00:00', 34.9739990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-22 00:00:00', 37.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-23 00:00:00', 36.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-24 00:00:00', 32.6839981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-25 00:00:00', 32.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-26 00:00:00', 30.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-27 00:00:00', 31.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-28 00:00:00', 33.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-29 00:00:00', 36.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-06-30 00:00:00', 36.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-01 00:00:00', 32.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-02 00:00:00', 32.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-03 00:00:00', 31.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-04 00:00:00', 30.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-05 00:00:00', 30.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-06 00:00:00', 31.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-07 00:00:00', 32.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-08 00:00:00', 32.0589981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-09 00:00:00', 27.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-10 00:00:00', 27.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-11 00:00:00', 27.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-12 00:00:00', 25.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-13 00:00:00', 26.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-14 00:00:00', 26.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-15 00:00:00', 29.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-16 00:00:00', 28.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-17 00:00:00', 32.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-18 00:00:00', 32.095001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-19 00:00:00', 32.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-20 00:00:00', 30.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-21 00:00:00', 29.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-22 00:00:00', 27.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-23 00:00:00', 29.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-24 00:00:00', 33.8909988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-25 00:00:00', 34.9189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-26 00:00:00', 32.3559989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-27 00:00:00', 30.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-28 00:00:00', 32.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-29 00:00:00', 34.1689987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-30 00:00:00', 36.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-07-31 00:00:00', 36.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-01 00:00:00', 35.2690010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-02 00:00:00', 30.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-03 00:00:00', 31.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-04 00:00:00', 31.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-05 00:00:00', 32.7130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-06 00:00:00', 34.3940010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-07 00:00:00', 35.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-08 00:00:00', 35.9399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-09 00:00:00', 35.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-10 00:00:00', 34.78900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-11 00:00:00', 36.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-12 00:00:00', 33.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-13 00:00:00', 29.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-14 00:00:00', 26.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-15 00:00:00', 30.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-16 00:00:00', 31.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-17 00:00:00', 32.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-18 00:00:00', 31.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-19 00:00:00', 30.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-20 00:00:00', 32.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-21 00:00:00', 31.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-22 00:00:00', 30.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-23 00:00:00', 28.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-24 00:00:00', 27.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-25 00:00:00', 28.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-26 00:00:00', 29.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-27 00:00:00', 31.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-28 00:00:00', 33.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-29 00:00:00', 32.5660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-30 00:00:00', 28.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-08-31 00:00:00', 27.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-01 00:00:00', 28.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-02 00:00:00', 30.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-03 00:00:00', 26.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-04 00:00:00', 25.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-05 00:00:00', 26.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-06 00:00:00', 27.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-07 00:00:00', 28.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-08 00:00:00', 27.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-09 00:00:00', 26.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-10 00:00:00', 26.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-11 00:00:00', 26.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-12 00:00:00', 26.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-13 00:00:00', 29.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-14 00:00:00', 29.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-15 00:00:00', 31.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-16 00:00:00', 31.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-17 00:00:00', 30.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-18 00:00:00', 27.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-19 00:00:00', 27.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-20 00:00:00', 26.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-21 00:00:00', 28.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-22 00:00:00', 28.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-23 00:00:00', 27.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-24 00:00:00', 24.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-25 00:00:00', 25.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-26 00:00:00', 24.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-27 00:00:00', 24.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-28 00:00:00', 24.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-29 00:00:00', 24.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-09-30 00:00:00', 24.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-01 00:00:00', 24.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-02 00:00:00', 25.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-03 00:00:00', 23.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-04 00:00:00', 24.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-05 00:00:00', 23.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-06 00:00:00', 15.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-07 00:00:00', 18.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-08 00:00:00', 19.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-09 00:00:00', 18.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-10 00:00:00', 21.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-11 00:00:00', 21.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-12 00:00:00', 19.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-13 00:00:00', 16.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-14 00:00:00', 18.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-15 00:00:00', 16.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-16 00:00:00', 11.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-17 00:00:00', 10.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-18 00:00:00', 6.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-19 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-20 00:00:00', 13.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-21 00:00:00', 15.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-22 00:00:00', 16.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-23 00:00:00', 15.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-24 00:00:00', 16.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-25 00:00:00', 16.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-26 00:00:00', 18.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-27 00:00:00', 17.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-28 00:00:00', 17.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-29 00:00:00', 14.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-30 00:00:00', 11.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-10-31 00:00:00', 11.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-01 00:00:00', 9.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-02 00:00:00', 11.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-03 00:00:00', 11.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-04 00:00:00', 15.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-05 00:00:00', 16.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-06 00:00:00', 15.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-07 00:00:00', 16.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-08 00:00:00', 16.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-09 00:00:00', 16.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-10 00:00:00', 16.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-11 00:00:00', 16.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-12 00:00:00', 15.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-13 00:00:00', 16.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-14 00:00:00', 9.60299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-15 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-16 00:00:00', 7.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-17 00:00:00', 4.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-18 00:00:00', 6.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-19 00:00:00', 9.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-20 00:00:00', 12.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-21 00:00:00', 11.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-22 00:00:00', 10.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-23 00:00:00', 8.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-24 00:00:00', 10.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-25 00:00:00', 10.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-26 00:00:00', 10.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-27 00:00:00', 7.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-28 00:00:00', 8.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-29 00:00:00', 9.51299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-11-30 00:00:00', 8.93999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-01 00:00:00', 11.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-02 00:00:00', 11.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-03 00:00:00', 12.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-04 00:00:00', 10.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-05 00:00:00', 10.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-06 00:00:00', 11.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-07 00:00:00', 12.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-08 00:00:00', 7.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-09 00:00:00', 8.33899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-10 00:00:00', 3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-11 00:00:00', 4.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-12 00:00:00', 3.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-13 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-14 00:00:00', 0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-15 00:00:00', 0.510999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-16 00:00:00', -0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-17 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-18 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-19 00:00:00', 6.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-20 00:00:00', 4.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-21 00:00:00', 5.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-22 00:00:00', 5.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-23 00:00:00', 1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-24 00:00:00', 0.593999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-25 00:00:00', -0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-26 00:00:00', 0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-27 00:00:00', -4.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-28 00:00:00', -6.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-29 00:00:00', -7.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-30 00:00:00', -8.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1990-12-31 00:00:00', -4.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-01 00:00:00', -3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-02 00:00:00', -0.702000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-03 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-04 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-05 00:00:00', -0.072999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-06 00:00:00', -1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-07 00:00:00', -1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-08 00:00:00', -1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-09 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-10 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-11 00:00:00', -0.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-12 00:00:00', -0.272000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-13 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-14 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-15 00:00:00', 5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-16 00:00:00', -2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-17 00:00:00', -1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-18 00:00:00', -0.0949999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-19 00:00:00', -0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-20 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-21 00:00:00', -0.0460000000894069672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-22 00:00:00', 0.768000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-23 00:00:00', -0.499000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-24 00:00:00', 1.22899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-25 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-26 00:00:00', 2.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-27 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-28 00:00:00', -0.400999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-29 00:00:00', 0.264999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-30 00:00:00', 3.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-01-31 00:00:00', 2.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-01 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-02 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-03 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-04 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-05 00:00:00', 4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-06 00:00:00', -0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-07 00:00:00', -1.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-08 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-09 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-10 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-11 00:00:00', -2.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-12 00:00:00', -2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-13 00:00:00', -0.351999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-14 00:00:00', -5.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-15 00:00:00', -5.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-16 00:00:00', 0.224000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-17 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-18 00:00:00', 3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-19 00:00:00', 6.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-20 00:00:00', 8.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-21 00:00:00', 8.97000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-22 00:00:00', 11.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-23 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-24 00:00:00', 4.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-25 00:00:00', -1.22800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-26 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-27 00:00:00', 4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-02-28 00:00:00', 8.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-01 00:00:00', 7.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-02 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-03 00:00:00', 6.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-04 00:00:00', 5.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-05 00:00:00', 0.365999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-06 00:00:00', 6.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-07 00:00:00', 5.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-08 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-09 00:00:00', 4.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-10 00:00:00', 6.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-11 00:00:00', 7.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-12 00:00:00', 2.48300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-13 00:00:00', 5.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-14 00:00:00', 2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-15 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-16 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-17 00:00:00', 1.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-18 00:00:00', 1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-19 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-20 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-21 00:00:00', 7.09600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-22 00:00:00', 5.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-23 00:00:00', 7.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-24 00:00:00', 9.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-25 00:00:00', 10.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-26 00:00:00', 13.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-27 00:00:00', 16.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-28 00:00:00', 16.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-29 00:00:00', 13.4110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-30 00:00:00', 15.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-03-31 00:00:00', 16.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-01 00:00:00', 18.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-02 00:00:00', 14.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-03 00:00:00', 16.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-04 00:00:00', 17.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-05 00:00:00', 18.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-06 00:00:00', 15.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-07 00:00:00', 12.6689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-08 00:00:00', 12.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-09 00:00:00', 7.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-10 00:00:00', 11.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-11 00:00:00', 13.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-12 00:00:00', 14.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-13 00:00:00', 11.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-14 00:00:00', 12.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-15 00:00:00', 4.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-16 00:00:00', 8.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-17 00:00:00', 11.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-18 00:00:00', 14.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-19 00:00:00', 18.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-20 00:00:00', 17.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-21 00:00:00', 15.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-22 00:00:00', 18.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-23 00:00:00', 18.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-24 00:00:00', 18.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-25 00:00:00', 18.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-26 00:00:00', 18.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-27 00:00:00', 16.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-28 00:00:00', 16.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-29 00:00:00', 15.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-04-30 00:00:00', 19.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-01 00:00:00', 14.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-02 00:00:00', 14.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-03 00:00:00', 18.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-04 00:00:00', 18.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-05 00:00:00', 16.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-06 00:00:00', 18.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-07 00:00:00', 18.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-08 00:00:00', 19.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-09 00:00:00', 18.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-10 00:00:00', 19.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-11 00:00:00', 21.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-12 00:00:00', 17.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-13 00:00:00', 18.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-14 00:00:00', 18.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-15 00:00:00', 19.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-16 00:00:00', 16.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-17 00:00:00', 21.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-18 00:00:00', 21.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-19 00:00:00', 18.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-20 00:00:00', 17.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-21 00:00:00', 14.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-22 00:00:00', 19.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-23 00:00:00', 22.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-24 00:00:00', 18.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-25 00:00:00', 16.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-26 00:00:00', 17.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-27 00:00:00', 19.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-28 00:00:00', 21.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-29 00:00:00', 22.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-30 00:00:00', 23.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-05-31 00:00:00', 25.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-01 00:00:00', 28.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-02 00:00:00', 28.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-03 00:00:00', 29.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-04 00:00:00', 28.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-05 00:00:00', 30.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-06 00:00:00', 29.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-07 00:00:00', 26.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-08 00:00:00', 28.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-09 00:00:00', 26.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-10 00:00:00', 23.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-11 00:00:00', 23.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-12 00:00:00', 27.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-13 00:00:00', 31.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-14 00:00:00', 30.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-15 00:00:00', 27.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-16 00:00:00', 26.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-17 00:00:00', 29.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-18 00:00:00', 26.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-19 00:00:00', 25.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-20 00:00:00', 25.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-21 00:00:00', 26.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-22 00:00:00', 24.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-23 00:00:00', 22.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-24 00:00:00', 18.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-25 00:00:00', 19.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-26 00:00:00', 22.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-27 00:00:00', 26.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-28 00:00:00', 28.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-29 00:00:00', 28.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-06-30 00:00:00', 28.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-01 00:00:00', 30.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-02 00:00:00', 29.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-03 00:00:00', 29.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-04 00:00:00', 28.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-05 00:00:00', 28.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-06 00:00:00', 29.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-07 00:00:00', 29.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-08 00:00:00', 31.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-09 00:00:00', 32.0379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-10 00:00:00', 30.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-11 00:00:00', 29.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-12 00:00:00', 26.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-13 00:00:00', 24.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-14 00:00:00', 27.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-15 00:00:00', 28.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-16 00:00:00', 30.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-17 00:00:00', 28.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-18 00:00:00', 30.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-19 00:00:00', 30.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-20 00:00:00', 31.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-21 00:00:00', 29.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-22 00:00:00', 29.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-23 00:00:00', 30.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-24 00:00:00', 29.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-25 00:00:00', 29.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-26 00:00:00', 28.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-27 00:00:00', 31.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-28 00:00:00', 31.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-29 00:00:00', 33.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-30 00:00:00', 33.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-07-31 00:00:00', 30.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-01 00:00:00', 30.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-02 00:00:00', 31.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-03 00:00:00', 32.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-04 00:00:00', 31.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-05 00:00:00', 31.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-06 00:00:00', 31.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-07 00:00:00', 31.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-08 00:00:00', 28.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-09 00:00:00', 25.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-10 00:00:00', 27.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-11 00:00:00', 30.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-12 00:00:00', 31.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-13 00:00:00', 32.3100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-14 00:00:00', 32.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-15 00:00:00', 32.2820014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-16 00:00:00', 31.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-17 00:00:00', 31.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-18 00:00:00', 32.4840011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-19 00:00:00', 32.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-20 00:00:00', 30.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-21 00:00:00', 28.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-22 00:00:00', 27.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-23 00:00:00', 27.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-24 00:00:00', 28.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-25 00:00:00', 29.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-26 00:00:00', 31.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-27 00:00:00', 31.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-28 00:00:00', 30.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-29 00:00:00', 29.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-30 00:00:00', 29.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-08-31 00:00:00', 29.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-01 00:00:00', 29.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-02 00:00:00', 30.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-03 00:00:00', 32.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-04 00:00:00', 31.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-05 00:00:00', 30.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-06 00:00:00', 25.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-07 00:00:00', 25.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-08 00:00:00', 29.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-09 00:00:00', 30.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-10 00:00:00', 29.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-11 00:00:00', 29.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-12 00:00:00', 27.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-13 00:00:00', 27.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-14 00:00:00', 26.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-15 00:00:00', 26.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-16 00:00:00', 23.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-17 00:00:00', 21.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-18 00:00:00', 20.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-19 00:00:00', 22.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-20 00:00:00', 23.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-21 00:00:00', 25.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-22 00:00:00', 27.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-23 00:00:00', 26.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-24 00:00:00', 26.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-25 00:00:00', 22.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-26 00:00:00', 18.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-27 00:00:00', 13.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-28 00:00:00', 15.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-29 00:00:00', 13.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-09-30 00:00:00', 11.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-01 00:00:00', 13.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-02 00:00:00', 13.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-03 00:00:00', 17.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-04 00:00:00', 19.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-05 00:00:00', 18.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-06 00:00:00', 18.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-07 00:00:00', 16.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-08 00:00:00', 14.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-09 00:00:00', 16.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-10 00:00:00', 16.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-11 00:00:00', 11.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-12 00:00:00', 12.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-13 00:00:00', 11.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-14 00:00:00', 11.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-15 00:00:00', 13.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-16 00:00:00', 15.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-17 00:00:00', 17.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-18 00:00:00', 15.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-19 00:00:00', 15.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-20 00:00:00', 17.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-21 00:00:00', 16.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-22 00:00:00', 17.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-23 00:00:00', 17.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-24 00:00:00', 17.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-25 00:00:00', 16.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-26 00:00:00', 17.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-27 00:00:00', 17.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-28 00:00:00', 17.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-29 00:00:00', 15.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-30 00:00:00', 15.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-10-31 00:00:00', 16.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-01 00:00:00', 15.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-02 00:00:00', 14.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-03 00:00:00', 14.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-04 00:00:00', 12.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-05 00:00:00', 17.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-06 00:00:00', 16.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-07 00:00:00', 14.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-08 00:00:00', 11.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-09 00:00:00', 11.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-10 00:00:00', 10.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-11 00:00:00', 9.37100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-12 00:00:00', 10.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-13 00:00:00', 8.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-14 00:00:00', 7.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-15 00:00:00', 9.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-16 00:00:00', 8.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-17 00:00:00', 6.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-18 00:00:00', 8.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-19 00:00:00', 7.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-20 00:00:00', 5.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-21 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-22 00:00:00', 7.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-23 00:00:00', 5.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-24 00:00:00', 6.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-25 00:00:00', 5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-26 00:00:00', 8.05500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-27 00:00:00', 5.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-28 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-29 00:00:00', 0.700999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-11-30 00:00:00', 3.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-01 00:00:00', 4.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-02 00:00:00', 7.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-03 00:00:00', 6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-04 00:00:00', 5.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-05 00:00:00', 6.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-06 00:00:00', 6.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-07 00:00:00', 6.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-08 00:00:00', 6.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-09 00:00:00', 5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-10 00:00:00', 4.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-11 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-12 00:00:00', 3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-13 00:00:00', 4.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-14 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-15 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-16 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-17 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-18 00:00:00', -0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-19 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-20 00:00:00', 2.23900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-21 00:00:00', 1.08399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-22 00:00:00', 1.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-23 00:00:00', 2.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-24 00:00:00', 0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-25 00:00:00', -1.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-26 00:00:00', 1.47800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-27 00:00:00', -2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-28 00:00:00', -0.0399999991059303284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-29 00:00:00', 0.246000006794929504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-30 00:00:00', -0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1991-12-31 00:00:00', -3.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-01 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-02 00:00:00', 1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-03 00:00:00', 1.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-04 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-05 00:00:00', 0.853999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-06 00:00:00', 5.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-07 00:00:00', -1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-08 00:00:00', 2.37100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-09 00:00:00', -1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-10 00:00:00', -3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-11 00:00:00', -3.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-12 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-13 00:00:00', 4.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-14 00:00:00', 3.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-15 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-16 00:00:00', 2.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-17 00:00:00', 4.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-18 00:00:00', 2.02200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-19 00:00:00', 4.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-20 00:00:00', 7.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-21 00:00:00', 4.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-22 00:00:00', 4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-23 00:00:00', 2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-24 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-25 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-26 00:00:00', 1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-27 00:00:00', -1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-28 00:00:00', -0.660000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-29 00:00:00', -2.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-30 00:00:00', 0.284999996423721313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-01-31 00:00:00', 1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-01 00:00:00', 0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-02 00:00:00', 1.7640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-03 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-04 00:00:00', 3.92300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-05 00:00:00', 5.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-06 00:00:00', 3.68600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-07 00:00:00', 0.837000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-08 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-09 00:00:00', 2.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-10 00:00:00', 2.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-11 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-12 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-13 00:00:00', -3.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-14 00:00:00', -0.878000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-15 00:00:00', 0.42300000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-16 00:00:00', 0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-17 00:00:00', -0.930999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-18 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-19 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-20 00:00:00', 5.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-21 00:00:00', 6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-22 00:00:00', 3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-23 00:00:00', 5.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-24 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-25 00:00:00', 7.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-26 00:00:00', 7.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-27 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-28 00:00:00', -1.00199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-02-29 00:00:00', -1.10300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-01 00:00:00', 0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-02 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-03 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-04 00:00:00', 0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-05 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-06 00:00:00', 5.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-07 00:00:00', 4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-08 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-09 00:00:00', 2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-10 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-11 00:00:00', 0.0309999994933605194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-12 00:00:00', -2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-13 00:00:00', -1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-14 00:00:00', 2.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-15 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-16 00:00:00', 3.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-17 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-18 00:00:00', 5.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-19 00:00:00', 5.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-20 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-21 00:00:00', 7.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-22 00:00:00', 6.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-23 00:00:00', 6.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-24 00:00:00', 7.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-25 00:00:00', 9.87899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-26 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-27 00:00:00', 5.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-28 00:00:00', 8.35700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-29 00:00:00', 7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-30 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-03-31 00:00:00', 9.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-01 00:00:00', 13.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-02 00:00:00', 8.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-03 00:00:00', 12.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-04 00:00:00', 11.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-05 00:00:00', 15.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-06 00:00:00', 8.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-07 00:00:00', 10.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-08 00:00:00', 14.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-09 00:00:00', 16.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-10 00:00:00', 12.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-11 00:00:00', 12.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-12 00:00:00', 13.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-13 00:00:00', 17.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-14 00:00:00', 19.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-15 00:00:00', 19.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-16 00:00:00', 15.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-17 00:00:00', 11.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-18 00:00:00', 16.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-19 00:00:00', 18.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-20 00:00:00', 16.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-21 00:00:00', 15.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-22 00:00:00', 16.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-23 00:00:00', 19.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-24 00:00:00', 12.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-25 00:00:00', 18.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-26 00:00:00', 17.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-27 00:00:00', 17.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-28 00:00:00', 16.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-29 00:00:00', 15.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-04-30 00:00:00', 17.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-01 00:00:00', 12.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-02 00:00:00', 6.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-03 00:00:00', 7.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-04 00:00:00', 11.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-05 00:00:00', 14.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-06 00:00:00', 7.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-07 00:00:00', 13.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-08 00:00:00', 13.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-09 00:00:00', 17.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-10 00:00:00', 19.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-11 00:00:00', 21.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-12 00:00:00', 23.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-13 00:00:00', 21.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-14 00:00:00', 20.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-15 00:00:00', 16.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-16 00:00:00', 16.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-17 00:00:00', 17.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-18 00:00:00', 15.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-19 00:00:00', 17.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-20 00:00:00', 17.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-21 00:00:00', 18.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-22 00:00:00', 20.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-23 00:00:00', 21.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-24 00:00:00', 20.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-25 00:00:00', 19.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-26 00:00:00', 15.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-27 00:00:00', 16.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-28 00:00:00', 18.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-29 00:00:00', 19.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-30 00:00:00', 20.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-05-31 00:00:00', 21.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-01 00:00:00', 22.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-02 00:00:00', 21.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-03 00:00:00', 24.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-04 00:00:00', 26.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-05 00:00:00', 26.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-06 00:00:00', 24.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-07 00:00:00', 24.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-08 00:00:00', 23.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-09 00:00:00', 24.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-10 00:00:00', 24.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-11 00:00:00', 25.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-12 00:00:00', 24.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-13 00:00:00', 21.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-14 00:00:00', 20.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-15 00:00:00', 23.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-16 00:00:00', 23.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-17 00:00:00', 23.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-18 00:00:00', 25.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-19 00:00:00', 29.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-20 00:00:00', 32.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-21 00:00:00', 25.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-22 00:00:00', 24.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-23 00:00:00', 24.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-24 00:00:00', 25.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-25 00:00:00', 25.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-26 00:00:00', 28.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-27 00:00:00', 28.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-28 00:00:00', 28.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-29 00:00:00', 28.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-06-30 00:00:00', 27.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-01 00:00:00', 28.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-02 00:00:00', 24.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-03 00:00:00', 24.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-04 00:00:00', 28.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-05 00:00:00', 29.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-06 00:00:00', 32.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-07 00:00:00', 32.6829986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-08 00:00:00', 31.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-09 00:00:00', 29.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-10 00:00:00', 31.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-11 00:00:00', 32.0320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-12 00:00:00', 30.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-13 00:00:00', 30.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-14 00:00:00', 27.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-15 00:00:00', 27.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-16 00:00:00', 29.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-17 00:00:00', 30.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-18 00:00:00', 31.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-19 00:00:00', 31.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-20 00:00:00', 32.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-21 00:00:00', 32.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-22 00:00:00', 33.2389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-23 00:00:00', 30.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-24 00:00:00', 31.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-25 00:00:00', 31.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-26 00:00:00', 32.6160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-27 00:00:00', 33.654998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-28 00:00:00', 33.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-29 00:00:00', 31.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-30 00:00:00', 28.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-07-31 00:00:00', 29.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-01 00:00:00', 32.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-02 00:00:00', 33.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-03 00:00:00', 32.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-04 00:00:00', 31.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-05 00:00:00', 28.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-06 00:00:00', 25.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-07 00:00:00', 25.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-08 00:00:00', 22.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-09 00:00:00', 24.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-10 00:00:00', 25.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-11 00:00:00', 26.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-12 00:00:00', 27.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-13 00:00:00', 25.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-14 00:00:00', 28.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-15 00:00:00', 28.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-16 00:00:00', 26.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-17 00:00:00', 24.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-18 00:00:00', 27.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-19 00:00:00', 27.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-20 00:00:00', 28.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-21 00:00:00', 26.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-22 00:00:00', 28.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-23 00:00:00', 29.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-24 00:00:00', 29.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-25 00:00:00', 31.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-26 00:00:00', 31.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-27 00:00:00', 30.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-28 00:00:00', 25.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-29 00:00:00', 25.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-30 00:00:00', 22.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-08-31 00:00:00', 21.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-01 00:00:00', 25.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-02 00:00:00', 21.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-03 00:00:00', 21.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-04 00:00:00', 25.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-05 00:00:00', 24.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-06 00:00:00', 23.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-07 00:00:00', 24.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-08 00:00:00', 25.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-09 00:00:00', 24.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-10 00:00:00', 22.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-11 00:00:00', 23.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-12 00:00:00', 22.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-13 00:00:00', 22.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-14 00:00:00', 23.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-15 00:00:00', 23.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-16 00:00:00', 22.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-17 00:00:00', 21.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-18 00:00:00', 21.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-19 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-20 00:00:00', 21.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-21 00:00:00', 21.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-22 00:00:00', 23.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-23 00:00:00', 23.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-24 00:00:00', 23.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-25 00:00:00', 24.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-26 00:00:00', 26.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-27 00:00:00', 24.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-28 00:00:00', 24.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-29 00:00:00', 20.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-09-30 00:00:00', 15.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-01 00:00:00', 15.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-02 00:00:00', 15.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-03 00:00:00', 17.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-04 00:00:00', 18.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-05 00:00:00', 16.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-06 00:00:00', 16.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-07 00:00:00', 13.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-08 00:00:00', 15.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-09 00:00:00', 14.7100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-10 00:00:00', 19.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-11 00:00:00', 22.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-12 00:00:00', 23.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-13 00:00:00', 21.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-14 00:00:00', 21.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-15 00:00:00', 18.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-16 00:00:00', 12.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-17 00:00:00', 8.35299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-18 00:00:00', 11.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-19 00:00:00', 14.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-20 00:00:00', 16.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-21 00:00:00', 14.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-22 00:00:00', 15.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-23 00:00:00', 16.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-24 00:00:00', 15.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-25 00:00:00', 15.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-26 00:00:00', 18.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-27 00:00:00', 18.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-28 00:00:00', 18.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-29 00:00:00', 20.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-30 00:00:00', 16.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-10-31 00:00:00', 16.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-01 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-02 00:00:00', 15.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-03 00:00:00', 14.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-04 00:00:00', 6.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-05 00:00:00', 7.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-06 00:00:00', 12.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-07 00:00:00', 14.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-08 00:00:00', 17.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-09 00:00:00', 16.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-10 00:00:00', 18.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-11 00:00:00', 17.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-12 00:00:00', 18.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-13 00:00:00', 20.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-14 00:00:00', 17.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-15 00:00:00', 15.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-16 00:00:00', 13.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-17 00:00:00', 14.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-18 00:00:00', 8.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-19 00:00:00', 5.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-20 00:00:00', 6.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-21 00:00:00', 5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-22 00:00:00', 9.05799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-23 00:00:00', 13.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-24 00:00:00', 15.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-25 00:00:00', 14.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-26 00:00:00', 16.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-27 00:00:00', 7.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-28 00:00:00', 8.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-29 00:00:00', 8.99899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-11-30 00:00:00', 11.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-01 00:00:00', 8.84599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-02 00:00:00', 7.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-03 00:00:00', 3.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-04 00:00:00', 7.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-05 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-06 00:00:00', 6.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-07 00:00:00', 6.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-08 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-09 00:00:00', 5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-10 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-11 00:00:00', 0.873000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-12 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-13 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-14 00:00:00', 6.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-15 00:00:00', 7.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-16 00:00:00', 8.38799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-17 00:00:00', 7.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-18 00:00:00', 5.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-19 00:00:00', 8.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-20 00:00:00', 9.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-21 00:00:00', 8.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-22 00:00:00', 5.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-23 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-24 00:00:00', 2.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-25 00:00:00', 3.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-26 00:00:00', 2.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-27 00:00:00', 1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-28 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-29 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-30 00:00:00', 1.45500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1992-12-31 00:00:00', 1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-01 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-02 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-03 00:00:00', -0.00600000005215406418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-04 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-05 00:00:00', 0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-06 00:00:00', -2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-07 00:00:00', -6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-08 00:00:00', -5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-09 00:00:00', -2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-10 00:00:00', -1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-11 00:00:00', -0.0780000016093254089, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-12 00:00:00', -1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-13 00:00:00', -2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-14 00:00:00', -2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-15 00:00:00', 0.202000007033348083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-16 00:00:00', -2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-17 00:00:00', 0.12200000137090683, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-18 00:00:00', -2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-19 00:00:00', -2.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-20 00:00:00', -2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-21 00:00:00', -1.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-22 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-23 00:00:00', 1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-24 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-25 00:00:00', 4.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-26 00:00:00', 2.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-27 00:00:00', 9.16100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-28 00:00:00', 7.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-29 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-30 00:00:00', 6.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-01-31 00:00:00', 6.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-01 00:00:00', 4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-02 00:00:00', 5.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-03 00:00:00', 7.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-04 00:00:00', 4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-05 00:00:00', 5.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-06 00:00:00', 4.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-07 00:00:00', 7.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-08 00:00:00', 5.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-09 00:00:00', 7.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-10 00:00:00', 5.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-11 00:00:00', 6.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-12 00:00:00', 7.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-13 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-14 00:00:00', 5.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-15 00:00:00', 5.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-16 00:00:00', 1.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-17 00:00:00', -1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-18 00:00:00', -4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-19 00:00:00', -2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-20 00:00:00', 0.164000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-21 00:00:00', 1.60300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-22 00:00:00', 1.6239999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-23 00:00:00', 4.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-24 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-25 00:00:00', -0.155000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-26 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-27 00:00:00', 2.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-02-28 00:00:00', 5.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-01 00:00:00', 3.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-02 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-03 00:00:00', -0.0970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-04 00:00:00', 5.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-05 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-06 00:00:00', 9.63599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-07 00:00:00', 7.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-08 00:00:00', 10.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-09 00:00:00', 11.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-10 00:00:00', 6.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-11 00:00:00', 5.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-12 00:00:00', 5.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-13 00:00:00', 4.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-14 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-15 00:00:00', 4.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-16 00:00:00', 3.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-17 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-18 00:00:00', 5.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-19 00:00:00', 6.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-20 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-21 00:00:00', 6.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-22 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-23 00:00:00', 5.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-24 00:00:00', 0.712999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-25 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-26 00:00:00', 5.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-27 00:00:00', 10.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-28 00:00:00', 11.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-29 00:00:00', 11.1479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-30 00:00:00', 11.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-03-31 00:00:00', 9.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-01 00:00:00', 7.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-02 00:00:00', 7.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-03 00:00:00', 11.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-04 00:00:00', 14.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-05 00:00:00', 12.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-06 00:00:00', 15.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-07 00:00:00', 12.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-08 00:00:00', 14.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-09 00:00:00', 17.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-10 00:00:00', 14.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-11 00:00:00', 15.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-12 00:00:00', 17.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-13 00:00:00', 18.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-14 00:00:00', 14.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-15 00:00:00', 8.24600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-16 00:00:00', 9.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-17 00:00:00', 13.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-18 00:00:00', 19.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-19 00:00:00', 19.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-20 00:00:00', 22.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-21 00:00:00', 22.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-22 00:00:00', 21.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-23 00:00:00', 19.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-24 00:00:00', 13.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-25 00:00:00', 15.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-26 00:00:00', 18.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-27 00:00:00', 17.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-28 00:00:00', 17.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-29 00:00:00', 15.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-04-30 00:00:00', 16.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-01 00:00:00', 19.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-02 00:00:00', 18.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-03 00:00:00', 19.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-04 00:00:00', 21.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-05 00:00:00', 18.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-06 00:00:00', 19.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-07 00:00:00', 19.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-08 00:00:00', 16.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-09 00:00:00', 8.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-10 00:00:00', 10.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-11 00:00:00', 10.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-12 00:00:00', 13.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-13 00:00:00', 17.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-14 00:00:00', 21.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-15 00:00:00', 17.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-16 00:00:00', 15.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-17 00:00:00', 19.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-18 00:00:00', 18.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-19 00:00:00', 18.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-20 00:00:00', 21.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-21 00:00:00', 18.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-22 00:00:00', 21.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-23 00:00:00', 24.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-24 00:00:00', 20.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-25 00:00:00', 21.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-26 00:00:00', 20.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-27 00:00:00', 23.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-28 00:00:00', 23.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-29 00:00:00', 22.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-30 00:00:00', 16.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-05-31 00:00:00', 17.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-01 00:00:00', 23.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-02 00:00:00', 19.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-03 00:00:00', 23.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-04 00:00:00', 25.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-05 00:00:00', 25.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-06 00:00:00', 22.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-07 00:00:00', 22.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-08 00:00:00', 21.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-09 00:00:00', 26.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-10 00:00:00', 29.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-11 00:00:00', 28.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-12 00:00:00', 27.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-13 00:00:00', 24.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-14 00:00:00', 25.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-15 00:00:00', 24.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-16 00:00:00', 25.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-17 00:00:00', 27.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-18 00:00:00', 28.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-19 00:00:00', 28.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-20 00:00:00', 30.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-21 00:00:00', 30.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-22 00:00:00', 31.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-23 00:00:00', 20.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-24 00:00:00', 24.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-25 00:00:00', 26.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-26 00:00:00', 23.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-27 00:00:00', 27.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-28 00:00:00', 28.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-29 00:00:00', 30.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-06-30 00:00:00', 32.9259986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-01 00:00:00', 32.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-02 00:00:00', 31.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-03 00:00:00', 32.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-04 00:00:00', 33.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-05 00:00:00', 32.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-06 00:00:00', 32.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-07 00:00:00', 33.1199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-08 00:00:00', 29.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-09 00:00:00', 25.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-10 00:00:00', 26.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-11 00:00:00', 26.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-12 00:00:00', 27.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-13 00:00:00', 29.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-14 00:00:00', 30.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-15 00:00:00', 29.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-16 00:00:00', 31.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-17 00:00:00', 31.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-18 00:00:00', 30.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-19 00:00:00', 32.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-20 00:00:00', 33.0940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-21 00:00:00', 31.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-22 00:00:00', 25.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-23 00:00:00', 25.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-24 00:00:00', 21.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-25 00:00:00', 24.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-26 00:00:00', 25.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-27 00:00:00', 28.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-28 00:00:00', 28.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-29 00:00:00', 28.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-30 00:00:00', 28.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-07-31 00:00:00', 28.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-01 00:00:00', 27.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-02 00:00:00', 29.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-03 00:00:00', 28.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-04 00:00:00', 27.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-05 00:00:00', 28.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-06 00:00:00', 28.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-07 00:00:00', 28.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-08 00:00:00', 26.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-09 00:00:00', 27.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-10 00:00:00', 24.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-11 00:00:00', 23.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-12 00:00:00', 25.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-13 00:00:00', 26.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-14 00:00:00', 28.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-15 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-16 00:00:00', 29.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-17 00:00:00', 27.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-18 00:00:00', 25.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-19 00:00:00', 23.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-20 00:00:00', 25.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-21 00:00:00', 26.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-22 00:00:00', 25.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-23 00:00:00', 26.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-24 00:00:00', 24.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-25 00:00:00', 23.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-26 00:00:00', 26.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-27 00:00:00', 30.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-28 00:00:00', 30.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-29 00:00:00', 31.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-30 00:00:00', 30.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-08-31 00:00:00', 31.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-01 00:00:00', 32.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-02 00:00:00', 30.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-03 00:00:00', 27.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-04 00:00:00', 28.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-05 00:00:00', 28.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-06 00:00:00', 28.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-07 00:00:00', 29.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-08 00:00:00', 28.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-09 00:00:00', 28.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-10 00:00:00', 28.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-11 00:00:00', 26.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-12 00:00:00', 24.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-13 00:00:00', 27.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-14 00:00:00', 27.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-15 00:00:00', 28.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-16 00:00:00', 22.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-17 00:00:00', 22.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-18 00:00:00', 25.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-19 00:00:00', 26.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-20 00:00:00', 27.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-21 00:00:00', 25.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-22 00:00:00', 25.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-23 00:00:00', 21.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-24 00:00:00', 21.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-25 00:00:00', 23.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-26 00:00:00', 22.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-27 00:00:00', 19.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-28 00:00:00', 18.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-29 00:00:00', 23.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-09-30 00:00:00', 24.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-01 00:00:00', 22.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-02 00:00:00', 25.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-03 00:00:00', 20.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-04 00:00:00', 19.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-05 00:00:00', 9.84300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-06 00:00:00', 9.99699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-07 00:00:00', 10.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-08 00:00:00', 7.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-09 00:00:00', 10.5819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-10 00:00:00', 12.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-11 00:00:00', 14.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-12 00:00:00', 16.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-13 00:00:00', 15.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-14 00:00:00', 15.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-15 00:00:00', 16.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-16 00:00:00', 12.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-17 00:00:00', 12.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-18 00:00:00', 14.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-19 00:00:00', 14.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-20 00:00:00', 14.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-21 00:00:00', 13.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-22 00:00:00', 11.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-23 00:00:00', 12.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-24 00:00:00', 12.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-25 00:00:00', 9.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-26 00:00:00', 12.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-27 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-28 00:00:00', 16.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-29 00:00:00', 16.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-30 00:00:00', 15.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-10-31 00:00:00', 15.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-01 00:00:00', 16.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-02 00:00:00', 10.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-03 00:00:00', 9.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-04 00:00:00', 6.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-05 00:00:00', 8.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-06 00:00:00', 4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-07 00:00:00', 9.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-08 00:00:00', 1.72899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-09 00:00:00', 6.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-10 00:00:00', 11.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-11 00:00:00', 9.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-12 00:00:00', 14.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-13 00:00:00', 9.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-14 00:00:00', 14.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-15 00:00:00', 8.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-16 00:00:00', 11.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-17 00:00:00', 6.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-18 00:00:00', 3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-19 00:00:00', 10.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-20 00:00:00', 10.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-21 00:00:00', 3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-22 00:00:00', 0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-23 00:00:00', 2.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-24 00:00:00', 6.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-25 00:00:00', 6.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-26 00:00:00', 3.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-27 00:00:00', 3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-28 00:00:00', 6.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-29 00:00:00', 5.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-11-30 00:00:00', 3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-01 00:00:00', -0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-02 00:00:00', -0.643000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-03 00:00:00', -0.859000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-04 00:00:00', -0.81800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-05 00:00:00', 4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-06 00:00:00', 4.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-07 00:00:00', 1.34700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-08 00:00:00', 4.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-09 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-10 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-11 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-12 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-13 00:00:00', -1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-14 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-15 00:00:00', 5.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-16 00:00:00', 5.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-17 00:00:00', 5.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-18 00:00:00', 3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-19 00:00:00', 5.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-20 00:00:00', 3.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-21 00:00:00', -0.017000000923871994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-22 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-23 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-24 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-25 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-26 00:00:00', 4.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-27 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-28 00:00:00', 2.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-29 00:00:00', 2.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-30 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1993-12-31 00:00:00', 1.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-01 00:00:00', -1.88699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-02 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-03 00:00:00', 0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-04 00:00:00', 1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-05 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-06 00:00:00', 3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-07 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-08 00:00:00', 0.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-09 00:00:00', -0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-10 00:00:00', -4.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-11 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-12 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-13 00:00:00', 3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-14 00:00:00', -0.319999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-15 00:00:00', -0.603999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-16 00:00:00', 1.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-17 00:00:00', 3.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-18 00:00:00', -0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-19 00:00:00', -1.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-20 00:00:00', -2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-21 00:00:00', 0.352999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-22 00:00:00', -0.504000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-23 00:00:00', 3.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-24 00:00:00', 1.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-25 00:00:00', 5.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-26 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-27 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-28 00:00:00', 2.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-29 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-30 00:00:00', 3.0820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-01-31 00:00:00', 0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-01 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-02 00:00:00', 2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-03 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-04 00:00:00', -0.179000005125999451, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-05 00:00:00', -2.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-06 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-07 00:00:00', -0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-08 00:00:00', -2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-09 00:00:00', -2.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-10 00:00:00', -2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-11 00:00:00', -4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-12 00:00:00', -1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-13 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-14 00:00:00', 2.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-15 00:00:00', -0.764999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-16 00:00:00', -3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-17 00:00:00', -2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-18 00:00:00', -1.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-19 00:00:00', 0.677999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-20 00:00:00', -2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-21 00:00:00', -3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-22 00:00:00', -0.629000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-23 00:00:00', -0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-24 00:00:00', 2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-25 00:00:00', 4.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-26 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-27 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-02-28 00:00:00', 5.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-01 00:00:00', 6.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-02 00:00:00', 6.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-03 00:00:00', 2.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-04 00:00:00', 4.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-05 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-06 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-07 00:00:00', 8.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-08 00:00:00', 9.86200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-09 00:00:00', 9.23499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-10 00:00:00', 7.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-11 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-12 00:00:00', 6.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-13 00:00:00', 4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-14 00:00:00', 5.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-15 00:00:00', 3.86400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-16 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-17 00:00:00', 9.56000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-18 00:00:00', 5.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-19 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-20 00:00:00', 11.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-21 00:00:00', 8.39700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-22 00:00:00', 12.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-23 00:00:00', 13.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-24 00:00:00', 14.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-25 00:00:00', 5.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-26 00:00:00', 10.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-27 00:00:00', 13.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-28 00:00:00', 11.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-29 00:00:00', 13.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-30 00:00:00', 11.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-03-31 00:00:00', 13.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-01 00:00:00', 13.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-02 00:00:00', 15.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-03 00:00:00', 9.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-04 00:00:00', 9.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-05 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-06 00:00:00', -0.852999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-07 00:00:00', 4.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-08 00:00:00', 6.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-09 00:00:00', 5.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-10 00:00:00', 9.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-11 00:00:00', 12.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-12 00:00:00', 12.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-13 00:00:00', 10.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-14 00:00:00', 11.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-15 00:00:00', 11.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-16 00:00:00', 10.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-17 00:00:00', 13.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-18 00:00:00', 14.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-19 00:00:00', 13.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-20 00:00:00', 13.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-21 00:00:00', 11.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-22 00:00:00', 14.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-23 00:00:00', 15.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-24 00:00:00', 18.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-25 00:00:00', 21.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-26 00:00:00', 21.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-27 00:00:00', 21.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-28 00:00:00', 16.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-29 00:00:00', 16.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-04-30 00:00:00', 12.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-01 00:00:00', 16.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-02 00:00:00', 19.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-03 00:00:00', 19.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-04 00:00:00', 17.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-05 00:00:00', 19.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-06 00:00:00', 22.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-07 00:00:00', 22.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-08 00:00:00', 16.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-09 00:00:00', 15.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-10 00:00:00', 17.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-11 00:00:00', 20.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-12 00:00:00', 21.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-13 00:00:00', 21.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-14 00:00:00', 22.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-15 00:00:00', 25.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-16 00:00:00', 24.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-17 00:00:00', 24.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-18 00:00:00', 22.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-19 00:00:00', 17.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-20 00:00:00', 21.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-21 00:00:00', 22.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-22 00:00:00', 23.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-23 00:00:00', 20.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-24 00:00:00', 17.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-25 00:00:00', 22.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-26 00:00:00', 23.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-27 00:00:00', 24.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-28 00:00:00', 25.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-29 00:00:00', 26.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-30 00:00:00', 26.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-05-31 00:00:00', 24.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-01 00:00:00', 24.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-02 00:00:00', 24.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-03 00:00:00', 24.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-04 00:00:00', 26.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-05 00:00:00', 27.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-06 00:00:00', 30.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-07 00:00:00', 28.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-08 00:00:00', 23.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-09 00:00:00', 23.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-10 00:00:00', 24.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-11 00:00:00', 22.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-12 00:00:00', 22.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-13 00:00:00', 24.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-14 00:00:00', 25.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-15 00:00:00', 28.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-16 00:00:00', 27.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-17 00:00:00', 29.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-18 00:00:00', 33.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-19 00:00:00', 30.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-20 00:00:00', 30.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-21 00:00:00', 32.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-22 00:00:00', 30.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-23 00:00:00', 33.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-24 00:00:00', 30.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-25 00:00:00', 29.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-26 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-27 00:00:00', 29.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-28 00:00:00', 31.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-29 00:00:00', 32.66400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-06-30 00:00:00', 35.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-01 00:00:00', 35.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-02 00:00:00', 30.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-03 00:00:00', 29.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-04 00:00:00', 31.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-05 00:00:00', 32.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-06 00:00:00', 33.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-07 00:00:00', 34.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-08 00:00:00', 35.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-09 00:00:00', 36.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-10 00:00:00', 35.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-11 00:00:00', 30.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-12 00:00:00', 29.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-13 00:00:00', 27.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-14 00:00:00', 27.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-15 00:00:00', 30.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-16 00:00:00', 30.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-17 00:00:00', 32.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-18 00:00:00', 34.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-19 00:00:00', 32.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-20 00:00:00', 32.5239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-21 00:00:00', 33.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-22 00:00:00', 34.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-23 00:00:00', 32.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-24 00:00:00', 30.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-25 00:00:00', 31.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-26 00:00:00', 32.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-27 00:00:00', 33.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-28 00:00:00', 32.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-29 00:00:00', 31.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-30 00:00:00', 32.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-07-31 00:00:00', 33.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-01 00:00:00', 35.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-02 00:00:00', 36.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-03 00:00:00', 37.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-04 00:00:00', 36.2379989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-05 00:00:00', 35.266998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-06 00:00:00', 34.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-07 00:00:00', 33.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-08 00:00:00', 29.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-09 00:00:00', 27.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-10 00:00:00', 27.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-11 00:00:00', 30.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-12 00:00:00', 32.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-13 00:00:00', 34.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-14 00:00:00', 33.5110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-15 00:00:00', 30.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-16 00:00:00', 29.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-17 00:00:00', 28.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-18 00:00:00', 30.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-19 00:00:00', 32.1489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-20 00:00:00', 33.1769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-21 00:00:00', 33.1160011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-22 00:00:00', 32.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-23 00:00:00', 32.8079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-24 00:00:00', 32.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-25 00:00:00', 33.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-26 00:00:00', 31.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-27 00:00:00', 30.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-28 00:00:00', 29.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-29 00:00:00', 28.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-30 00:00:00', 30.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-08-31 00:00:00', 28.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-01 00:00:00', 28.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-02 00:00:00', 28.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-03 00:00:00', 28.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-04 00:00:00', 25.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-05 00:00:00', 22.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-06 00:00:00', 19.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-07 00:00:00', 22.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-08 00:00:00', 23.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-09 00:00:00', 24.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-10 00:00:00', 23.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-11 00:00:00', 23.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-12 00:00:00', 22.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-13 00:00:00', 22.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-14 00:00:00', 22.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-15 00:00:00', 18.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-16 00:00:00', 20.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-17 00:00:00', 18.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-18 00:00:00', 12.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-19 00:00:00', 12.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-20 00:00:00', 13.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-21 00:00:00', 15.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-22 00:00:00', 17.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-23 00:00:00', 16.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-24 00:00:00', 17.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-25 00:00:00', 19.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-26 00:00:00', 21.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-27 00:00:00', 23.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-28 00:00:00', 23.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-29 00:00:00', 22.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-09-30 00:00:00', 21.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-01 00:00:00', 21.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-02 00:00:00', 20.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-03 00:00:00', 20.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-04 00:00:00', 19.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-05 00:00:00', 16.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-06 00:00:00', 16.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-07 00:00:00', 18.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-08 00:00:00', 19.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-09 00:00:00', 17.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-10 00:00:00', 16.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-11 00:00:00', 15.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-12 00:00:00', 14.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-13 00:00:00', 14.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-14 00:00:00', 14.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-15 00:00:00', 15.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-16 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-17 00:00:00', 12.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-18 00:00:00', 18.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-19 00:00:00', 17.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-20 00:00:00', 19.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-21 00:00:00', 19.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-22 00:00:00', 18.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-23 00:00:00', 14.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-24 00:00:00', 9.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-25 00:00:00', 8.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-26 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-27 00:00:00', 12.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-28 00:00:00', 12.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-29 00:00:00', 12.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-30 00:00:00', 13.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-10-31 00:00:00', 13.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-01 00:00:00', 11.9049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-02 00:00:00', 9.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-03 00:00:00', 12.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-04 00:00:00', 13.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-05 00:00:00', 14.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-06 00:00:00', 14.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-07 00:00:00', 11.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-08 00:00:00', 14.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-09 00:00:00', 15.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-10 00:00:00', 10.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-11 00:00:00', 6.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-12 00:00:00', 10.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-13 00:00:00', 10.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-14 00:00:00', 8.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-15 00:00:00', 9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-16 00:00:00', 10.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-17 00:00:00', 10.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-18 00:00:00', 13.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-19 00:00:00', 8.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-20 00:00:00', 10.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-21 00:00:00', 11.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-22 00:00:00', 10.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-23 00:00:00', 11.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-24 00:00:00', 11.255000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-25 00:00:00', 8.25300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-26 00:00:00', 11.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-27 00:00:00', 7.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-28 00:00:00', 11.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-29 00:00:00', 9.17300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-11-30 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-01 00:00:00', 9.92800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-02 00:00:00', 6.82700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-03 00:00:00', 9.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-04 00:00:00', 8.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-05 00:00:00', 7.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-06 00:00:00', 2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-07 00:00:00', -1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-08 00:00:00', -5.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-09 00:00:00', -1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-10 00:00:00', -1.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-11 00:00:00', -0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-12 00:00:00', 0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-13 00:00:00', -0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-14 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-15 00:00:00', 0.574000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-16 00:00:00', 2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-17 00:00:00', 4.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-18 00:00:00', 4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-19 00:00:00', 6.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-20 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-21 00:00:00', 2.42300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-22 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-23 00:00:00', -2.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-24 00:00:00', -3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-25 00:00:00', 0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-26 00:00:00', -1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-27 00:00:00', 0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-28 00:00:00', -2.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-29 00:00:00', -2.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-30 00:00:00', 1.71599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1994-12-31 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-01 00:00:00', 7.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-02 00:00:00', 6.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-03 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-04 00:00:00', 3.49799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-05 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-06 00:00:00', 3.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-07 00:00:00', -0.232999995350837708, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-08 00:00:00', -0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-09 00:00:00', -0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-10 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-11 00:00:00', 0.879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-12 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-13 00:00:00', 0.404000014066696167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-14 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-15 00:00:00', -0.0489999987185001373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-16 00:00:00', -1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-17 00:00:00', 2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-18 00:00:00', 2.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-19 00:00:00', -0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-20 00:00:00', 0.660000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-21 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-22 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-23 00:00:00', 1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-24 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-25 00:00:00', -2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-26 00:00:00', 2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-27 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-28 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-29 00:00:00', 4.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-30 00:00:00', 7.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-01-31 00:00:00', 7.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-01 00:00:00', 5.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-02 00:00:00', 7.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-03 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-04 00:00:00', 4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-05 00:00:00', 4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-06 00:00:00', 2.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-07 00:00:00', 3.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-08 00:00:00', 3.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-09 00:00:00', 5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-10 00:00:00', 6.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-11 00:00:00', 2.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-12 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-13 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-14 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-15 00:00:00', 2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-16 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-17 00:00:00', -0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-18 00:00:00', -4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-19 00:00:00', -2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-20 00:00:00', 0.709999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-21 00:00:00', 3.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-22 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-23 00:00:00', 3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-24 00:00:00', 6.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-25 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-26 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-27 00:00:00', -1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-02-28 00:00:00', -0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-01 00:00:00', 2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-02 00:00:00', 3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-03 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-04 00:00:00', -0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-05 00:00:00', 4.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-06 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-07 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-08 00:00:00', 3.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-09 00:00:00', 0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-10 00:00:00', 3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-11 00:00:00', 4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-12 00:00:00', 4.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-13 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-14 00:00:00', 6.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-15 00:00:00', 7.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-16 00:00:00', 9.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-17 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-18 00:00:00', 7.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-19 00:00:00', 9.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-20 00:00:00', 5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-21 00:00:00', 7.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-22 00:00:00', 8.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-23 00:00:00', 9.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-24 00:00:00', 11.4110002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-25 00:00:00', 10.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-26 00:00:00', 12.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-27 00:00:00', 10.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-28 00:00:00', 9.47099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-29 00:00:00', 7.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-30 00:00:00', 8.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-03-31 00:00:00', 9.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-01 00:00:00', 7.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-02 00:00:00', 9.25399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-03 00:00:00', 13.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-04 00:00:00', 14.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-05 00:00:00', 17.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-06 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-07 00:00:00', 6.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-08 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-09 00:00:00', 12.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-10 00:00:00', 12.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-11 00:00:00', 16.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-12 00:00:00', 16.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-13 00:00:00', 19.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-14 00:00:00', 17.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-15 00:00:00', 16.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-16 00:00:00', 17.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-17 00:00:00', 18.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-18 00:00:00', 16.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-19 00:00:00', 14.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-20 00:00:00', 14.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-21 00:00:00', 16.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-22 00:00:00', 16.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-23 00:00:00', 17.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-24 00:00:00', 17.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-25 00:00:00', 19.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-26 00:00:00', 16.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-27 00:00:00', 14.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-28 00:00:00', 15.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-29 00:00:00', 20.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-04-30 00:00:00', 18.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-01 00:00:00', 21.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-02 00:00:00', 21.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-03 00:00:00', 23.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-04 00:00:00', 24.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-05 00:00:00', 24.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-06 00:00:00', 25.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-07 00:00:00', 27.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-08 00:00:00', 28.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-09 00:00:00', 27.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-10 00:00:00', 23.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-11 00:00:00', 22.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-12 00:00:00', 23.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-13 00:00:00', 23.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-14 00:00:00', 24.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-15 00:00:00', 25.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-16 00:00:00', 24.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-17 00:00:00', 21.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-18 00:00:00', 21.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-19 00:00:00', 17.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-20 00:00:00', 21.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-21 00:00:00', 20.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-22 00:00:00', 18.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-23 00:00:00', 17.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-24 00:00:00', 18.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-25 00:00:00', 12.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-26 00:00:00', 16.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-27 00:00:00', 16.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-28 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-29 00:00:00', 18.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-30 00:00:00', 20.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-05-31 00:00:00', 21.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-01 00:00:00', 23.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-02 00:00:00', 22.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-03 00:00:00', 21.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-04 00:00:00', 25.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-05 00:00:00', 28.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-06 00:00:00', 29.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-07 00:00:00', 24.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-08 00:00:00', 25.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-09 00:00:00', 25.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-10 00:00:00', 21.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-11 00:00:00', 24.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-12 00:00:00', 25.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-13 00:00:00', 20.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-14 00:00:00', 28.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-15 00:00:00', 31.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-16 00:00:00', 32.5940017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-17 00:00:00', 30.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-18 00:00:00', 28.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-19 00:00:00', 27.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-20 00:00:00', 24.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-21 00:00:00', 26.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-22 00:00:00', 26.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-23 00:00:00', 25.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-24 00:00:00', 16.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-25 00:00:00', 26.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-26 00:00:00', 26.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-27 00:00:00', 26.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-28 00:00:00', 27.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-29 00:00:00', 24.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-06-30 00:00:00', 24.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-01 00:00:00', 33.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-02 00:00:00', 26.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-03 00:00:00', 32.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-04 00:00:00', 33.3380012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-05 00:00:00', 31.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-06 00:00:00', 30.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-07 00:00:00', 23.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-08 00:00:00', 24.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-09 00:00:00', 25.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-10 00:00:00', 27.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-11 00:00:00', 26.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-12 00:00:00', 29.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-13 00:00:00', 31.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-14 00:00:00', 31.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-15 00:00:00', 34.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-16 00:00:00', 34.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-17 00:00:00', 36.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-18 00:00:00', 37.7750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-19 00:00:00', 26.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-20 00:00:00', 27.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-21 00:00:00', 31.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-22 00:00:00', 32.5099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-23 00:00:00', 32.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-24 00:00:00', 29.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-25 00:00:00', 25.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-26 00:00:00', 28.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-27 00:00:00', 31.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-28 00:00:00', 30.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-29 00:00:00', 31.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-30 00:00:00', 32.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-07-31 00:00:00', 34.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-01 00:00:00', 34.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-02 00:00:00', 33.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-03 00:00:00', 32.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-04 00:00:00', 30.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-05 00:00:00', 29.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-06 00:00:00', 26.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-07 00:00:00', 26.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-08 00:00:00', 29.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-09 00:00:00', 32.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-10 00:00:00', 34.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-11 00:00:00', 28.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-12 00:00:00', 34.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-13 00:00:00', 34.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-14 00:00:00', 32.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-15 00:00:00', 32.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-16 00:00:00', 31.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-17 00:00:00', 31.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-18 00:00:00', 31.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-19 00:00:00', 32.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-20 00:00:00', 31.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-21 00:00:00', 28.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-22 00:00:00', 29.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-23 00:00:00', 31.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-24 00:00:00', 32.0260009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-25 00:00:00', 27.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-26 00:00:00', 29.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-27 00:00:00', 29.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-28 00:00:00', 28.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-29 00:00:00', 15.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-30 00:00:00', 13.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-08-31 00:00:00', 12.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-01 00:00:00', 20.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-02 00:00:00', 19.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-03 00:00:00', 18.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-04 00:00:00', 22.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-05 00:00:00', 20.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-06 00:00:00', 23.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-07 00:00:00', 24.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-08 00:00:00', 24.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-09 00:00:00', 25.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-10 00:00:00', 26.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-11 00:00:00', 24.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-12 00:00:00', 24.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-13 00:00:00', 23.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-14 00:00:00', 24.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-15 00:00:00', 24.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-16 00:00:00', 24.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-17 00:00:00', 25.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-18 00:00:00', 26.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-19 00:00:00', 27.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-20 00:00:00', 29.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-21 00:00:00', 30.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-22 00:00:00', 23.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-23 00:00:00', 19.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-24 00:00:00', 23.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-25 00:00:00', 25.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-26 00:00:00', 26.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-27 00:00:00', 25.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-28 00:00:00', 15.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-29 00:00:00', 20.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-09-30 00:00:00', 22.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-01 00:00:00', 13.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-02 00:00:00', 9.51299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-03 00:00:00', 9.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-04 00:00:00', 7.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-05 00:00:00', 21.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-06 00:00:00', 22.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-07 00:00:00', 22.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-08 00:00:00', 22.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-09 00:00:00', 14.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-10 00:00:00', 8.83600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-11 00:00:00', 13.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-12 00:00:00', 9.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-13 00:00:00', 8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-14 00:00:00', 2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-15 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-16 00:00:00', 3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-17 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-18 00:00:00', 1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-19 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-20 00:00:00', 5.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-21 00:00:00', 6.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-22 00:00:00', 6.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-23 00:00:00', 13.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-24 00:00:00', 5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-25 00:00:00', 4.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-26 00:00:00', 8.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-27 00:00:00', 8.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-28 00:00:00', 7.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-29 00:00:00', 8.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-30 00:00:00', 8.44200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-10-31 00:00:00', 8.57699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-01 00:00:00', 11.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-02 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-03 00:00:00', 15.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-04 00:00:00', 16.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-05 00:00:00', 15.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-06 00:00:00', 14.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-07 00:00:00', 13.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-08 00:00:00', 15.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-09 00:00:00', 15.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-10 00:00:00', 15.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-11 00:00:00', 14.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-12 00:00:00', 13.3739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-13 00:00:00', 10.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-14 00:00:00', 10.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-15 00:00:00', 9.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-16 00:00:00', 6.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-17 00:00:00', 7.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-18 00:00:00', 6.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-19 00:00:00', 4.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-20 00:00:00', 6.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-21 00:00:00', 7.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-22 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-23 00:00:00', 5.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-24 00:00:00', 6.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-25 00:00:00', 7.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-26 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-27 00:00:00', 0.731999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-28 00:00:00', -1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-29 00:00:00', -0.430000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-11-30 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-01 00:00:00', 0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-02 00:00:00', 0.289000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-03 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-04 00:00:00', 0.958999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-05 00:00:00', 1.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-06 00:00:00', 1.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-07 00:00:00', 0.612999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-08 00:00:00', 0.072999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-09 00:00:00', -0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-10 00:00:00', -2.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-11 00:00:00', -4.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-12 00:00:00', -0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-13 00:00:00', -1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-14 00:00:00', -2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-15 00:00:00', -4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-16 00:00:00', -0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-17 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-18 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-19 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-20 00:00:00', -0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-21 00:00:00', 0.225999996066093445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-22 00:00:00', 0.606999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-23 00:00:00', 0.898999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-24 00:00:00', -1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-25 00:00:00', 1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-26 00:00:00', 2.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-27 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-28 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-29 00:00:00', 1.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-30 00:00:00', 1.63600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1995-12-31 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-01 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-02 00:00:00', 1.23500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-03 00:00:00', 0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-04 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-05 00:00:00', 1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-06 00:00:00', 1.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-07 00:00:00', 2.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-08 00:00:00', 0.935000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-09 00:00:00', 0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-10 00:00:00', -5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-11 00:00:00', -7.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-12 00:00:00', -2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-13 00:00:00', -4.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-14 00:00:00', -6.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-15 00:00:00', -7.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-16 00:00:00', -6.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-17 00:00:00', -1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-18 00:00:00', 0.676999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-19 00:00:00', -0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-20 00:00:00', -0.574000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-21 00:00:00', -3.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-22 00:00:00', -2.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-23 00:00:00', 0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-24 00:00:00', -0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-25 00:00:00', -1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-26 00:00:00', -1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-27 00:00:00', -2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-28 00:00:00', -3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-29 00:00:00', -0.305000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-30 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-01-31 00:00:00', 0.605000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-01 00:00:00', 0.651000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-02 00:00:00', 1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-03 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-04 00:00:00', -0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-05 00:00:00', 2.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-06 00:00:00', 2.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-07 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-08 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-09 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-10 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-11 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-12 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-13 00:00:00', -1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-14 00:00:00', -4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-15 00:00:00', -5.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-16 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-17 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-18 00:00:00', 4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-19 00:00:00', 6.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-20 00:00:00', 6.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-21 00:00:00', 3.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-22 00:00:00', 2.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-23 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-24 00:00:00', -1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-25 00:00:00', -0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-26 00:00:00', -2.3320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-27 00:00:00', -3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-28 00:00:00', -0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-02-29 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-01 00:00:00', 1.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-02 00:00:00', 2.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-03 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-04 00:00:00', 5.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-05 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-06 00:00:00', 4.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-07 00:00:00', 4.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-08 00:00:00', 8.15200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-09 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-10 00:00:00', 9.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-11 00:00:00', 10.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-12 00:00:00', 5.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-13 00:00:00', 10.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-14 00:00:00', 10.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-15 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-16 00:00:00', 4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-17 00:00:00', 4.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-18 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-19 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-20 00:00:00', 2.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-21 00:00:00', 2.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-22 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-23 00:00:00', 8.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-24 00:00:00', 4.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-25 00:00:00', 7.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-26 00:00:00', 10.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-27 00:00:00', 6.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-28 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-29 00:00:00', 3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-30 00:00:00', 3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-03-31 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-01 00:00:00', 5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-02 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-03 00:00:00', 5.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-04 00:00:00', 2.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-05 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-06 00:00:00', 6.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-07 00:00:00', 4.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-08 00:00:00', 8.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-09 00:00:00', 7.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-10 00:00:00', 9.68700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-11 00:00:00', 9.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-12 00:00:00', 8.37899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-13 00:00:00', 12.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-14 00:00:00', 17.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-15 00:00:00', 18.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-16 00:00:00', 15.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-17 00:00:00', 11.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-18 00:00:00', 14.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-19 00:00:00', 19.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-20 00:00:00', 17.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-21 00:00:00', 18.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-22 00:00:00', 17.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-23 00:00:00', 17.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-24 00:00:00', 14.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-25 00:00:00', 13.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-26 00:00:00', 9.53199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-27 00:00:00', 14.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-28 00:00:00', 15.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-29 00:00:00', 16.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-04-30 00:00:00', 11.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-01 00:00:00', 12.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-02 00:00:00', 12.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-03 00:00:00', 12.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-04 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-05 00:00:00', 9.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-06 00:00:00', 11.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-07 00:00:00', 14.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-08 00:00:00', 12.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-09 00:00:00', 14.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-10 00:00:00', 14.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-11 00:00:00', 15.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-12 00:00:00', 15.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-13 00:00:00', 19.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-14 00:00:00', 19.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-15 00:00:00', 18.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-16 00:00:00', 19.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-17 00:00:00', 21.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-18 00:00:00', 21.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-19 00:00:00', 21.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-20 00:00:00', 18.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-21 00:00:00', 20.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-22 00:00:00', 21.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-23 00:00:00', 21.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-24 00:00:00', 21.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-25 00:00:00', 24.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-26 00:00:00', 25.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-27 00:00:00', 20.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-28 00:00:00', 18.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-29 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-30 00:00:00', 22.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-05-31 00:00:00', 23.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-01 00:00:00', 24.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-02 00:00:00', 25.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-03 00:00:00', 27.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-04 00:00:00', 26.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-05 00:00:00', 25.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-06 00:00:00', 27.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-07 00:00:00', 31.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-08 00:00:00', 30.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-09 00:00:00', 29.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-10 00:00:00', 31.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-11 00:00:00', 29.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-12 00:00:00', 25.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-13 00:00:00', 26.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-14 00:00:00', 24.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-15 00:00:00', 22.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-16 00:00:00', 20.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-17 00:00:00', 21.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-18 00:00:00', 22.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-19 00:00:00', 24.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-20 00:00:00', 26.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-21 00:00:00', 27.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-22 00:00:00', 29.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-23 00:00:00', 29.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-24 00:00:00', 29.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-25 00:00:00', 28.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-26 00:00:00', 28.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-27 00:00:00', 28.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-28 00:00:00', 25.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-29 00:00:00', 23.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-06-30 00:00:00', 26.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-01 00:00:00', 29.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-02 00:00:00', 28.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-03 00:00:00', 27.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-04 00:00:00', 26.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-05 00:00:00', 27.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-06 00:00:00', 28.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-07 00:00:00', 30.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-08 00:00:00', 31.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-09 00:00:00', 32.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-10 00:00:00', 29.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-11 00:00:00', 27.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-12 00:00:00', 27.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-13 00:00:00', 24.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-14 00:00:00', 22.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-15 00:00:00', 22.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-16 00:00:00', 22.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-17 00:00:00', 24.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-18 00:00:00', 27.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-19 00:00:00', 27.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-20 00:00:00', 25.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-21 00:00:00', 26.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-22 00:00:00', 28.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-23 00:00:00', 29.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-24 00:00:00', 31.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-25 00:00:00', 32.8979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-26 00:00:00', 33.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-27 00:00:00', 33.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-28 00:00:00', 34.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-29 00:00:00', 32.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-30 00:00:00', 32.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-07-31 00:00:00', 30.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-01 00:00:00', 32.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-02 00:00:00', 29.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-03 00:00:00', 31.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-04 00:00:00', 31.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-05 00:00:00', 32.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-06 00:00:00', 32.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-07 00:00:00', 32.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-08 00:00:00', 31.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-09 00:00:00', 33.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-10 00:00:00', 33.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-11 00:00:00', 34.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-12 00:00:00', 35.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-13 00:00:00', 34.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-14 00:00:00', 32.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-15 00:00:00', 28.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-16 00:00:00', 25.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-17 00:00:00', 24.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-18 00:00:00', 24.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-19 00:00:00', 25.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-20 00:00:00', 25.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-21 00:00:00', 26.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-22 00:00:00', 27.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-23 00:00:00', 27.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-24 00:00:00', 27.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-25 00:00:00', 27.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-26 00:00:00', 29.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-27 00:00:00', 30.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-28 00:00:00', 31.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-29 00:00:00', 28.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-30 00:00:00', 21.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-08-31 00:00:00', 23.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-01 00:00:00', 24.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-02 00:00:00', 23.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-03 00:00:00', 23.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-04 00:00:00', 22.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-05 00:00:00', 25.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-06 00:00:00', 27.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-07 00:00:00', 26.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-08 00:00:00', 27.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-09 00:00:00', 30.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-10 00:00:00', 31.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-11 00:00:00', 32.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-12 00:00:00', 31.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-13 00:00:00', 30.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-14 00:00:00', 30.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-15 00:00:00', 26.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-16 00:00:00', 25.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-17 00:00:00', 25.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-18 00:00:00', 26.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-19 00:00:00', 27, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-20 00:00:00', 25.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-21 00:00:00', 25.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-22 00:00:00', 28.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-23 00:00:00', 27.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-24 00:00:00', 24.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-25 00:00:00', 20.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-26 00:00:00', 20.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-27 00:00:00', 21.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-28 00:00:00', 22.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-29 00:00:00', 24.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-09-30 00:00:00', 25.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-01 00:00:00', 22.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-02 00:00:00', 11.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-03 00:00:00', 14.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-04 00:00:00', 15.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-05 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-06 00:00:00', 16.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-07 00:00:00', 17.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-08 00:00:00', 14.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-09 00:00:00', 13.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-10 00:00:00', 15.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-11 00:00:00', 15.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-12 00:00:00', 15.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-13 00:00:00', 17.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-14 00:00:00', 18.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-15 00:00:00', 16.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-16 00:00:00', 12.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-17 00:00:00', 11.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-18 00:00:00', 12.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-19 00:00:00', 8.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-20 00:00:00', 10.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-21 00:00:00', 10.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-22 00:00:00', 13.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-23 00:00:00', 13.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-24 00:00:00', 16.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-25 00:00:00', 16.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-26 00:00:00', 17.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-27 00:00:00', 14.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-28 00:00:00', 17.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-29 00:00:00', 13.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-30 00:00:00', 12.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-10-31 00:00:00', 14.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-01 00:00:00', 7.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-02 00:00:00', 11.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-03 00:00:00', 11.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-04 00:00:00', 8.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-05 00:00:00', 9.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-06 00:00:00', 8.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-07 00:00:00', 12.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-08 00:00:00', 13.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-09 00:00:00', 14.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-10 00:00:00', 12.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-11 00:00:00', 8.68299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-12 00:00:00', 6.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-13 00:00:00', 0.214000001549720764, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-14 00:00:00', 0.308999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-15 00:00:00', 5.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-16 00:00:00', 5.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-17 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-18 00:00:00', 1.87300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-19 00:00:00', -0.759999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-20 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-21 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-22 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-23 00:00:00', 5.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-24 00:00:00', 4.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-25 00:00:00', 3.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-26 00:00:00', 4.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-27 00:00:00', 5.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-28 00:00:00', 4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-29 00:00:00', 5.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-11-30 00:00:00', 4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-01 00:00:00', 4.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-02 00:00:00', 1.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-03 00:00:00', 0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-04 00:00:00', -0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-05 00:00:00', -0.439999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-06 00:00:00', -1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-07 00:00:00', -1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-08 00:00:00', 0.115999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-09 00:00:00', 0.379999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-10 00:00:00', 1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-11 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-12 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-13 00:00:00', 2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-14 00:00:00', 3.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-15 00:00:00', 3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-16 00:00:00', 3.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-17 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-18 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-19 00:00:00', 3.7780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-20 00:00:00', 3.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-21 00:00:00', 3.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-22 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-23 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-24 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-25 00:00:00', 2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-26 00:00:00', 4.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-27 00:00:00', 3.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-28 00:00:00', 4.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-29 00:00:00', 5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-30 00:00:00', 7.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1996-12-31 00:00:00', 6.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-01 00:00:00', 6.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-02 00:00:00', 8.14500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-03 00:00:00', 6.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-04 00:00:00', 1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-05 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-06 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-07 00:00:00', 3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-08 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-09 00:00:00', 5.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-10 00:00:00', 5.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-11 00:00:00', 5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-12 00:00:00', 1.9859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-13 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-14 00:00:00', -0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-15 00:00:00', 0.688000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-16 00:00:00', 2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-17 00:00:00', 1.99800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-18 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-19 00:00:00', -5.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-20 00:00:00', -3.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-21 00:00:00', -1.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-22 00:00:00', 0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-23 00:00:00', -2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-24 00:00:00', -2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-25 00:00:00', 0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-26 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-27 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-28 00:00:00', 2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-29 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-30 00:00:00', 1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-01-31 00:00:00', 0.864000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-01 00:00:00', 0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-02 00:00:00', -3.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-03 00:00:00', 0.052000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-04 00:00:00', 1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-05 00:00:00', 0.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-06 00:00:00', 1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-07 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-08 00:00:00', -5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-09 00:00:00', -2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-10 00:00:00', -1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-11 00:00:00', -2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-12 00:00:00', 0.759999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-13 00:00:00', 2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-14 00:00:00', 2.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-15 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-16 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-17 00:00:00', 4.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-18 00:00:00', 4.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-19 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-20 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-21 00:00:00', 2.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-22 00:00:00', 2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-23 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-24 00:00:00', 3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-25 00:00:00', 1.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-26 00:00:00', 4.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-27 00:00:00', 7.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-02-28 00:00:00', 5.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-01 00:00:00', 4.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-02 00:00:00', 0.199000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-03 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-04 00:00:00', 7.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-05 00:00:00', 7.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-06 00:00:00', 7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-07 00:00:00', 3.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-08 00:00:00', 9.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-09 00:00:00', 4.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-10 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-11 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-12 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-13 00:00:00', 6.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-14 00:00:00', 4.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-15 00:00:00', 4.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-16 00:00:00', 5.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-17 00:00:00', 8.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-18 00:00:00', 8.65699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-19 00:00:00', 7.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-20 00:00:00', 8.59099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-21 00:00:00', 10.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-22 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-23 00:00:00', 7.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-24 00:00:00', 12.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-25 00:00:00', 16.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-26 00:00:00', 17.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-27 00:00:00', 10.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-28 00:00:00', 8.84300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-29 00:00:00', 11.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-30 00:00:00', 17.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-03-31 00:00:00', 15.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-01 00:00:00', 12.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-02 00:00:00', 10.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-03 00:00:00', 11.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-04 00:00:00', 11.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-05 00:00:00', 13.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-06 00:00:00', 11.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-07 00:00:00', 13.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-08 00:00:00', 14.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-09 00:00:00', 13.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-10 00:00:00', 17.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-11 00:00:00', 17.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-12 00:00:00', 11.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-13 00:00:00', 10.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-14 00:00:00', 9.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-15 00:00:00', 7.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-16 00:00:00', 14.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-17 00:00:00', 16.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-18 00:00:00', 17.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-19 00:00:00', 16.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-20 00:00:00', 17.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-21 00:00:00', 16.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-22 00:00:00', 19.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-23 00:00:00', 21.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-24 00:00:00', 21.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-25 00:00:00', 20.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-26 00:00:00', 23.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-27 00:00:00', 22.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-28 00:00:00', 21.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-29 00:00:00', 22.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-04-30 00:00:00', 19.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-01 00:00:00', 19.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-02 00:00:00', 19.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-03 00:00:00', 18.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-04 00:00:00', 19.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-05 00:00:00', 22.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-06 00:00:00', 16.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-07 00:00:00', 12.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-08 00:00:00', 11.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-09 00:00:00', 14.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-10 00:00:00', 16.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-11 00:00:00', 15.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-12 00:00:00', 13.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-13 00:00:00', 15.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-14 00:00:00', 18.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-15 00:00:00', 18.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-16 00:00:00', 12.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-17 00:00:00', 14.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-18 00:00:00', 18.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-19 00:00:00', 21.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-20 00:00:00', 22.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-21 00:00:00', 22.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-22 00:00:00', 22.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-23 00:00:00', 24.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-24 00:00:00', 25.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-25 00:00:00', 24.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-26 00:00:00', 24.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-27 00:00:00', 23.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-28 00:00:00', 24.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-29 00:00:00', 25.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-30 00:00:00', 27.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-05-31 00:00:00', 26.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-01 00:00:00', 26.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-02 00:00:00', 27.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-03 00:00:00', 26.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-04 00:00:00', 22.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-05 00:00:00', 25.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-06 00:00:00', 25.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-07 00:00:00', 26.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-08 00:00:00', 27.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-09 00:00:00', 25.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-10 00:00:00', 26.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-11 00:00:00', 24.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-12 00:00:00', 23.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-13 00:00:00', 26.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-14 00:00:00', 27.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-15 00:00:00', 28.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-16 00:00:00', 29.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-17 00:00:00', 29.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-18 00:00:00', 28.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-19 00:00:00', 24.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-20 00:00:00', 28.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-21 00:00:00', 27.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-22 00:00:00', 26.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-23 00:00:00', 29.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-24 00:00:00', 31.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-25 00:00:00', 32.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-26 00:00:00', 31.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-27 00:00:00', 30.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-28 00:00:00', 29.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-29 00:00:00', 26.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-06-30 00:00:00', 26.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-01 00:00:00', 28.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-02 00:00:00', 29.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-03 00:00:00', 31.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-04 00:00:00', 31.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-05 00:00:00', 31.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-06 00:00:00', 31.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-07 00:00:00', 33.6910018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-08 00:00:00', 32.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-09 00:00:00', 29.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-10 00:00:00', 29.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-11 00:00:00', 30.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-12 00:00:00', 31.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-13 00:00:00', 31.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-14 00:00:00', 33.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-15 00:00:00', 34.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-16 00:00:00', 37.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-17 00:00:00', 37.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-18 00:00:00', 38.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-19 00:00:00', 38.7459983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-20 00:00:00', 35.9819984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-21 00:00:00', 34.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-22 00:00:00', 30.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-23 00:00:00', 31.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-24 00:00:00', 32.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-25 00:00:00', 33.3510017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-26 00:00:00', 36.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-27 00:00:00', 36.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-28 00:00:00', 36.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-29 00:00:00', 33.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-30 00:00:00', 32.6430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-07-31 00:00:00', 31.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-01 00:00:00', 27.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-02 00:00:00', 25.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-03 00:00:00', 25.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-04 00:00:00', 27.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-05 00:00:00', 29.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-06 00:00:00', 31.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-07 00:00:00', 34.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-08 00:00:00', 35.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-09 00:00:00', 34.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-10 00:00:00', 33.7309989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-11 00:00:00', 32.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-12 00:00:00', 29.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-13 00:00:00', 30.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-14 00:00:00', 32.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-15 00:00:00', 34.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-16 00:00:00', 34.5740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-17 00:00:00', 34.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-18 00:00:00', 35.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-19 00:00:00', 36.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-20 00:00:00', 35.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-21 00:00:00', 34.5509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-22 00:00:00', 35.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-23 00:00:00', 32.9420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-24 00:00:00', 29.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-25 00:00:00', 26.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-26 00:00:00', 26.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-27 00:00:00', 26.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-28 00:00:00', 27.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-29 00:00:00', 27.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-30 00:00:00', 28.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-08-31 00:00:00', 29.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-01 00:00:00', 31.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-02 00:00:00', 32.8289985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-03 00:00:00', 33.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-04 00:00:00', 31.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-05 00:00:00', 30.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-06 00:00:00', 27.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-07 00:00:00', 23.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-08 00:00:00', 22.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-09 00:00:00', 22.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-10 00:00:00', 25.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-11 00:00:00', 27.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-12 00:00:00', 27.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-13 00:00:00', 27.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-14 00:00:00', 28.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-15 00:00:00', 25.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-16 00:00:00', 23.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-17 00:00:00', 24.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-18 00:00:00', 24.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-19 00:00:00', 23.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-20 00:00:00', 23.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-21 00:00:00', 22.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-22 00:00:00', 23.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-23 00:00:00', 24.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-24 00:00:00', 25.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-25 00:00:00', 25.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-26 00:00:00', 25.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-27 00:00:00', 25.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-28 00:00:00', 23.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-29 00:00:00', 24.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-09-30 00:00:00', 24.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-01 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-02 00:00:00', 24.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-03 00:00:00', 24.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-04 00:00:00', 25.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-05 00:00:00', 23.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-06 00:00:00', 21.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-07 00:00:00', 21.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-08 00:00:00', 17.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-09 00:00:00', 17.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-10 00:00:00', 17.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-11 00:00:00', 18.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-12 00:00:00', 18.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-13 00:00:00', 19.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-14 00:00:00', 21.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-15 00:00:00', 17.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-16 00:00:00', 19.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-17 00:00:00', 19.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-18 00:00:00', 17.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-19 00:00:00', 18.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-20 00:00:00', 19.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-21 00:00:00', 17.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-22 00:00:00', 15.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-23 00:00:00', 17.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-24 00:00:00', 18.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-25 00:00:00', 17.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-26 00:00:00', 14.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-27 00:00:00', 15.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-28 00:00:00', 15.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-29 00:00:00', 14.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-30 00:00:00', 14.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-10-31 00:00:00', 14.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-01 00:00:00', 15.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-02 00:00:00', 7.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-03 00:00:00', 12.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-04 00:00:00', 12.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-05 00:00:00', 15.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-06 00:00:00', 10.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-07 00:00:00', 7.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-08 00:00:00', 6.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-09 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-10 00:00:00', 7.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-11 00:00:00', 9.35000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-12 00:00:00', 11.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-13 00:00:00', 12.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-14 00:00:00', 9.56499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-15 00:00:00', 5.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-16 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-17 00:00:00', 7.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-18 00:00:00', 7.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-19 00:00:00', 7.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-20 00:00:00', 7.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-21 00:00:00', 8.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-22 00:00:00', 9.40200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-23 00:00:00', 7.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-24 00:00:00', 4.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-25 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-26 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-27 00:00:00', 2.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-28 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-29 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-11-30 00:00:00', 4.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-01 00:00:00', 7.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-02 00:00:00', 2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-03 00:00:00', 2.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-04 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-05 00:00:00', 4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-06 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-07 00:00:00', 7.02299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-08 00:00:00', 6.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-09 00:00:00', 6.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-10 00:00:00', 5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-11 00:00:00', 8.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-12 00:00:00', 3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-13 00:00:00', 2.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-14 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-15 00:00:00', 6.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-16 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-17 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-18 00:00:00', 0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-19 00:00:00', -0.709999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-20 00:00:00', 1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-21 00:00:00', 2.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-22 00:00:00', 0.555999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-23 00:00:00', 0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-24 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-25 00:00:00', 0.919000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-26 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-27 00:00:00', 1.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-28 00:00:00', -1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-29 00:00:00', -1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-30 00:00:00', 2.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1997-12-31 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-01 00:00:00', 2.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-02 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-03 00:00:00', 3.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-04 00:00:00', 0.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-05 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-06 00:00:00', 2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-07 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-08 00:00:00', -1.4859999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-09 00:00:00', 0.361999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-10 00:00:00', 2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-11 00:00:00', 0.225999996066093445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-12 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-13 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-14 00:00:00', 0.518999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-15 00:00:00', -5.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-16 00:00:00', -1.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-17 00:00:00', -4.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-18 00:00:00', -4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-19 00:00:00', -2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-20 00:00:00', -2.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-21 00:00:00', -0.697000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-22 00:00:00', -2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-23 00:00:00', -4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-24 00:00:00', -2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-25 00:00:00', -1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-26 00:00:00', 0.510999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-27 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-28 00:00:00', 0.052000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-29 00:00:00', 0.954999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-30 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-01-31 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-01 00:00:00', 0.764999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-02 00:00:00', -0.210999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-03 00:00:00', 0.55699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-04 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-05 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-06 00:00:00', 2.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-07 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-08 00:00:00', 1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-09 00:00:00', 2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-10 00:00:00', 3.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-11 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-12 00:00:00', 3.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-13 00:00:00', 2.63400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-14 00:00:00', 1.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-15 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-16 00:00:00', 0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-17 00:00:00', -2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-18 00:00:00', -3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-19 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-20 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-21 00:00:00', -0.172999992966651917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-22 00:00:00', -1.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-23 00:00:00', -3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-24 00:00:00', -0.00600000005215406418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-25 00:00:00', 1.15600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-26 00:00:00', 4.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-27 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-02-28 00:00:00', 5.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-01 00:00:00', -0.0109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-02 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-03 00:00:00', 0.94300001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-04 00:00:00', 0.657999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-05 00:00:00', 1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-06 00:00:00', -1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-07 00:00:00', -2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-08 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-09 00:00:00', 5.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-10 00:00:00', 5.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-11 00:00:00', 6.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-12 00:00:00', 4.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-13 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-14 00:00:00', 3.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-15 00:00:00', 7.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-16 00:00:00', 8.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-17 00:00:00', 6.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-18 00:00:00', 8.64299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-19 00:00:00', 5.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-20 00:00:00', 7.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-21 00:00:00', 7.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-22 00:00:00', 5.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-23 00:00:00', 6.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-24 00:00:00', 7.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-25 00:00:00', 11.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-26 00:00:00', 10.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-27 00:00:00', 9.79399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-28 00:00:00', 10.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-29 00:00:00', 11.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-30 00:00:00', 12.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-03-31 00:00:00', 13.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-01 00:00:00', 13.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-02 00:00:00', 10.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-03 00:00:00', 10.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-04 00:00:00', 12.9469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-05 00:00:00', 16.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-06 00:00:00', 14.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-07 00:00:00', 17.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-08 00:00:00', 10.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-09 00:00:00', 12.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-10 00:00:00', 15.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-11 00:00:00', 15.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-12 00:00:00', 16.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-13 00:00:00', 16.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-14 00:00:00', 21.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-15 00:00:00', 21.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-16 00:00:00', 21.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-17 00:00:00', 21.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-18 00:00:00', 21.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-19 00:00:00', 23.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-20 00:00:00', 18.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-21 00:00:00', 15.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-22 00:00:00', 18.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-23 00:00:00', 20.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-24 00:00:00', 16.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-25 00:00:00', 9.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-26 00:00:00', 10.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-27 00:00:00', 12.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-28 00:00:00', 17.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-29 00:00:00', 19.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-04-30 00:00:00', 18.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-01 00:00:00', 14.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-02 00:00:00', 11.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-03 00:00:00', 10.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-04 00:00:00', 15.7209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-05 00:00:00', 13.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-06 00:00:00', 12.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-07 00:00:00', 15.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-08 00:00:00', 18.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-09 00:00:00', 17.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-10 00:00:00', 16.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-11 00:00:00', 15.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-12 00:00:00', 18.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-13 00:00:00', 16.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-14 00:00:00', 22.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-15 00:00:00', 23.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-16 00:00:00', 22.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-17 00:00:00', 22.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-18 00:00:00', 17.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-19 00:00:00', 20.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-20 00:00:00', 22.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-21 00:00:00', 22.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-22 00:00:00', 23.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-23 00:00:00', 25.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-24 00:00:00', 25.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-25 00:00:00', 25.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-26 00:00:00', 22.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-27 00:00:00', 20.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-28 00:00:00', 17.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-29 00:00:00', 18.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-30 00:00:00', 21.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-05-31 00:00:00', 20.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-01 00:00:00', 23.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-02 00:00:00', 23.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-03 00:00:00', 19.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-04 00:00:00', 22.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-05 00:00:00', 24.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-06 00:00:00', 21.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-07 00:00:00', 20.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-08 00:00:00', 24.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-09 00:00:00', 24.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-10 00:00:00', 21.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-11 00:00:00', 21.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-12 00:00:00', 20.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-13 00:00:00', 21.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-14 00:00:00', 20.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-15 00:00:00', 24.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-16 00:00:00', 27.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-17 00:00:00', 25.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-18 00:00:00', 24.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-19 00:00:00', 26.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-20 00:00:00', 27.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-21 00:00:00', 27.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-22 00:00:00', 26.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-23 00:00:00', 26.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-24 00:00:00', 29.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-25 00:00:00', 30.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-26 00:00:00', 29.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-27 00:00:00', 31.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-28 00:00:00', 29.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-29 00:00:00', 31.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-06-30 00:00:00', 27.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-01 00:00:00', 26.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-02 00:00:00', 26.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-03 00:00:00', 27.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-04 00:00:00', 29.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-05 00:00:00', 30.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-06 00:00:00', 31.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-07 00:00:00', 34.7389984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-08 00:00:00', 35.8520011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-09 00:00:00', 36.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-10 00:00:00', 37.3629989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-11 00:00:00', 34.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-12 00:00:00', 29.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-13 00:00:00', 30.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-14 00:00:00', 31.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-15 00:00:00', 31.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-16 00:00:00', 29.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-17 00:00:00', 29.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-18 00:00:00', 30.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-19 00:00:00', 29.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-20 00:00:00', 28.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-21 00:00:00', 28.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-22 00:00:00', 28.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-23 00:00:00', 27.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-24 00:00:00', 28.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-25 00:00:00', 27.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-26 00:00:00', 24.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-27 00:00:00', 27.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-28 00:00:00', 29.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-29 00:00:00', 28.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-30 00:00:00', 29.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-07-31 00:00:00', 31.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-01 00:00:00', 30.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-02 00:00:00', 29.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-03 00:00:00', 30.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-04 00:00:00', 29.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-05 00:00:00', 25.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-06 00:00:00', 28.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-07 00:00:00', 27.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-08 00:00:00', 26.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-09 00:00:00', 30.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-10 00:00:00', 30.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-11 00:00:00', 32.0239982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-12 00:00:00', 32.2610015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-13 00:00:00', 31.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-14 00:00:00', 31.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-15 00:00:00', 29.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-16 00:00:00', 28.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-17 00:00:00', 29.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-18 00:00:00', 30.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-19 00:00:00', 28.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-20 00:00:00', 28.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-21 00:00:00', 27.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-22 00:00:00', 26.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-23 00:00:00', 27.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-24 00:00:00', 28.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-25 00:00:00', 27.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-26 00:00:00', 28.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-27 00:00:00', 30.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-28 00:00:00', 30.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-29 00:00:00', 29.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-30 00:00:00', 27.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-08-31 00:00:00', 29.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-01 00:00:00', 30.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-02 00:00:00', 31.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-03 00:00:00', 31.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-04 00:00:00', 31.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-05 00:00:00', 31.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-06 00:00:00', 31.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-07 00:00:00', 31.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-08 00:00:00', 28.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-09 00:00:00', 25.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-10 00:00:00', 26.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-11 00:00:00', 25.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-12 00:00:00', 21.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-13 00:00:00', 16.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-14 00:00:00', 12.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-15 00:00:00', 15.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-16 00:00:00', 17.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-17 00:00:00', 20.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-18 00:00:00', 22.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-19 00:00:00', 20.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-20 00:00:00', 19.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-21 00:00:00', 20.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-22 00:00:00', 21.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-23 00:00:00', 23.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-24 00:00:00', 25.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-25 00:00:00', 27.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-26 00:00:00', 27.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-27 00:00:00', 27.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-28 00:00:00', 23.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-29 00:00:00', 21.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-09-30 00:00:00', 21.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-01 00:00:00', 24.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-02 00:00:00', 23.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-03 00:00:00', 22.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-04 00:00:00', 21.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-05 00:00:00', 21.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-06 00:00:00', 20.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-07 00:00:00', 21.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-08 00:00:00', 22.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-09 00:00:00', 12.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-10 00:00:00', 8.91199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-11 00:00:00', 14.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-12 00:00:00', 18.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-13 00:00:00', 17.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-14 00:00:00', 15.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-15 00:00:00', 17.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-16 00:00:00', 18.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-17 00:00:00', 18.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-18 00:00:00', 19.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-19 00:00:00', 18.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-20 00:00:00', 19.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-21 00:00:00', 16.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-22 00:00:00', 16.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-23 00:00:00', 14.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-24 00:00:00', 12.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-25 00:00:00', 10.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-26 00:00:00', 9.75300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-27 00:00:00', 9.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-28 00:00:00', 10.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-29 00:00:00', 11.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-30 00:00:00', 14.9940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-10-31 00:00:00', 18.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-01 00:00:00', 19.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-02 00:00:00', 17.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-03 00:00:00', 18.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-04 00:00:00', 17.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-05 00:00:00', 15.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-06 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-07 00:00:00', 15.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-08 00:00:00', 13.6029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-09 00:00:00', 14.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-10 00:00:00', 13.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-11 00:00:00', 15.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-12 00:00:00', 14.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-13 00:00:00', 10.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-14 00:00:00', 10.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-15 00:00:00', 13.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-16 00:00:00', 13.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-17 00:00:00', 9.31200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-18 00:00:00', 11.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-19 00:00:00', 13.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-20 00:00:00', 13.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-21 00:00:00', 10.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-22 00:00:00', 11.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-23 00:00:00', 7.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-24 00:00:00', 7.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-25 00:00:00', 7.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-26 00:00:00', 7.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-27 00:00:00', 6.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-28 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-29 00:00:00', 1.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-11-30 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-01 00:00:00', 4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-02 00:00:00', 3.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-03 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-04 00:00:00', 5.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-05 00:00:00', 8.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-06 00:00:00', 6.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-07 00:00:00', 5.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-08 00:00:00', 7.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-09 00:00:00', 8.81700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-10 00:00:00', 6.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-11 00:00:00', 9.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-12 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-13 00:00:00', 11.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-14 00:00:00', 8.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-15 00:00:00', 5.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-16 00:00:00', 5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-17 00:00:00', 6.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-18 00:00:00', 8.16199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-19 00:00:00', 8.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-20 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-21 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-22 00:00:00', 3.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-23 00:00:00', 4.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-24 00:00:00', 4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-25 00:00:00', 3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-26 00:00:00', 3.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-27 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-28 00:00:00', 5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-29 00:00:00', 2.64299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-30 00:00:00', 1.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1998-12-31 00:00:00', 5.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-02 00:00:00', 0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-04 00:00:00', 1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-06 00:00:00', 2.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-08 00:00:00', 2.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-10 00:00:00', 1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-12 00:00:00', 2.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-14 00:00:00', 2.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-16 00:00:00', 4.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-18 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-20 00:00:00', 6.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-22 00:00:00', 8.46100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-24 00:00:00', 5.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-26 00:00:00', 6.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-28 00:00:00', 7.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-30 00:00:00', 7.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-01 00:00:00', 7.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-03 00:00:00', 7.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-05 00:00:00', 8.27999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-07 00:00:00', 6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-09 00:00:00', 7.20100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-11 00:00:00', 5.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-13 00:00:00', 6.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-15 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-17 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-19 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-21 00:00:00', 8.77900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-23 00:00:00', 7.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-25 00:00:00', 8.01799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-27 00:00:00', 7.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-01 00:00:00', 7.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-03 00:00:00', 6.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-04 00:00:00', 8.33899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-05 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-06 00:00:00', 7.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-07 00:00:00', 4.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-08 00:00:00', 4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-09 00:00:00', 6.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-10 00:00:00', 8.59099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-11 00:00:00', 9.55500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-12 00:00:00', 8.85999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-13 00:00:00', 9.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-14 00:00:00', 5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-15 00:00:00', 8.74600028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-16 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-17 00:00:00', 4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-18 00:00:00', 5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-19 00:00:00', 2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-20 00:00:00', 3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-21 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-22 00:00:00', 8.91100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-23 00:00:00', 9.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-24 00:00:00', 9.02999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-25 00:00:00', 9.52000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-26 00:00:00', 10.630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-27 00:00:00', 10.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-28 00:00:00', 11.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-29 00:00:00', 10.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-30 00:00:00', 10.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-03-31 00:00:00', 10.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-01 00:00:00', 10.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-02 00:00:00', 14.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-03 00:00:00', 14.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-04 00:00:00', 10.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-05 00:00:00', 13.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-06 00:00:00', 9.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-07 00:00:00', 11.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-08 00:00:00', 10.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-09 00:00:00', 11.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-10 00:00:00', 10.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-11 00:00:00', 8.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-12 00:00:00', 10.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-13 00:00:00', 15.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-14 00:00:00', 13.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-15 00:00:00', 17.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-16 00:00:00', 17.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-17 00:00:00', 23.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-18 00:00:00', 19.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-19 00:00:00', 14.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-20 00:00:00', 16.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-21 00:00:00', 16.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-22 00:00:00', 13.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-23 00:00:00', 10.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-24 00:00:00', 15.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-25 00:00:00', 12.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-26 00:00:00', 18.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-27 00:00:00', 18.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-28 00:00:00', 18.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-29 00:00:00', 18.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-04-30 00:00:00', 19.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-01 00:00:00', 19.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-02 00:00:00', 20.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-03 00:00:00', 19.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-04 00:00:00', 22.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-05 00:00:00', 20.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-06 00:00:00', 21.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-07 00:00:00', 23.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-08 00:00:00', 24.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-09 00:00:00', 25.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-10 00:00:00', 23.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-11 00:00:00', 23.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-12 00:00:00', 13.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-13 00:00:00', 18.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-14 00:00:00', 22.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-15 00:00:00', 25.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-16 00:00:00', 23.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-17 00:00:00', 26.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-18 00:00:00', 27.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-19 00:00:00', 27.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-20 00:00:00', 27.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-21 00:00:00', 30.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-22 00:00:00', 22.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-23 00:00:00', 18.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-24 00:00:00', 18.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-25 00:00:00', 18.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-26 00:00:00', 17.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-27 00:00:00', 22.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-28 00:00:00', 24.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-29 00:00:00', 23.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-30 00:00:00', 23.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-05-31 00:00:00', 24.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-01 00:00:00', 24.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-02 00:00:00', 23.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-03 00:00:00', 23.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-04 00:00:00', 24.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-05 00:00:00', 24.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-06 00:00:00', 28.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-07 00:00:00', 27.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-08 00:00:00', 28.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-09 00:00:00', 25.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-10 00:00:00', 24.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-11 00:00:00', 24.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-12 00:00:00', 24.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-13 00:00:00', 26.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-14 00:00:00', 28.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-15 00:00:00', 31.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-16 00:00:00', 29.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-17 00:00:00', 26.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-18 00:00:00', 28.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-19 00:00:00', 28.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-20 00:00:00', 27.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-21 00:00:00', 26.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-22 00:00:00', 27.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-23 00:00:00', 25.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-24 00:00:00', 23.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-25 00:00:00', 28.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-26 00:00:00', 33.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-27 00:00:00', 35.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-28 00:00:00', 33.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-29 00:00:00', 32.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-06-30 00:00:00', 32.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-01 00:00:00', 32.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-02 00:00:00', 28.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-03 00:00:00', 28.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-04 00:00:00', 29.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-05 00:00:00', 30.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-06 00:00:00', 29.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-07 00:00:00', 28.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-08 00:00:00', 29.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-09 00:00:00', 33.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-10 00:00:00', 30.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-11 00:00:00', 26.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-12 00:00:00', 25.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-13 00:00:00', 25.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-14 00:00:00', 28.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-15 00:00:00', 29.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-16 00:00:00', 31.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-17 00:00:00', 34.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-18 00:00:00', 31.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-19 00:00:00', 29.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-20 00:00:00', 29.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-21 00:00:00', 28.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-22 00:00:00', 29.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-23 00:00:00', 29.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-24 00:00:00', 28.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-25 00:00:00', 27.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-26 00:00:00', 27.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-27 00:00:00', 27.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-28 00:00:00', 26.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-29 00:00:00', 28.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-30 00:00:00', 28.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-07-31 00:00:00', 30.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-01 00:00:00', 31.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-02 00:00:00', 30.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-03 00:00:00', 29.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-04 00:00:00', 32.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-05 00:00:00', 34.4620018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-06 00:00:00', 34.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-07 00:00:00', 33.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-08 00:00:00', 33.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-09 00:00:00', 35.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-10 00:00:00', 31.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-11 00:00:00', 30.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-12 00:00:00', 27.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-13 00:00:00', 25.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-14 00:00:00', 27.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-15 00:00:00', 29.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-16 00:00:00', 31.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-17 00:00:00', 31.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-18 00:00:00', 31.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-19 00:00:00', 32.7449989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-20 00:00:00', 33.0730018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-21 00:00:00', 33.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-22 00:00:00', 31.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-23 00:00:00', 32.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-24 00:00:00', 32.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-25 00:00:00', 31.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-26 00:00:00', 29.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-27 00:00:00', 31.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-28 00:00:00', 33.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-29 00:00:00', 32.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-30 00:00:00', 32.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-08-31 00:00:00', 29.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-01 00:00:00', 27.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-02 00:00:00', 26.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-03 00:00:00', 26.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-04 00:00:00', 27.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-05 00:00:00', 25.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-06 00:00:00', 24.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-07 00:00:00', 27.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-08 00:00:00', 26.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-09 00:00:00', 26.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-10 00:00:00', 26.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-11 00:00:00', 26.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-12 00:00:00', 28.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-13 00:00:00', 30.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-14 00:00:00', 31.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-15 00:00:00', 31.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-16 00:00:00', 30.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-17 00:00:00', 31.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-18 00:00:00', 29.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-19 00:00:00', 27.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-20 00:00:00', 26.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-21 00:00:00', 27.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-22 00:00:00', 27.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-23 00:00:00', 28.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-24 00:00:00', 20.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-25 00:00:00', 20.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-26 00:00:00', 20.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-27 00:00:00', 23.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-28 00:00:00', 24.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-29 00:00:00', 12.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-09-30 00:00:00', 17.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-01 00:00:00', 18.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-02 00:00:00', 21.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-03 00:00:00', 21.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-04 00:00:00', 21.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-05 00:00:00', 20.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-06 00:00:00', 19.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-07 00:00:00', 17.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-08 00:00:00', 17.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-09 00:00:00', 18.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-10 00:00:00', 18.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-11 00:00:00', 19.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-12 00:00:00', 18.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-13 00:00:00', 19.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-14 00:00:00', 17.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-15 00:00:00', 18.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-16 00:00:00', 21.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-17 00:00:00', 21.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-18 00:00:00', 20.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-19 00:00:00', 21.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-20 00:00:00', 20.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-21 00:00:00', 18.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-22 00:00:00', 18.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-23 00:00:00', 18.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-24 00:00:00', 19.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-25 00:00:00', 20.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-26 00:00:00', 10.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-27 00:00:00', 10.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-28 00:00:00', 7.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-29 00:00:00', 14.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-30 00:00:00', 14.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-10-31 00:00:00', 14.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-01 00:00:00', 16.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-02 00:00:00', 14.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-03 00:00:00', 5.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-04 00:00:00', 7.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-05 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-06 00:00:00', 9.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-07 00:00:00', 7.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-08 00:00:00', 6.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-09 00:00:00', 3.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-10 00:00:00', 5.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-11 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-12 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-13 00:00:00', 3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-14 00:00:00', 4.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-15 00:00:00', 8.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-16 00:00:00', 7.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-17 00:00:00', 7.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-18 00:00:00', 8.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-19 00:00:00', 4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-20 00:00:00', 3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-21 00:00:00', 4.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-22 00:00:00', 1.06700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-23 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-24 00:00:00', 5.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-25 00:00:00', 4.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-26 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-27 00:00:00', 2.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-28 00:00:00', 3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-29 00:00:00', 2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-11-30 00:00:00', 1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-01 00:00:00', -0.209999993443489075, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-02 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-03 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-04 00:00:00', 7.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-05 00:00:00', 3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-06 00:00:00', 3.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-07 00:00:00', 6.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-08 00:00:00', 6.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-09 00:00:00', 5.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-10 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-11 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-12 00:00:00', 4.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-13 00:00:00', 3.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-14 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-15 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-16 00:00:00', 4.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-17 00:00:00', 4.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-18 00:00:00', 2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-19 00:00:00', 2.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-20 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-21 00:00:00', 4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-22 00:00:00', 8.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-23 00:00:00', 4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-24 00:00:00', 5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-25 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-26 00:00:00', 2.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-27 00:00:00', 4.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-28 00:00:00', 5.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-29 00:00:00', 3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-30 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '1999-12-31 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-01 00:00:00', 4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-02 00:00:00', 6.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-03 00:00:00', 7.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-04 00:00:00', 8.17300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-05 00:00:00', 5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-06 00:00:00', 5.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-07 00:00:00', 4.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-08 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-09 00:00:00', -3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-10 00:00:00', -0.791999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-11 00:00:00', 0.598999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-12 00:00:00', -1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-13 00:00:00', -5.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-14 00:00:00', -3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-15 00:00:00', -3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-16 00:00:00', -0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-17 00:00:00', 2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-18 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-19 00:00:00', 0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-20 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-21 00:00:00', 4.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-22 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-23 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-24 00:00:00', 3.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-25 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-26 00:00:00', 1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-27 00:00:00', 2.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-28 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-29 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-30 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-01-31 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-01 00:00:00', 0.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-02 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-03 00:00:00', 0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-04 00:00:00', 2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-05 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-06 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-07 00:00:00', 4.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-08 00:00:00', 4.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-09 00:00:00', -1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-10 00:00:00', -1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-11 00:00:00', -1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-12 00:00:00', -0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-13 00:00:00', 2.14899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-14 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-15 00:00:00', 1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-16 00:00:00', -0.552999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-17 00:00:00', 0.804000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-18 00:00:00', 1.73500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-19 00:00:00', 2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-20 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-21 00:00:00', 3.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-22 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-23 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-24 00:00:00', 4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-25 00:00:00', 5.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-26 00:00:00', 4.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-27 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-28 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-02-29 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-01 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-02 00:00:00', 1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-03 00:00:00', 5.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-04 00:00:00', -1.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-05 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-06 00:00:00', 2.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-07 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-08 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-09 00:00:00', 6.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-10 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-11 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-12 00:00:00', 8.88300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-13 00:00:00', 9.74699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-14 00:00:00', 10.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-15 00:00:00', 10.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-16 00:00:00', 1.34300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-17 00:00:00', 3.57699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-18 00:00:00', 5.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-19 00:00:00', 9.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-20 00:00:00', 11.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-21 00:00:00', 11.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-22 00:00:00', 12.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-23 00:00:00', 11.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-24 00:00:00', 11.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-25 00:00:00', 16.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-26 00:00:00', 15.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-27 00:00:00', 8.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-28 00:00:00', 8.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-29 00:00:00', 8.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-30 00:00:00', 11.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-03-31 00:00:00', 12.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-01 00:00:00', 13.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-02 00:00:00', 8.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-03 00:00:00', 6.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-04 00:00:00', 7.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-05 00:00:00', 9.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-06 00:00:00', 12.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-07 00:00:00', 15.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-08 00:00:00', 14.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-09 00:00:00', 18.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-10 00:00:00', 20.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-11 00:00:00', 24.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-12 00:00:00', 24.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-13 00:00:00', 18.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-14 00:00:00', 19.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-15 00:00:00', 20.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-16 00:00:00', 19.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-17 00:00:00', 21.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-18 00:00:00', 20.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-19 00:00:00', 21.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-20 00:00:00', 22.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-21 00:00:00', 22.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-22 00:00:00', 23.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-23 00:00:00', 21.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-24 00:00:00', 22.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-25 00:00:00', 20.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-26 00:00:00', 19.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-27 00:00:00', 19.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-28 00:00:00', 17.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-29 00:00:00', 17.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-04-30 00:00:00', 20.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-01 00:00:00', 23.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-02 00:00:00', 24.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-03 00:00:00', 23.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-04 00:00:00', 23.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-05 00:00:00', 25.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-06 00:00:00', 25.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-07 00:00:00', 28.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-08 00:00:00', 29.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-09 00:00:00', 31.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-10 00:00:00', 30.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-11 00:00:00', 24.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-12 00:00:00', 24.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-13 00:00:00', 25.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-14 00:00:00', 25.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-15 00:00:00', 24.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-16 00:00:00', 27.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-17 00:00:00', 28.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-18 00:00:00', 29.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-19 00:00:00', 28.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-20 00:00:00', 28.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-21 00:00:00', 29.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-22 00:00:00', 23.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-23 00:00:00', 24.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-24 00:00:00', 24.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-25 00:00:00', 25.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-26 00:00:00', 25.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-27 00:00:00', 26.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-28 00:00:00', 30.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-29 00:00:00', 27.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-30 00:00:00', 25.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-05-31 00:00:00', 26.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-01 00:00:00', 26.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-02 00:00:00', 23.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-03 00:00:00', 24.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-04 00:00:00', 25.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-05 00:00:00', 27.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-06 00:00:00', 28.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-07 00:00:00', 28.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-08 00:00:00', 29.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-09 00:00:00', 28.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-10 00:00:00', 28.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-11 00:00:00', 28.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-12 00:00:00', 29.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-13 00:00:00', 28.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-14 00:00:00', 22.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-15 00:00:00', 27.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-16 00:00:00', 26.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-17 00:00:00', 28.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-18 00:00:00', 30.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-19 00:00:00', 29.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-20 00:00:00', 28.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-21 00:00:00', 28.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-22 00:00:00', 30.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-23 00:00:00', 31.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-24 00:00:00', 33.3849983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-25 00:00:00', 34.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-26 00:00:00', 34.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-27 00:00:00', 32.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-28 00:00:00', 32.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-29 00:00:00', 31.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-06-30 00:00:00', 30.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-01 00:00:00', 30.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-02 00:00:00', 30.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-03 00:00:00', 30.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-04 00:00:00', 30.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-05 00:00:00', 30.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-06 00:00:00', 31.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-07 00:00:00', 33.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-08 00:00:00', 33.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-09 00:00:00', 32.7760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-10 00:00:00', 33.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-11 00:00:00', 32.4490013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-12 00:00:00', 32.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-13 00:00:00', 31.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-14 00:00:00', 30.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-15 00:00:00', 29.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-16 00:00:00', 27.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-17 00:00:00', 25.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-18 00:00:00', 25.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-19 00:00:00', 28.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-20 00:00:00', 28.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-21 00:00:00', 30.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-22 00:00:00', 29.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-23 00:00:00', 28.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-24 00:00:00', 29.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-25 00:00:00', 27.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-26 00:00:00', 29.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-27 00:00:00', 30.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-28 00:00:00', 32.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-29 00:00:00', 33.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-30 00:00:00', 33.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-07-31 00:00:00', 34.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-01 00:00:00', 33.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-02 00:00:00', 31.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-03 00:00:00', 32.8019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-04 00:00:00', 32.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-05 00:00:00', 31.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-06 00:00:00', 32.9770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-07 00:00:00', 33.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-08 00:00:00', 32.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-09 00:00:00', 30.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-10 00:00:00', 32.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-11 00:00:00', 32.3590011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-12 00:00:00', 31.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-13 00:00:00', 31.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-14 00:00:00', 31.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-15 00:00:00', 31.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-16 00:00:00', 30.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-17 00:00:00', 27.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-18 00:00:00', 27.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-19 00:00:00', 28.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-20 00:00:00', 27.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-21 00:00:00', 28.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-22 00:00:00', 29.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-23 00:00:00', 29.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-24 00:00:00', 31.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-25 00:00:00', 30.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-26 00:00:00', 32.2400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-27 00:00:00', 33.1440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-28 00:00:00', 33.8149986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-29 00:00:00', 34.2750015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-30 00:00:00', 32.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-08-31 00:00:00', 32.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-01 00:00:00', 29.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-02 00:00:00', 30.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-03 00:00:00', 30.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-04 00:00:00', 30.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-05 00:00:00', 29.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-06 00:00:00', 27.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-07 00:00:00', 27.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-08 00:00:00', 27.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-09 00:00:00', 27.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-10 00:00:00', 25.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-11 00:00:00', 26.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-12 00:00:00', 26.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-13 00:00:00', 28.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-14 00:00:00', 28.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-15 00:00:00', 29.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-16 00:00:00', 30.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-17 00:00:00', 31.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-18 00:00:00', 29.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-19 00:00:00', 28.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-20 00:00:00', 22.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-21 00:00:00', 21.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-22 00:00:00', 20.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-23 00:00:00', 22.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-24 00:00:00', 22.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-25 00:00:00', 17.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-26 00:00:00', 16.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-27 00:00:00', 19.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-28 00:00:00', 21.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-29 00:00:00', 23.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-09-30 00:00:00', 20.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-01 00:00:00', 21.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-02 00:00:00', 18.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-03 00:00:00', 20.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-04 00:00:00', 15.060999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-05 00:00:00', 11.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-06 00:00:00', 15.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-07 00:00:00', 12.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-08 00:00:00', 13.8459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-09 00:00:00', 13.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-10 00:00:00', 14.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-11 00:00:00', 16.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-12 00:00:00', 18.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-13 00:00:00', 19.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-14 00:00:00', 16.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-15 00:00:00', 12.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-16 00:00:00', 8.26299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-17 00:00:00', 14.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-18 00:00:00', 7.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-19 00:00:00', 10.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-20 00:00:00', 12.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-21 00:00:00', 12.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-22 00:00:00', 11.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-23 00:00:00', 10.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-24 00:00:00', 11.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-25 00:00:00', 12.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-26 00:00:00', 17.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-27 00:00:00', 18.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-28 00:00:00', 19.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-29 00:00:00', 19.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-30 00:00:00', 18.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-10-31 00:00:00', 16.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-01 00:00:00', 13.9429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-02 00:00:00', 16.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-03 00:00:00', 17.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-04 00:00:00', 18.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-05 00:00:00', 13.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-06 00:00:00', 13.800999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-07 00:00:00', 11.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-08 00:00:00', 3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-09 00:00:00', 11.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-10 00:00:00', 12.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-11 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-12 00:00:00', 0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-13 00:00:00', 1.53799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-14 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-15 00:00:00', 2.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-16 00:00:00', 0.676999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-17 00:00:00', 0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-18 00:00:00', 1.42299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-19 00:00:00', 3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-20 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-21 00:00:00', 3.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-22 00:00:00', 2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-23 00:00:00', 3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-24 00:00:00', 4.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-25 00:00:00', 4.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-26 00:00:00', 5.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-27 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-28 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-29 00:00:00', 0.734000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-11-30 00:00:00', 0.94300001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-01 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-02 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-03 00:00:00', 2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-04 00:00:00', 2.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-05 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-06 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-07 00:00:00', 2.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-08 00:00:00', 2.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-09 00:00:00', 2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-10 00:00:00', 0.712999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-11 00:00:00', 4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-12 00:00:00', 3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-13 00:00:00', 2.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-14 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-15 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-16 00:00:00', 2.77399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-17 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-18 00:00:00', 1.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-19 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-20 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-21 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-22 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-23 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-24 00:00:00', 2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-25 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-26 00:00:00', 2.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-27 00:00:00', 2.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-28 00:00:00', 0.815999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-29 00:00:00', 1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-30 00:00:00', 1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2000-12-31 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-01 00:00:00', 2.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-02 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-03 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-04 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-05 00:00:00', 2.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-06 00:00:00', 2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-07 00:00:00', 1.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-08 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-09 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-10 00:00:00', 1.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-11 00:00:00', 3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-12 00:00:00', 2.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-13 00:00:00', 2.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-14 00:00:00', 3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-15 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-16 00:00:00', -1.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-17 00:00:00', -0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-18 00:00:00', 0.566999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-19 00:00:00', 1.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-20 00:00:00', 1.07099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-21 00:00:00', -1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-22 00:00:00', -5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-23 00:00:00', -4.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-24 00:00:00', -1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-25 00:00:00', -2.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-26 00:00:00', -3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-27 00:00:00', -0.976000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-28 00:00:00', 1.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-29 00:00:00', -3.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-30 00:00:00', -3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-01-31 00:00:00', -1.57700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-01 00:00:00', -0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-02 00:00:00', 1.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-03 00:00:00', 1.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-04 00:00:00', 0.300999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-05 00:00:00', 0.377000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-06 00:00:00', -0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-07 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-08 00:00:00', 1.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-09 00:00:00', -0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-10 00:00:00', -1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-11 00:00:00', -1.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-12 00:00:00', 3.22799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-13 00:00:00', 3.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-14 00:00:00', 3.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-15 00:00:00', 5.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-16 00:00:00', 2.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-17 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-18 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-19 00:00:00', 6.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-20 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-21 00:00:00', 5.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-22 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-23 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-24 00:00:00', 5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-25 00:00:00', 4.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-26 00:00:00', 8.36699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-27 00:00:00', 6.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-02-28 00:00:00', 8.72099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-01 00:00:00', 9.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-02 00:00:00', 8.06499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-03 00:00:00', 7.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-04 00:00:00', 8.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-05 00:00:00', 8.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-06 00:00:00', 7.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-07 00:00:00', 8.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-08 00:00:00', 10.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-09 00:00:00', 11.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-10 00:00:00', 11.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-11 00:00:00', 7.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-12 00:00:00', 1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-13 00:00:00', 1.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-14 00:00:00', 1.58000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-15 00:00:00', 5.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-16 00:00:00', 11.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-17 00:00:00', 10.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-18 00:00:00', 8.28699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-19 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-20 00:00:00', 9.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-21 00:00:00', 11.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-22 00:00:00', 13.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-23 00:00:00', 13.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-24 00:00:00', 8.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-25 00:00:00', 7.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-26 00:00:00', 9.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-27 00:00:00', 6.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-28 00:00:00', 5.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-29 00:00:00', 8.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-30 00:00:00', 12.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-03-31 00:00:00', 14.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-01 00:00:00', 14.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-02 00:00:00', 10.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-03 00:00:00', 13.0679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-04 00:00:00', 17.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-05 00:00:00', 16.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-06 00:00:00', 18.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-07 00:00:00', 22.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-08 00:00:00', 24.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-09 00:00:00', 22.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-10 00:00:00', 21.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-11 00:00:00', 21.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-12 00:00:00', 21.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-13 00:00:00', 21.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-14 00:00:00', 19.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-15 00:00:00', 20.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-16 00:00:00', 19.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-17 00:00:00', 16.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-18 00:00:00', 17.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-19 00:00:00', 12.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-20 00:00:00', 16.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-21 00:00:00', 18.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-22 00:00:00', 20.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-23 00:00:00', 17.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-24 00:00:00', 20.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-25 00:00:00', 20.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-26 00:00:00', 20.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-27 00:00:00', 23.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-28 00:00:00', 22.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-29 00:00:00', 22.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-04-30 00:00:00', 23.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-01 00:00:00', 20.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-02 00:00:00', 21.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-03 00:00:00', 24.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-04 00:00:00', 26.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-05 00:00:00', 26.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-06 00:00:00', 27.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-07 00:00:00', 26.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-08 00:00:00', 24.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-09 00:00:00', 26, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-10 00:00:00', 27.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-11 00:00:00', 30.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-12 00:00:00', 30.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-13 00:00:00', 29.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-14 00:00:00', 28.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-15 00:00:00', 30.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-16 00:00:00', 30.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-17 00:00:00', 31.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-18 00:00:00', 29.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-19 00:00:00', 25.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-20 00:00:00', 22.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-21 00:00:00', 23.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-22 00:00:00', 25.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-23 00:00:00', 26.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-24 00:00:00', 24.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-25 00:00:00', 25.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-26 00:00:00', 29.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-27 00:00:00', 31.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-28 00:00:00', 27.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-29 00:00:00', 27.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-30 00:00:00', 31.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-05-31 00:00:00', 31.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-01 00:00:00', 31.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-02 00:00:00', 29.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-03 00:00:00', 29.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-04 00:00:00', 28.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-05 00:00:00', 28.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-06 00:00:00', 29.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-07 00:00:00', 29.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-08 00:00:00', 30.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-09 00:00:00', 32.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-10 00:00:00', 32.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-11 00:00:00', 31.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-12 00:00:00', 31.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-13 00:00:00', 31.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-14 00:00:00', 27.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-15 00:00:00', 27.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-16 00:00:00', 28.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-17 00:00:00', 28.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-18 00:00:00', 31.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-19 00:00:00', 32.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-20 00:00:00', 33.4189987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-21 00:00:00', 30.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-22 00:00:00', 27.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-23 00:00:00', 30.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-24 00:00:00', 31.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-25 00:00:00', 32.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-26 00:00:00', 33.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-27 00:00:00', 36.2589988708496094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-28 00:00:00', 37.7599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-29 00:00:00', 37.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-06-30 00:00:00', 36.3709983825683594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-01 00:00:00', 34.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-02 00:00:00', 31.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-03 00:00:00', 30.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-04 00:00:00', 30.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-05 00:00:00', 28.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-06 00:00:00', 29.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-07 00:00:00', 30.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-08 00:00:00', 32.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-09 00:00:00', 32.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-10 00:00:00', 34.8429985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-11 00:00:00', 36.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-12 00:00:00', 36.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-13 00:00:00', 35.3079986572265625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-14 00:00:00', 34.2659988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-15 00:00:00', 30.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-16 00:00:00', 28.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-17 00:00:00', 27.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-18 00:00:00', 28.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-19 00:00:00', 33.0110015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-20 00:00:00', 31.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-21 00:00:00', 30.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-22 00:00:00', 30.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-23 00:00:00', 30.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-24 00:00:00', 27.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-25 00:00:00', 31.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-26 00:00:00', 32.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-27 00:00:00', 31.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-28 00:00:00', 28.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-29 00:00:00', 26.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-30 00:00:00', 25.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-07-31 00:00:00', 28.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-01 00:00:00', 30.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-02 00:00:00', 31.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-03 00:00:00', 31.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-04 00:00:00', 32.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-05 00:00:00', 33.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-06 00:00:00', 31.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-07 00:00:00', 31.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-08 00:00:00', 29.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-09 00:00:00', 30.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-10 00:00:00', 30.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-11 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-12 00:00:00', 29.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-13 00:00:00', 29.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-14 00:00:00', 25.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-15 00:00:00', 25.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-16 00:00:00', 27.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-17 00:00:00', 29.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-18 00:00:00', 29.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-19 00:00:00', 28.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-20 00:00:00', 30.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-21 00:00:00', 29.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-22 00:00:00', 29.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-23 00:00:00', 29.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-24 00:00:00', 29.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-25 00:00:00', 29.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-26 00:00:00', 26.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-27 00:00:00', 28.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-28 00:00:00', 23.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-29 00:00:00', 24.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-30 00:00:00', 26.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-08-31 00:00:00', 28.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-01 00:00:00', 31.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-02 00:00:00', 30.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-03 00:00:00', 27.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-04 00:00:00', 26.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-05 00:00:00', 28.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-06 00:00:00', 27.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-07 00:00:00', 28.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-08 00:00:00', 29.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-09 00:00:00', 30.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-10 00:00:00', 26.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-11 00:00:00', 25.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-12 00:00:00', 22.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-13 00:00:00', 22.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-14 00:00:00', 21.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-15 00:00:00', 23.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-16 00:00:00', 22.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-17 00:00:00', 23.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-18 00:00:00', 21.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-19 00:00:00', 17.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-20 00:00:00', 16.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-21 00:00:00', 19.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-22 00:00:00', 17.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-23 00:00:00', 18.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-24 00:00:00', 20.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-25 00:00:00', 19.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-26 00:00:00', 21.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-27 00:00:00', 24.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-28 00:00:00', 25.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-29 00:00:00', 25.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-09-30 00:00:00', 26.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-01 00:00:00', 26.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-02 00:00:00', 24.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-03 00:00:00', 19.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-04 00:00:00', 18.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-05 00:00:00', 17.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-06 00:00:00', 20.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-07 00:00:00', 24.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-08 00:00:00', 23.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-09 00:00:00', 17.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-10 00:00:00', 13.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-11 00:00:00', 12.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-12 00:00:00', 17.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-13 00:00:00', 17.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-14 00:00:00', 18.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-15 00:00:00', 18.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-16 00:00:00', 18.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-17 00:00:00', 18.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-18 00:00:00', 13.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-19 00:00:00', 16.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-20 00:00:00', 19.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-21 00:00:00', 18.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-22 00:00:00', 17.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-23 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-24 00:00:00', 15.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-25 00:00:00', 18.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-26 00:00:00', 20.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-27 00:00:00', 14.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-28 00:00:00', 11.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-29 00:00:00', 13.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-30 00:00:00', 12.255000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-10-31 00:00:00', 12.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-01 00:00:00', 12.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-02 00:00:00', 9.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-03 00:00:00', 5.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-04 00:00:00', 7.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-05 00:00:00', 6.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-06 00:00:00', 7.23799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-07 00:00:00', 10.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-08 00:00:00', 11.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-09 00:00:00', 8.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-10 00:00:00', 9.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-11 00:00:00', 9.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-12 00:00:00', 12.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-13 00:00:00', 16.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-14 00:00:00', 16.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-15 00:00:00', 11.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-16 00:00:00', 13.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-17 00:00:00', 15.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-18 00:00:00', 15.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-19 00:00:00', 15.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-20 00:00:00', 9.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-21 00:00:00', 10.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-22 00:00:00', 11.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-23 00:00:00', 15.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-24 00:00:00', 12.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-25 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-26 00:00:00', 8.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-27 00:00:00', 7.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-28 00:00:00', 7.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-29 00:00:00', 2.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-11-30 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-01 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-02 00:00:00', 3.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-03 00:00:00', 2.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-04 00:00:00', 2.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-05 00:00:00', 5.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-06 00:00:00', 4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-07 00:00:00', 5.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-08 00:00:00', 4.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-09 00:00:00', 5.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-10 00:00:00', 1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-11 00:00:00', 0.944999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-12 00:00:00', 2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-13 00:00:00', 1.50199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-14 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-15 00:00:00', 4.70200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-16 00:00:00', 4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-17 00:00:00', 3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-18 00:00:00', 0.634999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-19 00:00:00', 2.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-20 00:00:00', 3.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-21 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-22 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-23 00:00:00', 1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-24 00:00:00', 2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-25 00:00:00', 4.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-26 00:00:00', 4.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-27 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-28 00:00:00', 4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-29 00:00:00', 4.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-30 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2001-12-31 00:00:00', 4.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-01 00:00:00', 5.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-02 00:00:00', 7.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-03 00:00:00', 10.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-04 00:00:00', 7.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-05 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-06 00:00:00', 5.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-07 00:00:00', 6.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-08 00:00:00', 7.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-09 00:00:00', 5.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-10 00:00:00', 3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-11 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-12 00:00:00', 3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-13 00:00:00', 1.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-14 00:00:00', -2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-15 00:00:00', -3.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-16 00:00:00', -4.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-17 00:00:00', -2.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-18 00:00:00', 0.296000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-19 00:00:00', 0.663999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-20 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-21 00:00:00', 1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-22 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-23 00:00:00', 0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-24 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-25 00:00:00', 0.10300000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-26 00:00:00', -0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-27 00:00:00', 0.771000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-28 00:00:00', 2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-29 00:00:00', 4.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-30 00:00:00', 3.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-01-31 00:00:00', 2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-01 00:00:00', 1.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-02 00:00:00', -2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-03 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-04 00:00:00', -0.0680000036954879761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-05 00:00:00', -3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-06 00:00:00', -4.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-07 00:00:00', -1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-08 00:00:00', 0.379000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-09 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-10 00:00:00', 3.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-11 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-12 00:00:00', 0.238999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-13 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-14 00:00:00', 4.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-15 00:00:00', 3.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-16 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-17 00:00:00', 1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-18 00:00:00', 2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-19 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-20 00:00:00', 5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-21 00:00:00', 4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-22 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-23 00:00:00', 3.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-24 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-25 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-26 00:00:00', 2.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-27 00:00:00', 2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-02-28 00:00:00', 3.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-01 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-02 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-03 00:00:00', 4.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-04 00:00:00', 5.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-05 00:00:00', 7.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-06 00:00:00', 9.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-07 00:00:00', 0.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-08 00:00:00', 1.38999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-09 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-10 00:00:00', 2.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-11 00:00:00', -1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-12 00:00:00', 1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-13 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-14 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-15 00:00:00', 9.36699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-16 00:00:00', 10.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-17 00:00:00', 12.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-18 00:00:00', 13.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-19 00:00:00', 16.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-20 00:00:00', 13.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-21 00:00:00', 10.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-22 00:00:00', 12.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-23 00:00:00', 10.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-24 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-25 00:00:00', 7.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-26 00:00:00', 9.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-27 00:00:00', 13.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-28 00:00:00', 15.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-29 00:00:00', 16.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-30 00:00:00', 9.93500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-03-31 00:00:00', 10.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-01 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-02 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-03 00:00:00', 11.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-04 00:00:00', 12.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-05 00:00:00', 9.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-06 00:00:00', 12.0570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-07 00:00:00', 16.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-08 00:00:00', 14.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-09 00:00:00', 20.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-10 00:00:00', 18.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-11 00:00:00', 19.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-12 00:00:00', 16.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-13 00:00:00', 18.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-14 00:00:00', 16.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-15 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-16 00:00:00', 17.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-17 00:00:00', 16.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-18 00:00:00', 18.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-19 00:00:00', 21.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-20 00:00:00', 23.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-21 00:00:00', 23.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-22 00:00:00', 17.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-23 00:00:00', 11.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-24 00:00:00', 13.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-25 00:00:00', 11.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-26 00:00:00', 9.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-27 00:00:00', 9.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-28 00:00:00', 11.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-29 00:00:00', 13.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-04-30 00:00:00', 12.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-01 00:00:00', 15.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-02 00:00:00', 14.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-03 00:00:00', 17.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-04 00:00:00', 18.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-05 00:00:00', 18.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-06 00:00:00', 17.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-07 00:00:00', 20.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-08 00:00:00', 22.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-09 00:00:00', 22.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-10 00:00:00', 22.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-11 00:00:00', 24.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-12 00:00:00', 25.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-13 00:00:00', 19.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-14 00:00:00', 14.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-15 00:00:00', 18.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-16 00:00:00', 20.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-17 00:00:00', 21.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-18 00:00:00', 18.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-19 00:00:00', 17.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-20 00:00:00', 17.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-21 00:00:00', 20.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-22 00:00:00', 23.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-23 00:00:00', 22.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-24 00:00:00', 24.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-25 00:00:00', 26.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-26 00:00:00', 27.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-27 00:00:00', 23.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-28 00:00:00', 22.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-29 00:00:00', 23.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-30 00:00:00', 25.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-05-31 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-01 00:00:00', 27.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-02 00:00:00', 29.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-03 00:00:00', 30.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-04 00:00:00', 28.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-05 00:00:00', 25.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-06 00:00:00', 23.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-07 00:00:00', 28.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-08 00:00:00', 25.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-09 00:00:00', 23.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-10 00:00:00', 24.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-11 00:00:00', 26.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-12 00:00:00', 28.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-13 00:00:00', 29.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-14 00:00:00', 31.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-15 00:00:00', 27.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-16 00:00:00', 26.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-17 00:00:00', 25.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-18 00:00:00', 27.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-19 00:00:00', 27.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-20 00:00:00', 28.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-21 00:00:00', 31.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-22 00:00:00', 32.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-23 00:00:00', 25.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-24 00:00:00', 25.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-25 00:00:00', 27.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-26 00:00:00', 30.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-27 00:00:00', 33.4420013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-28 00:00:00', 31.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-29 00:00:00', 30.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-06-30 00:00:00', 29.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-01 00:00:00', 28.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-02 00:00:00', 28.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-03 00:00:00', 28.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-04 00:00:00', 28.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-05 00:00:00', 27.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-06 00:00:00', 26.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-07 00:00:00', 27.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-08 00:00:00', 27.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-09 00:00:00', 26.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-10 00:00:00', 27.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-11 00:00:00', 27.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-12 00:00:00', 29.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-13 00:00:00', 30.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-14 00:00:00', 30.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-15 00:00:00', 30.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-16 00:00:00', 32.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-17 00:00:00', 33.1360015869140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-18 00:00:00', 33.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-19 00:00:00', 33.6440010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-20 00:00:00', 34.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-21 00:00:00', 29.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-22 00:00:00', 26.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-23 00:00:00', 29.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-24 00:00:00', 31.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-25 00:00:00', 32.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-26 00:00:00', 33.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-27 00:00:00', 31.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-28 00:00:00', 30.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-29 00:00:00', 28.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-30 00:00:00', 28.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-07-31 00:00:00', 28.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-01 00:00:00', 30.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-02 00:00:00', 30.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-03 00:00:00', 30.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-04 00:00:00', 30.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-05 00:00:00', 33.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-06 00:00:00', 33.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-07 00:00:00', 33.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-08 00:00:00', 35.1430015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-09 00:00:00', 35.3800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-10 00:00:00', 36.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-11 00:00:00', 37.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-12 00:00:00', 33.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-13 00:00:00', 28.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-14 00:00:00', 24.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-15 00:00:00', 27.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-16 00:00:00', 30.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-17 00:00:00', 31.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-18 00:00:00', 32.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-19 00:00:00', 32.9129981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-20 00:00:00', 33.33599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-21 00:00:00', 30.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-22 00:00:00', 31.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-23 00:00:00', 33.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-24 00:00:00', 33.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-25 00:00:00', 33.8660011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-26 00:00:00', 32.595001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-27 00:00:00', 32.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-28 00:00:00', 32.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-29 00:00:00', 32.6920013427734375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-30 00:00:00', 32.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-08-31 00:00:00', 29.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-01 00:00:00', 26.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-02 00:00:00', 24.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-03 00:00:00', 23.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-04 00:00:00', 23.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-05 00:00:00', 24.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-06 00:00:00', 24.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-07 00:00:00', 24.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-08 00:00:00', 26.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-09 00:00:00', 25.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-10 00:00:00', 26.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-11 00:00:00', 27.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-12 00:00:00', 29.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-13 00:00:00', 30.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-14 00:00:00', 30.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-15 00:00:00', 30.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-16 00:00:00', 28.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-17 00:00:00', 24.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-18 00:00:00', 26.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-19 00:00:00', 25.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-20 00:00:00', 27.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-21 00:00:00', 27.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-22 00:00:00', 26.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-23 00:00:00', 24.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-24 00:00:00', 23.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-25 00:00:00', 22.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-26 00:00:00', 22.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-27 00:00:00', 21.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-28 00:00:00', 22.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-29 00:00:00', 24.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-09-30 00:00:00', 23.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-01 00:00:00', 25.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-02 00:00:00', 25.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-03 00:00:00', 25.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-04 00:00:00', 28.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-05 00:00:00', 28.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-06 00:00:00', 26.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-07 00:00:00', 25.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-08 00:00:00', 24.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-09 00:00:00', 23.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-10 00:00:00', 24.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-11 00:00:00', 24.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-12 00:00:00', 22.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-13 00:00:00', 21.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-14 00:00:00', 21.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-15 00:00:00', 20.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-16 00:00:00', 18.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-17 00:00:00', 19.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-18 00:00:00', 17.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-19 00:00:00', 17.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-20 00:00:00', 18.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-21 00:00:00', 19.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-22 00:00:00', 18.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-23 00:00:00', 17.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-24 00:00:00', 14.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-25 00:00:00', 16.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-26 00:00:00', 16.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-27 00:00:00', 17.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-28 00:00:00', 17.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-29 00:00:00', 17.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-30 00:00:00', 18.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-10-31 00:00:00', 19.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-01 00:00:00', 18.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-02 00:00:00', 19.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-03 00:00:00', 17.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-04 00:00:00', 14.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-05 00:00:00', 12.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-06 00:00:00', 14.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-07 00:00:00', 15.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-08 00:00:00', 13.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-09 00:00:00', 12.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-10 00:00:00', 12.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-11 00:00:00', 11.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-12 00:00:00', 11.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-13 00:00:00', 13.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-14 00:00:00', 11.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-15 00:00:00', 11.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-16 00:00:00', 7.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-17 00:00:00', 9.14999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-18 00:00:00', 7.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-19 00:00:00', 8.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-20 00:00:00', 11.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-21 00:00:00', 10.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-22 00:00:00', 11.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-23 00:00:00', 9.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-24 00:00:00', 10.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-25 00:00:00', 12.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-26 00:00:00', 10.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-27 00:00:00', 6.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-28 00:00:00', 6.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-29 00:00:00', 6.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-11-30 00:00:00', 3.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-01 00:00:00', 5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-02 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-03 00:00:00', -1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-04 00:00:00', -9.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-05 00:00:00', -5.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-06 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-07 00:00:00', 1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-08 00:00:00', 1.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-09 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-10 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-11 00:00:00', 1.9299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-12 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-13 00:00:00', 2.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-14 00:00:00', 1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-15 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-16 00:00:00', 1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-17 00:00:00', 0.781000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-18 00:00:00', -0.112999998033046722, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-19 00:00:00', -1.49100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-20 00:00:00', -1.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-21 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-22 00:00:00', 4.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-23 00:00:00', 2.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-24 00:00:00', 0.218999996781349182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-25 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-26 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-27 00:00:00', -1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-28 00:00:00', -0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-29 00:00:00', 1.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-30 00:00:00', -1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2002-12-31 00:00:00', 3.10199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-01 00:00:00', 4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-02 00:00:00', 4.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-03 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-04 00:00:00', 5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-05 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-06 00:00:00', 3.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-07 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-08 00:00:00', 0.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-09 00:00:00', 1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-10 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-11 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-12 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-13 00:00:00', 2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-14 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-15 00:00:00', 3.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-16 00:00:00', 4.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-17 00:00:00', 5.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-18 00:00:00', 5.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-19 00:00:00', 3.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-20 00:00:00', 6.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-21 00:00:00', 3.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-22 00:00:00', 1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-23 00:00:00', 1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-24 00:00:00', 2.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-25 00:00:00', 2.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-26 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-27 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-28 00:00:00', 2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-29 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-30 00:00:00', 1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-01-31 00:00:00', 1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-01 00:00:00', 2.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-02 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-03 00:00:00', 6.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-04 00:00:00', 6.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-05 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-06 00:00:00', 4.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-07 00:00:00', 1.28100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-08 00:00:00', 3.12299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-09 00:00:00', 3.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-10 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-11 00:00:00', 7.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-12 00:00:00', 3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-13 00:00:00', -1.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-14 00:00:00', 2.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-15 00:00:00', 4.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-16 00:00:00', 4.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-17 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-18 00:00:00', -2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-19 00:00:00', -1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-20 00:00:00', -0.0670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-21 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-22 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-23 00:00:00', 3.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-24 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-25 00:00:00', 3.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-26 00:00:00', 3.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-27 00:00:00', 4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-02-28 00:00:00', 2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-01 00:00:00', 2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-02 00:00:00', -2.77999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-03 00:00:00', -5.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-04 00:00:00', -1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-05 00:00:00', 0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-06 00:00:00', 0.740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-07 00:00:00', 1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-08 00:00:00', 2.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-09 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-10 00:00:00', 2.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-11 00:00:00', 4.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-12 00:00:00', 5.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-13 00:00:00', 6.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-14 00:00:00', 8.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-15 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-16 00:00:00', 3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-17 00:00:00', 8.50599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-18 00:00:00', 8.01799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-19 00:00:00', 7.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-20 00:00:00', 9.96800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-21 00:00:00', 14.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-22 00:00:00', 9.46599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-23 00:00:00', 12.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-24 00:00:00', 10.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-25 00:00:00', 12.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-26 00:00:00', 15.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-27 00:00:00', 9.62800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-28 00:00:00', 8.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-29 00:00:00', 9.67599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-30 00:00:00', 10.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-03-31 00:00:00', 4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-01 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-02 00:00:00', 8.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-03 00:00:00', 7.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-04 00:00:00', 8.01500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-05 00:00:00', 8.51500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-06 00:00:00', 12.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-07 00:00:00', 18.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-08 00:00:00', 21.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-09 00:00:00', 20.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-10 00:00:00', 21.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-11 00:00:00', 20.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-12 00:00:00', 21.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-13 00:00:00', 20.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-14 00:00:00', 17.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-15 00:00:00', 11.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-16 00:00:00', 6.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-17 00:00:00', 12.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-18 00:00:00', 11.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-19 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-20 00:00:00', 7.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-21 00:00:00', 14.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-22 00:00:00', 18.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-23 00:00:00', 20.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-24 00:00:00', 14.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-25 00:00:00', 15.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-26 00:00:00', 18.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-27 00:00:00', 22.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-28 00:00:00', 23.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-29 00:00:00', 21.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-04-30 00:00:00', 15.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-01 00:00:00', 12.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-02 00:00:00', 6.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-03 00:00:00', 9.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-04 00:00:00', 12.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-05 00:00:00', 13.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-06 00:00:00', 17.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-07 00:00:00', 20.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-08 00:00:00', 23.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-09 00:00:00', 21.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-10 00:00:00', 14.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-11 00:00:00', 15.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-12 00:00:00', 15.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-13 00:00:00', 18.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-14 00:00:00', 16.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-15 00:00:00', 17.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-16 00:00:00', 19.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-17 00:00:00', 21.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-18 00:00:00', 21.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-19 00:00:00', 20.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-20 00:00:00', 22.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-21 00:00:00', 22.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-22 00:00:00', 21.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-23 00:00:00', 22.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-24 00:00:00', 23.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-25 00:00:00', 22.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-26 00:00:00', 20.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-27 00:00:00', 14.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-28 00:00:00', 19.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-29 00:00:00', 20.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-30 00:00:00', 24.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-05-31 00:00:00', 28.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-01 00:00:00', 25.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-02 00:00:00', 27.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-03 00:00:00', 25.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-04 00:00:00', 25.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-05 00:00:00', 27.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-06 00:00:00', 27.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-07 00:00:00', 22.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-08 00:00:00', 22.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-09 00:00:00', 25.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-10 00:00:00', 25.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-11 00:00:00', 22.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-12 00:00:00', 20.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-13 00:00:00', 25.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-14 00:00:00', 26.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-15 00:00:00', 26.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-16 00:00:00', 28.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-17 00:00:00', 29.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-18 00:00:00', 28.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-19 00:00:00', 28.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-20 00:00:00', 28.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-21 00:00:00', 27.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-22 00:00:00', 25.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-23 00:00:00', 28.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-24 00:00:00', 29.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-25 00:00:00', 31.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-26 00:00:00', 28.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-27 00:00:00', 29.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-28 00:00:00', 28.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-29 00:00:00', 26.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-06-30 00:00:00', 28.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-01 00:00:00', 30.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-02 00:00:00', 32.4350013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-03 00:00:00', 35.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-04 00:00:00', 33.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-05 00:00:00', 29.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-06 00:00:00', 30.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-07 00:00:00', 30.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-08 00:00:00', 31.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-09 00:00:00', 30.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-10 00:00:00', 31.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-11 00:00:00', 31.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-12 00:00:00', 30.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-13 00:00:00', 28.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-14 00:00:00', 30.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-15 00:00:00', 31.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-16 00:00:00', 32.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-17 00:00:00', 32.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-18 00:00:00', 35.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-19 00:00:00', 37.0159988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-20 00:00:00', 37.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-21 00:00:00', 37.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-22 00:00:00', 34.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-23 00:00:00', 31.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-24 00:00:00', 29.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-25 00:00:00', 30.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-26 00:00:00', 31.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-27 00:00:00', 32.0309982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-28 00:00:00', 32.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-29 00:00:00', 31.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-30 00:00:00', 31.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-07-31 00:00:00', 33.7879981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-01 00:00:00', 35.0989990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-02 00:00:00', 32.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-03 00:00:00', 29.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-04 00:00:00', 27.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-05 00:00:00', 26.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-06 00:00:00', 27.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-07 00:00:00', 27.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-08 00:00:00', 29.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-09 00:00:00', 29.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-10 00:00:00', 28.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-11 00:00:00', 29.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-12 00:00:00', 30.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-13 00:00:00', 29.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-14 00:00:00', 32.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-15 00:00:00', 34.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-16 00:00:00', 35.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-17 00:00:00', 35.2809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-18 00:00:00', 33.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-19 00:00:00', 31.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-20 00:00:00', 28.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-21 00:00:00', 26.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-22 00:00:00', 27.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-23 00:00:00', 28.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-24 00:00:00', 29.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-25 00:00:00', 29.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-26 00:00:00', 28.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-27 00:00:00', 29.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-28 00:00:00', 30.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-29 00:00:00', 29.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-30 00:00:00', 27.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-08-31 00:00:00', 29.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-01 00:00:00', 29.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-02 00:00:00', 30.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-03 00:00:00', 29.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-04 00:00:00', 28.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-05 00:00:00', 25.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-06 00:00:00', 26.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-07 00:00:00', 28.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-08 00:00:00', 29.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-09 00:00:00', 30.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-10 00:00:00', 30.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-11 00:00:00', 29.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-12 00:00:00', 28.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-13 00:00:00', 26.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-14 00:00:00', 27.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-15 00:00:00', 23.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-16 00:00:00', 21.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-17 00:00:00', 23.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-18 00:00:00', 26.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-19 00:00:00', 27.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-20 00:00:00', 29.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-21 00:00:00', 27.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-22 00:00:00', 25.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-23 00:00:00', 21.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-24 00:00:00', 19.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-25 00:00:00', 20.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-26 00:00:00', 16.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-27 00:00:00', 16.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-28 00:00:00', 17.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-29 00:00:00', 17.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-09-30 00:00:00', 18.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-01 00:00:00', 19.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-02 00:00:00', 21.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-03 00:00:00', 22.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-04 00:00:00', 23.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-05 00:00:00', 23.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-06 00:00:00', 20.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-07 00:00:00', 15.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-08 00:00:00', 16.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-09 00:00:00', 15.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-10 00:00:00', 16.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-11 00:00:00', 16.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-12 00:00:00', 14.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-13 00:00:00', 16.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-14 00:00:00', 17.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-15 00:00:00', 17.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-16 00:00:00', 15.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-17 00:00:00', 18.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-18 00:00:00', 19.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-19 00:00:00', 19.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-20 00:00:00', 19.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-21 00:00:00', 17.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-22 00:00:00', 18.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-23 00:00:00', 18.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-24 00:00:00', 18.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-25 00:00:00', 19.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-26 00:00:00', 19.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-27 00:00:00', 19.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-28 00:00:00', 21.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-29 00:00:00', 22.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-30 00:00:00', 22.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-10-31 00:00:00', 23.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-01 00:00:00', 19.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-02 00:00:00', 18.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-03 00:00:00', 18.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-04 00:00:00', 12.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-05 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-06 00:00:00', 5.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-07 00:00:00', 5.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-08 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-09 00:00:00', 8.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-10 00:00:00', 10.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-11 00:00:00', 12.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-12 00:00:00', 11.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-13 00:00:00', 9.37800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-14 00:00:00', 8.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-15 00:00:00', 8.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-16 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-17 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-18 00:00:00', 3.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-19 00:00:00', 3.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-20 00:00:00', 5.45200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-21 00:00:00', 6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-22 00:00:00', 6.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-23 00:00:00', 1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-24 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-25 00:00:00', 7.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-26 00:00:00', 7.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-27 00:00:00', 8.01299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-28 00:00:00', 9.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-29 00:00:00', 7.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-11-30 00:00:00', 6.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-01 00:00:00', 5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-02 00:00:00', 5.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-03 00:00:00', 6.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-04 00:00:00', 6.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-05 00:00:00', 4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-06 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-07 00:00:00', 5.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-08 00:00:00', 2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-09 00:00:00', 2.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-10 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-11 00:00:00', 2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-12 00:00:00', -0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-13 00:00:00', -6.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-14 00:00:00', -2.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-15 00:00:00', 0.699000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-16 00:00:00', 1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-17 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-18 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-19 00:00:00', 2.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-20 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-21 00:00:00', 2.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-22 00:00:00', -0.0619999989867210388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-23 00:00:00', -4.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-24 00:00:00', -1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-25 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-26 00:00:00', -1.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-27 00:00:00', 0.131999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-28 00:00:00', 0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-29 00:00:00', 0.973999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-30 00:00:00', -0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2003-12-31 00:00:00', -0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-01 00:00:00', -2.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-02 00:00:00', -3.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-03 00:00:00', -1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-04 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-05 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-06 00:00:00', 0.728999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-07 00:00:00', 0.321999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-08 00:00:00', 1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-09 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-10 00:00:00', 3.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-11 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-12 00:00:00', 2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-13 00:00:00', 2.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-14 00:00:00', 5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-15 00:00:00', 5.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-16 00:00:00', 5.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-17 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-18 00:00:00', 4.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-19 00:00:00', 7.72800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-20 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-21 00:00:00', 2.0280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-22 00:00:00', 2.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-23 00:00:00', 2.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-24 00:00:00', 3.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-25 00:00:00', 3.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-26 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-27 00:00:00', 3.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-28 00:00:00', 2.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-29 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-30 00:00:00', 0.236000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-01-31 00:00:00', -0.762000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-01 00:00:00', -0.580999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-02 00:00:00', 0.987999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-03 00:00:00', 4.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-04 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-05 00:00:00', 2.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-06 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-07 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-08 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-09 00:00:00', 3.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-10 00:00:00', 5.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-11 00:00:00', 8.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-12 00:00:00', 9.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-13 00:00:00', 7.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-14 00:00:00', 8.00399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-15 00:00:00', 8.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-16 00:00:00', 10.9049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-17 00:00:00', 3.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-18 00:00:00', 2.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-19 00:00:00', 3.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-20 00:00:00', 5.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-21 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-22 00:00:00', 7.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-23 00:00:00', 8.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-24 00:00:00', 7.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-25 00:00:00', 8.25599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-26 00:00:00', 7.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-27 00:00:00', 7.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-28 00:00:00', 8.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-02-29 00:00:00', 7.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-01 00:00:00', 5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-02 00:00:00', 8.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-03 00:00:00', 8.33600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-04 00:00:00', 8.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-05 00:00:00', 9.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-06 00:00:00', 14.560999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-07 00:00:00', 18.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-08 00:00:00', 16.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-09 00:00:00', 10.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-10 00:00:00', 9.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-11 00:00:00', 11.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-12 00:00:00', 14.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-13 00:00:00', 14.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-14 00:00:00', 10.2869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-15 00:00:00', 11.1829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-16 00:00:00', 13.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-17 00:00:00', 6.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-18 00:00:00', 9.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-19 00:00:00', 10.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-20 00:00:00', 8.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-21 00:00:00', 5.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-22 00:00:00', 7.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-23 00:00:00', 8.42099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-24 00:00:00', 11.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-25 00:00:00', 11.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-26 00:00:00', 14.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-27 00:00:00', 15.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-28 00:00:00', 15.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-29 00:00:00', 18.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-30 00:00:00', 18.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-03-31 00:00:00', 19.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-01 00:00:00', 18.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-02 00:00:00', 17.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-03 00:00:00', 13.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-04 00:00:00', 19.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-05 00:00:00', 21.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-06 00:00:00', 14.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-07 00:00:00', 10.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-08 00:00:00', 12.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-09 00:00:00', 12.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-10 00:00:00', 13.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-11 00:00:00', 15.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-12 00:00:00', 16.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-13 00:00:00', 16.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-14 00:00:00', 19.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-15 00:00:00', 20.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-16 00:00:00', 19.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-17 00:00:00', 18.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-18 00:00:00', 19.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-19 00:00:00', 15.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-20 00:00:00', 19.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-21 00:00:00', 21.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-22 00:00:00', 13.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-23 00:00:00', 17.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-24 00:00:00', 22.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-25 00:00:00', 22.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-26 00:00:00', 21.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-27 00:00:00', 17.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-28 00:00:00', 16.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-29 00:00:00', 10.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-04-30 00:00:00', 14.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-01 00:00:00', 15.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-02 00:00:00', 17.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-03 00:00:00', 20.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-04 00:00:00', 21.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-05 00:00:00', 24.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-06 00:00:00', 24.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-07 00:00:00', 13.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-08 00:00:00', 19.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-09 00:00:00', 20.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-10 00:00:00', 23.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-11 00:00:00', 23.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-12 00:00:00', 25.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-13 00:00:00', 28.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-14 00:00:00', 29.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-15 00:00:00', 30.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-16 00:00:00', 28.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-17 00:00:00', 28.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-18 00:00:00', 29.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-19 00:00:00', 24.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-20 00:00:00', 21.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-21 00:00:00', 24.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-22 00:00:00', 19.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-23 00:00:00', 19.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-24 00:00:00', 23.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-25 00:00:00', 24.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-26 00:00:00', 23.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-27 00:00:00', 21.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-28 00:00:00', 22.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-29 00:00:00', 23.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-30 00:00:00', 24.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-05-31 00:00:00', 24.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-01 00:00:00', 24.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-02 00:00:00', 25.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-03 00:00:00', 27.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-04 00:00:00', 28.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-05 00:00:00', 30.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-06 00:00:00', 26.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-07 00:00:00', 24.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-08 00:00:00', 25.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-09 00:00:00', 26.7150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-10 00:00:00', 29.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-11 00:00:00', 30.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-12 00:00:00', 31.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-13 00:00:00', 31.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-14 00:00:00', 26.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-15 00:00:00', 29.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-16 00:00:00', 30.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-17 00:00:00', 32.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-18 00:00:00', 31.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-19 00:00:00', 32.16400146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-20 00:00:00', 31.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-21 00:00:00', 31.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-22 00:00:00', 30.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-23 00:00:00', 31.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-24 00:00:00', 29.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-25 00:00:00', 29.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-26 00:00:00', 29.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-27 00:00:00', 29.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-28 00:00:00', 29.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-29 00:00:00', 31.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-06-30 00:00:00', 31.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-01 00:00:00', 31.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-02 00:00:00', 32.0190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-03 00:00:00', 32.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-04 00:00:00', 33.6010017395019531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-05 00:00:00', 30.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-06 00:00:00', 28.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-07 00:00:00', 29.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-08 00:00:00', 28.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-09 00:00:00', 28.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-10 00:00:00', 30.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-11 00:00:00', 32.154998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-12 00:00:00', 30.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-13 00:00:00', 28.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-14 00:00:00', 27.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-15 00:00:00', 26.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-16 00:00:00', 25.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-17 00:00:00', 24.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-18 00:00:00', 22.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-19 00:00:00', 20.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-20 00:00:00', 23.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-21 00:00:00', 25.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-22 00:00:00', 28.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-23 00:00:00', 28.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-24 00:00:00', 32.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-25 00:00:00', 32.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-26 00:00:00', 32.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-27 00:00:00', 32.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-28 00:00:00', 32.529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-29 00:00:00', 33.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-30 00:00:00', 30.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-07-31 00:00:00', 29.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-01 00:00:00', 26.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-02 00:00:00', 26.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-03 00:00:00', 26.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-04 00:00:00', 29.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-05 00:00:00', 32.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-06 00:00:00', 32.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-07 00:00:00', 28.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-08 00:00:00', 27.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-09 00:00:00', 28.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-10 00:00:00', 28.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-11 00:00:00', 28.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-12 00:00:00', 29.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-13 00:00:00', 33.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-14 00:00:00', 35.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-15 00:00:00', 34.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-16 00:00:00', 33.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-17 00:00:00', 31.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-18 00:00:00', 31.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-19 00:00:00', 30.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-20 00:00:00', 28.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-21 00:00:00', 28.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-22 00:00:00', 31.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-23 00:00:00', 32.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-24 00:00:00', 31.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-25 00:00:00', 29.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-26 00:00:00', 28.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-27 00:00:00', 27.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-28 00:00:00', 27.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-29 00:00:00', 27.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-30 00:00:00', 26.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-08-31 00:00:00', 25.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-01 00:00:00', 25.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-02 00:00:00', 25.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-03 00:00:00', 26.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-04 00:00:00', 25.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-05 00:00:00', 26.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-06 00:00:00', 28.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-07 00:00:00', 32.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-08 00:00:00', 30.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-09 00:00:00', 28.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-10 00:00:00', 30.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-11 00:00:00', 32.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-12 00:00:00', 30.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-13 00:00:00', 29.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-14 00:00:00', 27.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-15 00:00:00', 21.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-16 00:00:00', 21.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-17 00:00:00', 21.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-18 00:00:00', 24.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-19 00:00:00', 24.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-20 00:00:00', 22.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-21 00:00:00', 19.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-22 00:00:00', 20.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-23 00:00:00', 24.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-24 00:00:00', 24.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-25 00:00:00', 24.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-26 00:00:00', 25.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-27 00:00:00', 25.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-28 00:00:00', 23.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-29 00:00:00', 23.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-09-30 00:00:00', 24.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-01 00:00:00', 23.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-02 00:00:00', 22.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-03 00:00:00', 22.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-04 00:00:00', 24.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-05 00:00:00', 24.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-06 00:00:00', 20.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-07 00:00:00', 15.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-08 00:00:00', 12.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-09 00:00:00', 12.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-10 00:00:00', 13.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-11 00:00:00', 16.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-12 00:00:00', 16.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-13 00:00:00', 17.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-14 00:00:00', 18.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-15 00:00:00', 13.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-16 00:00:00', 13.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-17 00:00:00', 13.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-18 00:00:00', 11.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-19 00:00:00', 11.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-20 00:00:00', 13.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-21 00:00:00', 16.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-22 00:00:00', 19.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-23 00:00:00', 20.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-24 00:00:00', 13.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-25 00:00:00', 13.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-26 00:00:00', 13.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-27 00:00:00', 9.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-28 00:00:00', 11.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-29 00:00:00', 16.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-30 00:00:00', 16.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-10-31 00:00:00', 15.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-01 00:00:00', 14.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-02 00:00:00', 14.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-03 00:00:00', 15.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-04 00:00:00', 18.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-05 00:00:00', 13.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-06 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-07 00:00:00', 15.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-08 00:00:00', 13.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-09 00:00:00', 12.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-10 00:00:00', 10.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-11 00:00:00', 11.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-12 00:00:00', 12.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-13 00:00:00', 9.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-14 00:00:00', 12.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-15 00:00:00', 12.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-16 00:00:00', 10.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-17 00:00:00', 11.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-18 00:00:00', 13.4630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-19 00:00:00', 9.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-20 00:00:00', 9.56000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-21 00:00:00', 9.89500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-22 00:00:00', 9.81499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-23 00:00:00', 12.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-24 00:00:00', 13.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-25 00:00:00', 8.56000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-26 00:00:00', 8.49199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-27 00:00:00', 10.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-28 00:00:00', 11.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-29 00:00:00', 5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-11-30 00:00:00', 3.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-01 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-02 00:00:00', 7.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-03 00:00:00', 3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-04 00:00:00', 2.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-05 00:00:00', 4.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-06 00:00:00', 6.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-07 00:00:00', 4.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-08 00:00:00', 3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-09 00:00:00', 7.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-10 00:00:00', 7.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-11 00:00:00', 8.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-12 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-13 00:00:00', 8.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-14 00:00:00', 5.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-15 00:00:00', 6.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-16 00:00:00', 6.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-17 00:00:00', 10.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-18 00:00:00', 4.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-19 00:00:00', -1.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-20 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-21 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-22 00:00:00', 1.6260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-23 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-24 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-25 00:00:00', 1.67900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-26 00:00:00', 5.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-27 00:00:00', 3.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-28 00:00:00', 2.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-29 00:00:00', -0.0590000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-30 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2004-12-31 00:00:00', 6.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-01 00:00:00', 1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-02 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-03 00:00:00', 1.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-04 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-05 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-06 00:00:00', 2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-07 00:00:00', 3.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-08 00:00:00', 1.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-09 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-10 00:00:00', 0.81800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-11 00:00:00', 6.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-12 00:00:00', 2.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-13 00:00:00', 2.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-14 00:00:00', -1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-15 00:00:00', -0.391999989748001099, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-16 00:00:00', 0.449000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-17 00:00:00', -1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-18 00:00:00', 0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-19 00:00:00', 0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-20 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-21 00:00:00', 1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-22 00:00:00', -1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-23 00:00:00', 1.01100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-24 00:00:00', -0.126000002026557922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-25 00:00:00', 2.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-26 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-27 00:00:00', -3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-28 00:00:00', -4.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-29 00:00:00', -2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-30 00:00:00', -3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-01-31 00:00:00', -1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-01 00:00:00', -0.164000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-02 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-03 00:00:00', 0.550999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-04 00:00:00', -2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-05 00:00:00', 0.150000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-06 00:00:00', -1.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-07 00:00:00', -0.591000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-08 00:00:00', -0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-09 00:00:00', 3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-10 00:00:00', 2.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-11 00:00:00', -0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-12 00:00:00', -0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-13 00:00:00', -2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-14 00:00:00', -0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-15 00:00:00', -2.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-16 00:00:00', -4.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-17 00:00:00', -4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-18 00:00:00', -2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-19 00:00:00', 0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-20 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-21 00:00:00', 3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-22 00:00:00', 3.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-23 00:00:00', 2.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-24 00:00:00', 0.29800000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-25 00:00:00', 2.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-26 00:00:00', 4.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-27 00:00:00', 7.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-02-28 00:00:00', 7.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-01 00:00:00', 9.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-02 00:00:00', 13.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-03 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-04 00:00:00', 13.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-05 00:00:00', 14.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-06 00:00:00', 14.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-07 00:00:00', 14.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-08 00:00:00', 12.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-09 00:00:00', 11.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-10 00:00:00', 10.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-11 00:00:00', 13.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-12 00:00:00', 18.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-13 00:00:00', 18.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-14 00:00:00', 10.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-15 00:00:00', 12.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-16 00:00:00', 8.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-17 00:00:00', 8.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-18 00:00:00', 10.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-19 00:00:00', 8.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-20 00:00:00', 11.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-21 00:00:00', 12.0819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-22 00:00:00', 13.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-23 00:00:00', 13.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-24 00:00:00', 13.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-25 00:00:00', 9.85299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-26 00:00:00', 10.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-27 00:00:00', 3.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-28 00:00:00', 6.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-29 00:00:00', 9.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-30 00:00:00', 10.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-03-31 00:00:00', 14.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-01 00:00:00', 17.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-02 00:00:00', 17.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-03 00:00:00', 16.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-04 00:00:00', 14.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-05 00:00:00', 9.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-06 00:00:00', 5.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-07 00:00:00', 6.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-08 00:00:00', 5.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-09 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-10 00:00:00', 8.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-11 00:00:00', 10.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-12 00:00:00', 9.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-13 00:00:00', 14.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-14 00:00:00', 13.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-15 00:00:00', 16.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-16 00:00:00', 18.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-17 00:00:00', 20.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-18 00:00:00', 24.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-19 00:00:00', 20.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-20 00:00:00', 22.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-21 00:00:00', 23.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-22 00:00:00', 22.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-23 00:00:00', 21.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-24 00:00:00', 19.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-25 00:00:00', 17.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-26 00:00:00', 18.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-27 00:00:00', 18.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-28 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-29 00:00:00', 21.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-04-30 00:00:00', 25.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-01 00:00:00', 23.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-02 00:00:00', 23.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-03 00:00:00', 22.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-04 00:00:00', 23.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-05 00:00:00', 24.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-06 00:00:00', 22.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-07 00:00:00', 21.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-08 00:00:00', 14.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-09 00:00:00', 15.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-10 00:00:00', 20.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-11 00:00:00', 20.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-12 00:00:00', 19.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-13 00:00:00', 17.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-14 00:00:00', 17.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-15 00:00:00', 19.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-16 00:00:00', 20.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-17 00:00:00', 21.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-18 00:00:00', 18.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-19 00:00:00', 15.3660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-20 00:00:00', 13.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-21 00:00:00', 18.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-22 00:00:00', 18.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-23 00:00:00', 18.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-24 00:00:00', 16.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-25 00:00:00', 20.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-26 00:00:00', 18.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-27 00:00:00', 21.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-28 00:00:00', 22.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-29 00:00:00', 24.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-30 00:00:00', 25.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-05-31 00:00:00', 26.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-01 00:00:00', 25.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-02 00:00:00', 27.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-03 00:00:00', 26.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-04 00:00:00', 29.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-05 00:00:00', 27.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-06 00:00:00', 27.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-07 00:00:00', 27.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-08 00:00:00', 27.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-09 00:00:00', 25.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-10 00:00:00', 20.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-11 00:00:00', 20.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-12 00:00:00', 23.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-13 00:00:00', 24.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-14 00:00:00', 27.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-15 00:00:00', 30.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-16 00:00:00', 31.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-17 00:00:00', 32.4070014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-18 00:00:00', 32.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-19 00:00:00', 31.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-20 00:00:00', 31.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-21 00:00:00', 32.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-22 00:00:00', 34.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-23 00:00:00', 36.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-24 00:00:00', 33.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-25 00:00:00', 29.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-26 00:00:00', 29.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-27 00:00:00', 31.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-28 00:00:00', 31.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-29 00:00:00', 30.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-06-30 00:00:00', 30.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-01 00:00:00', 30.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-02 00:00:00', 29.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-03 00:00:00', 30.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-04 00:00:00', 30.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-05 00:00:00', 31.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-06 00:00:00', 32.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-07 00:00:00', 33.2340011596679688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-08 00:00:00', 36.0789985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-09 00:00:00', 37.404998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-10 00:00:00', 33.6619987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-11 00:00:00', 32.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-12 00:00:00', 31.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-13 00:00:00', 32.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-14 00:00:00', 30.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-15 00:00:00', 30.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-16 00:00:00', 27.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-17 00:00:00', 28.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-18 00:00:00', 31.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-19 00:00:00', 30.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-20 00:00:00', 32.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-21 00:00:00', 32.5379981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-22 00:00:00', 29.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-23 00:00:00', 29.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-24 00:00:00', 29.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-25 00:00:00', 30.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-26 00:00:00', 30.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-27 00:00:00', 31.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-28 00:00:00', 31.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-29 00:00:00', 29.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-30 00:00:00', 28.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-07-31 00:00:00', 30.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-01 00:00:00', 28.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-02 00:00:00', 27.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-03 00:00:00', 28.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-04 00:00:00', 29.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-05 00:00:00', 27.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-06 00:00:00', 31.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-07 00:00:00', 29.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-08 00:00:00', 28.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-09 00:00:00', 30.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-10 00:00:00', 30.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-11 00:00:00', 28.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-12 00:00:00', 25.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-13 00:00:00', 27.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-14 00:00:00', 29.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-15 00:00:00', 28.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-16 00:00:00', 27.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-17 00:00:00', 27.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-18 00:00:00', 28.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-19 00:00:00', 29.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-20 00:00:00', 30.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-21 00:00:00', 29.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-22 00:00:00', 30.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-23 00:00:00', 28.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-24 00:00:00', 26.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-25 00:00:00', 25.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-26 00:00:00', 25.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-27 00:00:00', 21.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-28 00:00:00', 21.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-29 00:00:00', 22.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-30 00:00:00', 22.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-08-31 00:00:00', 25.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-01 00:00:00', 27.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-02 00:00:00', 29.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-03 00:00:00', 29.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-04 00:00:00', 31.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-05 00:00:00', 32.9900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-06 00:00:00', 33.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-07 00:00:00', 30.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-08 00:00:00', 29.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-09 00:00:00', 26.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-10 00:00:00', 24.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-11 00:00:00', 25.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-12 00:00:00', 26.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-13 00:00:00', 28.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-14 00:00:00', 27.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-15 00:00:00', 29.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-16 00:00:00', 30.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-17 00:00:00', 28.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-18 00:00:00', 24.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-19 00:00:00', 24.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-20 00:00:00', 25.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-21 00:00:00', 25.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-22 00:00:00', 25.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-23 00:00:00', 24.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-24 00:00:00', 24.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-25 00:00:00', 23.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-26 00:00:00', 21.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-27 00:00:00', 21.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-28 00:00:00', 21.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-29 00:00:00', 22.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-09-30 00:00:00', 23.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-01 00:00:00', 26.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-02 00:00:00', 24.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-03 00:00:00', 20.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-04 00:00:00', 20.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-05 00:00:00', 20.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-06 00:00:00', 25.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-07 00:00:00', 25.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-08 00:00:00', 23.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-09 00:00:00', 22.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-10 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-11 00:00:00', 18.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-12 00:00:00', 15.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-13 00:00:00', 14.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-14 00:00:00', 11.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-15 00:00:00', 13.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-16 00:00:00', 12.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-17 00:00:00', 15.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-18 00:00:00', 18.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-19 00:00:00', 20.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-20 00:00:00', 21.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-21 00:00:00', 21.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-22 00:00:00', 22.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-23 00:00:00', 15.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-24 00:00:00', 9.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-25 00:00:00', 12.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-26 00:00:00', 15.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-27 00:00:00', 13.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-28 00:00:00', 16.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-29 00:00:00', 17.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-30 00:00:00', 18.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-10-31 00:00:00', 14.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-01 00:00:00', 13.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-02 00:00:00', 13.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-03 00:00:00', 14.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-04 00:00:00', 15.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-05 00:00:00', 15.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-06 00:00:00', 14.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-07 00:00:00', 9.12100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-08 00:00:00', 12.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-09 00:00:00', 13.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-10 00:00:00', 7.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-11 00:00:00', 6.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-12 00:00:00', 7.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-13 00:00:00', 7.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-14 00:00:00', 6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-15 00:00:00', 6.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-16 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-17 00:00:00', 8.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-18 00:00:00', 12.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-19 00:00:00', 14.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-20 00:00:00', 14.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-21 00:00:00', 12.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-22 00:00:00', 10.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-23 00:00:00', 10.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-24 00:00:00', 7.02899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-25 00:00:00', 5.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-26 00:00:00', 4.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-27 00:00:00', 4.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-28 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-29 00:00:00', 4.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-11-30 00:00:00', 5.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-01 00:00:00', 7.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-02 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-03 00:00:00', 4.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-04 00:00:00', 5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-05 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-06 00:00:00', 7.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-07 00:00:00', 7.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-08 00:00:00', 3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-09 00:00:00', 4.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-10 00:00:00', 6.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-11 00:00:00', 8.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-12 00:00:00', 6.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-13 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-14 00:00:00', 2.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-15 00:00:00', 6.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-16 00:00:00', 8.09799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-17 00:00:00', 10.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-18 00:00:00', 11.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-19 00:00:00', 9.11400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-20 00:00:00', 9.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-21 00:00:00', 8.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-22 00:00:00', 7.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-23 00:00:00', 7.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-24 00:00:00', 7.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-25 00:00:00', 6.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-26 00:00:00', 8.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-27 00:00:00', 5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-28 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-29 00:00:00', -0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-30 00:00:00', -0.86799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2005-12-31 00:00:00', -0.782999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-01 00:00:00', -2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-02 00:00:00', -5.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-03 00:00:00', -8.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-04 00:00:00', -6.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-05 00:00:00', -6.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-06 00:00:00', -4.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-07 00:00:00', 0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-08 00:00:00', 1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-09 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-10 00:00:00', -0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-11 00:00:00', 1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-12 00:00:00', 0.794000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-13 00:00:00', 2.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-14 00:00:00', 1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-15 00:00:00', -0.763999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-16 00:00:00', -0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-17 00:00:00', -2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-18 00:00:00', -0.0930000022053718567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-19 00:00:00', 0.800999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-20 00:00:00', -0.586000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-21 00:00:00', 0.796000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-22 00:00:00', 3.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-23 00:00:00', -0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-24 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-25 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-26 00:00:00', 2.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-27 00:00:00', 1.16700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-28 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-29 00:00:00', 1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-30 00:00:00', 3.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-01-31 00:00:00', 0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-01 00:00:00', 0.957000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-02 00:00:00', 1.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-03 00:00:00', 2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-04 00:00:00', 11.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-05 00:00:00', 10.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-06 00:00:00', 9.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-07 00:00:00', 10.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-08 00:00:00', 10.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-09 00:00:00', 10.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-10 00:00:00', 8.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-11 00:00:00', 6.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-12 00:00:00', 9.58100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-13 00:00:00', 7.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-14 00:00:00', 11.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-15 00:00:00', 9.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-16 00:00:00', 7.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-17 00:00:00', 5.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-18 00:00:00', 8.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-19 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-20 00:00:00', 6.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-21 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-22 00:00:00', 4.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-23 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-24 00:00:00', 5.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-25 00:00:00', 2.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-26 00:00:00', 5.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-27 00:00:00', 7.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-02-28 00:00:00', 9.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-01 00:00:00', 9.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-02 00:00:00', 8.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-03 00:00:00', 11.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-04 00:00:00', 9.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-05 00:00:00', 10.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-06 00:00:00', 9.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-07 00:00:00', 8.34599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-08 00:00:00', 9.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-09 00:00:00', 11.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-10 00:00:00', 13.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-11 00:00:00', 17.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-12 00:00:00', 14.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-13 00:00:00', 6.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-14 00:00:00', 6.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-15 00:00:00', 4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-16 00:00:00', 6.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-17 00:00:00', 9.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-18 00:00:00', 10.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-19 00:00:00', 10.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-20 00:00:00', 12.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-21 00:00:00', 11.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-22 00:00:00', 9.70400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-23 00:00:00', 12.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-24 00:00:00', 11.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-25 00:00:00', 13.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-26 00:00:00', 9.07199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-27 00:00:00', 10.1309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-28 00:00:00', 14.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-29 00:00:00', 14.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-30 00:00:00', 14.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-03-31 00:00:00', 11.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-01 00:00:00', 6.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-02 00:00:00', 12.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-03 00:00:00', 15.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-04 00:00:00', 15.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-05 00:00:00', 17.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-06 00:00:00', 15.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-07 00:00:00', 19.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-08 00:00:00', 17.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-09 00:00:00', 8.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-10 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-11 00:00:00', 11.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-12 00:00:00', 10.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-13 00:00:00', 12.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-14 00:00:00', 13.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-15 00:00:00', 13.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-16 00:00:00', 15.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-17 00:00:00', 16.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-18 00:00:00', 18.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-19 00:00:00', 20.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-20 00:00:00', 19.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-21 00:00:00', 15.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-22 00:00:00', 18.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-23 00:00:00', 19.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-24 00:00:00', 23.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-25 00:00:00', 26.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-26 00:00:00', 26.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-27 00:00:00', 27.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-28 00:00:00', 25.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-29 00:00:00', 22.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-04-30 00:00:00', 20.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-01 00:00:00', 19.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-02 00:00:00', 21.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-03 00:00:00', 22.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-04 00:00:00', 21.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-05 00:00:00', 22.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-06 00:00:00', 22.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-07 00:00:00', 20.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-08 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-09 00:00:00', 24.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-10 00:00:00', 26.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-11 00:00:00', 27.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-12 00:00:00', 29.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-13 00:00:00', 29.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-14 00:00:00', 29.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-15 00:00:00', 31.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-16 00:00:00', 32.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-17 00:00:00', 27.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-18 00:00:00', 26.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-19 00:00:00', 26.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-20 00:00:00', 28.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-21 00:00:00', 25.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-22 00:00:00', 26.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-23 00:00:00', 26.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-24 00:00:00', 26.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-25 00:00:00', 26.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-26 00:00:00', 25.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-27 00:00:00', 25.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-28 00:00:00', 24.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-29 00:00:00', 25.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-30 00:00:00', 25.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-05-31 00:00:00', 22.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-01 00:00:00', 24.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-02 00:00:00', 28.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-03 00:00:00', 25.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-04 00:00:00', 26.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-05 00:00:00', 27.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-06 00:00:00', 26.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-07 00:00:00', 24.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-08 00:00:00', 24.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-09 00:00:00', 24.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-10 00:00:00', 24.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-11 00:00:00', 24.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-12 00:00:00', 27.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-13 00:00:00', 28.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-14 00:00:00', 31.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-15 00:00:00', 29.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-16 00:00:00', 29.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-17 00:00:00', 30.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-18 00:00:00', 31.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-19 00:00:00', 33.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-20 00:00:00', 32.5719985961914062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-21 00:00:00', 32.9119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-22 00:00:00', 32.2729988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-23 00:00:00', 31.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-24 00:00:00', 32.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-25 00:00:00', 32.1629981994628906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-26 00:00:00', 32.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-27 00:00:00', 33.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-28 00:00:00', 31.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-29 00:00:00', 29.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-06-30 00:00:00', 30.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-01 00:00:00', 26.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-02 00:00:00', 26.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-03 00:00:00', 30.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-04 00:00:00', 30.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-05 00:00:00', 30.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-06 00:00:00', 33.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-07 00:00:00', 33.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-08 00:00:00', 33.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-09 00:00:00', 35.7809982299804688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-10 00:00:00', 34.2120018005371094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-11 00:00:00', 31.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-12 00:00:00', 25.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-13 00:00:00', 22.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-14 00:00:00', 23.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-15 00:00:00', 26.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-16 00:00:00', 28.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-17 00:00:00', 30.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-18 00:00:00', 29.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-19 00:00:00', 30.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-20 00:00:00', 32.2680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-21 00:00:00', 34.3769989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-22 00:00:00', 36.3639984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-23 00:00:00', 36.7470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-24 00:00:00', 35.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-25 00:00:00', 35.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-26 00:00:00', 34.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-27 00:00:00', 33.7519989013671875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-28 00:00:00', 31.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-29 00:00:00', 34.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-30 00:00:00', 37.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-07-31 00:00:00', 36.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-01 00:00:00', 35.8089981079101562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-02 00:00:00', 35.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-03 00:00:00', 34.1570014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-04 00:00:00', 34.0509986877441406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-05 00:00:00', 32.733001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-06 00:00:00', 31.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-07 00:00:00', 32.9690017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-08 00:00:00', 31.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-09 00:00:00', 33.845001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-10 00:00:00', 34.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-11 00:00:00', 33.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-12 00:00:00', 33.2130012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-13 00:00:00', 35.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-14 00:00:00', 35.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-15 00:00:00', 30.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-16 00:00:00', 28.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-17 00:00:00', 28.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-18 00:00:00', 30.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-19 00:00:00', 31.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-20 00:00:00', 32.0740013122558594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-21 00:00:00', 30.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-22 00:00:00', 30.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-23 00:00:00', 31.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-24 00:00:00', 31.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-25 00:00:00', 32.5880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-26 00:00:00', 30.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-27 00:00:00', 29.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-28 00:00:00', 28.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-29 00:00:00', 27.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-30 00:00:00', 30.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-08-31 00:00:00', 30.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-01 00:00:00', 28.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-02 00:00:00', 26.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-03 00:00:00', 24.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-04 00:00:00', 21.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-05 00:00:00', 22.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-06 00:00:00', 26.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-07 00:00:00', 28.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-08 00:00:00', 29.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-09 00:00:00', 29.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-10 00:00:00', 27.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-11 00:00:00', 26.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-12 00:00:00', 26.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-13 00:00:00', 26.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-14 00:00:00', 24.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-15 00:00:00', 24.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-16 00:00:00', 27.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-17 00:00:00', 28.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-18 00:00:00', 22.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-19 00:00:00', 18.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-20 00:00:00', 19.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-21 00:00:00', 21.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-22 00:00:00', 22.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-23 00:00:00', 23.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-24 00:00:00', 21.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-25 00:00:00', 21.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-26 00:00:00', 22.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-27 00:00:00', 24.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-28 00:00:00', 25.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-29 00:00:00', 20.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-09-30 00:00:00', 22.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-01 00:00:00', 22.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-02 00:00:00', 23.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-03 00:00:00', 23.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-04 00:00:00', 24.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-05 00:00:00', 23.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-06 00:00:00', 22.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-07 00:00:00', 24.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-08 00:00:00', 22.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-09 00:00:00', 24.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-10 00:00:00', 23.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-11 00:00:00', 24.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-12 00:00:00', 22.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-13 00:00:00', 20.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-14 00:00:00', 18.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-15 00:00:00', 17.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-16 00:00:00', 21.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-17 00:00:00', 21.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-18 00:00:00', 20.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-19 00:00:00', 19.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-20 00:00:00', 17.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-21 00:00:00', 15.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-22 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-23 00:00:00', 18.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-24 00:00:00', 15.3380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-25 00:00:00', 14.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-26 00:00:00', 15.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-27 00:00:00', 15.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-28 00:00:00', 16.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-29 00:00:00', 16.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-30 00:00:00', 17.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-10-31 00:00:00', 21.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-01 00:00:00', 20.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-02 00:00:00', 18.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-03 00:00:00', 19.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-04 00:00:00', 21.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-05 00:00:00', 20.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-06 00:00:00', 20.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-07 00:00:00', 20.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-08 00:00:00', 19.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-09 00:00:00', 15.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-10 00:00:00', 10.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-11 00:00:00', 12.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-12 00:00:00', 10.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-13 00:00:00', 10.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-14 00:00:00', 10.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-15 00:00:00', 9.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-16 00:00:00', 9.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-17 00:00:00', 5.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-18 00:00:00', 9.21300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-19 00:00:00', 11.6129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-20 00:00:00', 7.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-21 00:00:00', 2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-22 00:00:00', -1.65600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-23 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-24 00:00:00', 1.08700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-25 00:00:00', 0.873000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-26 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-27 00:00:00', 1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-28 00:00:00', 3.4440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-29 00:00:00', 2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-11-30 00:00:00', 2.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-01 00:00:00', -0.0780000016093254089, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-02 00:00:00', 3.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-03 00:00:00', 4.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-04 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-05 00:00:00', -2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-06 00:00:00', 0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-07 00:00:00', 1.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-08 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-09 00:00:00', 5.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-10 00:00:00', 2.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-11 00:00:00', 2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-12 00:00:00', 1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-13 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-14 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-15 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-16 00:00:00', 1.01800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-17 00:00:00', 4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-18 00:00:00', 8.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-19 00:00:00', 7.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-20 00:00:00', 6.08900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-21 00:00:00', 7.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-22 00:00:00', 7.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-23 00:00:00', 6.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-24 00:00:00', 1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-25 00:00:00', 3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-26 00:00:00', 3.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-27 00:00:00', 5.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-28 00:00:00', 8.49400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-29 00:00:00', 5.75400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-30 00:00:00', 0.717000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2006-12-31 00:00:00', -0.726999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-01 00:00:00', -5.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-02 00:00:00', -4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-03 00:00:00', -1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-04 00:00:00', -0.908999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-05 00:00:00', 0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-06 00:00:00', 1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-07 00:00:00', 3.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-08 00:00:00', 5.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-09 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-10 00:00:00', 1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-11 00:00:00', -0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-12 00:00:00', -1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-13 00:00:00', -2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-14 00:00:00', -1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-15 00:00:00', -1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-16 00:00:00', -0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-17 00:00:00', 1.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-18 00:00:00', -0.0979999974370002747, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-19 00:00:00', -1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-20 00:00:00', 1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-21 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-22 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-23 00:00:00', 2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-24 00:00:00', 1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-25 00:00:00', 3.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-26 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-27 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-28 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-29 00:00:00', 5.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-30 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-01-31 00:00:00', 6.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-01 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-02 00:00:00', 4.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-03 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-04 00:00:00', 2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-05 00:00:00', 2.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-06 00:00:00', 4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-07 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-08 00:00:00', 7.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-09 00:00:00', 5.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-10 00:00:00', 5.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-11 00:00:00', 3.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-12 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-13 00:00:00', 3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-14 00:00:00', 4.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-15 00:00:00', 4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-16 00:00:00', 5.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-17 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-18 00:00:00', 4.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-19 00:00:00', 1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-20 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-21 00:00:00', 0.442000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-22 00:00:00', 0.587999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-23 00:00:00', 3.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-24 00:00:00', 4.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-25 00:00:00', 1.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-26 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-27 00:00:00', -3.22000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-02-28 00:00:00', -0.237000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-01 00:00:00', -1.19900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-02 00:00:00', 0.708999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-03 00:00:00', 1.5140000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-04 00:00:00', 2.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-05 00:00:00', 5.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-06 00:00:00', 6.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-07 00:00:00', 8.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-08 00:00:00', 10.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-09 00:00:00', 4.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-10 00:00:00', 6.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-11 00:00:00', 5.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-12 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-13 00:00:00', 5.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-14 00:00:00', 5.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-15 00:00:00', 7.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-16 00:00:00', 7.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-17 00:00:00', 8.98200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-18 00:00:00', 7.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-19 00:00:00', 6.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-20 00:00:00', 10.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-21 00:00:00', 9.96100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-22 00:00:00', 11.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-23 00:00:00', 11.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-24 00:00:00', 9.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-25 00:00:00', 10.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-26 00:00:00', 9.18500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-27 00:00:00', 13.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-28 00:00:00', 13.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-29 00:00:00', 9.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-30 00:00:00', 8.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-03-31 00:00:00', 7.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-01 00:00:00', 6.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-02 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-03 00:00:00', 11.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-04 00:00:00', 11.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-05 00:00:00', 12.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-06 00:00:00', 10.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-07 00:00:00', 13.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-08 00:00:00', 15.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-09 00:00:00', 17.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-10 00:00:00', 21.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-11 00:00:00', 21.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-12 00:00:00', 24.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-13 00:00:00', 25.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-14 00:00:00', 21.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-15 00:00:00', 24.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-16 00:00:00', 22.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-17 00:00:00', 20.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-18 00:00:00', 20.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-19 00:00:00', 21.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-20 00:00:00', 22.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-21 00:00:00', 23.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-22 00:00:00', 18.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-23 00:00:00', 19.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-24 00:00:00', 19.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-25 00:00:00', 22.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-26 00:00:00', 25.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-27 00:00:00', 21.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-28 00:00:00', 23.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-29 00:00:00', 23.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-04-30 00:00:00', 24.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-01 00:00:00', 24.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-02 00:00:00', 25.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-03 00:00:00', 23.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-04 00:00:00', 24.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-05 00:00:00', 25.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-06 00:00:00', 24.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-07 00:00:00', 15.8760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-08 00:00:00', 17.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-09 00:00:00', 21.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-10 00:00:00', 23.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-11 00:00:00', 25.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-12 00:00:00', 26.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-13 00:00:00', 25.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-14 00:00:00', 27.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-15 00:00:00', 28.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-16 00:00:00', 18.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-17 00:00:00', 14.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-18 00:00:00', 16.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-19 00:00:00', 14.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-20 00:00:00', 17.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-21 00:00:00', 21.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-22 00:00:00', 22.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-23 00:00:00', 22.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-24 00:00:00', 23.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-25 00:00:00', 22.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-26 00:00:00', 24.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-27 00:00:00', 27.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-28 00:00:00', 26.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-29 00:00:00', 27.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-30 00:00:00', 27.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-05-31 00:00:00', 26.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-01 00:00:00', 27.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-02 00:00:00', 27.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-03 00:00:00', 26.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-04 00:00:00', 27.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-05 00:00:00', 22.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-06 00:00:00', 24.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-07 00:00:00', 25.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-08 00:00:00', 27.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-09 00:00:00', 29.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-10 00:00:00', 31.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-11 00:00:00', 29.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-12 00:00:00', 30.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-13 00:00:00', 29.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-14 00:00:00', 32.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-15 00:00:00', 29.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-16 00:00:00', 25.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-17 00:00:00', 27.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-18 00:00:00', 27.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-19 00:00:00', 29.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-20 00:00:00', 30.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-21 00:00:00', 34.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-22 00:00:00', 34.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-23 00:00:00', 37.4980010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-24 00:00:00', 34.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-25 00:00:00', 33.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-26 00:00:00', 33.7869987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-27 00:00:00', 32.7249984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-28 00:00:00', 31.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-29 00:00:00', 30.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-06-30 00:00:00', 32.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-01 00:00:00', 32.1980018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-02 00:00:00', 29.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-03 00:00:00', 32.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-04 00:00:00', 33.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-05 00:00:00', 30.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-06 00:00:00', 30.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-07 00:00:00', 30.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-08 00:00:00', 29.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-09 00:00:00', 32.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-10 00:00:00', 34.1479988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-11 00:00:00', 33.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-12 00:00:00', 31.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-13 00:00:00', 31.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-14 00:00:00', 29.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-15 00:00:00', 29.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-16 00:00:00', 29.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-17 00:00:00', 30.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-18 00:00:00', 33.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-19 00:00:00', 35.1300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-20 00:00:00', 34.2470016479492188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-21 00:00:00', 25.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-22 00:00:00', 28.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-23 00:00:00', 28.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-24 00:00:00', 30.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-25 00:00:00', 31.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-26 00:00:00', 29.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-27 00:00:00', 28.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-28 00:00:00', 30.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-29 00:00:00', 31.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-30 00:00:00', 33.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-07-31 00:00:00', 31.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-01 00:00:00', 31.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-02 00:00:00', 29.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-03 00:00:00', 28.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-04 00:00:00', 29.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-05 00:00:00', 30.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-06 00:00:00', 29.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-07 00:00:00', 30.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-08 00:00:00', 30.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-09 00:00:00', 33.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-10 00:00:00', 34.1230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-11 00:00:00', 32.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-12 00:00:00', 28.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-13 00:00:00', 28.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-14 00:00:00', 29.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-15 00:00:00', 28.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-16 00:00:00', 28.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-17 00:00:00', 28.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-18 00:00:00', 29.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-19 00:00:00', 29.88800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-20 00:00:00', 30.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-21 00:00:00', 30.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-22 00:00:00', 29.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-23 00:00:00', 30.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-24 00:00:00', 30.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-25 00:00:00', 30.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-26 00:00:00', 29.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-27 00:00:00', 29.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-28 00:00:00', 29.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-29 00:00:00', 30.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-30 00:00:00', 30.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-08-31 00:00:00', 30.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-01 00:00:00', 30.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-02 00:00:00', 30.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-03 00:00:00', 31.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-04 00:00:00', 29.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-05 00:00:00', 26.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-06 00:00:00', 28.7490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-07 00:00:00', 27.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-08 00:00:00', 26.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-09 00:00:00', 28.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-10 00:00:00', 29.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-11 00:00:00', 30.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-12 00:00:00', 30.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-13 00:00:00', 29.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-14 00:00:00', 29.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-15 00:00:00', 29.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-16 00:00:00', 28.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-17 00:00:00', 28.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-18 00:00:00', 28.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-19 00:00:00', 27.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-20 00:00:00', 23.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-21 00:00:00', 22.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-22 00:00:00', 20.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-23 00:00:00', 20.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-24 00:00:00', 21.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-25 00:00:00', 21.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-26 00:00:00', 20.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-27 00:00:00', 17.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-28 00:00:00', 16.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-29 00:00:00', 18.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-09-30 00:00:00', 19.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-01 00:00:00', 16.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-02 00:00:00', 16.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-03 00:00:00', 15.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-04 00:00:00', 15.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-05 00:00:00', 14.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-06 00:00:00', 14.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-07 00:00:00', 15.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-08 00:00:00', 16.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-09 00:00:00', 16.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-10 00:00:00', 15.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-11 00:00:00', 15.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-12 00:00:00', 16.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-13 00:00:00', 18.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-14 00:00:00', 19.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-15 00:00:00', 20.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-16 00:00:00', 19.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-17 00:00:00', 19.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-18 00:00:00', 21.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-19 00:00:00', 15.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-20 00:00:00', 14.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-21 00:00:00', 16.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-22 00:00:00', 17.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-23 00:00:00', 15.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-24 00:00:00', 14.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-25 00:00:00', 13.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-26 00:00:00', 12.9329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-27 00:00:00', 14.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-28 00:00:00', 16.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-29 00:00:00', 12.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-30 00:00:00', 14.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-10-31 00:00:00', 17.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-01 00:00:00', 20.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-02 00:00:00', 18.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-03 00:00:00', 17.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-04 00:00:00', 19.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-05 00:00:00', 16.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-06 00:00:00', 19.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-07 00:00:00', 18.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-08 00:00:00', 16.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-09 00:00:00', 12.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-10 00:00:00', 14.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-11 00:00:00', 14.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-12 00:00:00', 15.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-13 00:00:00', 12.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-14 00:00:00', 9.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-15 00:00:00', 11.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-16 00:00:00', 11.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-17 00:00:00', 12.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-18 00:00:00', 12.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-19 00:00:00', 12.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-20 00:00:00', 10.4399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-21 00:00:00', 10.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-22 00:00:00', 13.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-23 00:00:00', 12.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-24 00:00:00', 9.03400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-25 00:00:00', 11.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-26 00:00:00', 12.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-27 00:00:00', 10.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-28 00:00:00', 8.31499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-29 00:00:00', 9.01099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-11-30 00:00:00', 6.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-01 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-02 00:00:00', 4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-03 00:00:00', 3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-04 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-05 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-06 00:00:00', 2.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-07 00:00:00', 1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-08 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-09 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-10 00:00:00', -0.437000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-11 00:00:00', -0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-12 00:00:00', -0.0630000010132789612, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-13 00:00:00', -0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-14 00:00:00', -0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-15 00:00:00', 1.3200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-16 00:00:00', 0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-17 00:00:00', 1.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-18 00:00:00', 1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-19 00:00:00', 0.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-20 00:00:00', 0.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-21 00:00:00', -0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-22 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-23 00:00:00', -0.518999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-24 00:00:00', -1.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-25 00:00:00', -1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-26 00:00:00', -2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-27 00:00:00', -3.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-28 00:00:00', -2.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-29 00:00:00', -4.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-30 00:00:00', -1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2007-12-31 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-01 00:00:00', 0.252999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-02 00:00:00', -2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-03 00:00:00', -0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-04 00:00:00', -0.404000014066696167, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-05 00:00:00', -0.00300000002607703209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-06 00:00:00', 0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-07 00:00:00', 0.859000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-08 00:00:00', -3.83299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-09 00:00:00', -1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-10 00:00:00', -5.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-11 00:00:00', -3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-12 00:00:00', -2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-13 00:00:00', -7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-14 00:00:00', -4.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-15 00:00:00', -0.456000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-16 00:00:00', -4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-17 00:00:00', -6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-18 00:00:00', -7.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-19 00:00:00', -9.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-20 00:00:00', -10.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-21 00:00:00', -8.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-22 00:00:00', -9.26299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-23 00:00:00', -8.66100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-24 00:00:00', -7.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-25 00:00:00', -6.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-26 00:00:00', -4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-27 00:00:00', -0.208000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-28 00:00:00', -3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-29 00:00:00', -2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-30 00:00:00', 0.13099999725818634, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-01-31 00:00:00', 1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-01 00:00:00', 1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-02 00:00:00', -0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-03 00:00:00', -4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-04 00:00:00', -4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-05 00:00:00', -6.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-06 00:00:00', -6.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-07 00:00:00', -4.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-08 00:00:00', -3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-09 00:00:00', -4.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-10 00:00:00', -6.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-11 00:00:00', -5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-12 00:00:00', -2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-13 00:00:00', -0.10899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-14 00:00:00', -0.32699999213218689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-15 00:00:00', 0.243000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-16 00:00:00', 1.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-17 00:00:00', 0.995999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-18 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-19 00:00:00', 2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-20 00:00:00', 5.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-21 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-22 00:00:00', -0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-23 00:00:00', 0.628000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-24 00:00:00', 2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-25 00:00:00', 4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-26 00:00:00', 6.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-27 00:00:00', 9.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-28 00:00:00', 9.22500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-02-29 00:00:00', 11.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-01 00:00:00', 7.68699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-02 00:00:00', 9.71100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-03 00:00:00', 9.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-04 00:00:00', 10.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-05 00:00:00', 11.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-06 00:00:00', 7.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-07 00:00:00', 8.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-08 00:00:00', 12.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-09 00:00:00', 9.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-10 00:00:00', 12.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-11 00:00:00', 12.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-12 00:00:00', 12.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-13 00:00:00', 13.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-14 00:00:00', 15.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-15 00:00:00', 16.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-16 00:00:00', 16.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-17 00:00:00', 12.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-18 00:00:00', 11.6029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-19 00:00:00', 14.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-20 00:00:00', 16.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-21 00:00:00', 16.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-22 00:00:00', 17.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-23 00:00:00', 19.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-24 00:00:00', 19.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-25 00:00:00', 19.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-26 00:00:00', 18.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-27 00:00:00', 18.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-28 00:00:00', 20.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-29 00:00:00', 19.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-30 00:00:00', 18.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-03-31 00:00:00', 17.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-01 00:00:00', 18.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-02 00:00:00', 19.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-03 00:00:00', 21.3029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-04 00:00:00', 15.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-05 00:00:00', 14.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-06 00:00:00', 14.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-07 00:00:00', 9.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-08 00:00:00', 13.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-09 00:00:00', 17.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-10 00:00:00', 16.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-11 00:00:00', 15.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-12 00:00:00', 16.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-13 00:00:00', 14.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-14 00:00:00', 13.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-15 00:00:00', 10.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-16 00:00:00', 14.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-17 00:00:00', 16.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-18 00:00:00', 16.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-19 00:00:00', 14.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-20 00:00:00', 21.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-21 00:00:00', 22.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-22 00:00:00', 17.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-23 00:00:00', 17.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-24 00:00:00', 19.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-25 00:00:00', 22.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-26 00:00:00', 24.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-27 00:00:00', 25.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-28 00:00:00', 25.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-29 00:00:00', 26.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-04-30 00:00:00', 26.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-01 00:00:00', 26.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-02 00:00:00', 26.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-03 00:00:00', 26.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-04 00:00:00', 18.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-05 00:00:00', 18.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-06 00:00:00', 22.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-07 00:00:00', 26.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-08 00:00:00', 27.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-09 00:00:00', 22.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-10 00:00:00', 25.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-11 00:00:00', 29.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-12 00:00:00', 28.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-13 00:00:00', 25.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-14 00:00:00', 28.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-15 00:00:00', 26.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-16 00:00:00', 24.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-17 00:00:00', 27.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-18 00:00:00', 28.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-19 00:00:00', 28.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-20 00:00:00', 29.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-21 00:00:00', 30.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-22 00:00:00', 26.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-23 00:00:00', 23.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-24 00:00:00', 23.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-25 00:00:00', 22.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-26 00:00:00', 21.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-27 00:00:00', 22.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-28 00:00:00', 25.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-29 00:00:00', 29.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-30 00:00:00', 30.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-05-31 00:00:00', 28.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-01 00:00:00', 29.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-02 00:00:00', 30.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-03 00:00:00', 29.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-04 00:00:00', 31.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-05 00:00:00', 32.4900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-06 00:00:00', 32.0649986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-07 00:00:00', 30.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-08 00:00:00', 30.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-09 00:00:00', 33.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-10 00:00:00', 33.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-11 00:00:00', 32.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-12 00:00:00', 35.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-13 00:00:00', 36.6230010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-14 00:00:00', 35.9210014343261719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-15 00:00:00', 32.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-16 00:00:00', 30.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-17 00:00:00', 29.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-18 00:00:00', 30.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-19 00:00:00', 30.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-20 00:00:00', 32.0660018920898438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-21 00:00:00', 32.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-22 00:00:00', 32.2179985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-23 00:00:00', 31.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-24 00:00:00', 31.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-25 00:00:00', 32.8870010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-26 00:00:00', 32.5040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-27 00:00:00', 31.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-28 00:00:00', 30.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-29 00:00:00', 28.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-06-30 00:00:00', 28.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-01 00:00:00', 29.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-02 00:00:00', 31.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-03 00:00:00', 32.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-04 00:00:00', 32.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-05 00:00:00', 34.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-06 00:00:00', 34.1139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-07 00:00:00', 33.1349983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-08 00:00:00', 30.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-09 00:00:00', 31.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-10 00:00:00', 32.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-11 00:00:00', 33.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-12 00:00:00', 33.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-13 00:00:00', 33.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-14 00:00:00', 34.0439987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-15 00:00:00', 32.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-16 00:00:00', 30.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-17 00:00:00', 32.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-18 00:00:00', 31.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-19 00:00:00', 31.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-20 00:00:00', 28.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-21 00:00:00', 28.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-22 00:00:00', 28.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-23 00:00:00', 28.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-24 00:00:00', 28.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-25 00:00:00', 28.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-26 00:00:00', 28.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-27 00:00:00', 30.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-28 00:00:00', 31.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-29 00:00:00', 34.8440017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-30 00:00:00', 36.233001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-07-31 00:00:00', 37.3730010986328125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-01 00:00:00', 37.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-02 00:00:00', 37.6139984130859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-03 00:00:00', 38.141998291015625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-04 00:00:00', 33.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-05 00:00:00', 32.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-06 00:00:00', 34.4119987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-07 00:00:00', 35.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-08 00:00:00', 35.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-09 00:00:00', 35.8569984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-10 00:00:00', 32.720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-11 00:00:00', 30.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-12 00:00:00', 30.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-13 00:00:00', 31.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-14 00:00:00', 31.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-15 00:00:00', 29.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-16 00:00:00', 26.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-17 00:00:00', 25.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-18 00:00:00', 29.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-19 00:00:00', 31.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-20 00:00:00', 30.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-21 00:00:00', 29.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-22 00:00:00', 30.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-23 00:00:00', 31.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-24 00:00:00', 31.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-25 00:00:00', 30.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-26 00:00:00', 30.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-27 00:00:00', 29.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-28 00:00:00', 29.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-29 00:00:00', 29.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-30 00:00:00', 27.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-08-31 00:00:00', 28.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-01 00:00:00', 29.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-02 00:00:00', 30.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-03 00:00:00', 29.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-04 00:00:00', 26.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-05 00:00:00', 22.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-06 00:00:00', 24.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-07 00:00:00', 24.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-08 00:00:00', 25.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-09 00:00:00', 26.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-10 00:00:00', 24.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-11 00:00:00', 26.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-12 00:00:00', 29.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-13 00:00:00', 28.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-14 00:00:00', 28.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-15 00:00:00', 28.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-16 00:00:00', 26.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-17 00:00:00', 26.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-18 00:00:00', 24.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-19 00:00:00', 23.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-20 00:00:00', 20.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-21 00:00:00', 21.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-22 00:00:00', 21.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-23 00:00:00', 20.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-24 00:00:00', 21.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-25 00:00:00', 23.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-26 00:00:00', 24.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-27 00:00:00', 23.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-28 00:00:00', 23.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-29 00:00:00', 25.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-09-30 00:00:00', 18.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-01 00:00:00', 21.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-02 00:00:00', 26.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-03 00:00:00', 26.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-04 00:00:00', 21.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-05 00:00:00', 21.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-06 00:00:00', 21.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-07 00:00:00', 20.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-08 00:00:00', 19.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-09 00:00:00', 19.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-10 00:00:00', 20.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-11 00:00:00', 17.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-12 00:00:00', 19.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-13 00:00:00', 16.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-14 00:00:00', 16.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-15 00:00:00', 16.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-16 00:00:00', 17.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-17 00:00:00', 20.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-18 00:00:00', 20.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-19 00:00:00', 16.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-20 00:00:00', 17.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-21 00:00:00', 17.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-22 00:00:00', 16.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-23 00:00:00', 17.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-24 00:00:00', 10.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-25 00:00:00', 12.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-26 00:00:00', 16.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-27 00:00:00', 15.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-28 00:00:00', 6.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-29 00:00:00', 7.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-30 00:00:00', 7.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-10-31 00:00:00', 9.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-01 00:00:00', 7.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-02 00:00:00', 9.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-03 00:00:00', 11.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-04 00:00:00', 16.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-05 00:00:00', 14.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-06 00:00:00', 12.5500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-07 00:00:00', 15.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-08 00:00:00', 10.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-09 00:00:00', 9.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-10 00:00:00', 7.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-11 00:00:00', 6.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-12 00:00:00', 4.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-13 00:00:00', 1.89300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-14 00:00:00', 3.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-15 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-16 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-17 00:00:00', 4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-18 00:00:00', 8.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-19 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-20 00:00:00', 5.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-21 00:00:00', 8.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-22 00:00:00', 8.12800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-23 00:00:00', 10.4980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-24 00:00:00', 10.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-25 00:00:00', 11.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-26 00:00:00', 12.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-27 00:00:00', 12.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-28 00:00:00', 13.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-29 00:00:00', 14.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-11-30 00:00:00', 13.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-01 00:00:00', 12.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-02 00:00:00', 12.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-03 00:00:00', 11.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-04 00:00:00', 10.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-05 00:00:00', 9.68299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-06 00:00:00', 9.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-07 00:00:00', 12.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-08 00:00:00', 5.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-09 00:00:00', 6.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-10 00:00:00', 7.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-11 00:00:00', 6.68800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-12 00:00:00', 9.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-13 00:00:00', 9.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-14 00:00:00', 4.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-15 00:00:00', 9.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-16 00:00:00', 4.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-17 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-18 00:00:00', 0.143000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-19 00:00:00', -0.363000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-20 00:00:00', -3.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-21 00:00:00', -1.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-22 00:00:00', -0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-23 00:00:00', 0.801999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-24 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-25 00:00:00', 6.96400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-26 00:00:00', 9.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-27 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-28 00:00:00', 3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-29 00:00:00', 1.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-30 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2008-12-31 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-01 00:00:00', 6.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-02 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-03 00:00:00', 2.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-04 00:00:00', 0.595000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-05 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-06 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-07 00:00:00', 4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-08 00:00:00', 7.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-09 00:00:00', 7.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-10 00:00:00', 4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-11 00:00:00', 4.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-12 00:00:00', 5.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-13 00:00:00', 2.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-14 00:00:00', 3.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-15 00:00:00', 5.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-16 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-17 00:00:00', 4.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-18 00:00:00', 6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-19 00:00:00', 5.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-20 00:00:00', 9.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-21 00:00:00', 7.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-22 00:00:00', 9.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-23 00:00:00', 8.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-24 00:00:00', 9.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-25 00:00:00', 6.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-26 00:00:00', 7.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-27 00:00:00', 5.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-28 00:00:00', 5.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-29 00:00:00', 6.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-30 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-01-31 00:00:00', 8.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-01 00:00:00', 6.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-02 00:00:00', 7.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-03 00:00:00', 2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-04 00:00:00', 3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-05 00:00:00', -0.828000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-06 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-07 00:00:00', 7.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-08 00:00:00', 10.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-09 00:00:00', 8.49899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-10 00:00:00', 4.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-11 00:00:00', 4.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-12 00:00:00', 7.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-13 00:00:00', 6.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-14 00:00:00', 4.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-15 00:00:00', 5.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-16 00:00:00', 7.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-17 00:00:00', 7.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-18 00:00:00', 7.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-19 00:00:00', 8.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-20 00:00:00', 2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-21 00:00:00', 6.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-22 00:00:00', 7.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-23 00:00:00', 4.08799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-24 00:00:00', 3.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-25 00:00:00', 3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-26 00:00:00', 5.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-27 00:00:00', 7.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-02-28 00:00:00', 9.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-01 00:00:00', 8.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-02 00:00:00', 10.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-03 00:00:00', 9.51500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-04 00:00:00', 8.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-05 00:00:00', 7.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-06 00:00:00', 6.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-07 00:00:00', 4.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-08 00:00:00', 7.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-09 00:00:00', 10.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-10 00:00:00', 12.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-11 00:00:00', 17.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-12 00:00:00', 15.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-13 00:00:00', 16.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-14 00:00:00', 17.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-15 00:00:00', 18.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-16 00:00:00', 16.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-17 00:00:00', 16.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-18 00:00:00', 9.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-19 00:00:00', 9.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-20 00:00:00', 12.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-21 00:00:00', 13.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-22 00:00:00', 13.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-23 00:00:00', 13.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-24 00:00:00', 13.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-25 00:00:00', 15.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-26 00:00:00', 16.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-27 00:00:00', 12.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-28 00:00:00', 14.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-29 00:00:00', 13.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-30 00:00:00', 16.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-03-31 00:00:00', 17.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-01 00:00:00', 18.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-02 00:00:00', 12.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-03 00:00:00', 11.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-04 00:00:00', 16.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-05 00:00:00', 12.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-06 00:00:00', 8.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-07 00:00:00', 9.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-08 00:00:00', 12.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-09 00:00:00', 14.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-10 00:00:00', 14.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-11 00:00:00', 11.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-12 00:00:00', 16.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-13 00:00:00', 16.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-14 00:00:00', 15.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-15 00:00:00', 5.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-16 00:00:00', 11.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-17 00:00:00', 15.5889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-18 00:00:00', 18.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-19 00:00:00', 19.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-20 00:00:00', 16.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-21 00:00:00', 11.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-22 00:00:00', 13.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-23 00:00:00', 15.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-24 00:00:00', 18.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-25 00:00:00', 17.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-26 00:00:00', 13.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-27 00:00:00', 11.0810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-28 00:00:00', 13.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-29 00:00:00', 17.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-04-30 00:00:00', 20.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-01 00:00:00', 21.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-02 00:00:00', 20.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-03 00:00:00', 20.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-04 00:00:00', 15.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-05 00:00:00', 15.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-06 00:00:00', 16.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-07 00:00:00', 20.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-08 00:00:00', 18.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-09 00:00:00', 17.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-10 00:00:00', 16.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-11 00:00:00', 18.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-12 00:00:00', 21.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-13 00:00:00', 21.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-14 00:00:00', 22.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-15 00:00:00', 19.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-16 00:00:00', 21.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-17 00:00:00', 26.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-18 00:00:00', 26.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-19 00:00:00', 22.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-20 00:00:00', 20.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-21 00:00:00', 22.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-22 00:00:00', 22.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-23 00:00:00', 24.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-24 00:00:00', 22.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-25 00:00:00', 24.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-26 00:00:00', 26.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-27 00:00:00', 26.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-28 00:00:00', 27.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-29 00:00:00', 28.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-30 00:00:00', 29.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-05-31 00:00:00', 26.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-01 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-02 00:00:00', 19.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-03 00:00:00', 22.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-04 00:00:00', 21.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-05 00:00:00', 20.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-06 00:00:00', 21.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-07 00:00:00', 21.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-08 00:00:00', 22.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-09 00:00:00', 24.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-10 00:00:00', 26.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-11 00:00:00', 27.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-12 00:00:00', 26.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-13 00:00:00', 26.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-14 00:00:00', 27.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-15 00:00:00', 26.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-16 00:00:00', 26.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-17 00:00:00', 27.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-18 00:00:00', 25.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-19 00:00:00', 28.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-20 00:00:00', 27.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-21 00:00:00', 29.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-22 00:00:00', 28.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-23 00:00:00', 27.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-24 00:00:00', 27.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-25 00:00:00', 29.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-26 00:00:00', 29.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-27 00:00:00', 29.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-28 00:00:00', 31.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-29 00:00:00', 29.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-06-30 00:00:00', 27.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-01 00:00:00', 27.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-02 00:00:00', 27.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-03 00:00:00', 23.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-04 00:00:00', 24.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-05 00:00:00', 27.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-06 00:00:00', 29.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-07 00:00:00', 31.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-08 00:00:00', 31.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-09 00:00:00', 30.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-10 00:00:00', 31.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-11 00:00:00', 30.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-12 00:00:00', 30.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-13 00:00:00', 28.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-14 00:00:00', 27.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-15 00:00:00', 31.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-16 00:00:00', 31.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-17 00:00:00', 31.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-18 00:00:00', 32.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-19 00:00:00', 31.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-20 00:00:00', 31.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-21 00:00:00', 32.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-22 00:00:00', 31.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-23 00:00:00', 31.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-24 00:00:00', 33.5369987487792969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-25 00:00:00', 35.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-26 00:00:00', 36.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-27 00:00:00', 36.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-28 00:00:00', 34.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-29 00:00:00', 32.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-30 00:00:00', 29.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-07-31 00:00:00', 32.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-01 00:00:00', 31.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-02 00:00:00', 32.029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-03 00:00:00', 32.6409988403320312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-04 00:00:00', 30.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-05 00:00:00', 29.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-06 00:00:00', 28.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-07 00:00:00', 30.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-08 00:00:00', 31.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-09 00:00:00', 31.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-10 00:00:00', 33.8699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-11 00:00:00', 33.6899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-12 00:00:00', 34.8889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-13 00:00:00', 37.1059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-14 00:00:00', 35.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-15 00:00:00', 34.2620010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-16 00:00:00', 30.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-17 00:00:00', 30.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-18 00:00:00', 29.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-19 00:00:00', 27.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-20 00:00:00', 27.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-21 00:00:00', 26.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-22 00:00:00', 27.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-23 00:00:00', 28.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-24 00:00:00', 30.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-25 00:00:00', 25.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-26 00:00:00', 26.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-27 00:00:00', 28.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-28 00:00:00', 31.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-29 00:00:00', 30.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-30 00:00:00', 27.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-08-31 00:00:00', 27.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-01 00:00:00', 26.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-02 00:00:00', 22.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-03 00:00:00', 21.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-04 00:00:00', 23.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-05 00:00:00', 22.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-06 00:00:00', 21.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-07 00:00:00', 22.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-08 00:00:00', 21.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-09 00:00:00', 19.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-10 00:00:00', 23.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-11 00:00:00', 25.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-12 00:00:00', 24.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-13 00:00:00', 27.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-14 00:00:00', 27.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-15 00:00:00', 27.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-16 00:00:00', 23.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-17 00:00:00', 24.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-18 00:00:00', 27.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-19 00:00:00', 27.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-20 00:00:00', 28.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-21 00:00:00', 27.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-22 00:00:00', 26.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-23 00:00:00', 23.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-24 00:00:00', 26.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-25 00:00:00', 29.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-26 00:00:00', 21.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-27 00:00:00', 22.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-28 00:00:00', 24.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-29 00:00:00', 24.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-09-30 00:00:00', 26.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-01 00:00:00', 28.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-02 00:00:00', 24.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-03 00:00:00', 21.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-04 00:00:00', 21.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-05 00:00:00', 21.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-06 00:00:00', 20.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-07 00:00:00', 20.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-08 00:00:00', 17.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-09 00:00:00', 14.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-10 00:00:00', 16.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-11 00:00:00', 17.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-12 00:00:00', 20.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-13 00:00:00', 19.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-14 00:00:00', 20.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-15 00:00:00', 20.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-16 00:00:00', 19.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-17 00:00:00', 18.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-18 00:00:00', 17.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-19 00:00:00', 17.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-20 00:00:00', 18.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-21 00:00:00', 16.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-22 00:00:00', 16.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-23 00:00:00', 15.5159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-24 00:00:00', 14.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-25 00:00:00', 16.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-26 00:00:00', 14.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-27 00:00:00', 14.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-28 00:00:00', 9.48900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-29 00:00:00', 14.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-30 00:00:00', 13.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-10-31 00:00:00', 17.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-01 00:00:00', 18.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-02 00:00:00', 12.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-03 00:00:00', 18.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-04 00:00:00', 17.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-05 00:00:00', 16.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-06 00:00:00', 16.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-07 00:00:00', 11.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-08 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-09 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-10 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-11 00:00:00', 12.9870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-12 00:00:00', 13.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-13 00:00:00', 13.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-14 00:00:00', 9.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-15 00:00:00', 6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-16 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-17 00:00:00', 6.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-18 00:00:00', 9.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-19 00:00:00', 11.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-20 00:00:00', 14.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-21 00:00:00', 10.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-22 00:00:00', 12.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-23 00:00:00', 3.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-24 00:00:00', 9.98200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-25 00:00:00', 5.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-26 00:00:00', 6.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-27 00:00:00', 6.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-28 00:00:00', 4.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-29 00:00:00', 7.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-11-30 00:00:00', 9.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-01 00:00:00', 6.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-02 00:00:00', 7.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-03 00:00:00', 7.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-04 00:00:00', 1.31799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-05 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-06 00:00:00', 5.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-07 00:00:00', 4.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-08 00:00:00', 6.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-09 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-10 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-11 00:00:00', 3.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-12 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-13 00:00:00', 4.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-14 00:00:00', 6.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-15 00:00:00', 6.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-16 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-17 00:00:00', 6.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-18 00:00:00', 8.29399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-19 00:00:00', 11.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-20 00:00:00', 5.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-21 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-22 00:00:00', 5.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-23 00:00:00', 6.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-24 00:00:00', 7.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-25 00:00:00', 7.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-26 00:00:00', 6.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-27 00:00:00', 5.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-28 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-29 00:00:00', 5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-30 00:00:00', 8.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2009-12-31 00:00:00', 8.54800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-01 00:00:00', 12.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-02 00:00:00', 11.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-03 00:00:00', 6.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-04 00:00:00', 7.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-05 00:00:00', 8.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-06 00:00:00', 7.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-07 00:00:00', 1.64600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-08 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-09 00:00:00', 0.00100000004749745131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-10 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-11 00:00:00', 3.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-12 00:00:00', 7.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-13 00:00:00', 5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-14 00:00:00', 6.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-15 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-16 00:00:00', 8.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-17 00:00:00', 5.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-18 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-19 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-20 00:00:00', 8.17599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-21 00:00:00', 8.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-22 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-23 00:00:00', 6.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-24 00:00:00', 6.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-25 00:00:00', 8.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-26 00:00:00', 9.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-27 00:00:00', 6.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-28 00:00:00', 1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-29 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-30 00:00:00', 6.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-01-31 00:00:00', 2.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-01 00:00:00', 5.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-02 00:00:00', 5.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-03 00:00:00', 5.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-04 00:00:00', 6.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-05 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-06 00:00:00', 4.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-07 00:00:00', 3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-08 00:00:00', -1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-09 00:00:00', -6.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-10 00:00:00', 0.703999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-11 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-12 00:00:00', -2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-13 00:00:00', -3.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-14 00:00:00', -4.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-15 00:00:00', -2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-16 00:00:00', 2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-17 00:00:00', 5.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-18 00:00:00', 3.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-19 00:00:00', 3.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-20 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-21 00:00:00', 12.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-22 00:00:00', 9.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-23 00:00:00', 10.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-24 00:00:00', 6.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-25 00:00:00', 9.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-26 00:00:00', 5.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-27 00:00:00', 8.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-02-28 00:00:00', 5.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-01 00:00:00', 6.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-02 00:00:00', 9.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-03 00:00:00', 14.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-04 00:00:00', 6.90399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-05 00:00:00', 9.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-06 00:00:00', 9.31799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-07 00:00:00', 10.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-08 00:00:00', 12.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-09 00:00:00', 11.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-10 00:00:00', 15.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-11 00:00:00', 15.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-12 00:00:00', 7.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-13 00:00:00', 11.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-14 00:00:00', 15.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-15 00:00:00', 18.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-16 00:00:00', 20.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-17 00:00:00', 21.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-18 00:00:00', 19.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-19 00:00:00', 23.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-20 00:00:00', 13.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-21 00:00:00', 10.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-22 00:00:00', 9.15200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-23 00:00:00', 11.4149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-24 00:00:00', 12.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-25 00:00:00', 15.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-26 00:00:00', 12.9289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-27 00:00:00', 12.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-28 00:00:00', 15.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-29 00:00:00', 16.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-30 00:00:00', 12.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-03-31 00:00:00', 13.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-01 00:00:00', 15.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-02 00:00:00', 15.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-03 00:00:00', 10.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-04 00:00:00', 14.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-05 00:00:00', 14.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-06 00:00:00', 17.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-07 00:00:00', 13.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-08 00:00:00', 19.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-09 00:00:00', 21.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-10 00:00:00', 18.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-11 00:00:00', 18.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-12 00:00:00', 11.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-13 00:00:00', 18.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-14 00:00:00', 23.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-15 00:00:00', 15.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-16 00:00:00', 19.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-17 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-18 00:00:00', 20.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-19 00:00:00', 22.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-20 00:00:00', 22.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-21 00:00:00', 14.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-22 00:00:00', 16.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-23 00:00:00', 18.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-24 00:00:00', 21.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-25 00:00:00', 21.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-26 00:00:00', 21.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-27 00:00:00', 20.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-28 00:00:00', 22.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-29 00:00:00', 20.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-04-30 00:00:00', 23.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-01 00:00:00', 20.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-02 00:00:00', 21.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-03 00:00:00', 24.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-04 00:00:00', 20.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-05 00:00:00', 21.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-06 00:00:00', 20.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-07 00:00:00', 17.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-08 00:00:00', 21.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-09 00:00:00', 22.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-10 00:00:00', 20.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-11 00:00:00', 18.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-12 00:00:00', 20.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-13 00:00:00', 21.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-14 00:00:00', 23.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-15 00:00:00', 23.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-16 00:00:00', 18.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-17 00:00:00', 19.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-18 00:00:00', 20.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-19 00:00:00', 22.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-20 00:00:00', 24.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-21 00:00:00', 20.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-22 00:00:00', 21.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-23 00:00:00', 21.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-24 00:00:00', 22.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-25 00:00:00', 27.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-26 00:00:00', 22.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-27 00:00:00', 21.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-28 00:00:00', 23.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-29 00:00:00', 24.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-30 00:00:00', 26.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-05-31 00:00:00', 28.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-01 00:00:00', 27.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-02 00:00:00', 19.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-03 00:00:00', 19.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-04 00:00:00', 19.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-05 00:00:00', 22.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-06 00:00:00', 21.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-07 00:00:00', 24.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-08 00:00:00', 21.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-09 00:00:00', 26.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-10 00:00:00', 28.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-11 00:00:00', 29.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-12 00:00:00', 27.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-13 00:00:00', 29.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-14 00:00:00', 26.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-15 00:00:00', 26.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-16 00:00:00', 28.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-17 00:00:00', 26.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-18 00:00:00', 28.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-19 00:00:00', 29.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-20 00:00:00', 31.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-21 00:00:00', 32.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-22 00:00:00', 31.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-23 00:00:00', 31.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-24 00:00:00', 26.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-25 00:00:00', 24.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-26 00:00:00', 28.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-27 00:00:00', 30.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-28 00:00:00', 28.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-29 00:00:00', 29.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-06-30 00:00:00', 28.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-01 00:00:00', 29.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-02 00:00:00', 29.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-03 00:00:00', 31.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-04 00:00:00', 30.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-05 00:00:00', 29.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-06 00:00:00', 29.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-07 00:00:00', 31.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-08 00:00:00', 33.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-09 00:00:00', 33.2319984436035156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-10 00:00:00', 32.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-11 00:00:00', 30.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-12 00:00:00', 28.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-13 00:00:00', 28.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-14 00:00:00', 30.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-15 00:00:00', 33.4010009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-16 00:00:00', 36.58599853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-17 00:00:00', 36.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-18 00:00:00', 34.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-19 00:00:00', 32.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-20 00:00:00', 30.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-21 00:00:00', 27.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-22 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-23 00:00:00', 28.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-24 00:00:00', 29.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-25 00:00:00', 30.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-26 00:00:00', 30.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-27 00:00:00', 29.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-28 00:00:00', 31.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-29 00:00:00', 28.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-30 00:00:00', 29.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-07-31 00:00:00', 28.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-01 00:00:00', 30.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-02 00:00:00', 31.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-03 00:00:00', 27.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-04 00:00:00', 26.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-05 00:00:00', 30.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-06 00:00:00', 31.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-07 00:00:00', 30.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-08 00:00:00', 31.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-09 00:00:00', 33.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-10 00:00:00', 30.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-11 00:00:00', 31.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-12 00:00:00', 31.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-13 00:00:00', 30.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-14 00:00:00', 29.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-15 00:00:00', 30.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-16 00:00:00', 31.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-17 00:00:00', 31.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-18 00:00:00', 31.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-19 00:00:00', 31.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-20 00:00:00', 32.6699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-21 00:00:00', 34.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-22 00:00:00', 34.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-23 00:00:00', 29.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-24 00:00:00', 23.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-25 00:00:00', 25.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-26 00:00:00', 27.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-27 00:00:00', 28.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-28 00:00:00', 29.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-29 00:00:00', 29.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-30 00:00:00', 30.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-08-31 00:00:00', 31.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-01 00:00:00', 30.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-02 00:00:00', 30.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-03 00:00:00', 30.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-04 00:00:00', 30.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-05 00:00:00', 29.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-06 00:00:00', 27.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-07 00:00:00', 28.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-08 00:00:00', 28.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-09 00:00:00', 28.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-10 00:00:00', 27.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-11 00:00:00', 27.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-12 00:00:00', 21.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-13 00:00:00', 19.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-14 00:00:00', 24.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-15 00:00:00', 24.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-16 00:00:00', 13.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-17 00:00:00', 13.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-18 00:00:00', 16.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-19 00:00:00', 18.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-20 00:00:00', 21.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-21 00:00:00', 23.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-22 00:00:00', 20.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-23 00:00:00', 21.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-24 00:00:00', 22.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-25 00:00:00', 21.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-26 00:00:00', 20.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-27 00:00:00', 19.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-28 00:00:00', 18.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-29 00:00:00', 20.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-09-30 00:00:00', 20.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-01 00:00:00', 22.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-02 00:00:00', 24.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-03 00:00:00', 25.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-04 00:00:00', 26.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-05 00:00:00', 26.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-06 00:00:00', 25.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-07 00:00:00', 24.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-08 00:00:00', 20.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-09 00:00:00', 17.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-10 00:00:00', 17.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-11 00:00:00', 19.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-12 00:00:00', 21.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-13 00:00:00', 16.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-14 00:00:00', 19.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-15 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-16 00:00:00', 24.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-17 00:00:00', 23.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-18 00:00:00', 23.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-19 00:00:00', 23.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-20 00:00:00', 20.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-21 00:00:00', 17.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-22 00:00:00', 12.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-23 00:00:00', 13.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-24 00:00:00', 15.1850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-25 00:00:00', 15.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-26 00:00:00', 13.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-27 00:00:00', 15.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-28 00:00:00', 13.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-29 00:00:00', 14.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-30 00:00:00', 12.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-10-31 00:00:00', 16.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-01 00:00:00', 18.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-02 00:00:00', 16.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-03 00:00:00', 9.66100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-04 00:00:00', 12.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-05 00:00:00', 8.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-06 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-07 00:00:00', 15.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-08 00:00:00', 19.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-09 00:00:00', 18.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-10 00:00:00', 19.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-11 00:00:00', 16.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-12 00:00:00', 14.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-13 00:00:00', 13.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-14 00:00:00', 13.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-15 00:00:00', 13.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-16 00:00:00', 12.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-17 00:00:00', 13.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-18 00:00:00', 12.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-19 00:00:00', 11.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-20 00:00:00', 9.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-21 00:00:00', 9.19200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-22 00:00:00', 10.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-23 00:00:00', 12.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-24 00:00:00', 12.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-25 00:00:00', 10.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-26 00:00:00', 9.13099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-27 00:00:00', 12.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-28 00:00:00', 13.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-29 00:00:00', 12.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-11-30 00:00:00', 11.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-01 00:00:00', 10.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-02 00:00:00', 10.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-03 00:00:00', 10.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-04 00:00:00', 4.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-05 00:00:00', 5.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-06 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-07 00:00:00', 7.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-08 00:00:00', 7.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-09 00:00:00', 9.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-10 00:00:00', 9.30300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-11 00:00:00', 10.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-12 00:00:00', 12.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-13 00:00:00', 12.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-14 00:00:00', 14.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-15 00:00:00', 7.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-16 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-17 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-18 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-19 00:00:00', 8.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-20 00:00:00', 9.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-21 00:00:00', 7.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-22 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-23 00:00:00', 2.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-24 00:00:00', 7.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-25 00:00:00', 6.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-26 00:00:00', 5.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-27 00:00:00', 4.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-28 00:00:00', 5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-29 00:00:00', 5.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-30 00:00:00', 5.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2010-12-31 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-01 00:00:00', 9.36900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-02 00:00:00', 9.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-03 00:00:00', 7.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-04 00:00:00', 3.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-05 00:00:00', 4.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-06 00:00:00', 4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-07 00:00:00', 4.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-08 00:00:00', 2.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-09 00:00:00', 3.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-10 00:00:00', 6.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-11 00:00:00', 1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-12 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-13 00:00:00', -0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-14 00:00:00', -3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-15 00:00:00', -2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-16 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-17 00:00:00', 0.0610000006854534149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-18 00:00:00', -1.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-19 00:00:00', 0.883000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-20 00:00:00', 4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-21 00:00:00', 1.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-22 00:00:00', 1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-23 00:00:00', 1.44900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-24 00:00:00', 4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-25 00:00:00', 4.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-26 00:00:00', 5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-27 00:00:00', 7.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-28 00:00:00', 5.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-29 00:00:00', 5.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-30 00:00:00', 5.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-01-31 00:00:00', 5.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-01 00:00:00', 7.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-02 00:00:00', 9.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-03 00:00:00', 8.73499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-04 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-05 00:00:00', 2.94499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-06 00:00:00', 2.11400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-07 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-08 00:00:00', 0.720000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-09 00:00:00', -0.691999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-10 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-11 00:00:00', 8.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-12 00:00:00', 4.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-13 00:00:00', 3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-14 00:00:00', 4.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-15 00:00:00', 5.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-16 00:00:00', 5.30499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-17 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-18 00:00:00', 4.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-19 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-20 00:00:00', 1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-21 00:00:00', 6.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-22 00:00:00', 6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-23 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-24 00:00:00', -1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-25 00:00:00', -3.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-26 00:00:00', -6.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-27 00:00:00', -0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-02-28 00:00:00', -1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-01 00:00:00', 0.829999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-02 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-03 00:00:00', 2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-04 00:00:00', -0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-05 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-06 00:00:00', 6.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-07 00:00:00', 6.10099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-08 00:00:00', 10.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-09 00:00:00', 13.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-10 00:00:00', 13.6579999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-11 00:00:00', 13.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-12 00:00:00', 14.0399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-13 00:00:00', 16.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-14 00:00:00', 18.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-15 00:00:00', 11.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-16 00:00:00', 10.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-17 00:00:00', 6.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-18 00:00:00', 12.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-19 00:00:00', 8.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-20 00:00:00', 9.60700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-21 00:00:00', 13.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-22 00:00:00', 14.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-23 00:00:00', 16.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-24 00:00:00', 18.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-25 00:00:00', 14.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-26 00:00:00', 14.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-27 00:00:00', 12.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-28 00:00:00', 13.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-29 00:00:00', 14.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-30 00:00:00', 12.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-03-31 00:00:00', 12.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-01 00:00:00', 12.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-02 00:00:00', 13.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-03 00:00:00', 9.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-04 00:00:00', 8.22299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-05 00:00:00', 13.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-06 00:00:00', 15.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-07 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-08 00:00:00', 15.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-09 00:00:00', 12.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-10 00:00:00', 17.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-11 00:00:00', 17.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-12 00:00:00', 20.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-13 00:00:00', 22.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-14 00:00:00', 21.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-15 00:00:00', 15.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-16 00:00:00', 17.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-17 00:00:00', 19.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-18 00:00:00', 19.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-19 00:00:00', 19.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-20 00:00:00', 20.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-21 00:00:00', 24.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-22 00:00:00', 27.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-23 00:00:00', 28.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-24 00:00:00', 29.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-25 00:00:00', 27.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-26 00:00:00', 27.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-27 00:00:00', 28.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-28 00:00:00', 23.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-29 00:00:00', 20.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-04-30 00:00:00', 23.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-01 00:00:00', 27.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-02 00:00:00', 29.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-03 00:00:00', 29.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-04 00:00:00', 29.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-05 00:00:00', 22.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-06 00:00:00', 17.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-07 00:00:00', 21.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-08 00:00:00', 21.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-09 00:00:00', 23.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-10 00:00:00', 22.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-11 00:00:00', 19.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-12 00:00:00', 20.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-13 00:00:00', 24.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-14 00:00:00', 29, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-15 00:00:00', 31.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-16 00:00:00', 33.03900146484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-17 00:00:00', 31.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-18 00:00:00', 26.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-19 00:00:00', 25.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-20 00:00:00', 23.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-21 00:00:00', 24.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-22 00:00:00', 25.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-23 00:00:00', 27.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-24 00:00:00', 28.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-25 00:00:00', 26.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-26 00:00:00', 26.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-27 00:00:00', 25.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-28 00:00:00', 25.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-29 00:00:00', 27.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-30 00:00:00', 26.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-05-31 00:00:00', 26.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-01 00:00:00', 22.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-02 00:00:00', 24.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-03 00:00:00', 25.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-04 00:00:00', 25.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-05 00:00:00', 26.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-06 00:00:00', 28.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-07 00:00:00', 31.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-08 00:00:00', 32.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-09 00:00:00', 31.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-10 00:00:00', 31.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-11 00:00:00', 29.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-12 00:00:00', 28.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-13 00:00:00', 27.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-14 00:00:00', 30.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-15 00:00:00', 32.1150016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-16 00:00:00', 32.6489982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-17 00:00:00', 29.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-18 00:00:00', 29.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-19 00:00:00', 29.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-20 00:00:00', 29.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-21 00:00:00', 31.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-22 00:00:00', 31.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-23 00:00:00', 31.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-24 00:00:00', 32.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-25 00:00:00', 31.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-26 00:00:00', 27.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-27 00:00:00', 30.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-28 00:00:00', 30.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-29 00:00:00', 30.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-06-30 00:00:00', 29.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-01 00:00:00', 28.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-02 00:00:00', 28.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-03 00:00:00', 30.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-04 00:00:00', 32.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-05 00:00:00', 31.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-06 00:00:00', 31.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-07 00:00:00', 31.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-08 00:00:00', 31.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-09 00:00:00', 32.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-10 00:00:00', 31.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-11 00:00:00', 33.7270011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-12 00:00:00', 35.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-13 00:00:00', 36.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-14 00:00:00', 32.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-15 00:00:00', 30.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-16 00:00:00', 29.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-17 00:00:00', 29.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-18 00:00:00', 30.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-19 00:00:00', 28.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-20 00:00:00', 29.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-21 00:00:00', 31.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-22 00:00:00', 31.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-23 00:00:00', 30.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-24 00:00:00', 31.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-25 00:00:00', 30.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-26 00:00:00', 32.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-27 00:00:00', 31.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-28 00:00:00', 31.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-29 00:00:00', 31.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-30 00:00:00', 31.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-07-31 00:00:00', 30.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-01 00:00:00', 33.0800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-02 00:00:00', 35.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-03 00:00:00', 36.7939987182617188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-04 00:00:00', 37.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-05 00:00:00', 37.4809989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-06 00:00:00', 37.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-07 00:00:00', 36.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-08 00:00:00', 33.8779983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-09 00:00:00', 29.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-10 00:00:00', 30.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-11 00:00:00', 31.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-12 00:00:00', 31.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-13 00:00:00', 31.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-14 00:00:00', 32.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-15 00:00:00', 33.0250015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-16 00:00:00', 31.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-17 00:00:00', 31.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-18 00:00:00', 30.8600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-19 00:00:00', 31.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-20 00:00:00', 32.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-21 00:00:00', 34.1279983520507812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-22 00:00:00', 33.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-23 00:00:00', 35.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-24 00:00:00', 35.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-25 00:00:00', 33.0040016174316406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-26 00:00:00', 29.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-27 00:00:00', 26.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-28 00:00:00', 25.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-29 00:00:00', 23.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-30 00:00:00', 23.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-08-31 00:00:00', 27.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-01 00:00:00', 28.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-02 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-03 00:00:00', 28.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-04 00:00:00', 30.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-05 00:00:00', 31.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-06 00:00:00', 30.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-07 00:00:00', 29.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-08 00:00:00', 28.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-09 00:00:00', 29.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-10 00:00:00', 28.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-11 00:00:00', 29.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-12 00:00:00', 30.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-13 00:00:00', 30.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-14 00:00:00', 27.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-15 00:00:00', 25.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-16 00:00:00', 22.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-17 00:00:00', 26.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-18 00:00:00', 22.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-19 00:00:00', 22.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-20 00:00:00', 22.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-21 00:00:00', 20.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-22 00:00:00', 22.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-23 00:00:00', 20.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-24 00:00:00', 24.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-25 00:00:00', 23.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-26 00:00:00', 23.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-27 00:00:00', 24.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-28 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-29 00:00:00', 20.2870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-09-30 00:00:00', 21.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-01 00:00:00', 23.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-02 00:00:00', 25.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-03 00:00:00', 26.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-04 00:00:00', 24.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-05 00:00:00', 18.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-06 00:00:00', 19.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-07 00:00:00', 17.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-08 00:00:00', 18.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-09 00:00:00', 19.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-10 00:00:00', 20.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-11 00:00:00', 20.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-12 00:00:00', 19.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-13 00:00:00', 18.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-14 00:00:00', 18.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-15 00:00:00', 21.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-16 00:00:00', 20.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-17 00:00:00', 19.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-18 00:00:00', 19.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-19 00:00:00', 17.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-20 00:00:00', 19.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-21 00:00:00', 17.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-22 00:00:00', 18.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-23 00:00:00', 9.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-24 00:00:00', 12.939000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-25 00:00:00', 13.4980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-26 00:00:00', 16.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-27 00:00:00', 15.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-28 00:00:00', 10.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-29 00:00:00', 8.60299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-30 00:00:00', 11.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-10-31 00:00:00', 11.2899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-01 00:00:00', 8.32699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-02 00:00:00', 10.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-03 00:00:00', 9.96300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-04 00:00:00', 8.86699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-05 00:00:00', 11.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-06 00:00:00', 12.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-07 00:00:00', 14.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-08 00:00:00', 7.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-09 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-10 00:00:00', 9.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-11 00:00:00', 11.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-12 00:00:00', 10.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-13 00:00:00', 12.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-14 00:00:00', 7.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-15 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-16 00:00:00', 9.62199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-17 00:00:00', 10.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-18 00:00:00', 9.81000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-19 00:00:00', 9.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-20 00:00:00', 10.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-21 00:00:00', 13.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-22 00:00:00', 11.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-23 00:00:00', 10.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-24 00:00:00', 8.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-25 00:00:00', 8.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-26 00:00:00', 4.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-27 00:00:00', 4.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-28 00:00:00', 4.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-29 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-11-30 00:00:00', 11.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-01 00:00:00', 9.04800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-02 00:00:00', 7.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-03 00:00:00', 5.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-04 00:00:00', 4.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-05 00:00:00', 0.566999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-06 00:00:00', 0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-07 00:00:00', 1.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-08 00:00:00', 4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-09 00:00:00', 4.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-10 00:00:00', 5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-11 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-12 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-13 00:00:00', 3.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-14 00:00:00', 4.55999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-15 00:00:00', 2.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-16 00:00:00', 3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-17 00:00:00', 8.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-18 00:00:00', 4.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-19 00:00:00', 1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-20 00:00:00', -6.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-21 00:00:00', -7.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-22 00:00:00', -2.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-23 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-24 00:00:00', 1.61000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-25 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-26 00:00:00', 4.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-27 00:00:00', 0.856999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-28 00:00:00', -1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-29 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-30 00:00:00', 0.734000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2011-12-31 00:00:00', 2.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-01 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-02 00:00:00', 2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-03 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-04 00:00:00', 2.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-05 00:00:00', -2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-06 00:00:00', -3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-07 00:00:00', -1.15999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-08 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-09 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-10 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-11 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-12 00:00:00', 4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-13 00:00:00', 2.14299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-14 00:00:00', 4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-15 00:00:00', 1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-16 00:00:00', -0.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-17 00:00:00', 3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-18 00:00:00', 1.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-19 00:00:00', -0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-20 00:00:00', -1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-21 00:00:00', 1.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-22 00:00:00', -0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-23 00:00:00', 0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-24 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-25 00:00:00', 1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-26 00:00:00', -1.83000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-27 00:00:00', 0.709999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-28 00:00:00', 0.819999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-29 00:00:00', 5.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-30 00:00:00', 1.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-01-31 00:00:00', -0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-01 00:00:00', 2.64700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-02 00:00:00', 4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-03 00:00:00', 3.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-04 00:00:00', -3.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-05 00:00:00', -7.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-06 00:00:00', -5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-07 00:00:00', -3.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-08 00:00:00', -0.449000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-09 00:00:00', 0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-10 00:00:00', -0.189999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-11 00:00:00', 3.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-12 00:00:00', 0.246999993920326233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-13 00:00:00', -3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-14 00:00:00', -3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-15 00:00:00', -1.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-16 00:00:00', -0.538999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-17 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-18 00:00:00', 1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-19 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-20 00:00:00', 3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-21 00:00:00', -1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-22 00:00:00', -4.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-23 00:00:00', -3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-24 00:00:00', -1.17200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-25 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-26 00:00:00', 5.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-27 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-28 00:00:00', 5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-02-29 00:00:00', 5.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-01 00:00:00', 7.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-02 00:00:00', 8.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-03 00:00:00', 8.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-04 00:00:00', 5.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-05 00:00:00', 2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-06 00:00:00', 2.87299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-07 00:00:00', 1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-08 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-09 00:00:00', 3.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-10 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-11 00:00:00', 0.977999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-12 00:00:00', -0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-13 00:00:00', -1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-14 00:00:00', 1.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-15 00:00:00', 3.31200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-16 00:00:00', 5.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-17 00:00:00', 7.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-18 00:00:00', 8.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-19 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-20 00:00:00', -1.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-21 00:00:00', 1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-22 00:00:00', 3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-23 00:00:00', 4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-24 00:00:00', 9.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-25 00:00:00', 9.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-26 00:00:00', 10.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-27 00:00:00', 13.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-28 00:00:00', 15.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-29 00:00:00', 13.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-30 00:00:00', 17.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-03-31 00:00:00', 16.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-01 00:00:00', 12.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-02 00:00:00', 17.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-03 00:00:00', 17.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-04 00:00:00', 19.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-05 00:00:00', 18.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-06 00:00:00', 17.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-07 00:00:00', 17.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-08 00:00:00', 19.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-09 00:00:00', 16.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-10 00:00:00', 18.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-11 00:00:00', 17.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-12 00:00:00', 16.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-13 00:00:00', 18.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-14 00:00:00', 19.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-15 00:00:00', 20.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-16 00:00:00', 21.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-17 00:00:00', 21.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-18 00:00:00', 23.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-19 00:00:00', 24.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-20 00:00:00', 23.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-21 00:00:00', 16.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-22 00:00:00', 17.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-23 00:00:00', 18.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-24 00:00:00', 19.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-25 00:00:00', 18.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-26 00:00:00', 18.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-27 00:00:00', 18.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-28 00:00:00', 17.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-29 00:00:00', 15.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-04-30 00:00:00', 17.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-01 00:00:00', 16.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-02 00:00:00', 16.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-03 00:00:00', 18.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-04 00:00:00', 20.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-05 00:00:00', 21.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-06 00:00:00', 20.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-07 00:00:00', 18.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-08 00:00:00', 20.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-09 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-10 00:00:00', 20.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-11 00:00:00', 19.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-12 00:00:00', 17.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-13 00:00:00', 19.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-14 00:00:00', 20.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-15 00:00:00', 22.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-16 00:00:00', 23.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-17 00:00:00', 20.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-18 00:00:00', 20.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-19 00:00:00', 22.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-20 00:00:00', 22.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-21 00:00:00', 22.7380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-22 00:00:00', 21.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-23 00:00:00', 22.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-24 00:00:00', 27.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-25 00:00:00', 21.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-26 00:00:00', 22.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-27 00:00:00', 24.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-28 00:00:00', 27.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-29 00:00:00', 25.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-30 00:00:00', 27.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-05-31 00:00:00', 26.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-01 00:00:00', 27.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-02 00:00:00', 27.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-03 00:00:00', 27.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-04 00:00:00', 28.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-05 00:00:00', 24.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-06 00:00:00', 27.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-07 00:00:00', 26.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-08 00:00:00', 25.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-09 00:00:00', 27.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-10 00:00:00', 27.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-11 00:00:00', 27.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-12 00:00:00', 26.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-13 00:00:00', 26.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-14 00:00:00', 27.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-15 00:00:00', 28.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-16 00:00:00', 29.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-17 00:00:00', 30.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-18 00:00:00', 30.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-19 00:00:00', 30.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-20 00:00:00', 30.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-21 00:00:00', 28.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-22 00:00:00', 26.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-23 00:00:00', 26.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-24 00:00:00', 26.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-25 00:00:00', 26.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-26 00:00:00', 26.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-27 00:00:00', 26.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-28 00:00:00', 28.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-29 00:00:00', 30.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-06-30 00:00:00', 31.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-01 00:00:00', 31.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-02 00:00:00', 32.8499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-03 00:00:00', 33.2190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-04 00:00:00', 32.8489990234375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-05 00:00:00', 32.2410011291503906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-06 00:00:00', 31.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-07 00:00:00', 30.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-08 00:00:00', 31.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-09 00:00:00', 31.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-10 00:00:00', 33.0929985046386719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-11 00:00:00', 35.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-12 00:00:00', 32.5320014953613281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-13 00:00:00', 31.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-14 00:00:00', 29.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-15 00:00:00', 28.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-16 00:00:00', 29.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-17 00:00:00', 31.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-18 00:00:00', 30.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-19 00:00:00', 31.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-20 00:00:00', 31.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-21 00:00:00', 32.483001708984375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-22 00:00:00', 31.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-23 00:00:00', 31.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-24 00:00:00', 30.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-25 00:00:00', 28.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-26 00:00:00', 29.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-27 00:00:00', 26.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-28 00:00:00', 27.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-29 00:00:00', 29.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-30 00:00:00', 31.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-07-31 00:00:00', 31.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-01 00:00:00', 31.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-02 00:00:00', 30.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-03 00:00:00', 28.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-04 00:00:00', 27.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-05 00:00:00', 30.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-06 00:00:00', 30.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-07 00:00:00', 31.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-08 00:00:00', 31.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-09 00:00:00', 31.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-10 00:00:00', 31.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-11 00:00:00', 31.0330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-12 00:00:00', 29.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-13 00:00:00', 28.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-14 00:00:00', 30.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-15 00:00:00', 31.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-16 00:00:00', 32.2760009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-17 00:00:00', 32.5190010070800781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-18 00:00:00', 33.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-19 00:00:00', 34.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-20 00:00:00', 34.21099853515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-21 00:00:00', 34.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-22 00:00:00', 34.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-23 00:00:00', 32.3310012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-24 00:00:00', 31.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-25 00:00:00', 28.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-26 00:00:00', 29.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-27 00:00:00', 28.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-28 00:00:00', 30.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-29 00:00:00', 31.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-30 00:00:00', 31.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-08-31 00:00:00', 31.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-01 00:00:00', 31.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-02 00:00:00', 31.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-03 00:00:00', 30.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-04 00:00:00', 27.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-05 00:00:00', 24.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-06 00:00:00', 27.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-07 00:00:00', 24.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-08 00:00:00', 26.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-09 00:00:00', 27.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-10 00:00:00', 29.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-11 00:00:00', 29.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-12 00:00:00', 28.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-13 00:00:00', 26.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-14 00:00:00', 23.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-15 00:00:00', 24.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-16 00:00:00', 24.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-17 00:00:00', 22.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-18 00:00:00', 21.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-19 00:00:00', 23.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-20 00:00:00', 22.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-21 00:00:00', 21.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-22 00:00:00', 22.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-23 00:00:00', 23.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-24 00:00:00', 23.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-25 00:00:00', 22.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-26 00:00:00', 22.9599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-27 00:00:00', 24.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-28 00:00:00', 22.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-29 00:00:00', 20.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-09-30 00:00:00', 17.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-01 00:00:00', 21.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-02 00:00:00', 20.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-03 00:00:00', 19.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-04 00:00:00', 18.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-05 00:00:00', 19.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-06 00:00:00', 20.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-07 00:00:00', 23.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-08 00:00:00', 21.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-09 00:00:00', 21.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-10 00:00:00', 21.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-11 00:00:00', 21.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-12 00:00:00', 20.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-13 00:00:00', 21.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-14 00:00:00', 15.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-15 00:00:00', 15.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-16 00:00:00', 17.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-17 00:00:00', 14.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-18 00:00:00', 15.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-19 00:00:00', 14.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-20 00:00:00', 11.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-21 00:00:00', 12.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-22 00:00:00', 16.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-23 00:00:00', 15.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-24 00:00:00', 15.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-25 00:00:00', 13.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-26 00:00:00', 14.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-27 00:00:00', 15.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-28 00:00:00', 18.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-29 00:00:00', 17.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-30 00:00:00', 21.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-10-31 00:00:00', 19.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-01 00:00:00', 15.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-02 00:00:00', 14.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-03 00:00:00', 15.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-04 00:00:00', 11.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-05 00:00:00', 12.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-06 00:00:00', 15.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-07 00:00:00', 15.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-08 00:00:00', 16.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-09 00:00:00', 16.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-10 00:00:00', 16.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-11 00:00:00', 16.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-12 00:00:00', 12.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-13 00:00:00', 9.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-14 00:00:00', 13.255000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-15 00:00:00', 14.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-16 00:00:00', 8.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-17 00:00:00', 9.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-18 00:00:00', 7.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-19 00:00:00', 6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-20 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-21 00:00:00', 7.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-22 00:00:00', 8.83100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-23 00:00:00', 5.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-24 00:00:00', 5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-25 00:00:00', 9.99400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-26 00:00:00', 4.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-27 00:00:00', 9.46899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-28 00:00:00', 5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-29 00:00:00', 1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-11-30 00:00:00', 6.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-01 00:00:00', 9.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-02 00:00:00', 10.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-03 00:00:00', 10.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-04 00:00:00', 12.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-05 00:00:00', 13.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-06 00:00:00', 13.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-07 00:00:00', 12.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-08 00:00:00', 8.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-09 00:00:00', 12.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-10 00:00:00', 8.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-11 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-12 00:00:00', 5.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-13 00:00:00', 4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-14 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-15 00:00:00', 1.06099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-16 00:00:00', 0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-17 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-18 00:00:00', -1.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-19 00:00:00', -0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-20 00:00:00', 2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-21 00:00:00', 8.65200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-22 00:00:00', 12.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-23 00:00:00', 6.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-24 00:00:00', 5.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-25 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-26 00:00:00', 3.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-27 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-28 00:00:00', -6.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-29 00:00:00', 0.101999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-30 00:00:00', 2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2012-12-31 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-01 00:00:00', -5.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-02 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-03 00:00:00', -2.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-04 00:00:00', -2.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-05 00:00:00', 0.663999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-06 00:00:00', 0.941999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-07 00:00:00', 1.21300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-08 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-09 00:00:00', 1.09099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-10 00:00:00', 2.12700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-11 00:00:00', 2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-12 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-13 00:00:00', 0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-14 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-15 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-16 00:00:00', -1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-17 00:00:00', 0.221000000834465027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-18 00:00:00', 0.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-19 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-20 00:00:00', 2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-21 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-22 00:00:00', 2.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-23 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-24 00:00:00', 6.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-25 00:00:00', 6.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-26 00:00:00', 7.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-27 00:00:00', 7.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-28 00:00:00', 8.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-29 00:00:00', 7.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-30 00:00:00', 10.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-01-31 00:00:00', 7.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-01 00:00:00', 10.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-02 00:00:00', 6.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-03 00:00:00', 8.80500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-04 00:00:00', 4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-05 00:00:00', 3.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-06 00:00:00', 3.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-07 00:00:00', 7.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-08 00:00:00', 10.0959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-09 00:00:00', 5.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-10 00:00:00', 6.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-11 00:00:00', 6.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-12 00:00:00', 6.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-13 00:00:00', 7.64300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-14 00:00:00', 9.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-15 00:00:00', 7.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-16 00:00:00', 6.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-17 00:00:00', 9.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-18 00:00:00', 5.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-19 00:00:00', 5.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-20 00:00:00', 8.52200031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-21 00:00:00', 7.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-22 00:00:00', 8.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-23 00:00:00', 5.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-24 00:00:00', 7.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-25 00:00:00', 10.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-26 00:00:00', 5.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-27 00:00:00', -0.223000004887580872, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-02-28 00:00:00', 2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-01 00:00:00', 9.79800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-02 00:00:00', 12.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-03 00:00:00', 11.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-04 00:00:00', 10.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-05 00:00:00', 15.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-06 00:00:00', 17.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-07 00:00:00', 10.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-08 00:00:00', 7.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-09 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-10 00:00:00', 8.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-11 00:00:00', 11.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-12 00:00:00', 11.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-13 00:00:00', 10.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-14 00:00:00', 14.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-15 00:00:00', 12.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-16 00:00:00', 8.75599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-17 00:00:00', 8.64299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-18 00:00:00', 12.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-19 00:00:00', 16.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-20 00:00:00', 16.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-21 00:00:00', 10.3660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-22 00:00:00', 15.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-23 00:00:00', 12.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-24 00:00:00', 12.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-25 00:00:00', 16.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-26 00:00:00', 11.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-27 00:00:00', 16.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-28 00:00:00', 18.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-29 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-30 00:00:00', 18.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-03-31 00:00:00', 12.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-01 00:00:00', 7.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-02 00:00:00', 11.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-03 00:00:00', 14.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-04 00:00:00', 15.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-05 00:00:00', 11.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-06 00:00:00', 12.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-07 00:00:00', 15.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-08 00:00:00', 20.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-09 00:00:00', 21.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-10 00:00:00', 19.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-11 00:00:00', 22.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-12 00:00:00', 21.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-13 00:00:00', 20.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-14 00:00:00', 20.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-15 00:00:00', 13.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-16 00:00:00', 10.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-17 00:00:00', 13.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-18 00:00:00', 16.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-19 00:00:00', 16.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-20 00:00:00', 17.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-21 00:00:00', 17.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-22 00:00:00', 22.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-23 00:00:00', 20.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-24 00:00:00', 17.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-25 00:00:00', 15.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-26 00:00:00', 11.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-27 00:00:00', 17.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-28 00:00:00', 13.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-29 00:00:00', 13.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-04-30 00:00:00', 14.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-01 00:00:00', 17.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-02 00:00:00', 18.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-03 00:00:00', 16.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-04 00:00:00', 20.2900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-05 00:00:00', 19.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-06 00:00:00', 22.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-07 00:00:00', 22.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-08 00:00:00', 23.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-09 00:00:00', 23.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-10 00:00:00', 23.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-11 00:00:00', 21.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-12 00:00:00', 19.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-13 00:00:00', 20.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-14 00:00:00', 23.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-15 00:00:00', 24.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-16 00:00:00', 26.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-17 00:00:00', 27.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-18 00:00:00', 29.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-19 00:00:00', 20.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-20 00:00:00', 23.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-21 00:00:00', 23.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-22 00:00:00', 24.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-23 00:00:00', 27.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-24 00:00:00', 24.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-25 00:00:00', 22.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-26 00:00:00', 20.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-27 00:00:00', 20.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-28 00:00:00', 23.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-29 00:00:00', 26.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-30 00:00:00', 28.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-05-31 00:00:00', 30.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-01 00:00:00', 31.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-02 00:00:00', 27.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-03 00:00:00', 27.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-04 00:00:00', 27.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-05 00:00:00', 27.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-06 00:00:00', 28.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-07 00:00:00', 29.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-08 00:00:00', 33.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-09 00:00:00', 33.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-10 00:00:00', 32.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-11 00:00:00', 31.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-12 00:00:00', 30.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-13 00:00:00', 30.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-14 00:00:00', 26.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-15 00:00:00', 25.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-16 00:00:00', 26.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-17 00:00:00', 26.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-18 00:00:00', 28.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-19 00:00:00', 30.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-20 00:00:00', 31.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-21 00:00:00', 32.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-22 00:00:00', 33.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-23 00:00:00', 33.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-24 00:00:00', 33.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-25 00:00:00', 33.3989982604980469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-26 00:00:00', 33.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-27 00:00:00', 30.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-28 00:00:00', 25.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-29 00:00:00', 26.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-06-30 00:00:00', 27.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-01 00:00:00', 27.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-02 00:00:00', 28.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-03 00:00:00', 31.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-04 00:00:00', 32.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-05 00:00:00', 30.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-06 00:00:00', 29.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-07 00:00:00', 27.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-08 00:00:00', 27.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-09 00:00:00', 25.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-10 00:00:00', 29.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-11 00:00:00', 28.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-12 00:00:00', 29.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-13 00:00:00', 32.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-14 00:00:00', 30.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-15 00:00:00', 30.3309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-16 00:00:00', 30.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-17 00:00:00', 30.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-18 00:00:00', 33.7060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-19 00:00:00', 34.6370010375976562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-20 00:00:00', 34.6059989929199219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-21 00:00:00', 33.6769981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-22 00:00:00', 28.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-23 00:00:00', 30.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-24 00:00:00', 32.2039985656738281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-25 00:00:00', 32.1510009765625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-26 00:00:00', 34.1129989624023438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-27 00:00:00', 36.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-28 00:00:00', 38.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-29 00:00:00', 38.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-30 00:00:00', 37.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-07-31 00:00:00', 36.0880012512207031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-01 00:00:00', 34.3230018615722656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-02 00:00:00', 35.2060012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-03 00:00:00', 34.9749984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-04 00:00:00', 34.3979988098144531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-05 00:00:00', 32.3019981384277344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-06 00:00:00', 35.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-07 00:00:00', 32.0810012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-08 00:00:00', 28.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-09 00:00:00', 29.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-10 00:00:00', 30.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-11 00:00:00', 28.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-12 00:00:00', 29.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-13 00:00:00', 25.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-14 00:00:00', 28.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-15 00:00:00', 29.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-16 00:00:00', 28.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-17 00:00:00', 29.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-18 00:00:00', 28.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-19 00:00:00', 29.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-20 00:00:00', 29.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-21 00:00:00', 29.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-22 00:00:00', 30.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-23 00:00:00', 31.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-24 00:00:00', 28.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-25 00:00:00', 28.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-26 00:00:00', 31.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-27 00:00:00', 30.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-28 00:00:00', 31.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-29 00:00:00', 30.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-30 00:00:00', 28.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-08-31 00:00:00', 28.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-01 00:00:00', 28.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-02 00:00:00', 27.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-03 00:00:00', 28.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-04 00:00:00', 28.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-05 00:00:00', 30.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-06 00:00:00', 32.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-07 00:00:00', 31.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-08 00:00:00', 31.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-09 00:00:00', 31.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-10 00:00:00', 31.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-11 00:00:00', 30.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-12 00:00:00', 28.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-13 00:00:00', 26.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-14 00:00:00', 23.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-15 00:00:00', 21.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-16 00:00:00', 21.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-17 00:00:00', 24.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-18 00:00:00', 25.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-19 00:00:00', 28.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-20 00:00:00', 30.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-21 00:00:00', 30.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-22 00:00:00', 28.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-23 00:00:00', 27.9220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-24 00:00:00', 28.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-25 00:00:00', 30.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-26 00:00:00', 31.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-27 00:00:00', 26.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-28 00:00:00', 26.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-29 00:00:00', 26.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-09-30 00:00:00', 25.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-01 00:00:00', 26.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-02 00:00:00', 26.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-03 00:00:00', 27.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-04 00:00:00', 27.3729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-05 00:00:00', 28.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-06 00:00:00', 30.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-07 00:00:00', 28.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-08 00:00:00', 25.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-09 00:00:00', 22.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-10 00:00:00', 18.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-11 00:00:00', 19.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-12 00:00:00', 20.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-13 00:00:00', 19.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-14 00:00:00', 20.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-15 00:00:00', 18.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-16 00:00:00', 17.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-17 00:00:00', 17.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-18 00:00:00', 19.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-19 00:00:00', 21.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-20 00:00:00', 21.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-21 00:00:00', 22.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-22 00:00:00', 17.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-23 00:00:00', 11.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-24 00:00:00', 17.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-25 00:00:00', 15.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-26 00:00:00', 7.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-27 00:00:00', 8.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-28 00:00:00', 14.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-29 00:00:00', 16.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-30 00:00:00', 9.61900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-10-31 00:00:00', 9.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-01 00:00:00', 7.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-02 00:00:00', 11.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-03 00:00:00', 14.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-04 00:00:00', 11.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-05 00:00:00', 13.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-06 00:00:00', 12.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-07 00:00:00', 11.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-08 00:00:00', 13.5290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-09 00:00:00', 13.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-10 00:00:00', 12.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-11 00:00:00', 12.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-12 00:00:00', 10.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-13 00:00:00', 10.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-14 00:00:00', 13.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-15 00:00:00', 15.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-16 00:00:00', 14.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-17 00:00:00', 12.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-18 00:00:00', 12.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-19 00:00:00', 11.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-20 00:00:00', 6.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-21 00:00:00', 8.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-22 00:00:00', 12.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-23 00:00:00', 15.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-24 00:00:00', 9.78600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-25 00:00:00', 11.5220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-26 00:00:00', 10.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-27 00:00:00', 10.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-28 00:00:00', 10.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-29 00:00:00', 10.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-11-30 00:00:00', 13.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-01 00:00:00', 13.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-02 00:00:00', 5.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-03 00:00:00', 9.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-04 00:00:00', 10.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-05 00:00:00', 6.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-06 00:00:00', 6.29400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-07 00:00:00', 7.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-08 00:00:00', 8.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-09 00:00:00', 7.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-10 00:00:00', 9.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-11 00:00:00', 4.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-12 00:00:00', 7.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-13 00:00:00', 9.91199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-14 00:00:00', 13.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-15 00:00:00', 12.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-16 00:00:00', 5.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-17 00:00:00', 2.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-18 00:00:00', -1.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-19 00:00:00', 0.824000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-20 00:00:00', 4.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-21 00:00:00', -0.86799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-22 00:00:00', -1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-23 00:00:00', 0.878000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-24 00:00:00', -1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-25 00:00:00', 1.00199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-26 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-27 00:00:00', -3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-28 00:00:00', -5.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-29 00:00:00', -4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-30 00:00:00', -4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2013-12-31 00:00:00', -0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-01 00:00:00', 0.717000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-02 00:00:00', 2.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-03 00:00:00', 0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-04 00:00:00', 1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-05 00:00:00', -0.726000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-06 00:00:00', 0.294999986886978149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-07 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-08 00:00:00', -0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-09 00:00:00', -1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-10 00:00:00', -0.646000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-11 00:00:00', 3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-12 00:00:00', 7.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-13 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-14 00:00:00', 2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-15 00:00:00', 1.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-16 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-17 00:00:00', 4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-18 00:00:00', 7.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-19 00:00:00', 9.15699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-20 00:00:00', 9.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-21 00:00:00', 3.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-22 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-23 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-24 00:00:00', 4.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-25 00:00:00', 3.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-26 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-27 00:00:00', 6.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-28 00:00:00', 9.03600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-29 00:00:00', 11.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-30 00:00:00', 6.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-01-31 00:00:00', 5.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-01 00:00:00', 0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-02 00:00:00', -5.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-03 00:00:00', -7.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-04 00:00:00', -5.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-05 00:00:00', -4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-06 00:00:00', -1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-07 00:00:00', -6.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-08 00:00:00', -3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-09 00:00:00', 0.0489999987185001373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-10 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-11 00:00:00', 0.68199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-12 00:00:00', 1.88300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-13 00:00:00', 1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-14 00:00:00', 0.606999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-15 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-16 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-17 00:00:00', 7.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-18 00:00:00', 7.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-19 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-20 00:00:00', 5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-21 00:00:00', 5.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-22 00:00:00', 5.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-23 00:00:00', 2.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-24 00:00:00', 3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-25 00:00:00', 6.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-26 00:00:00', 4.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-27 00:00:00', 5.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-02-28 00:00:00', 7.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-01 00:00:00', 8.67300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-02 00:00:00', 10.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-03 00:00:00', 7.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-04 00:00:00', 7.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-05 00:00:00', 8.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-06 00:00:00', 8.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-07 00:00:00', 6.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-08 00:00:00', 8.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-09 00:00:00', 1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-10 00:00:00', 5.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-11 00:00:00', 7.69899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-12 00:00:00', 10.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-13 00:00:00', 11.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-14 00:00:00', 10.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-15 00:00:00', 7.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-16 00:00:00', 11.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-17 00:00:00', 7.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-18 00:00:00', 9.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-19 00:00:00', 11.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-20 00:00:00', 13.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-21 00:00:00', 11.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-22 00:00:00', 13.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-23 00:00:00', 7.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-24 00:00:00', 4.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-25 00:00:00', 6.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-26 00:00:00', 9.17800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-27 00:00:00', 9.06200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-28 00:00:00', 11.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-29 00:00:00', 12.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-30 00:00:00', 15.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-03-31 00:00:00', 18.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-01 00:00:00', 18.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-02 00:00:00', 13.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-03 00:00:00', 14.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-04 00:00:00', 11.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-05 00:00:00', 11.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-06 00:00:00', 12.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-07 00:00:00', 10.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-08 00:00:00', 12.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-09 00:00:00', 14.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-10 00:00:00', 15.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-11 00:00:00', 13.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-12 00:00:00', 10.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-13 00:00:00', 11.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-14 00:00:00', 15.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-15 00:00:00', 18.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-16 00:00:00', 17.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-17 00:00:00', 15.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-18 00:00:00', 15.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-19 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-20 00:00:00', 17.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-21 00:00:00', 18.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-22 00:00:00', 20.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-23 00:00:00', 21.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-24 00:00:00', 16.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-25 00:00:00', 16.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-26 00:00:00', 15.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-27 00:00:00', 19.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-28 00:00:00', 20.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-29 00:00:00', 20.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-04-30 00:00:00', 21.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-01 00:00:00', 24.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-02 00:00:00', 25.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-03 00:00:00', 24.6259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-04 00:00:00', 23.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-05 00:00:00', 25.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-06 00:00:00', 23.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-07 00:00:00', 24.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-08 00:00:00', 22.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-09 00:00:00', 22.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-10 00:00:00', 25.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-11 00:00:00', 23.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-12 00:00:00', 21.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-13 00:00:00', 20.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-14 00:00:00', 22.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-15 00:00:00', 24.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-16 00:00:00', 25.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-17 00:00:00', 26.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-18 00:00:00', 20.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-19 00:00:00', 21.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-20 00:00:00', 25.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-21 00:00:00', 23.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-22 00:00:00', 21.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-23 00:00:00', 23.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-24 00:00:00', 23.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-25 00:00:00', 25.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-26 00:00:00', 24.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-27 00:00:00', 26.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-28 00:00:00', 27.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-29 00:00:00', 26.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-30 00:00:00', 19.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-05-31 00:00:00', 21.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-01 00:00:00', 21.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-02 00:00:00', 23.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-03 00:00:00', 23.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-04 00:00:00', 24.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-05 00:00:00', 27.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-06 00:00:00', 26.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-07 00:00:00', 25.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-08 00:00:00', 25.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-09 00:00:00', 26.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-10 00:00:00', 26.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-11 00:00:00', 28.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-12 00:00:00', 29.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-13 00:00:00', 31.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-14 00:00:00', 31.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-15 00:00:00', 27.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-16 00:00:00', 27.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-17 00:00:00', 27.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-18 00:00:00', 27.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-19 00:00:00', 28.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-20 00:00:00', 29.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-21 00:00:00', 30.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-22 00:00:00', 31.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-23 00:00:00', 31.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-24 00:00:00', 31.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-25 00:00:00', 31.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-26 00:00:00', 31.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-27 00:00:00', 32.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-28 00:00:00', 34.2599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-29 00:00:00', 33.7190017700195312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-06-30 00:00:00', 34.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-01 00:00:00', 34.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-02 00:00:00', 30.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-03 00:00:00', 26.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-04 00:00:00', 26.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-05 00:00:00', 28.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-06 00:00:00', 29.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-07 00:00:00', 30.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-08 00:00:00', 30.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-09 00:00:00', 31.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-10 00:00:00', 31.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-11 00:00:00', 33.7680015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-12 00:00:00', 34.3930015563964844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-13 00:00:00', 31.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-14 00:00:00', 31.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-15 00:00:00', 31.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-16 00:00:00', 29.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-17 00:00:00', 29.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-18 00:00:00', 28.5020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-19 00:00:00', 28.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-20 00:00:00', 29.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-21 00:00:00', 32.9560012817382812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-22 00:00:00', 36.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-23 00:00:00', 37.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-24 00:00:00', 31.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-25 00:00:00', 32.4770011901855469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-26 00:00:00', 32.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-27 00:00:00', 33.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-28 00:00:00', 35.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-29 00:00:00', 31.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-30 00:00:00', 29.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (40, '2014-07-31 00:00:00', 28.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-01 00:00:00', 2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-02 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-03 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-04 00:00:00', 1.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-05 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-06 00:00:00', 1.36600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-07 00:00:00', -0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-08 00:00:00', -1.48199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-09 00:00:00', -4.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-10 00:00:00', -2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-11 00:00:00', 0.137999996542930603, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-12 00:00:00', 3.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-13 00:00:00', -0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-14 00:00:00', -5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-15 00:00:00', -3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-16 00:00:00', -4.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-17 00:00:00', -5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-18 00:00:00', -9.17800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-19 00:00:00', -8.88099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-20 00:00:00', -6.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-21 00:00:00', -4.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-22 00:00:00', -1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-23 00:00:00', -2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-24 00:00:00', 2.26099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-25 00:00:00', 0.834999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-26 00:00:00', -8.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-27 00:00:00', -9.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-28 00:00:00', -6.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-29 00:00:00', -7.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-30 00:00:00', -6.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-01-31 00:00:00', -6.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-01 00:00:00', -4.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-02 00:00:00', -2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-03 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-04 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-05 00:00:00', -2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-06 00:00:00', -2.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-07 00:00:00', 1.8760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-08 00:00:00', -0.50700002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-09 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-10 00:00:00', -0.660000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-11 00:00:00', 0.555000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-12 00:00:00', 1.02199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-13 00:00:00', -0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-14 00:00:00', 0.335000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-15 00:00:00', 1.76800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-16 00:00:00', 3.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-17 00:00:00', 1.2359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-18 00:00:00', -3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-19 00:00:00', -8.90400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-20 00:00:00', -12.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-21 00:00:00', -8.15400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-22 00:00:00', -8.18500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-23 00:00:00', -6.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-24 00:00:00', -5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-25 00:00:00', -5.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-26 00:00:00', -2.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-27 00:00:00', -4.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-02-28 00:00:00', -5.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-01 00:00:00', -5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-02 00:00:00', -6.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-03 00:00:00', -10.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-04 00:00:00', -8.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-05 00:00:00', -10.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-06 00:00:00', -11.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-07 00:00:00', -11.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-08 00:00:00', -8.90699958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-09 00:00:00', -3.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-10 00:00:00', -2.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-11 00:00:00', -2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-12 00:00:00', -2.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-13 00:00:00', -1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-14 00:00:00', -1.87999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-15 00:00:00', 0.272000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-16 00:00:00', -1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-17 00:00:00', -1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-18 00:00:00', 0.178000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-19 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-20 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-21 00:00:00', 1.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-22 00:00:00', 0.962000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-23 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-24 00:00:00', 1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-25 00:00:00', 1.98199999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-26 00:00:00', 0.437999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-27 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-28 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-29 00:00:00', 1.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-30 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-03-31 00:00:00', -1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-01 00:00:00', 0.874000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-02 00:00:00', -0.446999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-03 00:00:00', 0.402000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-04 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-05 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-06 00:00:00', 6.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-07 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-08 00:00:00', 8.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-09 00:00:00', 8.64299964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-10 00:00:00', 11.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-11 00:00:00', 8.20199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-12 00:00:00', 7.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-13 00:00:00', 7.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-14 00:00:00', 6.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-15 00:00:00', 8.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-16 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-17 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-18 00:00:00', 1.09500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-19 00:00:00', 0.853999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-20 00:00:00', 4.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-21 00:00:00', 6.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-22 00:00:00', 9.00399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-23 00:00:00', 11.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-24 00:00:00', 7.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-25 00:00:00', 10.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-26 00:00:00', 9.91899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-27 00:00:00', 3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-28 00:00:00', -0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-29 00:00:00', 4.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-04-30 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-01 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-02 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-03 00:00:00', 9.39000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-04 00:00:00', 11.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-05 00:00:00', 8.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-06 00:00:00', 10.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-07 00:00:00', 8.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-08 00:00:00', 6.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-09 00:00:00', 2.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-10 00:00:00', 2.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-11 00:00:00', 3.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-12 00:00:00', 1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-13 00:00:00', 4.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-14 00:00:00', 5.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-15 00:00:00', 5.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-16 00:00:00', 7.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-17 00:00:00', 9.53600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-18 00:00:00', 6.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-19 00:00:00', 4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-20 00:00:00', 7.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-21 00:00:00', 8.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-22 00:00:00', 10.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-23 00:00:00', 9.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-24 00:00:00', 5.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-25 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-26 00:00:00', 6.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-27 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-28 00:00:00', 4.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-29 00:00:00', 8.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-30 00:00:00', 9.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-05-31 00:00:00', 9.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-01 00:00:00', 10.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-02 00:00:00', 12.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-03 00:00:00', 13.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-04 00:00:00', 14.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-05 00:00:00', 13.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-06 00:00:00', 15.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-07 00:00:00', 16.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-08 00:00:00', 15.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-09 00:00:00', 16.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-10 00:00:00', 16.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-11 00:00:00', 13.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-12 00:00:00', 13.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-13 00:00:00', 14.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-14 00:00:00', 15.064000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-15 00:00:00', 16.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-16 00:00:00', 17.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-17 00:00:00', 17.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-18 00:00:00', 15.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-19 00:00:00', 16.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-20 00:00:00', 18.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-21 00:00:00', 19.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-22 00:00:00', 20.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-23 00:00:00', 21.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-24 00:00:00', 21.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-25 00:00:00', 22.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-26 00:00:00', 19.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-27 00:00:00', 17.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-28 00:00:00', 16.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-29 00:00:00', 18.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-06-30 00:00:00', 19.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-01 00:00:00', 18.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-02 00:00:00', 18.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-03 00:00:00', 20.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-04 00:00:00', 19.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-05 00:00:00', 21.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-06 00:00:00', 22.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-07 00:00:00', 23.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-08 00:00:00', 25.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-09 00:00:00', 26.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-10 00:00:00', 27.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-11 00:00:00', 25.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-12 00:00:00', 24.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-13 00:00:00', 23.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-14 00:00:00', 23.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-15 00:00:00', 25.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-16 00:00:00', 25.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-17 00:00:00', 24.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-18 00:00:00', 25.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-19 00:00:00', 26.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-20 00:00:00', 23.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-21 00:00:00', 20.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-22 00:00:00', 19.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-23 00:00:00', 20.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-24 00:00:00', 21.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-25 00:00:00', 22.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-26 00:00:00', 23.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-27 00:00:00', 22.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-28 00:00:00', 21.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-29 00:00:00', 24.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-30 00:00:00', 26.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-07-31 00:00:00', 27.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-01 00:00:00', 28.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-02 00:00:00', 25.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-03 00:00:00', 23.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-04 00:00:00', 19.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-05 00:00:00', 14.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-06 00:00:00', 18.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-07 00:00:00', 17.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-08 00:00:00', 18.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-09 00:00:00', 19.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-10 00:00:00', 20.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-11 00:00:00', 19.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-12 00:00:00', 20.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-13 00:00:00', 20.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-14 00:00:00', 21.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-15 00:00:00', 22.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-16 00:00:00', 21.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-17 00:00:00', 21.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-18 00:00:00', 24.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-19 00:00:00', 22.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-20 00:00:00', 16.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-21 00:00:00', 16.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-22 00:00:00', 15.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-23 00:00:00', 15.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-24 00:00:00', 16.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-25 00:00:00', 17.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-26 00:00:00', 18.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-27 00:00:00', 15.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-28 00:00:00', 15.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-29 00:00:00', 12.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-30 00:00:00', 13.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-08-31 00:00:00', 16.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-01 00:00:00', 17.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-02 00:00:00', 14.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-03 00:00:00', 18.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-04 00:00:00', 19.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-05 00:00:00', 19.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-06 00:00:00', 20.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-07 00:00:00', 20.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-08 00:00:00', 20.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-09 00:00:00', 18.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-10 00:00:00', 19.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-11 00:00:00', 20.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-12 00:00:00', 18.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-13 00:00:00', 16.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-14 00:00:00', 16.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-15 00:00:00', 13.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-16 00:00:00', 15.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-17 00:00:00', 15.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-18 00:00:00', 16.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-19 00:00:00', 16.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-20 00:00:00', 16.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-21 00:00:00', 14.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-22 00:00:00', 13.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-23 00:00:00', 10.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-24 00:00:00', 12.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-25 00:00:00', 13.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-26 00:00:00', 14.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-27 00:00:00', 13.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-28 00:00:00', 13.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-29 00:00:00', 12.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-09-30 00:00:00', 13.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-01 00:00:00', 14.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-02 00:00:00', 13.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-03 00:00:00', 12.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-04 00:00:00', 14.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-05 00:00:00', 15.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-06 00:00:00', 15.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-07 00:00:00', 14.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-08 00:00:00', 13.449000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-09 00:00:00', 9.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-10 00:00:00', 8.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-11 00:00:00', 8.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-12 00:00:00', 8.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-13 00:00:00', 9.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-14 00:00:00', 10.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-15 00:00:00', 11.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-16 00:00:00', 11.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-17 00:00:00', 12.4600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-18 00:00:00', 12.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-19 00:00:00', 11.7270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-20 00:00:00', 7.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-21 00:00:00', 9.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-22 00:00:00', 10.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-23 00:00:00', 12.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-24 00:00:00', 14.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-25 00:00:00', 14.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-26 00:00:00', 13.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-27 00:00:00', 13.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-28 00:00:00', 8.19200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-29 00:00:00', 9.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-30 00:00:00', 6.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-10-31 00:00:00', 5.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-01 00:00:00', 6.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-02 00:00:00', 9.28199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-03 00:00:00', 7.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-04 00:00:00', 4.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-05 00:00:00', 2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-06 00:00:00', -0.388000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-07 00:00:00', -1.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-08 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-09 00:00:00', 4.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-10 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-11 00:00:00', -1.86300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-12 00:00:00', -1.42900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-13 00:00:00', -2.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-14 00:00:00', 0.499000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-15 00:00:00', 2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-16 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-17 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-18 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-19 00:00:00', 0.662000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-20 00:00:00', -1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-21 00:00:00', -1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-22 00:00:00', -4.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-23 00:00:00', -1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-24 00:00:00', -0.595000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-25 00:00:00', 0.936999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-26 00:00:00', 2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-27 00:00:00', 4.92999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-28 00:00:00', 5.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-29 00:00:00', 4.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-11-30 00:00:00', 4.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-01 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-02 00:00:00', 1.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-03 00:00:00', -3.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-04 00:00:00', -2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-05 00:00:00', -1.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-06 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-07 00:00:00', 0.921000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-08 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-09 00:00:00', 1.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-10 00:00:00', -0.575999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-11 00:00:00', 0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-12 00:00:00', 0.310000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-13 00:00:00', 0.513999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-14 00:00:00', 0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-15 00:00:00', -0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-16 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-17 00:00:00', 0.56099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-18 00:00:00', -5.76800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-19 00:00:00', -4.86299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-20 00:00:00', -2.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-21 00:00:00', -2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-22 00:00:00', -5.87699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-23 00:00:00', -10.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-24 00:00:00', -2.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-25 00:00:00', -0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-26 00:00:00', -1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-27 00:00:00', -1.17599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-28 00:00:00', -3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-29 00:00:00', -2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-30 00:00:00', -5.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1979-12-31 00:00:00', -3.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-01 00:00:00', -5.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-02 00:00:00', -5.90500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-03 00:00:00', -3.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-04 00:00:00', -4.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-05 00:00:00', -5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-06 00:00:00', -1.11300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-07 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-08 00:00:00', -1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-09 00:00:00', -6.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-10 00:00:00', -9.68700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-11 00:00:00', -6.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-12 00:00:00', -5.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-13 00:00:00', -5.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-14 00:00:00', -3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-15 00:00:00', -5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-16 00:00:00', -9.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-17 00:00:00', -5.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-18 00:00:00', -3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-19 00:00:00', -4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-20 00:00:00', -5.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-21 00:00:00', -5.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-22 00:00:00', -5.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-23 00:00:00', -5.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-24 00:00:00', -5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-25 00:00:00', -5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-26 00:00:00', -7.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-27 00:00:00', -8.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-28 00:00:00', -9.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-29 00:00:00', -2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-30 00:00:00', -1.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-01-31 00:00:00', -5.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-01 00:00:00', -9.85000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-02 00:00:00', -13.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-03 00:00:00', -15.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-04 00:00:00', -14.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-05 00:00:00', -12.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-06 00:00:00', -7.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-07 00:00:00', -4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-08 00:00:00', -6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-09 00:00:00', -3.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-10 00:00:00', -2.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-11 00:00:00', -0.333999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-12 00:00:00', 1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-13 00:00:00', 1.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-14 00:00:00', -3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-15 00:00:00', -1.2489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-16 00:00:00', -0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-17 00:00:00', -3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-18 00:00:00', -1.0010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-19 00:00:00', -0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-20 00:00:00', -4.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-21 00:00:00', -3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-22 00:00:00', -6.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-23 00:00:00', -4.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-24 00:00:00', -6.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-25 00:00:00', -0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-26 00:00:00', -0.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-27 00:00:00', -5.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-28 00:00:00', -8.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-02-29 00:00:00', -7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-01 00:00:00', -4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-02 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-03 00:00:00', 0.587999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-04 00:00:00', -1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-05 00:00:00', -7.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-06 00:00:00', -4.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-07 00:00:00', -1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-08 00:00:00', -4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-09 00:00:00', -6.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-10 00:00:00', -6.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-11 00:00:00', -5.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-12 00:00:00', -3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-13 00:00:00', 0.654999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-14 00:00:00', -0.837000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-15 00:00:00', -1.51199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-16 00:00:00', -1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-17 00:00:00', -1.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-18 00:00:00', -0.962000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-19 00:00:00', 5.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-20 00:00:00', 1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-21 00:00:00', 0.702000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-22 00:00:00', 1.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-23 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-24 00:00:00', 0.878000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-25 00:00:00', 0.799000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-26 00:00:00', 2.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-27 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-28 00:00:00', 0.370000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-29 00:00:00', 3.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-30 00:00:00', 7.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-03-31 00:00:00', 3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-01 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-02 00:00:00', 0.0939999967813491821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-03 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-04 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-05 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-06 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-07 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-08 00:00:00', 10.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-09 00:00:00', 8.90600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-10 00:00:00', 11.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-11 00:00:00', 9.29800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-12 00:00:00', 8.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-13 00:00:00', 4.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-14 00:00:00', 10.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-15 00:00:00', 3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-16 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-17 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-18 00:00:00', 2.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-19 00:00:00', 2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-20 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-21 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-22 00:00:00', 3.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-23 00:00:00', 5.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-24 00:00:00', 9.73200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-25 00:00:00', 4.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-26 00:00:00', 8.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-27 00:00:00', 7.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-28 00:00:00', 5.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-29 00:00:00', 5.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-04-30 00:00:00', 6.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-01 00:00:00', 10.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-02 00:00:00', 12.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-03 00:00:00', 11.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-04 00:00:00', 14.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-05 00:00:00', 11.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-06 00:00:00', 15.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-07 00:00:00', 14.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-08 00:00:00', 5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-09 00:00:00', 8.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-10 00:00:00', 10.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-11 00:00:00', 5.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-12 00:00:00', 4.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-13 00:00:00', 8.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-14 00:00:00', 10.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-15 00:00:00', 10.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-16 00:00:00', 7.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-17 00:00:00', 7.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-18 00:00:00', 8.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-19 00:00:00', 9.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-20 00:00:00', 12.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-21 00:00:00', 12.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-22 00:00:00', 10.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-23 00:00:00', 12.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-24 00:00:00', 15.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-25 00:00:00', 16.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-26 00:00:00', 16.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-27 00:00:00', 15.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-28 00:00:00', 17.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-29 00:00:00', 16.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-30 00:00:00', 16.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-05-31 00:00:00', 14.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-01 00:00:00', 9.94200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-02 00:00:00', 11.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-03 00:00:00', 14.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-04 00:00:00', 16.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-05 00:00:00', 18.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-06 00:00:00', 20.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-07 00:00:00', 20.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-08 00:00:00', 21.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-09 00:00:00', 22.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-10 00:00:00', 23.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-11 00:00:00', 22.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-12 00:00:00', 13.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-13 00:00:00', 13.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-14 00:00:00', 16.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-15 00:00:00', 17.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-16 00:00:00', 18.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-17 00:00:00', 21.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-18 00:00:00', 21.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-19 00:00:00', 22.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-20 00:00:00', 18.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-21 00:00:00', 21.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-22 00:00:00', 22.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-23 00:00:00', 22.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-24 00:00:00', 17.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-25 00:00:00', 15.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-26 00:00:00', 16.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-27 00:00:00', 18.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-28 00:00:00', 19.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-29 00:00:00', 21.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-06-30 00:00:00', 20.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-01 00:00:00', 22.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-02 00:00:00', 24.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-03 00:00:00', 24.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-04 00:00:00', 22.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-05 00:00:00', 21.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-06 00:00:00', 23.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-07 00:00:00', 24.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-08 00:00:00', 23.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-09 00:00:00', 24.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-10 00:00:00', 25.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-11 00:00:00', 23.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-12 00:00:00', 23.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-13 00:00:00', 21.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-14 00:00:00', 20.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-15 00:00:00', 22.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-16 00:00:00', 22.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-17 00:00:00', 23.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-18 00:00:00', 20.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-19 00:00:00', 18.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-20 00:00:00', 21.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-21 00:00:00', 22.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-22 00:00:00', 21.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-23 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-24 00:00:00', 22.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-25 00:00:00', 24.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-26 00:00:00', 24.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-27 00:00:00', 24.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-28 00:00:00', 24.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-29 00:00:00', 24.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-30 00:00:00', 23.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-07-31 00:00:00', 24.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-01 00:00:00', 25.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-02 00:00:00', 24.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-03 00:00:00', 22.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-04 00:00:00', 22.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-05 00:00:00', 22.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-06 00:00:00', 23.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-07 00:00:00', 21.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-08 00:00:00', 15.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-09 00:00:00', 17.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-10 00:00:00', 15.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-11 00:00:00', 17.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-12 00:00:00', 17.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-13 00:00:00', 17.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-14 00:00:00', 19.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-15 00:00:00', 18.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-16 00:00:00', 14.508000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-17 00:00:00', 16.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-18 00:00:00', 18.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-19 00:00:00', 20.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-20 00:00:00', 22.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-21 00:00:00', 23.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-22 00:00:00', 23.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-23 00:00:00', 20.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-24 00:00:00', 20.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-25 00:00:00', 20.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-26 00:00:00', 21.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-27 00:00:00', 21.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-28 00:00:00', 21.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-29 00:00:00', 21.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-30 00:00:00', 19.7549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-08-31 00:00:00', 17.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-01 00:00:00', 16.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-02 00:00:00', 16.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-03 00:00:00', 17.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-04 00:00:00', 14.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-05 00:00:00', 17.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-06 00:00:00', 18.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-07 00:00:00', 20.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-08 00:00:00', 19.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-09 00:00:00', 16.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-10 00:00:00', 9.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-11 00:00:00', 13.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-12 00:00:00', 14.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-13 00:00:00', 15.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-14 00:00:00', 15.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-15 00:00:00', 14.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-16 00:00:00', 17.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-17 00:00:00', 18.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-18 00:00:00', 17.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-19 00:00:00', 17.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-20 00:00:00', 18.0009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-21 00:00:00', 18.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-22 00:00:00', 20.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-23 00:00:00', 13.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-24 00:00:00', 12.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-25 00:00:00', 13.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-26 00:00:00', 12.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-27 00:00:00', 11.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-28 00:00:00', 12.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-29 00:00:00', 13.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-09-30 00:00:00', 14.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-01 00:00:00', 12.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-02 00:00:00', 14.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-03 00:00:00', 16.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-04 00:00:00', 16.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-05 00:00:00', 13.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-06 00:00:00', 13.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-07 00:00:00', 9.33100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-08 00:00:00', 8.98700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-09 00:00:00', 8.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-10 00:00:00', 0.575999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-11 00:00:00', -1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-12 00:00:00', 6.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-13 00:00:00', 5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-14 00:00:00', 7.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-15 00:00:00', 4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-16 00:00:00', 3.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-17 00:00:00', 4.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-18 00:00:00', 6.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-19 00:00:00', 8.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-20 00:00:00', 9.12800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-21 00:00:00', 5.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-22 00:00:00', 2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-23 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-24 00:00:00', 5.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-25 00:00:00', 8.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-26 00:00:00', 7.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-27 00:00:00', 7.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-28 00:00:00', 6.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-29 00:00:00', 5.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-30 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-10-31 00:00:00', 5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-01 00:00:00', 6.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-02 00:00:00', 4.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-03 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-04 00:00:00', -0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-05 00:00:00', -1.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-06 00:00:00', -0.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-07 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-08 00:00:00', 1.3059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-09 00:00:00', 2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-10 00:00:00', 3.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-11 00:00:00', 2.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-12 00:00:00', 2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-13 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-14 00:00:00', 2.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-15 00:00:00', 2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-16 00:00:00', 0.819999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-17 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-18 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-19 00:00:00', -0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-20 00:00:00', 0.658999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-21 00:00:00', 1.06700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-22 00:00:00', 1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-23 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-24 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-25 00:00:00', -1.03799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-26 00:00:00', -2.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-27 00:00:00', -0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-28 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-29 00:00:00', 4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-11-30 00:00:00', 5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-01 00:00:00', 2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-02 00:00:00', -1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-03 00:00:00', -0.171000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-04 00:00:00', 1.16999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-05 00:00:00', 0.781000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-06 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-07 00:00:00', 5.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-08 00:00:00', 7.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-09 00:00:00', 3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-10 00:00:00', 2.93899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-11 00:00:00', 1.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-12 00:00:00', 0.323000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-13 00:00:00', 0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-14 00:00:00', -4.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-15 00:00:00', -1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-16 00:00:00', -4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-17 00:00:00', -2.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-18 00:00:00', -3.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-19 00:00:00', -0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-20 00:00:00', -1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-21 00:00:00', -2.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-22 00:00:00', -0.711000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-23 00:00:00', 0.211999997496604919, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-24 00:00:00', -1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-25 00:00:00', -1.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-26 00:00:00', -2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-27 00:00:00', -4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-28 00:00:00', -3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-29 00:00:00', -2.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-30 00:00:00', -1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1980-12-31 00:00:00', -1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-01 00:00:00', -0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-02 00:00:00', -3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-03 00:00:00', -5.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-04 00:00:00', -3.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-05 00:00:00', -5.06400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-06 00:00:00', -4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-07 00:00:00', -3.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-08 00:00:00', -2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-09 00:00:00', -4.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-10 00:00:00', -3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-11 00:00:00', -0.640999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-12 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-13 00:00:00', -1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-14 00:00:00', -4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-15 00:00:00', -6.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-16 00:00:00', -4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-17 00:00:00', -1.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-18 00:00:00', -1.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-19 00:00:00', 1.6799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-20 00:00:00', -1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-21 00:00:00', -2.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-22 00:00:00', -2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-23 00:00:00', -5.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-24 00:00:00', -9.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-25 00:00:00', -4.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-26 00:00:00', -6.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-27 00:00:00', -2.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-28 00:00:00', -4.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-29 00:00:00', -6.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-30 00:00:00', -8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-01-31 00:00:00', -8.29599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-01 00:00:00', -4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-02 00:00:00', -6.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-03 00:00:00', -6.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-04 00:00:00', -7.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-05 00:00:00', -3.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-06 00:00:00', -1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-07 00:00:00', -0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-08 00:00:00', -2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-09 00:00:00', -1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-10 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-11 00:00:00', -1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-12 00:00:00', -2.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-13 00:00:00', -6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-14 00:00:00', -5.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-15 00:00:00', -2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-16 00:00:00', -3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-17 00:00:00', -2.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-18 00:00:00', -1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-19 00:00:00', -2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-20 00:00:00', -0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-21 00:00:00', 0.717000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-22 00:00:00', 0.764999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-23 00:00:00', -0.80699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-24 00:00:00', -6.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-25 00:00:00', -1.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-26 00:00:00', -3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-27 00:00:00', -4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-02-28 00:00:00', -6.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-01 00:00:00', -5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-02 00:00:00', -0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-03 00:00:00', 0.848999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-04 00:00:00', 1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-05 00:00:00', -2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-06 00:00:00', -1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-07 00:00:00', 1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-08 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-09 00:00:00', -1.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-10 00:00:00', -2.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-11 00:00:00', -0.74299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-12 00:00:00', 0.633000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-13 00:00:00', 1.86000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-14 00:00:00', 1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-15 00:00:00', 1.12000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-16 00:00:00', 0.342000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-17 00:00:00', 1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-18 00:00:00', -1.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-19 00:00:00', -0.11900000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-20 00:00:00', -2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-21 00:00:00', 0.901000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-22 00:00:00', 3.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-23 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-24 00:00:00', 2.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-25 00:00:00', 1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-26 00:00:00', 5.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-27 00:00:00', 2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-28 00:00:00', 2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-29 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-30 00:00:00', -1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-03-31 00:00:00', 0.768000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-01 00:00:00', 1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-02 00:00:00', 1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-03 00:00:00', -2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-04 00:00:00', -1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-05 00:00:00', 0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-06 00:00:00', 2.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-07 00:00:00', 1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-08 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-09 00:00:00', 3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-10 00:00:00', 1.79400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-11 00:00:00', 1.27499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-12 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-13 00:00:00', 3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-14 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-15 00:00:00', 1.20500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-16 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-17 00:00:00', 8.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-18 00:00:00', 9.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-19 00:00:00', 4.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-20 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-21 00:00:00', 4.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-22 00:00:00', 6.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-23 00:00:00', 9.11900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-24 00:00:00', 11.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-25 00:00:00', 8.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-26 00:00:00', 11.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-27 00:00:00', 9.54399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-28 00:00:00', 4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-29 00:00:00', 10.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-04-30 00:00:00', 7.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-01 00:00:00', 11.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-02 00:00:00', 13.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-03 00:00:00', 14.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-04 00:00:00', 6.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-05 00:00:00', 10.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-06 00:00:00', 11.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-07 00:00:00', 12.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-08 00:00:00', 6.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-09 00:00:00', 10.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-10 00:00:00', 11.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-11 00:00:00', 8.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-12 00:00:00', 12.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-13 00:00:00', 11.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-14 00:00:00', 6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-15 00:00:00', 12.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-16 00:00:00', 15.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-17 00:00:00', 16.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-18 00:00:00', 9.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-19 00:00:00', 6.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-20 00:00:00', 8.43299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-21 00:00:00', 11.5329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-22 00:00:00', 11.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-23 00:00:00', 14.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-24 00:00:00', 15.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-25 00:00:00', 13.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-26 00:00:00', 14.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-27 00:00:00', 14.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-28 00:00:00', 16.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-29 00:00:00', 15.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-30 00:00:00', 7.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-05-31 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-01 00:00:00', 7.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-02 00:00:00', 8.98700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-03 00:00:00', 10.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-04 00:00:00', 13.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-05 00:00:00', 17.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-06 00:00:00', 14.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-07 00:00:00', 10.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-08 00:00:00', 10.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-09 00:00:00', 10.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-10 00:00:00', 10.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-11 00:00:00', 10.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-12 00:00:00', 11.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-13 00:00:00', 12.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-14 00:00:00', 12.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-15 00:00:00', 15.6649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-16 00:00:00', 18.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-17 00:00:00', 19.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-18 00:00:00', 18.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-19 00:00:00', 19.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-20 00:00:00', 19.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-21 00:00:00', 17.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-22 00:00:00', 18.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-23 00:00:00', 17.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-24 00:00:00', 17.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-25 00:00:00', 15.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-26 00:00:00', 17.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-27 00:00:00', 17.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-28 00:00:00', 18.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-29 00:00:00', 19.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-06-30 00:00:00', 17.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-01 00:00:00', 18.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-02 00:00:00', 18.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-03 00:00:00', 17.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-04 00:00:00', 18.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-05 00:00:00', 20.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-06 00:00:00', 22.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-07 00:00:00', 21.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-08 00:00:00', 16.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-09 00:00:00', 16.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-10 00:00:00', 17.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-11 00:00:00', 21.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-12 00:00:00', 24.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-13 00:00:00', 27.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-14 00:00:00', 25.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-15 00:00:00', 23.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-16 00:00:00', 22.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-17 00:00:00', 20.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-18 00:00:00', 18.6760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-19 00:00:00', 18.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-20 00:00:00', 21.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-21 00:00:00', 23.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-22 00:00:00', 19.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-23 00:00:00', 12.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-24 00:00:00', 10.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-25 00:00:00', 13.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-26 00:00:00', 15.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-27 00:00:00', 17.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-28 00:00:00', 17.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-29 00:00:00', 17.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-30 00:00:00', 16.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-07-31 00:00:00', 17.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-01 00:00:00', 16.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-02 00:00:00', 17.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-03 00:00:00', 17.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-04 00:00:00', 19.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-05 00:00:00', 19.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-06 00:00:00', 21.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-07 00:00:00', 21.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-08 00:00:00', 19.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-09 00:00:00', 20.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-10 00:00:00', 21.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-11 00:00:00', 20.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-12 00:00:00', 18.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-13 00:00:00', 18.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-14 00:00:00', 19.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-15 00:00:00', 17.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-16 00:00:00', 18.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-17 00:00:00', 19.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-18 00:00:00', 18.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-19 00:00:00', 15.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-20 00:00:00', 15.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-21 00:00:00', 13.4530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-22 00:00:00', 13.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-23 00:00:00', 13.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-24 00:00:00', 15.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-25 00:00:00', 17.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-26 00:00:00', 17.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-27 00:00:00', 16.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-28 00:00:00', 15.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-29 00:00:00', 13.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-30 00:00:00', 15.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-08-31 00:00:00', 18.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-01 00:00:00', 18.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-02 00:00:00', 17.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-03 00:00:00', 16.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-04 00:00:00', 16.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-05 00:00:00', 15.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-06 00:00:00', 15.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-07 00:00:00', 15.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-08 00:00:00', 16.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-09 00:00:00', 15.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-10 00:00:00', 11.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-11 00:00:00', 11.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-12 00:00:00', 16.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-13 00:00:00', 17.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-14 00:00:00', 20.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-15 00:00:00', 20.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-16 00:00:00', 20.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-17 00:00:00', 19.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-18 00:00:00', 19.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-19 00:00:00', 18.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-20 00:00:00', 19.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-21 00:00:00', 17.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-22 00:00:00', 14.9429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-23 00:00:00', 5.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-24 00:00:00', 6.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-25 00:00:00', 8.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-26 00:00:00', 12.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-27 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-28 00:00:00', 13.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-29 00:00:00', 11.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-09-30 00:00:00', 9.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-01 00:00:00', 7.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-02 00:00:00', 7.64699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-03 00:00:00', 7.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-04 00:00:00', 7.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-05 00:00:00', 8.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-06 00:00:00', 6.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-07 00:00:00', 6.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-08 00:00:00', 7.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-09 00:00:00', 8.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-10 00:00:00', 4.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-11 00:00:00', 5.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-12 00:00:00', 7.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-13 00:00:00', 9.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-14 00:00:00', 3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-15 00:00:00', 5.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-16 00:00:00', 3.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-17 00:00:00', 7.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-18 00:00:00', 6.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-19 00:00:00', 3.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-20 00:00:00', 0.990999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-21 00:00:00', 5.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-22 00:00:00', 6.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-23 00:00:00', 4.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-24 00:00:00', 2.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-25 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-26 00:00:00', 4.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-27 00:00:00', 4.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-28 00:00:00', 2.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-29 00:00:00', 2.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-30 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-10-31 00:00:00', 5.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-01 00:00:00', 5.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-02 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-03 00:00:00', 4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-04 00:00:00', 5.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-05 00:00:00', 7.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-06 00:00:00', 8.22299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-07 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-08 00:00:00', 1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-09 00:00:00', 1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-10 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-11 00:00:00', 2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-12 00:00:00', 3.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-13 00:00:00', 2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-14 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-15 00:00:00', 1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-16 00:00:00', -1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-17 00:00:00', -0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-18 00:00:00', 0.846000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-19 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-20 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-21 00:00:00', 0.794000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-22 00:00:00', 0.676999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-23 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-24 00:00:00', -5.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-25 00:00:00', -5.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-26 00:00:00', -2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-27 00:00:00', -0.823000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-28 00:00:00', 0.966000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-29 00:00:00', -0.277000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-11-30 00:00:00', 0.639999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-01 00:00:00', -0.939999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-02 00:00:00', -4.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-03 00:00:00', -3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-04 00:00:00', -3.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-05 00:00:00', -3.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-06 00:00:00', -2.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-07 00:00:00', -1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-08 00:00:00', -2.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-09 00:00:00', -1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-10 00:00:00', -3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-11 00:00:00', -0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-12 00:00:00', -0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-13 00:00:00', -1.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-14 00:00:00', -1.08399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-15 00:00:00', -0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-16 00:00:00', -1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-17 00:00:00', -0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-18 00:00:00', 0.340999990701675415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-19 00:00:00', 0.428000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-20 00:00:00', -2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-21 00:00:00', -3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-22 00:00:00', -2.10100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-23 00:00:00', 0.0109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-24 00:00:00', -0.614000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-25 00:00:00', -2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-26 00:00:00', -1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-27 00:00:00', -3.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-28 00:00:00', -7.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-29 00:00:00', -4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-30 00:00:00', -4.27899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1981-12-31 00:00:00', -4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-01 00:00:00', -0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-02 00:00:00', -1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-03 00:00:00', -1.44599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-04 00:00:00', -0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-05 00:00:00', -0.114000000059604645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-06 00:00:00', 1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-07 00:00:00', 3.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-08 00:00:00', 1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-09 00:00:00', 0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-10 00:00:00', -0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-11 00:00:00', -1.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-12 00:00:00', -0.307999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-13 00:00:00', -5.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-14 00:00:00', -1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-15 00:00:00', -0.759999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-16 00:00:00', -1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-17 00:00:00', -0.166999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-18 00:00:00', -1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-19 00:00:00', -11.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-20 00:00:00', -10.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-21 00:00:00', -13.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-22 00:00:00', -15.7139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-23 00:00:00', -10.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-24 00:00:00', -8.79800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-25 00:00:00', -6.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-26 00:00:00', -8.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-27 00:00:00', -4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-28 00:00:00', -6.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-29 00:00:00', -2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-30 00:00:00', -4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-01-31 00:00:00', -5.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-01 00:00:00', -0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-02 00:00:00', -3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-03 00:00:00', -4.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-04 00:00:00', -2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-05 00:00:00', -1.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-06 00:00:00', -4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-07 00:00:00', -11.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-08 00:00:00', -7.37599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-09 00:00:00', -4.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-10 00:00:00', -6.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-11 00:00:00', -10.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-12 00:00:00', -8.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-13 00:00:00', -5.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-14 00:00:00', 0.0509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-15 00:00:00', -3.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-16 00:00:00', -7.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-17 00:00:00', -4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-18 00:00:00', -2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-19 00:00:00', -8.19699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-20 00:00:00', -12.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-21 00:00:00', -7.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-22 00:00:00', -6.23899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-23 00:00:00', -9.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-24 00:00:00', -5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-25 00:00:00', -2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-26 00:00:00', -1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-27 00:00:00', -2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-02-28 00:00:00', -2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-01 00:00:00', -3.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-02 00:00:00', -2.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-03 00:00:00', -0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-04 00:00:00', -4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-05 00:00:00', -7.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-06 00:00:00', -7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-07 00:00:00', -4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-08 00:00:00', -4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-09 00:00:00', -4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-10 00:00:00', -1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-11 00:00:00', -1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-12 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-13 00:00:00', -0.0610000006854534149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-14 00:00:00', -0.74299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-15 00:00:00', 0.962000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-16 00:00:00', -2.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-17 00:00:00', -2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-18 00:00:00', -1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-19 00:00:00', 0.699000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-20 00:00:00', -0.865999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-21 00:00:00', -4.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-22 00:00:00', -2.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-23 00:00:00', -0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-24 00:00:00', -0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-25 00:00:00', -0.00600000005215406418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-26 00:00:00', -1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-27 00:00:00', -0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-28 00:00:00', -0.990000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-29 00:00:00', -0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-30 00:00:00', -1.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-03-31 00:00:00', -1.8739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-01 00:00:00', -0.648999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-02 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-03 00:00:00', 0.412999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-04 00:00:00', -4.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-05 00:00:00', -1.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-06 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-07 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-08 00:00:00', 5.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-09 00:00:00', 6.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-10 00:00:00', 6.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-11 00:00:00', 4.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-12 00:00:00', 6.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-13 00:00:00', 7.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-14 00:00:00', 7.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-15 00:00:00', 6.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-16 00:00:00', 3.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-17 00:00:00', 6.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-18 00:00:00', 8.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-19 00:00:00', 10.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-20 00:00:00', 11.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-21 00:00:00', 10.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-22 00:00:00', 12.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-23 00:00:00', 11.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-24 00:00:00', 8.98499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-25 00:00:00', 10.5369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-26 00:00:00', 8.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-27 00:00:00', 8.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-28 00:00:00', 10.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-29 00:00:00', 10.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-04-30 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-01 00:00:00', 12.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-02 00:00:00', 14.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-03 00:00:00', 15.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-04 00:00:00', 16.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-05 00:00:00', 15.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-06 00:00:00', 13.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-07 00:00:00', 15.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-08 00:00:00', 14.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-09 00:00:00', 12.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-10 00:00:00', 9.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-11 00:00:00', 9.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-12 00:00:00', 8.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-13 00:00:00', 9.71800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-14 00:00:00', 8.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-15 00:00:00', 11.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-16 00:00:00', 13.7030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-17 00:00:00', 11.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-18 00:00:00', 12.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-19 00:00:00', 16.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-20 00:00:00', 17.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-21 00:00:00', 17.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-22 00:00:00', 13.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-23 00:00:00', 14.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-24 00:00:00', 14.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-25 00:00:00', 9.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-26 00:00:00', 9.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-27 00:00:00', 10.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-28 00:00:00', 10.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-29 00:00:00', 7.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-30 00:00:00', 10.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-05-31 00:00:00', 13.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-01 00:00:00', 14.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-02 00:00:00', 15.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-03 00:00:00', 14.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-04 00:00:00', 13.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-05 00:00:00', 17.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-06 00:00:00', 19.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-07 00:00:00', 17.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-08 00:00:00', 19.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-09 00:00:00', 20.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-10 00:00:00', 21.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-11 00:00:00', 21.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-12 00:00:00', 20.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-13 00:00:00', 21.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-14 00:00:00', 16.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-15 00:00:00', 17.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-16 00:00:00', 19.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-17 00:00:00', 16.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-18 00:00:00', 16.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-19 00:00:00', 16.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-20 00:00:00', 14.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-21 00:00:00', 18.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-22 00:00:00', 19.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-23 00:00:00', 20.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-24 00:00:00', 20.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-25 00:00:00', 20.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-26 00:00:00', 16.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-27 00:00:00', 18.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-28 00:00:00', 18.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-29 00:00:00', 19.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-06-30 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-01 00:00:00', 8.46399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-02 00:00:00', 13.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-03 00:00:00', 14.5710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-04 00:00:00', 15.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-05 00:00:00', 18.1399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-06 00:00:00', 15.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-07 00:00:00', 18.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-08 00:00:00', 18.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-09 00:00:00', 18.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-10 00:00:00', 18.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-11 00:00:00', 19.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-12 00:00:00', 16.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-13 00:00:00', 15.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-14 00:00:00', 18.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-15 00:00:00', 19.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-16 00:00:00', 21.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-17 00:00:00', 21.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-18 00:00:00', 22.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-19 00:00:00', 23.7240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-20 00:00:00', 23.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-21 00:00:00', 23.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-22 00:00:00', 23.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-23 00:00:00', 23.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-24 00:00:00', 22.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-25 00:00:00', 22.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-26 00:00:00', 22.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-27 00:00:00', 22.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-28 00:00:00', 24.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-29 00:00:00', 22.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-30 00:00:00', 24.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-07-31 00:00:00', 26.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-01 00:00:00', 29.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-02 00:00:00', 28.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-03 00:00:00', 27.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-04 00:00:00', 26.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-05 00:00:00', 27.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-06 00:00:00', 27.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-07 00:00:00', 26.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-08 00:00:00', 26.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-09 00:00:00', 26.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-10 00:00:00', 23.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-11 00:00:00', 16.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-12 00:00:00', 17.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-13 00:00:00', 21.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-14 00:00:00', 20.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-15 00:00:00', 19.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-16 00:00:00', 17.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-17 00:00:00', 19.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-18 00:00:00', 20.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-19 00:00:00', 19.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-20 00:00:00', 18.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-21 00:00:00', 18.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-22 00:00:00', 17.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-23 00:00:00', 15.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-24 00:00:00', 10.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-25 00:00:00', 10.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-26 00:00:00', 11.9530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-27 00:00:00', 15.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-28 00:00:00', 17.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-29 00:00:00', 17.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-30 00:00:00', 16.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-08-31 00:00:00', 17.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-01 00:00:00', 18.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-02 00:00:00', 17.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-03 00:00:00', 16.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-04 00:00:00', 16.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-05 00:00:00', 17.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-06 00:00:00', 15.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-07 00:00:00', 15.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-08 00:00:00', 16.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-09 00:00:00', 16.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-10 00:00:00', 16.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-11 00:00:00', 16.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-12 00:00:00', 15.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-13 00:00:00', 14.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-14 00:00:00', 15.564000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-15 00:00:00', 15.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-16 00:00:00', 14.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-17 00:00:00', 8.31000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-18 00:00:00', 12.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-19 00:00:00', 9.41899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-20 00:00:00', 7.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-21 00:00:00', 7.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-22 00:00:00', 8.85999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-23 00:00:00', 9.50100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-24 00:00:00', 10.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-25 00:00:00', 10.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-26 00:00:00', 9.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-27 00:00:00', 9.46100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-28 00:00:00', 10.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-29 00:00:00', 8.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-09-30 00:00:00', 7.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-01 00:00:00', 10.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-02 00:00:00', 11.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-03 00:00:00', 12.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-04 00:00:00', 8.82900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-05 00:00:00', 11.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-06 00:00:00', 7.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-07 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-08 00:00:00', 5.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-09 00:00:00', 7.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-10 00:00:00', 11.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-11 00:00:00', 6.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-12 00:00:00', 8.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-13 00:00:00', 9.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-14 00:00:00', 10.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-15 00:00:00', 11.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-16 00:00:00', 10.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-17 00:00:00', 9.52999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-18 00:00:00', 9.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-19 00:00:00', 9.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-20 00:00:00', 9.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-21 00:00:00', 10.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-22 00:00:00', 8.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-23 00:00:00', 4.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-24 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-25 00:00:00', -3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-26 00:00:00', -9.25300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-27 00:00:00', -1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-28 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-29 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-30 00:00:00', 5.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-10-31 00:00:00', 1.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-01 00:00:00', 1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-02 00:00:00', -1.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-03 00:00:00', -1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-04 00:00:00', 0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-05 00:00:00', 0.635999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-06 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-07 00:00:00', 4.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-08 00:00:00', 4.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-09 00:00:00', 3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-10 00:00:00', 2.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-11 00:00:00', -1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-12 00:00:00', -0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-13 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-14 00:00:00', -0.523000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-15 00:00:00', -6.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-16 00:00:00', -4.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-17 00:00:00', -3.56999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-18 00:00:00', -5.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-19 00:00:00', -4.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-20 00:00:00', -6.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-21 00:00:00', -5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-22 00:00:00', -1.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-23 00:00:00', -2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-24 00:00:00', -2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-25 00:00:00', -3.81800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-26 00:00:00', -1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-27 00:00:00', -1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-28 00:00:00', -2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-29 00:00:00', -4.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-11-30 00:00:00', -6.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-01 00:00:00', -8.42800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-02 00:00:00', -7.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-03 00:00:00', -3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-04 00:00:00', -2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-05 00:00:00', -3.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-06 00:00:00', -4.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-07 00:00:00', -8.29599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-08 00:00:00', -2.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-09 00:00:00', -9.04800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-10 00:00:00', -6.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-11 00:00:00', -1.61699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-12 00:00:00', -0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-13 00:00:00', -1.95200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-14 00:00:00', -0.714999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-15 00:00:00', 0.00400000018998980522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-16 00:00:00', -0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-17 00:00:00', -3.33999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-18 00:00:00', -1.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-19 00:00:00', -1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-20 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-21 00:00:00', 0.837999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-22 00:00:00', -1.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-23 00:00:00', -1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-24 00:00:00', -0.449000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-25 00:00:00', 0.723999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-26 00:00:00', 0.337999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-27 00:00:00', -2.44300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-28 00:00:00', -4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-29 00:00:00', -6.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-30 00:00:00', -4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1982-12-31 00:00:00', -4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-01 00:00:00', -2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-02 00:00:00', -0.801999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-03 00:00:00', -2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-04 00:00:00', -2.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-05 00:00:00', -5.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-06 00:00:00', -3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-07 00:00:00', -6.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-08 00:00:00', -11.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-09 00:00:00', -10.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-10 00:00:00', -1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-11 00:00:00', -7.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-12 00:00:00', -7.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-13 00:00:00', -5.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-14 00:00:00', -10.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-15 00:00:00', -6.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-16 00:00:00', -0.456999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-17 00:00:00', -3.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-18 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-19 00:00:00', -0.00700000021606683731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-20 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-21 00:00:00', 3.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-22 00:00:00', 0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-23 00:00:00', -0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-24 00:00:00', 2.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-25 00:00:00', 0.456000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-26 00:00:00', -6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-27 00:00:00', -8.16399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-28 00:00:00', -9.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-29 00:00:00', -6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-30 00:00:00', -6.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-01-31 00:00:00', -5.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-01 00:00:00', -5.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-02 00:00:00', -4.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-03 00:00:00', -3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-04 00:00:00', -1.90699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-05 00:00:00', -0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-06 00:00:00', -1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-07 00:00:00', -2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-08 00:00:00', -2.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-09 00:00:00', -4.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-10 00:00:00', -3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-11 00:00:00', -3.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-12 00:00:00', -2.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-13 00:00:00', -3.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-14 00:00:00', -1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-15 00:00:00', -0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-16 00:00:00', -1.31700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-17 00:00:00', -1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-18 00:00:00', 0.107000000774860382, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-19 00:00:00', -1.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-20 00:00:00', -1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-21 00:00:00', -1.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-22 00:00:00', -0.976000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-23 00:00:00', -4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-24 00:00:00', -7.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-25 00:00:00', -3.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-26 00:00:00', -3.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-27 00:00:00', -2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-02-28 00:00:00', -3.55699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-01 00:00:00', -6.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-02 00:00:00', -5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-03 00:00:00', -4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-04 00:00:00', -2.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-05 00:00:00', 0.848999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-06 00:00:00', -0.0450000017881393433, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-07 00:00:00', 0.300999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-08 00:00:00', -3.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-09 00:00:00', -1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-10 00:00:00', -0.999000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-11 00:00:00', -2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-12 00:00:00', -1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-13 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-14 00:00:00', -1.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-15 00:00:00', -2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-16 00:00:00', -1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-17 00:00:00', -3.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-18 00:00:00', -4.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-19 00:00:00', -5.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-20 00:00:00', -5.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-21 00:00:00', -4.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-22 00:00:00', -1.37699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-23 00:00:00', -0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-24 00:00:00', -0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-25 00:00:00', -2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-26 00:00:00', -4.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-27 00:00:00', -4.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-28 00:00:00', -3.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-29 00:00:00', -1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-30 00:00:00', -0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-03-31 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-01 00:00:00', 2.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-02 00:00:00', 3.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-03 00:00:00', 4.62099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-04 00:00:00', 4.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-05 00:00:00', 2.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-06 00:00:00', 4.35799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-07 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-08 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-09 00:00:00', 0.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-10 00:00:00', 2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-11 00:00:00', 4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-12 00:00:00', 1.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-13 00:00:00', -0.0399999991059303284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-14 00:00:00', 0.680000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-15 00:00:00', 1.47200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-16 00:00:00', 0.437000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-17 00:00:00', 1.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-18 00:00:00', 4.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-19 00:00:00', 7.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-20 00:00:00', 8.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-21 00:00:00', 8.78199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-22 00:00:00', 8.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-23 00:00:00', 9.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-24 00:00:00', 8.59500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-25 00:00:00', 10.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-26 00:00:00', 7.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-27 00:00:00', 2.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-28 00:00:00', 7.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-29 00:00:00', 2.9849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-04-30 00:00:00', 0.381999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-01 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-02 00:00:00', 9.22500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-03 00:00:00', 9.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-04 00:00:00', 5.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-05 00:00:00', 10.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-06 00:00:00', 14.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-07 00:00:00', 12.0469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-08 00:00:00', 9.86699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-09 00:00:00', 14.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-10 00:00:00', 11.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-11 00:00:00', 9.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-12 00:00:00', 12.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-13 00:00:00', 10.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-14 00:00:00', 12.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-15 00:00:00', 13.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-16 00:00:00', 14.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-17 00:00:00', 14.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-18 00:00:00', 14.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-19 00:00:00', 13.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-20 00:00:00', 13.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-21 00:00:00', 12.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-22 00:00:00', 12.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-23 00:00:00', 13.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-24 00:00:00', 14.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-25 00:00:00', 15.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-26 00:00:00', 15.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-27 00:00:00', 14.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-28 00:00:00', 14.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-29 00:00:00', 14.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-30 00:00:00', 11.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-05-31 00:00:00', 6.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-01 00:00:00', 8.62100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-02 00:00:00', 11.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-03 00:00:00', 13.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-04 00:00:00', 14.4980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-05 00:00:00', 15.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-06 00:00:00', 14.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-07 00:00:00', 13.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-08 00:00:00', 13.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-09 00:00:00', 12.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-10 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-11 00:00:00', 17.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-12 00:00:00', 18.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-13 00:00:00', 20.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-14 00:00:00', 17.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-15 00:00:00', 16.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-16 00:00:00', 15.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-17 00:00:00', 15.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-18 00:00:00', 16.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-19 00:00:00', 18.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-20 00:00:00', 19.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-21 00:00:00', 20.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-22 00:00:00', 21.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-23 00:00:00', 22.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-24 00:00:00', 23.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-25 00:00:00', 22.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-26 00:00:00', 22.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-27 00:00:00', 22.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-28 00:00:00', 22.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-29 00:00:00', 23.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-06-30 00:00:00', 24.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-01 00:00:00', 21.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-02 00:00:00', 17.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-03 00:00:00', 16.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-04 00:00:00', 18.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-05 00:00:00', 17.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-06 00:00:00', 17.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-07 00:00:00', 16.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-08 00:00:00', 18.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-09 00:00:00', 20.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-10 00:00:00', 19.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-11 00:00:00', 18.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-12 00:00:00', 21.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-13 00:00:00', 21.9099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-14 00:00:00', 22.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-15 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-16 00:00:00', 21.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-17 00:00:00', 23.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-18 00:00:00', 21.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-19 00:00:00', 19.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-20 00:00:00', 22.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-21 00:00:00', 25.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-22 00:00:00', 27.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-23 00:00:00', 26.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-24 00:00:00', 26.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-25 00:00:00', 25.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-26 00:00:00', 23.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-27 00:00:00', 24.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-28 00:00:00', 28.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-29 00:00:00', 30.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-30 00:00:00', 30.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-07-31 00:00:00', 29.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-01 00:00:00', 26.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-02 00:00:00', 25.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-03 00:00:00', 25.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-04 00:00:00', 26.4880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-05 00:00:00', 25.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-06 00:00:00', 23.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-07 00:00:00', 17.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-08 00:00:00', 19.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-09 00:00:00', 20.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-10 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-11 00:00:00', 21.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-12 00:00:00', 21.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-13 00:00:00', 23.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-14 00:00:00', 22.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-15 00:00:00', 25.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-16 00:00:00', 23.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-17 00:00:00', 24.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-18 00:00:00', 24.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-19 00:00:00', 24.7649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-20 00:00:00', 23.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-21 00:00:00', 22.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-22 00:00:00', 22.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-23 00:00:00', 24.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-24 00:00:00', 24.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-25 00:00:00', 23.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-26 00:00:00', 22.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-27 00:00:00', 18.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-28 00:00:00', 20.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-29 00:00:00', 23.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-30 00:00:00', 25.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-08-31 00:00:00', 25.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-01 00:00:00', 13.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-03 00:00:00', 10.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-05 00:00:00', 11.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-07 00:00:00', 12.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-09 00:00:00', 14.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-11 00:00:00', 17.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-13 00:00:00', 12.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-15 00:00:00', 9.92800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-17 00:00:00', 8.18900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-19 00:00:00', 10.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-21 00:00:00', 12.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-23 00:00:00', 12.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-25 00:00:00', 10.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-27 00:00:00', 3.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-29 00:00:00', 6.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-09-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-01 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-03 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-05 00:00:00', 3.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-07 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-09 00:00:00', 2.84500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-11 00:00:00', 2.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-13 00:00:00', 5.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-15 00:00:00', 6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-17 00:00:00', 6.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-19 00:00:00', 5.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-21 00:00:00', 5.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-23 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-25 00:00:00', 8.12899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-27 00:00:00', 9.41399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-29 00:00:00', 5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-30 00:00:00', 7.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-10-31 00:00:00', 8.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-01 00:00:00', 10.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-02 00:00:00', 5.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-03 00:00:00', 0.328999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-04 00:00:00', 0.0250000003725290298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-05 00:00:00', -4.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-06 00:00:00', 0.0320000015199184418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-07 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-08 00:00:00', 2.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-09 00:00:00', -0.284000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-10 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-11 00:00:00', 3.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-12 00:00:00', 1.90900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-13 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-14 00:00:00', 5.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-15 00:00:00', 4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-16 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-17 00:00:00', 0.805999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-18 00:00:00', 1.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-19 00:00:00', 1.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-20 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-21 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-22 00:00:00', 3.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-23 00:00:00', 2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-24 00:00:00', 1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-25 00:00:00', 1.81400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-26 00:00:00', 0.722000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-27 00:00:00', -0.702000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-28 00:00:00', 3.33100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-29 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-11-30 00:00:00', 2.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-01 00:00:00', 1.74100005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-02 00:00:00', 0.546000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-03 00:00:00', -1.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-04 00:00:00', -3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-05 00:00:00', -2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-06 00:00:00', -2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-07 00:00:00', -0.735000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-08 00:00:00', 0.898999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-09 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-10 00:00:00', -0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-11 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-12 00:00:00', 1.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-13 00:00:00', 0.521000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-14 00:00:00', -1.9309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-15 00:00:00', -1.18200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-16 00:00:00', -8.51500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-17 00:00:00', -8.97000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-18 00:00:00', -10.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-19 00:00:00', -7.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-20 00:00:00', -7.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-21 00:00:00', -7.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-22 00:00:00', -8.37899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-23 00:00:00', -6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-24 00:00:00', -7.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-25 00:00:00', -8.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-26 00:00:00', -6.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-27 00:00:00', -1.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-28 00:00:00', -4.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-29 00:00:00', -5.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-30 00:00:00', -5.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1983-12-31 00:00:00', -6.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-01 00:00:00', -7.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-02 00:00:00', -2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-03 00:00:00', -6.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-04 00:00:00', -6.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-05 00:00:00', -9.83100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-06 00:00:00', -4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-07 00:00:00', -2.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-08 00:00:00', -3.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-09 00:00:00', -3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-10 00:00:00', -3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-11 00:00:00', -5.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-12 00:00:00', -5.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-13 00:00:00', -4.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-14 00:00:00', -4.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-15 00:00:00', -6.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-16 00:00:00', -7.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-17 00:00:00', -5.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-18 00:00:00', -7.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-19 00:00:00', -8.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-20 00:00:00', -7.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-21 00:00:00', -10.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-22 00:00:00', -9.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-23 00:00:00', -8.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-24 00:00:00', -7.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-25 00:00:00', -7.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-26 00:00:00', -7.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-27 00:00:00', -8.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-28 00:00:00', -8.49400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-29 00:00:00', -4.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-30 00:00:00', -3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-01-31 00:00:00', -5.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-01 00:00:00', -9.77400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-02 00:00:00', -8.47099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-03 00:00:00', -11.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-04 00:00:00', -12.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-05 00:00:00', -9.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-06 00:00:00', -12.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-07 00:00:00', -13.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-08 00:00:00', -7.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-09 00:00:00', -4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-10 00:00:00', -6.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-11 00:00:00', -9.16399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-12 00:00:00', -5.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-13 00:00:00', -0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-14 00:00:00', -0.202000007033348083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-15 00:00:00', -4.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-16 00:00:00', -9.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-17 00:00:00', -10.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-18 00:00:00', -15.241999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-19 00:00:00', -15.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-20 00:00:00', -16.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-21 00:00:00', -15.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-22 00:00:00', -11.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-23 00:00:00', -9.68700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-24 00:00:00', -5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-25 00:00:00', -6.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-26 00:00:00', -9.49699974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-27 00:00:00', -4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-28 00:00:00', -5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-02-29 00:00:00', -2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-01 00:00:00', -2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-02 00:00:00', -0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-03 00:00:00', -0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-04 00:00:00', -4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-05 00:00:00', -7.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-06 00:00:00', -4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-07 00:00:00', -2.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-08 00:00:00', -1.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-09 00:00:00', 1.83399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-10 00:00:00', -6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-11 00:00:00', -7.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-12 00:00:00', -0.978999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-13 00:00:00', 1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-14 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-15 00:00:00', 0.890999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-16 00:00:00', 0.80699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-17 00:00:00', 0.709999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-18 00:00:00', -3.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-19 00:00:00', 0.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-20 00:00:00', 1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-21 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-22 00:00:00', 1.07799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-23 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-24 00:00:00', 3.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-25 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-26 00:00:00', 1.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-27 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-28 00:00:00', 1.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-29 00:00:00', -0.458999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-30 00:00:00', 0.878000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-03-31 00:00:00', 0.958999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-01 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-02 00:00:00', 1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-03 00:00:00', -0.27000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-04 00:00:00', -0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-05 00:00:00', -0.916000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-06 00:00:00', 0.825999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-07 00:00:00', -0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-08 00:00:00', 0.368000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-09 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-10 00:00:00', 6.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-11 00:00:00', 7.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-12 00:00:00', 8.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-13 00:00:00', 3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-14 00:00:00', 3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-15 00:00:00', 5.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-16 00:00:00', 9.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-17 00:00:00', 10.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-18 00:00:00', 11.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-19 00:00:00', 5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-20 00:00:00', 0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-21 00:00:00', 7.24599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-22 00:00:00', 11.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-23 00:00:00', 13.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-24 00:00:00', 11.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-25 00:00:00', 14.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-26 00:00:00', 10.6920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-27 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-28 00:00:00', 6.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-29 00:00:00', 6.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-04-30 00:00:00', 9.12100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-01 00:00:00', 10.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-02 00:00:00', 13.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-03 00:00:00', 4.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-04 00:00:00', 8.98700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-05 00:00:00', 12.744999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-06 00:00:00', 11.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-07 00:00:00', 9.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-08 00:00:00', 6.31199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-09 00:00:00', 8.81000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-10 00:00:00', 11.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-11 00:00:00', 10.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-12 00:00:00', 7.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-13 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-14 00:00:00', 7.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-15 00:00:00', 6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-16 00:00:00', 6.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-17 00:00:00', 10.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-18 00:00:00', 10.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-19 00:00:00', 9.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-20 00:00:00', 9.37600040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-21 00:00:00', 11.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-22 00:00:00', 14.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-23 00:00:00', 8.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-24 00:00:00', 12.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-25 00:00:00', 12.6160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-26 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-27 00:00:00', 14.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-28 00:00:00', 15.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-29 00:00:00', 18.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-30 00:00:00', 21.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-05-31 00:00:00', 22.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-01 00:00:00', 18.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-02 00:00:00', 16.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-03 00:00:00', 15.9119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-04 00:00:00', 17.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-05 00:00:00', 16.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-06 00:00:00', 17.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-07 00:00:00', 17.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-08 00:00:00', 17.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-09 00:00:00', 18.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-10 00:00:00', 18.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-11 00:00:00', 16.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-12 00:00:00', 19.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-13 00:00:00', 21.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-14 00:00:00', 18.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-15 00:00:00', 21.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-16 00:00:00', 17.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-17 00:00:00', 16.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-18 00:00:00', 16.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-19 00:00:00', 16.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-20 00:00:00', 16.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-21 00:00:00', 18.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-22 00:00:00', 22.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-23 00:00:00', 24.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-24 00:00:00', 24.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-25 00:00:00', 24.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-26 00:00:00', 22.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-27 00:00:00', 20.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-28 00:00:00', 17.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-29 00:00:00', 16.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-06-30 00:00:00', 19.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-01 00:00:00', 18.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-02 00:00:00', 20.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-03 00:00:00', 19.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-04 00:00:00', 21.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-05 00:00:00', 23.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-06 00:00:00', 23.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-07 00:00:00', 22.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-08 00:00:00', 21.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-09 00:00:00', 24.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-10 00:00:00', 23.7479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-11 00:00:00', 24.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-12 00:00:00', 25.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-13 00:00:00', 25.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-14 00:00:00', 25.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-15 00:00:00', 24.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-16 00:00:00', 23.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-17 00:00:00', 24.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-18 00:00:00', 25.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-19 00:00:00', 25.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-20 00:00:00', 22.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-21 00:00:00', 21.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-22 00:00:00', 23.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-23 00:00:00', 23.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-24 00:00:00', 23.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-25 00:00:00', 22.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-26 00:00:00', 23.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-27 00:00:00', 24.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-28 00:00:00', 24.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-29 00:00:00', 24.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-30 00:00:00', 23.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-07-31 00:00:00', 23.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-01 00:00:00', 26.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-02 00:00:00', 26.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-03 00:00:00', 26.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-04 00:00:00', 26.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-05 00:00:00', 25.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-06 00:00:00', 24.76300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-07 00:00:00', 25.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-08 00:00:00', 26.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-09 00:00:00', 26.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-10 00:00:00', 23.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-11 00:00:00', 25.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-12 00:00:00', 23.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-13 00:00:00', 22.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-14 00:00:00', 24.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-15 00:00:00', 23.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-16 00:00:00', 24.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-17 00:00:00', 25.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-18 00:00:00', 26.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-19 00:00:00', 26.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-20 00:00:00', 27.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-21 00:00:00', 25.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-22 00:00:00', 23.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-23 00:00:00', 24.6819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-24 00:00:00', 24.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-25 00:00:00', 24.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-26 00:00:00', 23.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-27 00:00:00', 23.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-28 00:00:00', 24.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-29 00:00:00', 24.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-30 00:00:00', 24.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-08-31 00:00:00', 22.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-01 00:00:00', 20.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-02 00:00:00', 18.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-03 00:00:00', 18.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-04 00:00:00', 18.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-05 00:00:00', 16.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-06 00:00:00', 12.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-07 00:00:00', 11.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-08 00:00:00', 13.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-09 00:00:00', 16.4459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-10 00:00:00', 18.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-11 00:00:00', 16.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-12 00:00:00', 18.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-13 00:00:00', 17.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-14 00:00:00', 16.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-15 00:00:00', 16.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-16 00:00:00', 16.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-17 00:00:00', 16.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-18 00:00:00', 11.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-19 00:00:00', 8.15499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-20 00:00:00', 10.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-21 00:00:00', 12.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-22 00:00:00', 11.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-23 00:00:00', 11.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-24 00:00:00', 12.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-25 00:00:00', 13.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-26 00:00:00', 13.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-27 00:00:00', 11.8730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-28 00:00:00', 13.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-29 00:00:00', 14.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-09-30 00:00:00', 13.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-01 00:00:00', 12.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-02 00:00:00', 10.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-03 00:00:00', 11.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-04 00:00:00', 10.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-05 00:00:00', 10.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-06 00:00:00', 9.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-07 00:00:00', 10.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-08 00:00:00', 4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-09 00:00:00', -0.564999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-10 00:00:00', 7.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-11 00:00:00', 7.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-12 00:00:00', 5.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-13 00:00:00', 3.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-14 00:00:00', 6.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-15 00:00:00', 7.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-16 00:00:00', 8.55099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-17 00:00:00', 9.96800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-18 00:00:00', 8.79599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-19 00:00:00', 12.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-20 00:00:00', 14.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-21 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-22 00:00:00', -0.857999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-23 00:00:00', 5.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-24 00:00:00', 6.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-25 00:00:00', 4.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-26 00:00:00', 3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-27 00:00:00', 1.7489999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-28 00:00:00', 1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-29 00:00:00', -0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-30 00:00:00', 2.91899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-10-31 00:00:00', 5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-01 00:00:00', 4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-02 00:00:00', 5.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-03 00:00:00', 5.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-04 00:00:00', 3.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-05 00:00:00', 7.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-06 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-07 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-08 00:00:00', 1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-09 00:00:00', -0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-10 00:00:00', 0.777999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-11 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-12 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-13 00:00:00', 0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-14 00:00:00', 0.611000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-15 00:00:00', -0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-16 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-17 00:00:00', -2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-18 00:00:00', 0.499000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-19 00:00:00', 0.55699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-20 00:00:00', -2.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-21 00:00:00', -1.86699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-22 00:00:00', -3.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-23 00:00:00', -4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-24 00:00:00', -1.19599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-25 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-26 00:00:00', 0.619000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-27 00:00:00', -1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-28 00:00:00', 0.321000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-29 00:00:00', 0.705999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-11-30 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-01 00:00:00', -4.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-02 00:00:00', -8.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-03 00:00:00', -2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-04 00:00:00', -0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-05 00:00:00', -5.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-06 00:00:00', -6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-07 00:00:00', -0.998000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-08 00:00:00', -2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-09 00:00:00', -6.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-10 00:00:00', -5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-11 00:00:00', -3.65000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-12 00:00:00', -3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-13 00:00:00', -4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-14 00:00:00', -1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-15 00:00:00', -2.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-16 00:00:00', -6.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-17 00:00:00', -7.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-18 00:00:00', -8.26299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-19 00:00:00', -10.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-20 00:00:00', -10.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-21 00:00:00', -12.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-22 00:00:00', -12.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-23 00:00:00', -10.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-24 00:00:00', -11.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-25 00:00:00', -10.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-26 00:00:00', -10.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-27 00:00:00', -8.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-28 00:00:00', -8.58800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-29 00:00:00', -8.31000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-30 00:00:00', -10.8690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1984-12-31 00:00:00', -9.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-01 00:00:00', -11.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-02 00:00:00', -7.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-03 00:00:00', -5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-04 00:00:00', -5.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-05 00:00:00', -8.03400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-06 00:00:00', -7.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-07 00:00:00', -5.6939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-08 00:00:00', -5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-09 00:00:00', -3.89199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-10 00:00:00', -3.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-11 00:00:00', -3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-12 00:00:00', -2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-13 00:00:00', -3.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-14 00:00:00', -5.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-15 00:00:00', -5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-16 00:00:00', -3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-17 00:00:00', -4.71999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-18 00:00:00', -6.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-19 00:00:00', -2.67499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-20 00:00:00', -6.99700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-21 00:00:00', -2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-22 00:00:00', -1.9989999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-23 00:00:00', -2.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-24 00:00:00', -1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-25 00:00:00', -5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-26 00:00:00', -4.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-27 00:00:00', -1.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-28 00:00:00', -3.85199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-29 00:00:00', -3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-30 00:00:00', 0.151999995112419128, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-01-31 00:00:00', -0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-01 00:00:00', -3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-02 00:00:00', -0.238000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-03 00:00:00', -1.92900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-04 00:00:00', -3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-05 00:00:00', -4.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-06 00:00:00', -2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-07 00:00:00', -5.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-08 00:00:00', -9.87199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-09 00:00:00', -4.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-10 00:00:00', -6.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-11 00:00:00', -5.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-12 00:00:00', -1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-13 00:00:00', -0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-14 00:00:00', -0.314999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-15 00:00:00', -0.0140000004321336746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-16 00:00:00', 1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-17 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-18 00:00:00', -3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-19 00:00:00', -3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-20 00:00:00', -1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-21 00:00:00', 0.00800000037997961044, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-22 00:00:00', 0.626999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-23 00:00:00', -1.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-24 00:00:00', -5.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-25 00:00:00', -3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-26 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-27 00:00:00', 1.65400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-02-28 00:00:00', -5.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-01 00:00:00', -2.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-02 00:00:00', -2.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-03 00:00:00', -3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-04 00:00:00', -4.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-05 00:00:00', -8.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-06 00:00:00', -10.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-07 00:00:00', -3.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-08 00:00:00', -2.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-09 00:00:00', -7.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-10 00:00:00', -8.95600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-11 00:00:00', -9.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-12 00:00:00', -8.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-13 00:00:00', -3.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-14 00:00:00', -3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-15 00:00:00', -5.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-16 00:00:00', -2.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-17 00:00:00', -3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-18 00:00:00', -1.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-19 00:00:00', 0.773000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-20 00:00:00', 1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-21 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-22 00:00:00', 1.24399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-23 00:00:00', 1.21200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-24 00:00:00', 0.898000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-25 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-26 00:00:00', -0.677999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-27 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-28 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-29 00:00:00', -0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-30 00:00:00', 0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-03-31 00:00:00', 2.35500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-01 00:00:00', 3.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-02 00:00:00', 1.91600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-03 00:00:00', 0.828000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-04 00:00:00', 1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-05 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-06 00:00:00', 0.675999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-07 00:00:00', 0.972000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-08 00:00:00', -0.0320000015199184418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-09 00:00:00', 0.189999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-10 00:00:00', 1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-11 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-12 00:00:00', 1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-13 00:00:00', 3.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-14 00:00:00', 2.97799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-15 00:00:00', 7.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-16 00:00:00', 3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-17 00:00:00', 0.426999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-18 00:00:00', 3.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-19 00:00:00', 8.83800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-20 00:00:00', 11.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-21 00:00:00', 10.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-22 00:00:00', 10.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-23 00:00:00', 11.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-24 00:00:00', 13.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-25 00:00:00', 15.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-26 00:00:00', 14.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-27 00:00:00', 11.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-28 00:00:00', 10.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-29 00:00:00', 12.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-04-30 00:00:00', 6.96299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-01 00:00:00', 3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-02 00:00:00', 3.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-03 00:00:00', 8.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-04 00:00:00', 8.94699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-05 00:00:00', 10.8319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-06 00:00:00', 10.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-07 00:00:00', 10.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-08 00:00:00', 8.46399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-09 00:00:00', 8.09500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-10 00:00:00', 7.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-11 00:00:00', 8.87800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-12 00:00:00', 8.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-13 00:00:00', 7.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-14 00:00:00', 9.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-15 00:00:00', 10.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-16 00:00:00', 12.5950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-17 00:00:00', 14.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-18 00:00:00', 16.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-19 00:00:00', 16.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-20 00:00:00', 14.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-21 00:00:00', 15.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-22 00:00:00', 16.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-23 00:00:00', 11.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-24 00:00:00', 9.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-25 00:00:00', 10.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-26 00:00:00', 12.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-27 00:00:00', 14.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-28 00:00:00', 14.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-29 00:00:00', 15.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-30 00:00:00', 13.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-05-31 00:00:00', 16.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-01 00:00:00', 15.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-02 00:00:00', 16.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-03 00:00:00', 17.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-04 00:00:00', 19.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-05 00:00:00', 18.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-06 00:00:00', 15.9530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-07 00:00:00', 16.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-08 00:00:00', 18.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-09 00:00:00', 17.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-10 00:00:00', 15.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-11 00:00:00', 14.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-12 00:00:00', 17.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-13 00:00:00', 18.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-14 00:00:00', 18.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-15 00:00:00', 19.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-16 00:00:00', 19.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-17 00:00:00', 19.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-18 00:00:00', 17.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-19 00:00:00', 18.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-20 00:00:00', 19.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-21 00:00:00', 18.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-22 00:00:00', 20.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-23 00:00:00', 21.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-24 00:00:00', 21.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-25 00:00:00', 21.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-26 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-27 00:00:00', 22.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-28 00:00:00', 22.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-29 00:00:00', 21.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-06-30 00:00:00', 19.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-01 00:00:00', 19.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-02 00:00:00', 20.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-03 00:00:00', 22.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-04 00:00:00', 24.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-05 00:00:00', 24.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-06 00:00:00', 24.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-07 00:00:00', 22.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-08 00:00:00', 22.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-09 00:00:00', 26.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-10 00:00:00', 26.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-11 00:00:00', 24.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-12 00:00:00', 24.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-13 00:00:00', 22.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-14 00:00:00', 22.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-15 00:00:00', 25.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-16 00:00:00', 25.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-17 00:00:00', 22.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-18 00:00:00', 18.8220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-19 00:00:00', 20.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-20 00:00:00', 23.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-21 00:00:00', 24.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-22 00:00:00', 25.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-23 00:00:00', 24.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-24 00:00:00', 24.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-25 00:00:00', 23.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-26 00:00:00', 24.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-27 00:00:00', 24.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-28 00:00:00', 26.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-29 00:00:00', 25.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-30 00:00:00', 21.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-07-31 00:00:00', 19.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-01 00:00:00', 20.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-02 00:00:00', 18.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-03 00:00:00', 21.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-04 00:00:00', 22.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-05 00:00:00', 21.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-06 00:00:00', 22.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-07 00:00:00', 21.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-08 00:00:00', 22.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-09 00:00:00', 20.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-10 00:00:00', 20.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-11 00:00:00', 17.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-12 00:00:00', 18.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-13 00:00:00', 19.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-14 00:00:00', 19.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-15 00:00:00', 19.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-16 00:00:00', 20.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-17 00:00:00', 19.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-18 00:00:00', 19.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-19 00:00:00', 17.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-20 00:00:00', 18.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-21 00:00:00', 19.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-22 00:00:00', 20.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-23 00:00:00', 21.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-24 00:00:00', 20.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-25 00:00:00', 18.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-26 00:00:00', 15.9420003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-27 00:00:00', 15.991999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-28 00:00:00', 16.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-29 00:00:00', 14.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-30 00:00:00', 13.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-08-31 00:00:00', 14.7519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-01 00:00:00', 16.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-02 00:00:00', 19.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-03 00:00:00', 20.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-04 00:00:00', 18.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-05 00:00:00', 15.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-06 00:00:00', 15.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-07 00:00:00', 16.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-08 00:00:00', 16.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-09 00:00:00', 17.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-10 00:00:00', 18.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-11 00:00:00', 18.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-12 00:00:00', 18.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-13 00:00:00', 17.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-14 00:00:00', 18.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-15 00:00:00', 17.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-16 00:00:00', 18.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-17 00:00:00', 18.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-18 00:00:00', 14.050999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-19 00:00:00', 14.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-20 00:00:00', 16.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-21 00:00:00', 17.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-22 00:00:00', 15.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-23 00:00:00', 14.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-24 00:00:00', 16.3279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-25 00:00:00', 16.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-26 00:00:00', 15.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-27 00:00:00', 15.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-28 00:00:00', 16.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-29 00:00:00', 16.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-09-30 00:00:00', 17.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-01 00:00:00', 18.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-02 00:00:00', 15.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-03 00:00:00', 10.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-04 00:00:00', 11.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-05 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-06 00:00:00', 7.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-07 00:00:00', 7.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-08 00:00:00', 9.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-09 00:00:00', 7.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-10 00:00:00', 8.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-11 00:00:00', 7.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-12 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-13 00:00:00', 3.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-14 00:00:00', 0.517000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-15 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-16 00:00:00', 3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-17 00:00:00', 4.30100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-18 00:00:00', 6.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-19 00:00:00', 7.66099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-20 00:00:00', 8.33100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-21 00:00:00', 9.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-22 00:00:00', 3.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-23 00:00:00', 1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-24 00:00:00', 1.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-25 00:00:00', 0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-26 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-27 00:00:00', 4.13600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-28 00:00:00', 5.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-29 00:00:00', 3.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-30 00:00:00', 4.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-10-31 00:00:00', 1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-01 00:00:00', -0.35499998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-02 00:00:00', 2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-03 00:00:00', 3.80699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-04 00:00:00', 2.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-05 00:00:00', 2.14800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-06 00:00:00', 1.88999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-07 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-08 00:00:00', 1.29799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-09 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-10 00:00:00', -0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-11 00:00:00', 0.814999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-12 00:00:00', 0.898999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-13 00:00:00', 3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-14 00:00:00', 2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-15 00:00:00', 1.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-16 00:00:00', 1.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-17 00:00:00', 1.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-18 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-19 00:00:00', -1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-20 00:00:00', -4.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-21 00:00:00', -3.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-22 00:00:00', -3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-23 00:00:00', -2.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-24 00:00:00', -6.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-25 00:00:00', -4.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-26 00:00:00', -3.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-27 00:00:00', -1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-28 00:00:00', -1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-29 00:00:00', -0.40700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-11-30 00:00:00', 1.11399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-01 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-02 00:00:00', 3.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-03 00:00:00', 3.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-04 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-05 00:00:00', 1.54700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-06 00:00:00', -2.10299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-07 00:00:00', -7.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-08 00:00:00', -9.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-09 00:00:00', -9.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-10 00:00:00', -5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-11 00:00:00', -2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-12 00:00:00', 0.654999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-13 00:00:00', -2.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-14 00:00:00', -6.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-15 00:00:00', -6.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-16 00:00:00', -4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-17 00:00:00', -3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-18 00:00:00', -3.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-19 00:00:00', -0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-20 00:00:00', 1.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-21 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-22 00:00:00', -0.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-23 00:00:00', -2.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-24 00:00:00', -3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-25 00:00:00', -4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-26 00:00:00', -6.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-27 00:00:00', -4.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-28 00:00:00', -3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-29 00:00:00', -6.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-30 00:00:00', -4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1985-12-31 00:00:00', -5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-01 00:00:00', -6.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-02 00:00:00', -4.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-03 00:00:00', -4.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-04 00:00:00', -1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-05 00:00:00', -1.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-06 00:00:00', -2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-07 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-08 00:00:00', -1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-09 00:00:00', -2.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-10 00:00:00', -1.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-11 00:00:00', -4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-12 00:00:00', -3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-13 00:00:00', -4.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-14 00:00:00', -4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-15 00:00:00', -2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-16 00:00:00', -3.7349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-17 00:00:00', -4.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-18 00:00:00', -3.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-19 00:00:00', -0.587999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-20 00:00:00', -2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-21 00:00:00', -0.0869999974966049194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-22 00:00:00', -4.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-23 00:00:00', -4.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-24 00:00:00', -7.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-25 00:00:00', -10.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-26 00:00:00', -7.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-27 00:00:00', -7.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-28 00:00:00', -9.07900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-29 00:00:00', -10.0229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-30 00:00:00', -6.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-01-31 00:00:00', -4.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-01 00:00:00', -4.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-02 00:00:00', -0.703000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-03 00:00:00', -5.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-04 00:00:00', -3.7650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-05 00:00:00', -1.01800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-06 00:00:00', -1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-07 00:00:00', 3.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-08 00:00:00', -1.73800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-09 00:00:00', -3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-10 00:00:00', -2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-11 00:00:00', -0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-12 00:00:00', -4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-13 00:00:00', -8.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-14 00:00:00', -8.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-15 00:00:00', -5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-16 00:00:00', -3.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-17 00:00:00', -5.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-18 00:00:00', -8.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-19 00:00:00', -4.24700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-20 00:00:00', -4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-21 00:00:00', -2.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-22 00:00:00', -2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-23 00:00:00', -2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-24 00:00:00', -1.9179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-25 00:00:00', -1.35199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-26 00:00:00', -0.178000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-27 00:00:00', 0.915000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-02-28 00:00:00', 1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-01 00:00:00', 0.787999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-02 00:00:00', 0.989000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-03 00:00:00', -1.49500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-04 00:00:00', -0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-05 00:00:00', -2.35100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-06 00:00:00', 1.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-07 00:00:00', 5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-08 00:00:00', 5.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-09 00:00:00', 6.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-10 00:00:00', 2.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-11 00:00:00', -2.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-12 00:00:00', -4.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-13 00:00:00', -5.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-14 00:00:00', -6.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-15 00:00:00', -9.47299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-16 00:00:00', -8.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-17 00:00:00', -9.77000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-18 00:00:00', -6.14300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-19 00:00:00', -3.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-20 00:00:00', -3.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-21 00:00:00', -3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-22 00:00:00', -3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-23 00:00:00', -7.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-24 00:00:00', -4.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-25 00:00:00', -5.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-26 00:00:00', -3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-27 00:00:00', -2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-28 00:00:00', -6.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-29 00:00:00', -6.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-30 00:00:00', -8.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-03-31 00:00:00', -5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-01 00:00:00', -1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-02 00:00:00', 1.2640000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-03 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-04 00:00:00', 5.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-05 00:00:00', 4.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-06 00:00:00', 6.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-07 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-08 00:00:00', 6.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-09 00:00:00', 6.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-10 00:00:00', 7.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-11 00:00:00', 8.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-12 00:00:00', 4.59299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-13 00:00:00', 7.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-14 00:00:00', 3.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-15 00:00:00', 4.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-16 00:00:00', 6.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-17 00:00:00', 9.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-18 00:00:00', 10.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-19 00:00:00', 6.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-20 00:00:00', 10.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-21 00:00:00', 8.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-22 00:00:00', 2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-23 00:00:00', 1.08399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-24 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-25 00:00:00', 0.0680000036954879761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-26 00:00:00', 0.799000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-27 00:00:00', 2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-28 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-29 00:00:00', 3.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-04-30 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-01 00:00:00', 9.72000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-02 00:00:00', 9.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-03 00:00:00', 12.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-04 00:00:00', 13.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-05 00:00:00', 17.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-06 00:00:00', 15.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-07 00:00:00', 14.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-08 00:00:00', 13.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-09 00:00:00', 13.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-10 00:00:00', 15.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-11 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-12 00:00:00', 11.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-13 00:00:00', 13.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-14 00:00:00', 16.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-15 00:00:00', 13.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-16 00:00:00', 11.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-17 00:00:00', 7.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-18 00:00:00', 4.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-19 00:00:00', 5.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-20 00:00:00', 8.30500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-21 00:00:00', 8.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-22 00:00:00', 11.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-23 00:00:00', 14.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-24 00:00:00', 16.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-25 00:00:00', 14.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-26 00:00:00', 12.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-27 00:00:00', 13.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-28 00:00:00', 13.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-29 00:00:00', 10.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-30 00:00:00', 5.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-05-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-01 00:00:00', 9.01299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-02 00:00:00', 10.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-03 00:00:00', 12.6470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-04 00:00:00', 11.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-05 00:00:00', 12.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-06 00:00:00', 12.1379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-07 00:00:00', 15.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-08 00:00:00', 16.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-09 00:00:00', 15.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-10 00:00:00', 17.6100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-11 00:00:00', 14.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-12 00:00:00', 16.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-13 00:00:00', 16.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-14 00:00:00', 17.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-15 00:00:00', 15.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-16 00:00:00', 16.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-17 00:00:00', 18.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-18 00:00:00', 21.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-19 00:00:00', 24.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-20 00:00:00', 20.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-21 00:00:00', 20.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-22 00:00:00', 22.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-23 00:00:00', 22.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-24 00:00:00', 19.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-25 00:00:00', 19.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-26 00:00:00', 19.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-27 00:00:00', 20.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-28 00:00:00', 20.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-29 00:00:00', 20.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-06-30 00:00:00', 22.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-01 00:00:00', 23.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-02 00:00:00', 24.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-03 00:00:00', 24.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-04 00:00:00', 23.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-05 00:00:00', 23.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-06 00:00:00', 22.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-07 00:00:00', 22.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-08 00:00:00', 20.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-09 00:00:00', 19.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-10 00:00:00', 21.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-11 00:00:00', 21.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-12 00:00:00', 22.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-13 00:00:00', 22.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-14 00:00:00', 24.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-15 00:00:00', 24.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-16 00:00:00', 24.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-17 00:00:00', 23.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-18 00:00:00', 24.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-19 00:00:00', 23.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-20 00:00:00', 22.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-21 00:00:00', 21.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-22 00:00:00', 13.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-23 00:00:00', 16.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-24 00:00:00', 16.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-25 00:00:00', 20.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-26 00:00:00', 21.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-27 00:00:00', 22.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-28 00:00:00', 23.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-29 00:00:00', 22.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-30 00:00:00', 23.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-07-31 00:00:00', 24.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-01 00:00:00', 26.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-02 00:00:00', 25.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-03 00:00:00', 25.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-04 00:00:00', 22.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-05 00:00:00', 17.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-06 00:00:00', 18.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-07 00:00:00', 19.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-08 00:00:00', 15.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-09 00:00:00', 17.9890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-10 00:00:00', 19.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-11 00:00:00', 19.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-12 00:00:00', 21.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-13 00:00:00', 21.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-14 00:00:00', 22.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-15 00:00:00', 24.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-16 00:00:00', 25.0569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-17 00:00:00', 22.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-18 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-19 00:00:00', 20.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-20 00:00:00', 19.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-21 00:00:00', 18.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-22 00:00:00', 18.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-23 00:00:00', 18.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-24 00:00:00', 18.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-25 00:00:00', 18.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-26 00:00:00', 19.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-27 00:00:00', 19.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-28 00:00:00', 18.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-29 00:00:00', 18.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-30 00:00:00', 17.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-08-31 00:00:00', 14.4280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-01 00:00:00', 18.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-02 00:00:00', 20.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-03 00:00:00', 18.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-04 00:00:00', 18.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-05 00:00:00', 18.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-06 00:00:00', 18.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-07 00:00:00', 19.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-08 00:00:00', 18.3390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-09 00:00:00', 17.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-10 00:00:00', 16.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-11 00:00:00', 17.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-12 00:00:00', 17.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-13 00:00:00', 15.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-14 00:00:00', 16.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-15 00:00:00', 16.2950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-16 00:00:00', 16.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-17 00:00:00', 17.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-18 00:00:00', 16.6860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-19 00:00:00', 15.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-20 00:00:00', 12.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-21 00:00:00', 13.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-22 00:00:00', 15.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-23 00:00:00', 16.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-24 00:00:00', 18.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-25 00:00:00', 19.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-26 00:00:00', 17.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-27 00:00:00', 17.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-28 00:00:00', 16.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-29 00:00:00', 14.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-09-30 00:00:00', 8.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-01 00:00:00', 11.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-02 00:00:00', 13.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-03 00:00:00', 14.2410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-04 00:00:00', 13.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-05 00:00:00', 15.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-06 00:00:00', 15.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-07 00:00:00', 14.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-08 00:00:00', 10.1610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-09 00:00:00', 10.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-10 00:00:00', 11.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-11 00:00:00', 12.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-12 00:00:00', 10.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-13 00:00:00', 9.31299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-14 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-15 00:00:00', -0.167999997735023499, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-16 00:00:00', -0.356999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-17 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-18 00:00:00', 0.381000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-19 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-20 00:00:00', 5.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-21 00:00:00', 7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-22 00:00:00', 6.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-23 00:00:00', 8.60999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-24 00:00:00', 11.1440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-25 00:00:00', 11.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-26 00:00:00', 10.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-27 00:00:00', 9.82900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-28 00:00:00', 7.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-29 00:00:00', 6.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-30 00:00:00', 4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-10-31 00:00:00', 5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-01 00:00:00', 5.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-02 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-03 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-04 00:00:00', 6.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-05 00:00:00', 8.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-06 00:00:00', 8.45199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-07 00:00:00', 3.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-08 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-09 00:00:00', 3.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-10 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-11 00:00:00', 2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-12 00:00:00', 1.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-13 00:00:00', -3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-14 00:00:00', -4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-15 00:00:00', -3.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-16 00:00:00', -6.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-17 00:00:00', -4.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-18 00:00:00', -2.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-19 00:00:00', -3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-20 00:00:00', -3.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-21 00:00:00', -3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-22 00:00:00', -8.50100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-23 00:00:00', -3.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-24 00:00:00', -0.400000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-25 00:00:00', -1.74199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-26 00:00:00', -4.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-27 00:00:00', -3.45600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-28 00:00:00', -3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-29 00:00:00', -3.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-11-30 00:00:00', 0.43599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-01 00:00:00', 0.0540000014007091522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-02 00:00:00', 1.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-03 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-04 00:00:00', 0.740999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-05 00:00:00', -3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-06 00:00:00', -3.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-07 00:00:00', -4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-08 00:00:00', 0.606000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-09 00:00:00', -1.00499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-10 00:00:00', -6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-11 00:00:00', -13.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-12 00:00:00', -13.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-13 00:00:00', -11.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-14 00:00:00', -8.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-15 00:00:00', -8.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-16 00:00:00', -6.81400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-17 00:00:00', -7.37900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-18 00:00:00', -7.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-19 00:00:00', -4.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-20 00:00:00', -4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-21 00:00:00', -2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-22 00:00:00', -3.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-23 00:00:00', -4.01800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-24 00:00:00', -7.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-30 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1986-12-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-01 00:00:00', -6.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-02 00:00:00', -2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-03 00:00:00', -0.572000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-04 00:00:00', -2.26799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-05 00:00:00', -0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-06 00:00:00', -0.933000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-07 00:00:00', -0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-08 00:00:00', -3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-09 00:00:00', -1.70899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-10 00:00:00', -1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-11 00:00:00', -0.123000003397464752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-12 00:00:00', -3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-13 00:00:00', -3.92499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-14 00:00:00', -2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-15 00:00:00', -5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-16 00:00:00', -6.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-17 00:00:00', -3.5429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-18 00:00:00', -6.39300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-19 00:00:00', -7.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-20 00:00:00', -9.33100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-21 00:00:00', -10.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-22 00:00:00', -9.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-23 00:00:00', -1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-24 00:00:00', 0.134000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-25 00:00:00', 0.535000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-26 00:00:00', 0.526000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-27 00:00:00', 1.41999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-28 00:00:00', -0.128000006079673767, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-29 00:00:00', -0.640999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-30 00:00:00', -0.148000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-01-31 00:00:00', -0.398999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-01 00:00:00', 0.0109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-02 00:00:00', -2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-03 00:00:00', -1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-04 00:00:00', 0.672999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-05 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-06 00:00:00', -2.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-07 00:00:00', -6.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-08 00:00:00', -4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-09 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-10 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-11 00:00:00', 0.894999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-12 00:00:00', -7.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-13 00:00:00', -2.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-14 00:00:00', -3.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-15 00:00:00', -6.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-16 00:00:00', -8.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-17 00:00:00', -10.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-18 00:00:00', -7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-19 00:00:00', -0.887000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-20 00:00:00', -0.922999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-21 00:00:00', -0.884000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-22 00:00:00', -3.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-23 00:00:00', -3.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-24 00:00:00', -0.845000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-25 00:00:00', 0.430999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-26 00:00:00', 2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-27 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-02-28 00:00:00', 3.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-01 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-02 00:00:00', 1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-03 00:00:00', 5.8189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-04 00:00:00', 7.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-05 00:00:00', 3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-06 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-07 00:00:00', 2.07699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-08 00:00:00', 3.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-09 00:00:00', 2.38100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-10 00:00:00', 5.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-11 00:00:00', 2.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-12 00:00:00', 0.537999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-13 00:00:00', -0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-14 00:00:00', 5.57600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-15 00:00:00', 1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-16 00:00:00', -1.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-17 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-18 00:00:00', 0.561999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-19 00:00:00', 0.769999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-20 00:00:00', 0.0289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-21 00:00:00', -1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-22 00:00:00', -3.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-23 00:00:00', -3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-24 00:00:00', -0.666999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-25 00:00:00', 3.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-26 00:00:00', 5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-27 00:00:00', 2.1400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-28 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-29 00:00:00', 2.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-30 00:00:00', 4.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-03-31 00:00:00', 8.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-01 00:00:00', 2.2780001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-02 00:00:00', -1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-03 00:00:00', -1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-04 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-05 00:00:00', 4.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-06 00:00:00', 0.962000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-07 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-08 00:00:00', -1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-09 00:00:00', 1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-10 00:00:00', 3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-11 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-12 00:00:00', 5.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-13 00:00:00', 6.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-14 00:00:00', 5.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-15 00:00:00', 5.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-16 00:00:00', 4.88500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-17 00:00:00', 8.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-18 00:00:00', 10.4280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-19 00:00:00', 11.9530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-20 00:00:00', 9.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-21 00:00:00', 5.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-22 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-23 00:00:00', 6.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-24 00:00:00', 8.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-25 00:00:00', 10.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-26 00:00:00', 12.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-27 00:00:00', 12.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-28 00:00:00', 6.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-29 00:00:00', 7.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-04-30 00:00:00', 4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-01 00:00:00', 5.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-02 00:00:00', 8.76799964904785156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-03 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-04 00:00:00', 11.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-05 00:00:00', 8.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-06 00:00:00', 8.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-07 00:00:00', 8.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-08 00:00:00', 8.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-09 00:00:00', 9.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-10 00:00:00', 11.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-11 00:00:00', 13.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-12 00:00:00', 14.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-13 00:00:00', 15.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-14 00:00:00', 16.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-15 00:00:00', 16.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-16 00:00:00', 17.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-17 00:00:00', 15.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-18 00:00:00', 12.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-19 00:00:00', 11.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-20 00:00:00', 9.99199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-21 00:00:00', 10.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-22 00:00:00', 10.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-23 00:00:00', 13.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-24 00:00:00', 16.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-25 00:00:00', 18.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-26 00:00:00', 18.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-27 00:00:00', 17.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-28 00:00:00', 18.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-29 00:00:00', 17.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-30 00:00:00', 15.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-05-31 00:00:00', 13.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-01 00:00:00', 14.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-02 00:00:00', 14.8629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-03 00:00:00', 17.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-04 00:00:00', 18.5289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-05 00:00:00', 21.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-06 00:00:00', 16.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-07 00:00:00', 16.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-08 00:00:00', 14.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-09 00:00:00', 12.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-10 00:00:00', 15.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-11 00:00:00', 15.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-12 00:00:00', 15.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-13 00:00:00', 15.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-14 00:00:00', 15.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-15 00:00:00', 13.5819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-16 00:00:00', 16.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-17 00:00:00', 17.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-18 00:00:00', 18.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-19 00:00:00', 18.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-20 00:00:00', 11.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-21 00:00:00', 12.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-22 00:00:00', 15.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-23 00:00:00', 17.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-24 00:00:00', 18.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-25 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-26 00:00:00', 20.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-27 00:00:00', 20.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-28 00:00:00', 20.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-29 00:00:00', 19.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-06-30 00:00:00', 21.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-01 00:00:00', 19.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-02 00:00:00', 19.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-03 00:00:00', 21.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-04 00:00:00', 21.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-05 00:00:00', 15.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-06 00:00:00', 19.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-07 00:00:00', 18.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-08 00:00:00', 19.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-09 00:00:00', 20.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-10 00:00:00', 22.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-11 00:00:00', 12.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-12 00:00:00', 13.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-13 00:00:00', 10.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-14 00:00:00', 12.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-15 00:00:00', 12.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-16 00:00:00', 12.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-17 00:00:00', 15.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-18 00:00:00', 14.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-19 00:00:00', 14.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-20 00:00:00', 17.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-21 00:00:00', 20.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-22 00:00:00', 23.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-23 00:00:00', 23.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-24 00:00:00', 21.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-25 00:00:00', 17.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-26 00:00:00', 14.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-27 00:00:00', 15.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-28 00:00:00', 17.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-29 00:00:00', 14.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-30 00:00:00', 19.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-07-31 00:00:00', 17.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-01 00:00:00', 18.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-02 00:00:00', 19.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-03 00:00:00', 20.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-04 00:00:00', 21.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-05 00:00:00', 21.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-06 00:00:00', 20.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-07 00:00:00', 21.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-08 00:00:00', 20.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-09 00:00:00', 20.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-10 00:00:00', 19.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-11 00:00:00', 19.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-12 00:00:00', 22.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-13 00:00:00', 23.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-14 00:00:00', 23.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-15 00:00:00', 23.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-16 00:00:00', 23.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-17 00:00:00', 21.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-18 00:00:00', 23.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-19 00:00:00', 23.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-20 00:00:00', 22.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-21 00:00:00', 23.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-22 00:00:00', 23.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-23 00:00:00', 21.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-24 00:00:00', 21.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-25 00:00:00', 21.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-26 00:00:00', 22.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-27 00:00:00', 20.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-28 00:00:00', 21.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-29 00:00:00', 21.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-30 00:00:00', 23.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-08-31 00:00:00', 17.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-01 00:00:00', 18.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-02 00:00:00', 16.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-03 00:00:00', 17.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-04 00:00:00', 19.2800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-05 00:00:00', 21.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-06 00:00:00', 23.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-07 00:00:00', 20.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-08 00:00:00', 14.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-09 00:00:00', 12.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-10 00:00:00', 13.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-11 00:00:00', 14.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-12 00:00:00', 16.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-13 00:00:00', 17.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-14 00:00:00', 18.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-15 00:00:00', 17.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-16 00:00:00', 17.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-17 00:00:00', 19.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-18 00:00:00', 18.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-19 00:00:00', 13.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-20 00:00:00', 8.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-21 00:00:00', 11.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-22 00:00:00', 13.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-23 00:00:00', 16.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-24 00:00:00', 9.93000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-25 00:00:00', 13.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-26 00:00:00', 13.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-27 00:00:00', 13.800999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-28 00:00:00', 13.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-29 00:00:00', 13.9879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-09-30 00:00:00', 13.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-01 00:00:00', 7.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-02 00:00:00', 11.116999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-03 00:00:00', 13.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-04 00:00:00', 12.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-05 00:00:00', 14.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-06 00:00:00', 14.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-07 00:00:00', 12.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-08 00:00:00', 8.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-09 00:00:00', 5.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-10 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-11 00:00:00', -0.462999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-12 00:00:00', -1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-13 00:00:00', -2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-14 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-15 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-16 00:00:00', 2.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-17 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-18 00:00:00', 2.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-19 00:00:00', 2.39299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-20 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-21 00:00:00', 5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-22 00:00:00', 6.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-23 00:00:00', 7.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-24 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-25 00:00:00', 6.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-26 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-27 00:00:00', -1.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-28 00:00:00', -5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-29 00:00:00', -6.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-30 00:00:00', -1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-10-31 00:00:00', -0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-01 00:00:00', 1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-02 00:00:00', 3.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-03 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-04 00:00:00', 2.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-05 00:00:00', 2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-06 00:00:00', 5.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-07 00:00:00', 6.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-08 00:00:00', 4.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-09 00:00:00', 1.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-10 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-11 00:00:00', 1.54799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-12 00:00:00', 0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-13 00:00:00', 2.22699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-14 00:00:00', 5.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-15 00:00:00', 4.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-16 00:00:00', 2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-17 00:00:00', 0.760999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-18 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-19 00:00:00', 3.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-20 00:00:00', 2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-21 00:00:00', 5.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-22 00:00:00', 4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-23 00:00:00', 2.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-24 00:00:00', 0.691999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-25 00:00:00', -0.00400000018998980522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-26 00:00:00', -1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-27 00:00:00', -1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-28 00:00:00', -5.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-29 00:00:00', -5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-11-30 00:00:00', -7.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-01 00:00:00', -10.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-02 00:00:00', -9.0839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-03 00:00:00', -6.39699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-04 00:00:00', -1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-05 00:00:00', -0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-06 00:00:00', 1.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-07 00:00:00', 2.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-08 00:00:00', 1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-09 00:00:00', -0.654999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-10 00:00:00', 1.29400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-11 00:00:00', 0.853999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-12 00:00:00', 0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-13 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-14 00:00:00', 1.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-15 00:00:00', -3.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-16 00:00:00', -2.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-17 00:00:00', -0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-18 00:00:00', 0.871999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-19 00:00:00', 2.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-20 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-21 00:00:00', 4.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-22 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-23 00:00:00', 1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-24 00:00:00', 2.5690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-25 00:00:00', 1.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-26 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-27 00:00:00', 0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-28 00:00:00', 0.962999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-29 00:00:00', -2.1679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-30 00:00:00', -2.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1987-12-31 00:00:00', 0.515999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-01 00:00:00', -1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-02 00:00:00', -1.02499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-03 00:00:00', -10.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-04 00:00:00', -0.13099999725818634, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-05 00:00:00', 0.238000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-06 00:00:00', 0.837000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-07 00:00:00', -1.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-08 00:00:00', -3.47799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-09 00:00:00', -2.93700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-10 00:00:00', -2.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-11 00:00:00', -3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-12 00:00:00', -5.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-13 00:00:00', 1.27300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-14 00:00:00', -1.69900000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-15 00:00:00', -6.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-16 00:00:00', -3.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-17 00:00:00', -3.63599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-18 00:00:00', -3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-19 00:00:00', -0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-20 00:00:00', -2.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-21 00:00:00', -9.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-22 00:00:00', -6.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-23 00:00:00', -6.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-24 00:00:00', -6.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-25 00:00:00', -5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-26 00:00:00', -3.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-27 00:00:00', -3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-28 00:00:00', -3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-29 00:00:00', -0.935000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-30 00:00:00', -2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-01-31 00:00:00', -3.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-01 00:00:00', -3.72099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-02 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-03 00:00:00', 3.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-04 00:00:00', 0.96799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-05 00:00:00', -7.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-06 00:00:00', -6.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-07 00:00:00', -9.47999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-08 00:00:00', -9.39900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-09 00:00:00', -2.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-10 00:00:00', 1.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-11 00:00:00', -0.370000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-12 00:00:00', -1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-13 00:00:00', -1.05700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-14 00:00:00', -3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-15 00:00:00', -1.75399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-16 00:00:00', -6.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-17 00:00:00', 0.50700002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-18 00:00:00', -0.621999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-19 00:00:00', -3.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-20 00:00:00', -1.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-21 00:00:00', -4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-22 00:00:00', -3.76699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-23 00:00:00', -2.94300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-24 00:00:00', -0.666999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-25 00:00:00', 1.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-26 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-27 00:00:00', -4.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-28 00:00:00', -4.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-02-29 00:00:00', -2.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-01 00:00:00', -0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-02 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-03 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-04 00:00:00', 4.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-05 00:00:00', 6.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-06 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-07 00:00:00', -4.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-08 00:00:00', 0.760999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-09 00:00:00', 2.28500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-10 00:00:00', -0.314999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-11 00:00:00', -0.768000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-12 00:00:00', -1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-13 00:00:00', -2.78500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-14 00:00:00', 0.052000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-15 00:00:00', -1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-16 00:00:00', -2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-17 00:00:00', -3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-18 00:00:00', -1.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-19 00:00:00', 0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-20 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-21 00:00:00', 3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-22 00:00:00', 2.81200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-23 00:00:00', -3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-24 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-25 00:00:00', -1.26800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-26 00:00:00', -5.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-27 00:00:00', 0.592000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-28 00:00:00', -1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-29 00:00:00', -1.34500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-30 00:00:00', -1.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-03-31 00:00:00', -0.405999988317489624, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-01 00:00:00', 1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-02 00:00:00', 0.312999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-03 00:00:00', -4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-04 00:00:00', -3.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-05 00:00:00', -1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-06 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-07 00:00:00', 0.00499999988824129105, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-08 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-09 00:00:00', -0.291000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-10 00:00:00', -0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-11 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-12 00:00:00', 7.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-13 00:00:00', 10.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-14 00:00:00', 12.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-15 00:00:00', 13.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-16 00:00:00', 13.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-17 00:00:00', 7.41200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-18 00:00:00', 7.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-19 00:00:00', 9.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-20 00:00:00', 11.5439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-21 00:00:00', 12.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-22 00:00:00', 12.3170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-23 00:00:00', 11.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-24 00:00:00', 14.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-25 00:00:00', 14.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-26 00:00:00', 15.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-27 00:00:00', 14.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-28 00:00:00', 15.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-29 00:00:00', 9.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-04-30 00:00:00', 7.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-01 00:00:00', 7.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-02 00:00:00', 7.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-03 00:00:00', 9.71599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-04 00:00:00', 4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-05 00:00:00', 4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-06 00:00:00', 6.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-07 00:00:00', 7.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-08 00:00:00', 7.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-09 00:00:00', 11.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-10 00:00:00', 11.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-11 00:00:00', 12.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-12 00:00:00', 13.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-13 00:00:00', 13.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-14 00:00:00', 9.29399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-15 00:00:00', 9.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-16 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-17 00:00:00', 8.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-18 00:00:00', 7.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-19 00:00:00', 12.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-20 00:00:00', 14.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-21 00:00:00', 14.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-22 00:00:00', 10.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-23 00:00:00', 12.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-24 00:00:00', 11.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-25 00:00:00', 13.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-26 00:00:00', 17.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-27 00:00:00', 16.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-28 00:00:00', 16.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-29 00:00:00', 20.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-30 00:00:00', 17.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-05-31 00:00:00', 12.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-01 00:00:00', 12.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-02 00:00:00', 14.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-03 00:00:00', 16.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-04 00:00:00', 14.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-05 00:00:00', 13.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-06 00:00:00', 12.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-07 00:00:00', 12.883000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-08 00:00:00', 10.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-09 00:00:00', 10.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-10 00:00:00', 14.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-11 00:00:00', 16.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-12 00:00:00', 18.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-13 00:00:00', 19.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-14 00:00:00', 20.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-15 00:00:00', 19.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-16 00:00:00', 22.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-17 00:00:00', 23.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-18 00:00:00', 25.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-19 00:00:00', 24.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-20 00:00:00', 25.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-21 00:00:00', 21.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-22 00:00:00', 20.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-23 00:00:00', 22.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-24 00:00:00', 26.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-25 00:00:00', 26.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-26 00:00:00', 21.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-27 00:00:00', 18.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-28 00:00:00', 13.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-29 00:00:00', 15.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-06-30 00:00:00', 18.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-01 00:00:00', 24.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-02 00:00:00', 25.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-03 00:00:00', 23.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-04 00:00:00', 22.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-05 00:00:00', 20.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-06 00:00:00', 19.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-07 00:00:00', 19.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-08 00:00:00', 17.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-09 00:00:00', 20.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-10 00:00:00', 22.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-11 00:00:00', 23.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-12 00:00:00', 23.582000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-13 00:00:00', 21.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-14 00:00:00', 18.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-15 00:00:00', 17.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-16 00:00:00', 21.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-17 00:00:00', 21.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-18 00:00:00', 21.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-19 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-20 00:00:00', 23.3789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-21 00:00:00', 21.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-22 00:00:00', 19.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-23 00:00:00', 19.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-24 00:00:00', 19.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-25 00:00:00', 22.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-26 00:00:00', 22.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-27 00:00:00', 24.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-28 00:00:00', 26.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-29 00:00:00', 24.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-30 00:00:00', 23.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-07-31 00:00:00', 19.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-01 00:00:00', 20.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-02 00:00:00', 17.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-03 00:00:00', 18.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-04 00:00:00', 18.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-05 00:00:00', 22.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-06 00:00:00', 23.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-07 00:00:00', 23.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-08 00:00:00', 22.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-09 00:00:00', 22.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-10 00:00:00', 22.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-11 00:00:00', 23.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-12 00:00:00', 23.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-13 00:00:00', 22.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-14 00:00:00', 22.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-15 00:00:00', 19.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-16 00:00:00', 20.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-17 00:00:00', 21.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-18 00:00:00', 17.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-19 00:00:00', 20.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-20 00:00:00', 21.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-21 00:00:00', 20.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-22 00:00:00', 18.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-23 00:00:00', 16.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-24 00:00:00', 15.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-25 00:00:00', 16.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-26 00:00:00', 13.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-27 00:00:00', 13.949000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-28 00:00:00', 13.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-29 00:00:00', 17.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-30 00:00:00', 18.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-08-31 00:00:00', 17.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-01 00:00:00', 18.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-02 00:00:00', 16.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-03 00:00:00', 18.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-04 00:00:00', 18.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-05 00:00:00', 19.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-06 00:00:00', 22.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-07 00:00:00', 21.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-08 00:00:00', 18.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-09 00:00:00', 14.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-10 00:00:00', 19.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-11 00:00:00', 21.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-12 00:00:00', 20.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-13 00:00:00', 20.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-14 00:00:00', 18.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-15 00:00:00', 17.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-16 00:00:00', 15.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-17 00:00:00', 12.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-18 00:00:00', 15.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-19 00:00:00', 17.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-20 00:00:00', 16.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-21 00:00:00', 16.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-22 00:00:00', 9.19699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-23 00:00:00', 12.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-24 00:00:00', 10.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-25 00:00:00', 10.0120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-26 00:00:00', 11.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-27 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-28 00:00:00', 9.79599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-29 00:00:00', 9.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-09-30 00:00:00', 8.75800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-01 00:00:00', 8.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-02 00:00:00', 8.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-03 00:00:00', 4.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-04 00:00:00', 7.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-05 00:00:00', 8.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-06 00:00:00', 8.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-07 00:00:00', 7.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-08 00:00:00', 8.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-09 00:00:00', 8.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-10 00:00:00', 9.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-11 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-12 00:00:00', 6.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-13 00:00:00', 7.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-14 00:00:00', 6.61299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-15 00:00:00', 9.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-16 00:00:00', 4.20499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-17 00:00:00', 5.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-18 00:00:00', 6.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-19 00:00:00', 5.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-20 00:00:00', 7.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-21 00:00:00', 10.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-22 00:00:00', 7.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-23 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-24 00:00:00', 4.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-25 00:00:00', 3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-26 00:00:00', 4.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-27 00:00:00', 8.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-28 00:00:00', 9.66199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-29 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-30 00:00:00', 5.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-10-31 00:00:00', 8.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-01 00:00:00', 6.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-02 00:00:00', 8.87399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-03 00:00:00', 8.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-04 00:00:00', 8.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-05 00:00:00', 7.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-06 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-07 00:00:00', 6.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-08 00:00:00', 7.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-09 00:00:00', 8.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-10 00:00:00', 9.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-11 00:00:00', 10.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-12 00:00:00', 10.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-13 00:00:00', 10.619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-14 00:00:00', 10.7589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-15 00:00:00', 3.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-16 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-17 00:00:00', 7.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-18 00:00:00', 6.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-19 00:00:00', 6.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-20 00:00:00', 9.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-21 00:00:00', 1.95899999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-22 00:00:00', 0.317000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-23 00:00:00', -0.202000007033348083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-24 00:00:00', -1.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-25 00:00:00', -0.0750000029802322388, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-26 00:00:00', 0.0780000016093254089, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-27 00:00:00', 2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-28 00:00:00', 3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-29 00:00:00', 1.51499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-11-30 00:00:00', 1.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-01 00:00:00', 1.85399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-02 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-03 00:00:00', 2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-04 00:00:00', 4.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-05 00:00:00', 0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-06 00:00:00', 0.856999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-07 00:00:00', 1.20799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-08 00:00:00', 3.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-09 00:00:00', 3.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-10 00:00:00', 4.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-11 00:00:00', 2.79200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-12 00:00:00', 3.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-13 00:00:00', 1.50499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-14 00:00:00', -0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-15 00:00:00', -0.654999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-16 00:00:00', -1.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-17 00:00:00', -2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-18 00:00:00', -0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-19 00:00:00', -0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-20 00:00:00', -0.621999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-21 00:00:00', -2.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-22 00:00:00', -7.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-23 00:00:00', -2.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-24 00:00:00', -6.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-25 00:00:00', -4.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-26 00:00:00', -0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-27 00:00:00', -0.842000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-28 00:00:00', -0.275000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-29 00:00:00', -3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-30 00:00:00', -5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1988-12-31 00:00:00', -0.870999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-01 00:00:00', -5.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-02 00:00:00', -1.99500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-03 00:00:00', -2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-04 00:00:00', -6.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-05 00:00:00', -9.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-06 00:00:00', -12.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-07 00:00:00', -10.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-08 00:00:00', -8.99199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-09 00:00:00', -4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-10 00:00:00', -5.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-11 00:00:00', -4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-12 00:00:00', -3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-13 00:00:00', -5.04799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-14 00:00:00', -5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-15 00:00:00', -7.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-16 00:00:00', -6.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-17 00:00:00', -1.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-18 00:00:00', -6.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-19 00:00:00', -10.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-20 00:00:00', -5.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-21 00:00:00', -3.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-22 00:00:00', -5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-23 00:00:00', -4.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-24 00:00:00', -1.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-25 00:00:00', -6.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-26 00:00:00', -5.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-27 00:00:00', -9.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-28 00:00:00', -8.98499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-29 00:00:00', -7.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-30 00:00:00', -7.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-01-31 00:00:00', -11.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-01 00:00:00', -5.57700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-02 00:00:00', -5.89200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-03 00:00:00', -7.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-04 00:00:00', -10.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-05 00:00:00', -10.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-06 00:00:00', -13.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-07 00:00:00', -9.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-08 00:00:00', -8.56000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-09 00:00:00', -6.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-10 00:00:00', -3.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-11 00:00:00', -4.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-12 00:00:00', -5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-13 00:00:00', -12.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-14 00:00:00', -10.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-15 00:00:00', -6.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-16 00:00:00', -10.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-17 00:00:00', -9.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-18 00:00:00', -8.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-19 00:00:00', -4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-20 00:00:00', -6.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-21 00:00:00', -6.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-22 00:00:00', -3.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-23 00:00:00', -0.596000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-24 00:00:00', -4.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-25 00:00:00', -7.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-26 00:00:00', -6.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-27 00:00:00', -7.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-02-28 00:00:00', -1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-01 00:00:00', -1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-02 00:00:00', -1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-03 00:00:00', 0.0549999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-04 00:00:00', -0.186000004410743713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-05 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-06 00:00:00', 1.06400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-07 00:00:00', -1.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-08 00:00:00', -4.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-09 00:00:00', -5.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-10 00:00:00', -0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-11 00:00:00', 4.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-12 00:00:00', 1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-13 00:00:00', -0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-14 00:00:00', -2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-15 00:00:00', 3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-16 00:00:00', 6.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-17 00:00:00', 1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-18 00:00:00', 0.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-19 00:00:00', 3.25200009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-20 00:00:00', -0.830999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-21 00:00:00', 4.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-22 00:00:00', 2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-23 00:00:00', -1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-24 00:00:00', -0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-25 00:00:00', 3.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-26 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-27 00:00:00', 7.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-28 00:00:00', 7.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-29 00:00:00', 2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-30 00:00:00', 5.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-03-31 00:00:00', 0.925000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-01 00:00:00', -2.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-02 00:00:00', -3.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-03 00:00:00', -2.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-04 00:00:00', 0.052000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-05 00:00:00', 3.27399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-06 00:00:00', 4.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-07 00:00:00', 3.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-08 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-09 00:00:00', 0.0219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-10 00:00:00', 1.78100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-11 00:00:00', 2.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-12 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-13 00:00:00', 6.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-14 00:00:00', 9.40200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-15 00:00:00', 9.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-16 00:00:00', 4.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-17 00:00:00', 3.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-18 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-19 00:00:00', 8.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-20 00:00:00', 10.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-21 00:00:00', 8.18799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-22 00:00:00', 6.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-23 00:00:00', 8.06999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-24 00:00:00', 7.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-25 00:00:00', 7.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-26 00:00:00', 9.39700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-27 00:00:00', 10.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-28 00:00:00', 11.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-29 00:00:00', 12.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-04-30 00:00:00', 6.77199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-01 00:00:00', -3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-02 00:00:00', -1.93599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-03 00:00:00', -4.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-04 00:00:00', 1.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-05 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-06 00:00:00', 8.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-07 00:00:00', 11.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-08 00:00:00', 4.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-09 00:00:00', 1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-10 00:00:00', 7.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-11 00:00:00', 7.99599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-12 00:00:00', 9.41899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-13 00:00:00', 12.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-14 00:00:00', 8.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-15 00:00:00', 7.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-16 00:00:00', 8.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-17 00:00:00', 9.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-18 00:00:00', 9.86400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-19 00:00:00', 14.0579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-20 00:00:00', 10.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-21 00:00:00', 9.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-22 00:00:00', 10.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-23 00:00:00', 9.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-24 00:00:00', 12.7589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-25 00:00:00', 14.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-26 00:00:00', 17.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-27 00:00:00', 17.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-28 00:00:00', 19.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-29 00:00:00', 18.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-30 00:00:00', 17.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-05-31 00:00:00', 17.3759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-01 00:00:00', 19.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-02 00:00:00', 16.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-03 00:00:00', 16.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-04 00:00:00', 15.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-05 00:00:00', 14.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-06 00:00:00', 13.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-07 00:00:00', 12.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-08 00:00:00', 14.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-09 00:00:00', 12.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-10 00:00:00', 14.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-11 00:00:00', 17.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-12 00:00:00', 18.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-13 00:00:00', 16.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-14 00:00:00', 15.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-15 00:00:00', 16.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-16 00:00:00', 16.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-17 00:00:00', 16.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-18 00:00:00', 16.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-19 00:00:00', 15.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-20 00:00:00', 15.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-21 00:00:00', 15.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-22 00:00:00', 17.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-23 00:00:00', 18.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-24 00:00:00', 20.4640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-25 00:00:00', 21.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-26 00:00:00', 21.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-27 00:00:00', 20.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-28 00:00:00', 19.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-29 00:00:00', 18.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-06-30 00:00:00', 19.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-01 00:00:00', 17.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-02 00:00:00', 17.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-03 00:00:00', 18.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-04 00:00:00', 18.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-05 00:00:00', 18.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-06 00:00:00', 19.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-07 00:00:00', 22.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-08 00:00:00', 24.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-09 00:00:00', 25.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-10 00:00:00', 25.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-11 00:00:00', 25.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-12 00:00:00', 23.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-13 00:00:00', 20.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-14 00:00:00', 18.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-15 00:00:00', 18.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-16 00:00:00', 17.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-17 00:00:00', 17.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-18 00:00:00', 17.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-19 00:00:00', 18.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-20 00:00:00', 17.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-21 00:00:00', 18.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-22 00:00:00', 18.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-23 00:00:00', 16.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-24 00:00:00', 16.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-25 00:00:00', 18.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-26 00:00:00', 19.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-27 00:00:00', 21.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-28 00:00:00', 23.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-29 00:00:00', 22.4169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-30 00:00:00', 20.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-07-31 00:00:00', 18.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-01 00:00:00', 20.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-02 00:00:00', 22.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-03 00:00:00', 22.0529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-04 00:00:00', 21.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-05 00:00:00', 21.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-06 00:00:00', 22.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-07 00:00:00', 22.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-08 00:00:00', 21.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-09 00:00:00', 22.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-10 00:00:00', 23.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-11 00:00:00', 25.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-12 00:00:00', 23.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-13 00:00:00', 21.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-14 00:00:00', 21.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-15 00:00:00', 20.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-16 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-17 00:00:00', 22.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-18 00:00:00', 23.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-19 00:00:00', 18.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-20 00:00:00', 17.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-21 00:00:00', 19.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-22 00:00:00', 19.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-23 00:00:00', 19.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-24 00:00:00', 18.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-25 00:00:00', 18.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-26 00:00:00', 16.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-27 00:00:00', 14.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-28 00:00:00', 15.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-29 00:00:00', 16.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-30 00:00:00', 18.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-08-31 00:00:00', 16.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-01 00:00:00', 18.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-02 00:00:00', 19.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-03 00:00:00', 19.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-04 00:00:00', 16.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-05 00:00:00', 14.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-06 00:00:00', 14.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-07 00:00:00', 16.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-08 00:00:00', 17.1100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-09 00:00:00', 17.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-10 00:00:00', 18.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-11 00:00:00', 18.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-12 00:00:00', 18.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-13 00:00:00', 19.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-14 00:00:00', 21.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-15 00:00:00', 24.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-16 00:00:00', 22.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-17 00:00:00', 19.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-18 00:00:00', 19.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-19 00:00:00', 19.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-20 00:00:00', 12.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-21 00:00:00', 8.86699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-22 00:00:00', 5.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-23 00:00:00', 6.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-24 00:00:00', 8.91199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-25 00:00:00', 12.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-26 00:00:00', 13.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-27 00:00:00', 12.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-28 00:00:00', 13.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-29 00:00:00', 12.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-09-30 00:00:00', 11.2659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-01 00:00:00', 10.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-02 00:00:00', 13.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-03 00:00:00', 15.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-04 00:00:00', 15.8979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-05 00:00:00', 16.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-06 00:00:00', 15.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-07 00:00:00', 17.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-08 00:00:00', 17.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-09 00:00:00', 16.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-10 00:00:00', 11.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-11 00:00:00', 7.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-12 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-13 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-14 00:00:00', 6.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-15 00:00:00', 8.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-16 00:00:00', 9.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-17 00:00:00', 11.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-18 00:00:00', 12.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-19 00:00:00', 10.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-20 00:00:00', 13.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-21 00:00:00', 13.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-22 00:00:00', 11.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-23 00:00:00', 5.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-24 00:00:00', 0.781000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-25 00:00:00', 4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-26 00:00:00', 6.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-27 00:00:00', 4.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-28 00:00:00', 7.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-29 00:00:00', 7.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-30 00:00:00', 5.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-10-31 00:00:00', 8.38799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-01 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-02 00:00:00', -1.91999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-03 00:00:00', -0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-04 00:00:00', -0.717000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-05 00:00:00', 1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-06 00:00:00', 2.0690000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-07 00:00:00', -1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-08 00:00:00', -1.90499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-09 00:00:00', -0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-10 00:00:00', -1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-11 00:00:00', -2.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-12 00:00:00', 0.291999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-13 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-14 00:00:00', 3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-15 00:00:00', 0.653999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-16 00:00:00', 1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-17 00:00:00', 0.744000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-18 00:00:00', 0.0920000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-19 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-20 00:00:00', 4.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-21 00:00:00', 1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-22 00:00:00', -0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-23 00:00:00', -2.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-24 00:00:00', -0.776000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-25 00:00:00', -0.379999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-26 00:00:00', 0.986000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-27 00:00:00', 2.96499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-28 00:00:00', 3.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-29 00:00:00', 5.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-11-30 00:00:00', 6.49700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-01 00:00:00', 5.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-02 00:00:00', 4.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-03 00:00:00', 0.624000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-04 00:00:00', 0.870999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-05 00:00:00', 1.65900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-06 00:00:00', 1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-07 00:00:00', -0.277999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-08 00:00:00', -1.82700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-09 00:00:00', 1.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-10 00:00:00', -0.347999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-11 00:00:00', 0.864000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-12 00:00:00', -0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-13 00:00:00', 1.71899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-14 00:00:00', -0.824999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-15 00:00:00', 0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-16 00:00:00', 0.545000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-17 00:00:00', -0.370000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-18 00:00:00', -3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-19 00:00:00', -1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-20 00:00:00', -1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-21 00:00:00', -1.68799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-22 00:00:00', -3.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-23 00:00:00', -5.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-24 00:00:00', -5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-25 00:00:00', -5.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-26 00:00:00', -2.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-27 00:00:00', -3.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-28 00:00:00', -5.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-29 00:00:00', -6.15500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-30 00:00:00', -4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1989-12-31 00:00:00', -5.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-01 00:00:00', -6.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-02 00:00:00', -5.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-03 00:00:00', -4.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-04 00:00:00', -5.92600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-05 00:00:00', -1.49199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-06 00:00:00', -4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-07 00:00:00', -6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-08 00:00:00', -7.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-09 00:00:00', -7.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-10 00:00:00', -5.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-11 00:00:00', -7.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-12 00:00:00', -8.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-13 00:00:00', -7.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-14 00:00:00', -6.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-15 00:00:00', -3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-16 00:00:00', -5.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-17 00:00:00', -3.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-18 00:00:00', -2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-19 00:00:00', -1.5010000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-20 00:00:00', -3.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-21 00:00:00', 0.509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-22 00:00:00', -0.815999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-23 00:00:00', 2.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-24 00:00:00', 2.05200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-25 00:00:00', -2.01799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-26 00:00:00', -5.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-27 00:00:00', -9.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-28 00:00:00', -7.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-29 00:00:00', -2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-30 00:00:00', -5.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-01-31 00:00:00', -7.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-01 00:00:00', -9.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-02 00:00:00', -5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-03 00:00:00', -4.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-04 00:00:00', -4.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-05 00:00:00', -3.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-06 00:00:00', -4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-07 00:00:00', -5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-08 00:00:00', -6.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-09 00:00:00', -5.16300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-10 00:00:00', -2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-11 00:00:00', -1.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-12 00:00:00', -2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-13 00:00:00', -4.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-14 00:00:00', -5.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-15 00:00:00', -3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-16 00:00:00', -2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-17 00:00:00', -3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-18 00:00:00', -1.3739999532699585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-19 00:00:00', 0.0399999991059303284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-20 00:00:00', -0.367000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-21 00:00:00', -0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-22 00:00:00', -3.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-23 00:00:00', -4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-24 00:00:00', -8.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-25 00:00:00', -6.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-26 00:00:00', -7.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-27 00:00:00', -5.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-02-28 00:00:00', -2.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-01 00:00:00', -2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-02 00:00:00', -0.465999990701675415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-03 00:00:00', 1.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-04 00:00:00', 0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-05 00:00:00', 0.703000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-06 00:00:00', 0.0439999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-07 00:00:00', 0.0820000022649765015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-08 00:00:00', 1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-09 00:00:00', -0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-10 00:00:00', -2.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-11 00:00:00', 2.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-12 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-13 00:00:00', 4.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-14 00:00:00', 7.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-15 00:00:00', 4.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-16 00:00:00', 0.13099999725818634, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-17 00:00:00', -2.25999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-18 00:00:00', -5.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-19 00:00:00', -3.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-20 00:00:00', -4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-21 00:00:00', -8.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-22 00:00:00', -8.43700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-23 00:00:00', -4.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-24 00:00:00', -1.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-25 00:00:00', 2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-26 00:00:00', 0.637000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-27 00:00:00', -0.740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-28 00:00:00', 1.45200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-29 00:00:00', 2.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-30 00:00:00', 0.043000001460313797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-03-31 00:00:00', -1.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-01 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-02 00:00:00', 6.81300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-03 00:00:00', 6.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-04 00:00:00', 4.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-05 00:00:00', 3.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-06 00:00:00', 1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-07 00:00:00', 1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-08 00:00:00', 0.435000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-09 00:00:00', 2.77200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-10 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-11 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-12 00:00:00', 2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-13 00:00:00', 5.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-14 00:00:00', 1.62199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-15 00:00:00', 3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-16 00:00:00', 5.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-17 00:00:00', 2.45799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-18 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-19 00:00:00', 5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-20 00:00:00', 3.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-21 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-22 00:00:00', 9.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-23 00:00:00', 7.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-24 00:00:00', 4.36399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-25 00:00:00', 5.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-26 00:00:00', 5.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-27 00:00:00', 7.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-28 00:00:00', 11.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-29 00:00:00', 14.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-04-30 00:00:00', 11.491999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-01 00:00:00', 12.9779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-02 00:00:00', 8.15200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-03 00:00:00', 14.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-04 00:00:00', 16.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-05 00:00:00', 14.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-06 00:00:00', 12.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-07 00:00:00', 16.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-08 00:00:00', 11.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-09 00:00:00', 12.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-10 00:00:00', 14.4469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-11 00:00:00', 17.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-12 00:00:00', 19.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-13 00:00:00', 21.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-14 00:00:00', 16.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-15 00:00:00', 8.41399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-16 00:00:00', 12.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-17 00:00:00', 10.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-18 00:00:00', 12.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-19 00:00:00', 15.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-20 00:00:00', 15.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-21 00:00:00', 16.2730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-22 00:00:00', 16.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-23 00:00:00', 16.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-24 00:00:00', 16.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-25 00:00:00', 14.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-26 00:00:00', 17.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-27 00:00:00', 19.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-28 00:00:00', 12.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-29 00:00:00', 14.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-30 00:00:00', 13.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-05-31 00:00:00', 11.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-01 00:00:00', 14.7620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-02 00:00:00', 16.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-03 00:00:00', 15.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-04 00:00:00', 14.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-05 00:00:00', 17.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-06 00:00:00', 17.0219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-07 00:00:00', 19.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-08 00:00:00', 15.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-09 00:00:00', 13.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-10 00:00:00', 15.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-11 00:00:00', 16.0230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-12 00:00:00', 15.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-13 00:00:00', 16.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-14 00:00:00', 19.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-15 00:00:00', 21.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-16 00:00:00', 23.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-17 00:00:00', 22.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-18 00:00:00', 22.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-19 00:00:00', 23.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-20 00:00:00', 25.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-21 00:00:00', 25.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-22 00:00:00', 27.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-23 00:00:00', 27.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-24 00:00:00', 23.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-25 00:00:00', 22.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-26 00:00:00', 20.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-27 00:00:00', 21.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-28 00:00:00', 24.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-29 00:00:00', 27.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-06-30 00:00:00', 26.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-01 00:00:00', 24.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-02 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-03 00:00:00', 22.2409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-04 00:00:00', 22.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-05 00:00:00', 21.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-06 00:00:00', 22.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-07 00:00:00', 22.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-08 00:00:00', 21.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-09 00:00:00', 19.0370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-10 00:00:00', 18.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-11 00:00:00', 18.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-12 00:00:00', 16.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-13 00:00:00', 18.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-14 00:00:00', 16.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-15 00:00:00', 19.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-16 00:00:00', 19.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-17 00:00:00', 22.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-18 00:00:00', 22.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-19 00:00:00', 23.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-20 00:00:00', 21.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-21 00:00:00', 19.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-22 00:00:00', 17.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-23 00:00:00', 20.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-24 00:00:00', 24.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-25 00:00:00', 25.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-26 00:00:00', 22.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-27 00:00:00', 21.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-28 00:00:00', 23.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-29 00:00:00', 25.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-30 00:00:00', 27.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-07-31 00:00:00', 27.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-01 00:00:00', 26.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-02 00:00:00', 19.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-03 00:00:00', 22.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-04 00:00:00', 23.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-05 00:00:00', 23.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-06 00:00:00', 25.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-07 00:00:00', 26.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-08 00:00:00', 27.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-09 00:00:00', 26.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-10 00:00:00', 26.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-11 00:00:00', 26.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-12 00:00:00', 23.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-13 00:00:00', 20.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-14 00:00:00', 18.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-15 00:00:00', 21.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-16 00:00:00', 23.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-17 00:00:00', 24.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-18 00:00:00', 22.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-19 00:00:00', 21.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-20 00:00:00', 23.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-21 00:00:00', 21.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-22 00:00:00', 20.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-23 00:00:00', 20.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-24 00:00:00', 19.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-25 00:00:00', 20.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-26 00:00:00', 20.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-27 00:00:00', 23.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-28 00:00:00', 24.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-29 00:00:00', 23.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-30 00:00:00', 19.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-08-31 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-01 00:00:00', 19.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-02 00:00:00', 21.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-03 00:00:00', 16.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-04 00:00:00', 17.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-05 00:00:00', 18.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-06 00:00:00', 18.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-07 00:00:00', 20.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-08 00:00:00', 19.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-09 00:00:00', 18.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-10 00:00:00', 18.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-11 00:00:00', 18.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-12 00:00:00', 18.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-13 00:00:00', 20.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-14 00:00:00', 20.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-15 00:00:00', 22.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-16 00:00:00', 22.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-17 00:00:00', 21.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-18 00:00:00', 20.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-19 00:00:00', 19.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-20 00:00:00', 18.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-21 00:00:00', 19.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-22 00:00:00', 19.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-23 00:00:00', 18.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-24 00:00:00', 16.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-25 00:00:00', 16.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-26 00:00:00', 16.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-27 00:00:00', 16.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-28 00:00:00', 15.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-29 00:00:00', 16.2579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-09-30 00:00:00', 16.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-01 00:00:00', 16.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-02 00:00:00', 16.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-03 00:00:00', 15.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-04 00:00:00', 14.9460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-05 00:00:00', 14.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-06 00:00:00', 6.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-07 00:00:00', 9.58899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-08 00:00:00', 10.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-09 00:00:00', 10.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-10 00:00:00', 13.5159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-11 00:00:00', 12.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-12 00:00:00', 10.7379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-13 00:00:00', 8.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-14 00:00:00', 9.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-15 00:00:00', 5.15399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-16 00:00:00', 2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-17 00:00:00', 2.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-18 00:00:00', -0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-19 00:00:00', -0.809000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-20 00:00:00', 4.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-21 00:00:00', 6.72100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-22 00:00:00', 8.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-23 00:00:00', 5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-24 00:00:00', 8.93999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-25 00:00:00', 8.09500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-26 00:00:00', 10.9940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-27 00:00:00', 9.11900043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-28 00:00:00', 9.71100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-29 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-30 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-10-31 00:00:00', 3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-01 00:00:00', 2.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-02 00:00:00', 2.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-03 00:00:00', 4.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-04 00:00:00', 6.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-05 00:00:00', 7.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-06 00:00:00', 7.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-07 00:00:00', 7.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-08 00:00:00', 7.61700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-09 00:00:00', 7.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-10 00:00:00', 7.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-11 00:00:00', 8.65900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-12 00:00:00', 7.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-13 00:00:00', 7.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-14 00:00:00', 1.3890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-15 00:00:00', -0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-16 00:00:00', -1.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-17 00:00:00', -2.47099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-18 00:00:00', -1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-19 00:00:00', 1.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-20 00:00:00', 4.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-21 00:00:00', 3.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-22 00:00:00', 0.894999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-23 00:00:00', 0.250999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-24 00:00:00', 2.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-25 00:00:00', 3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-26 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-27 00:00:00', -0.149000003933906555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-28 00:00:00', 0.492000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-29 00:00:00', 1.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-11-30 00:00:00', 1.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-01 00:00:00', 3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-02 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-03 00:00:00', 3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-04 00:00:00', 3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-05 00:00:00', 2.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-06 00:00:00', 3.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-07 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-08 00:00:00', 1.18900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-09 00:00:00', -0.180999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-10 00:00:00', -3.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-11 00:00:00', -1.91900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-12 00:00:00', -4.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-13 00:00:00', -6.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-14 00:00:00', -7.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-15 00:00:00', -7.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-16 00:00:00', -7.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-17 00:00:00', -5.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-18 00:00:00', -4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-19 00:00:00', -0.879000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-20 00:00:00', -3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-21 00:00:00', -1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-22 00:00:00', -3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-23 00:00:00', -5.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-24 00:00:00', -6.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-25 00:00:00', -6.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-26 00:00:00', -4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-27 00:00:00', -11.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-28 00:00:00', -14.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-29 00:00:00', -12.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-30 00:00:00', -11.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1990-12-31 00:00:00', -10.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-01 00:00:00', -9.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-02 00:00:00', -5.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-03 00:00:00', -1.26499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-04 00:00:00', -4.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-05 00:00:00', -5.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-06 00:00:00', -6.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-07 00:00:00', -5.49100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-08 00:00:00', -6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-09 00:00:00', -1.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-10 00:00:00', -5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-11 00:00:00', -8.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-12 00:00:00', -7.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-13 00:00:00', -5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-14 00:00:00', -3.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-15 00:00:00', -1.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-16 00:00:00', -7.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-17 00:00:00', -8.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-18 00:00:00', -6.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-19 00:00:00', -6.5149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-20 00:00:00', -5.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-21 00:00:00', -6.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-22 00:00:00', -4.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-23 00:00:00', -5.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-24 00:00:00', -2.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-25 00:00:00', -3.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-26 00:00:00', -0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-27 00:00:00', -3.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-28 00:00:00', -5.09499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-29 00:00:00', -6.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-30 00:00:00', -1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-01-31 00:00:00', -2.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-01 00:00:00', -1.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-02 00:00:00', -2.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-03 00:00:00', -3.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-04 00:00:00', -2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-05 00:00:00', -1.77799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-06 00:00:00', -6.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-07 00:00:00', -8.14000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-08 00:00:00', -1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-09 00:00:00', -4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-10 00:00:00', -5.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-11 00:00:00', -9.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-12 00:00:00', -11.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-13 00:00:00', -9.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-14 00:00:00', -13.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-15 00:00:00', -11.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-16 00:00:00', -5.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-17 00:00:00', -2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-18 00:00:00', -2.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-19 00:00:00', -1.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-20 00:00:00', 0.189999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-21 00:00:00', 0.791999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-22 00:00:00', 2.96900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-23 00:00:00', -2.0150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-24 00:00:00', -4.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-25 00:00:00', -7.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-26 00:00:00', -8.18700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-27 00:00:00', -2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-02-28 00:00:00', 0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-01 00:00:00', 0.48399999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-02 00:00:00', -2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-03 00:00:00', -2.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-04 00:00:00', -2.93600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-05 00:00:00', -6.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-06 00:00:00', 0.142000004649162292, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-07 00:00:00', 0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-08 00:00:00', -1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-09 00:00:00', -4.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-10 00:00:00', -1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-11 00:00:00', -0.620000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-12 00:00:00', -4.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-13 00:00:00', -0.652000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-14 00:00:00', 0.694999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-15 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-16 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-17 00:00:00', -1.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-18 00:00:00', -2.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-19 00:00:00', -0.47999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-20 00:00:00', 0.202000007033348083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-21 00:00:00', -0.129999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-22 00:00:00', -1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-23 00:00:00', -0.981000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-24 00:00:00', 0.884000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-25 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-26 00:00:00', 3.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-27 00:00:00', 6.91800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-28 00:00:00', 5.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-29 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-30 00:00:00', 5.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-03-31 00:00:00', 6.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-01 00:00:00', 8.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-02 00:00:00', 6.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-03 00:00:00', 7.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-04 00:00:00', 9.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-05 00:00:00', 8.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-06 00:00:00', 4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-07 00:00:00', 2.73200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-08 00:00:00', 1.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-09 00:00:00', -0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-10 00:00:00', 1.85699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-11 00:00:00', 4.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-12 00:00:00', 2.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-13 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-14 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-15 00:00:00', -3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-16 00:00:00', -0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-17 00:00:00', 4.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-18 00:00:00', 7.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-19 00:00:00', 10.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-20 00:00:00', 7.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-21 00:00:00', 6.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-22 00:00:00', 9.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-23 00:00:00', 9.38099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-24 00:00:00', 9.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-25 00:00:00', 9.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-26 00:00:00', 8.37199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-27 00:00:00', 7.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-28 00:00:00', 5.31699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-29 00:00:00', 6.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-04-30 00:00:00', 8.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-01 00:00:00', 4.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-02 00:00:00', 4.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-03 00:00:00', 8.75399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-04 00:00:00', 10.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-05 00:00:00', 8.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-06 00:00:00', 8.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-07 00:00:00', 9.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-08 00:00:00', 6.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-09 00:00:00', 9.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-10 00:00:00', 10.9040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-11 00:00:00', 11.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-12 00:00:00', 9.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-13 00:00:00', 7.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-14 00:00:00', 6.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-15 00:00:00', 9.91399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-16 00:00:00', 7.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-17 00:00:00', 13.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-18 00:00:00', 12.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-19 00:00:00', 7.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-20 00:00:00', 8.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-21 00:00:00', 4.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-22 00:00:00', 11.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-23 00:00:00', 14.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-24 00:00:00', 9.82699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-25 00:00:00', 5.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-26 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-27 00:00:00', 8.37100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-28 00:00:00', 10.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-29 00:00:00', 11.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-30 00:00:00', 14.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-05-31 00:00:00', 16.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-01 00:00:00', 19.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-02 00:00:00', 19.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-03 00:00:00', 19.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-04 00:00:00', 18.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-05 00:00:00', 20.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-06 00:00:00', 16.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-07 00:00:00', 16.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-08 00:00:00', 19.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-09 00:00:00', 14.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-10 00:00:00', 12.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-11 00:00:00', 14.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-12 00:00:00', 18.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-13 00:00:00', 22.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-14 00:00:00', 21.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-15 00:00:00', 15.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-16 00:00:00', 16.8689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-17 00:00:00', 17.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-18 00:00:00', 15.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-19 00:00:00', 13.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-20 00:00:00', 16.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-21 00:00:00', 17.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-22 00:00:00', 15.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-23 00:00:00', 12.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-24 00:00:00', 7.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-25 00:00:00', 7.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-26 00:00:00', 10.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-27 00:00:00', 15.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-28 00:00:00', 17.6539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-29 00:00:00', 18.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-06-30 00:00:00', 18.5990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-01 00:00:00', 18.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-02 00:00:00', 19.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-03 00:00:00', 18.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-04 00:00:00', 17.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-05 00:00:00', 17.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-06 00:00:00', 18.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-07 00:00:00', 19.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-08 00:00:00', 22.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-09 00:00:00', 21.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-10 00:00:00', 20.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-11 00:00:00', 19.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-12 00:00:00', 16.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-13 00:00:00', 14.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-14 00:00:00', 18.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-15 00:00:00', 17.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-16 00:00:00', 19.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-17 00:00:00', 17.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-18 00:00:00', 20.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-19 00:00:00', 21.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-20 00:00:00', 21.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-21 00:00:00', 19.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-22 00:00:00', 20.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-23 00:00:00', 20.5219993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-24 00:00:00', 20.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-25 00:00:00', 18.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-26 00:00:00', 18.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-27 00:00:00', 19.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-28 00:00:00', 22.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-29 00:00:00', 24.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-30 00:00:00', 24.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-07-31 00:00:00', 21.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-01 00:00:00', 20.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-02 00:00:00', 22.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-03 00:00:00', 23.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-04 00:00:00', 23.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-05 00:00:00', 22.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-06 00:00:00', 22.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-07 00:00:00', 21.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-08 00:00:00', 19.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-09 00:00:00', 16.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-10 00:00:00', 17.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-11 00:00:00', 20.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-12 00:00:00', 22.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-13 00:00:00', 22.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-14 00:00:00', 23.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-15 00:00:00', 22.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-16 00:00:00', 23.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-17 00:00:00', 22.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-18 00:00:00', 23.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-19 00:00:00', 23.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-20 00:00:00', 20.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-21 00:00:00', 19.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-22 00:00:00', 19.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-23 00:00:00', 19.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-24 00:00:00', 20.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-25 00:00:00', 21.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-26 00:00:00', 22.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-27 00:00:00', 23.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-28 00:00:00', 22.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-29 00:00:00', 21.1819992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-30 00:00:00', 20.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-08-31 00:00:00', 20.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-01 00:00:00', 20.9319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-02 00:00:00', 21.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-03 00:00:00', 23.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-04 00:00:00', 22.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-05 00:00:00', 21.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-06 00:00:00', 17.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-07 00:00:00', 16.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-08 00:00:00', 20.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-09 00:00:00', 21.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-10 00:00:00', 21.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-11 00:00:00', 20.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-12 00:00:00', 19.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-13 00:00:00', 19.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-14 00:00:00', 18.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-15 00:00:00', 17.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-16 00:00:00', 14.4709997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-17 00:00:00', 11.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-18 00:00:00', 12.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-19 00:00:00', 13.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-20 00:00:00', 14.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-21 00:00:00', 17.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-22 00:00:00', 18.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-23 00:00:00', 18.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-24 00:00:00', 16.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-25 00:00:00', 12.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-26 00:00:00', 6.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-27 00:00:00', 4.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-28 00:00:00', 7.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-29 00:00:00', 4.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-09-30 00:00:00', 1.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-01 00:00:00', 3.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-02 00:00:00', 3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-03 00:00:00', 7.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-04 00:00:00', 9.50399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-05 00:00:00', 9.48200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-06 00:00:00', 8.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-07 00:00:00', 6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-08 00:00:00', 5.74300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-09 00:00:00', 6.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-10 00:00:00', 6.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-11 00:00:00', 2.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-12 00:00:00', 3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-13 00:00:00', 1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-14 00:00:00', 2.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-15 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-16 00:00:00', 6.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-17 00:00:00', 7.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-18 00:00:00', 5.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-19 00:00:00', 8.02700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-20 00:00:00', 8.47000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-21 00:00:00', 8.21800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-22 00:00:00', 8.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-23 00:00:00', 7.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-24 00:00:00', 8.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-25 00:00:00', 6.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-26 00:00:00', 8.32900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-27 00:00:00', 8.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-28 00:00:00', 8.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-29 00:00:00', 6.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-30 00:00:00', 6.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-10-31 00:00:00', 7.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-01 00:00:00', 6.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-02 00:00:00', 7.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-03 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-04 00:00:00', 6.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-05 00:00:00', 9.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-06 00:00:00', 7.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-07 00:00:00', 4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-08 00:00:00', 2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-09 00:00:00', 3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-10 00:00:00', 1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-11 00:00:00', 0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-12 00:00:00', 1.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-13 00:00:00', -0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-14 00:00:00', -0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-15 00:00:00', 0.772000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-16 00:00:00', -0.71799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-17 00:00:00', -0.84299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-18 00:00:00', -0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-19 00:00:00', -0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-20 00:00:00', -1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-21 00:00:00', -4.50699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-22 00:00:00', -1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-23 00:00:00', -2.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-24 00:00:00', -1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-25 00:00:00', 0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-26 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-27 00:00:00', -1.86399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-28 00:00:00', -4.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-29 00:00:00', -5.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-11-30 00:00:00', -3.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-01 00:00:00', -1.57799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-02 00:00:00', 0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-03 00:00:00', -1.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-04 00:00:00', -1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-05 00:00:00', -0.0829999968409538269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-06 00:00:00', 0.389999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-07 00:00:00', -0.597000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-08 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-09 00:00:00', -1.11699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-10 00:00:00', 0.0299999993294477463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-11 00:00:00', -0.795000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-12 00:00:00', -1.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-13 00:00:00', 0.675000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-14 00:00:00', -1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-15 00:00:00', 0.442000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-16 00:00:00', -0.861000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-17 00:00:00', -3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-18 00:00:00', -6.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-19 00:00:00', -6.10200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-20 00:00:00', -3.08999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-21 00:00:00', -4.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-22 00:00:00', -4.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-23 00:00:00', -3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-24 00:00:00', -6.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-25 00:00:00', -6.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-26 00:00:00', -2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-27 00:00:00', -7.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-28 00:00:00', -4.54799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-29 00:00:00', -6.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-30 00:00:00', -7.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1991-12-31 00:00:00', -7.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-01 00:00:00', -4.67299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-02 00:00:00', -4.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-03 00:00:00', -2.85100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-04 00:00:00', -1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-05 00:00:00', -6.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-06 00:00:00', -0.665000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-07 00:00:00', -7.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-08 00:00:00', -4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-09 00:00:00', -6.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-10 00:00:00', -9.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-11 00:00:00', -7.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-12 00:00:00', -3.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-13 00:00:00', -2.52900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-14 00:00:00', -3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-15 00:00:00', -5.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-16 00:00:00', -3.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-17 00:00:00', -1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-18 00:00:00', -3.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-19 00:00:00', -2.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-20 00:00:00', -0.455000013113021851, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-21 00:00:00', -1.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-22 00:00:00', -0.676999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-23 00:00:00', -4.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-24 00:00:00', -4.84399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-25 00:00:00', -6.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-26 00:00:00', -3.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-27 00:00:00', -8.59500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-28 00:00:00', -8.02499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-29 00:00:00', -8.85499954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-30 00:00:00', -5.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-01-31 00:00:00', -2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-01 00:00:00', -5.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-02 00:00:00', -4.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-03 00:00:00', -3.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-04 00:00:00', -4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-05 00:00:00', -1.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-06 00:00:00', -3.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-07 00:00:00', -4.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-08 00:00:00', -3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-09 00:00:00', -4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-10 00:00:00', -3.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-11 00:00:00', -1.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-12 00:00:00', -4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-13 00:00:00', -9.80900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-14 00:00:00', -6.46799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-15 00:00:00', -5.00799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-16 00:00:00', -6.95599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-17 00:00:00', -7.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-18 00:00:00', -1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-19 00:00:00', -3.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-20 00:00:00', -2.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-21 00:00:00', -1.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-22 00:00:00', -3.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-23 00:00:00', -1.33399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-24 00:00:00', -0.090999998152256012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-25 00:00:00', 0.407999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-26 00:00:00', 0.660000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-27 00:00:00', -8.29399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-28 00:00:00', -9.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-02-29 00:00:00', -8.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-01 00:00:00', -6.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-02 00:00:00', -6.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-03 00:00:00', -7.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-04 00:00:00', -8.54399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-05 00:00:00', -4.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-06 00:00:00', -1.71800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-07 00:00:00', -2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-08 00:00:00', -4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-09 00:00:00', -5.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-10 00:00:00', -3.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-11 00:00:00', -7.76399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-12 00:00:00', -11.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-13 00:00:00', -9.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-14 00:00:00', -3.45199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-15 00:00:00', -1.51100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-16 00:00:00', -0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-17 00:00:00', -1.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-18 00:00:00', -1.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-19 00:00:00', 0.709999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-20 00:00:00', -3.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-21 00:00:00', -0.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-22 00:00:00', -1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-23 00:00:00', -1.02199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-24 00:00:00', -0.759000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-25 00:00:00', 1.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-26 00:00:00', -3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-27 00:00:00', -2.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-28 00:00:00', -1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-29 00:00:00', -1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-30 00:00:00', -2.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-03-31 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-01 00:00:00', 2.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-02 00:00:00', 0.324000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-03 00:00:00', 1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-04 00:00:00', 2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-05 00:00:00', 5.8619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-06 00:00:00', 1.41299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-07 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-08 00:00:00', 5.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-09 00:00:00', 7.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-10 00:00:00', 3.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-11 00:00:00', 2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-12 00:00:00', 3.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-13 00:00:00', 9.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-14 00:00:00', 11.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-15 00:00:00', 11.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-16 00:00:00', 6.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-17 00:00:00', 4.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-18 00:00:00', 7.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-19 00:00:00', 9.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-20 00:00:00', 5.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-21 00:00:00', 5.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-22 00:00:00', 8.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-23 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-24 00:00:00', 4.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-25 00:00:00', 10.3450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-26 00:00:00', 9.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-27 00:00:00', 7.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-28 00:00:00', 6.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-29 00:00:00', 5.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-04-30 00:00:00', 7.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-01 00:00:00', 2.34999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-02 00:00:00', -1.32099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-03 00:00:00', -2.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-04 00:00:00', 2.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-05 00:00:00', 2.08100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-06 00:00:00', -0.442000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-07 00:00:00', 4.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-08 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-09 00:00:00', 8.06999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-10 00:00:00', 12.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-11 00:00:00', 11.2270002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-12 00:00:00', 9.43999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-13 00:00:00', 11.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-14 00:00:00', 10.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-15 00:00:00', 5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-16 00:00:00', 5.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-17 00:00:00', 6.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-18 00:00:00', 6.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-19 00:00:00', 8.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-20 00:00:00', 8.22000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-21 00:00:00', 8.75599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-22 00:00:00', 10.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-23 00:00:00', 11.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-24 00:00:00', 9.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-25 00:00:00', 10.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-26 00:00:00', 6.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-27 00:00:00', 7.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-28 00:00:00', 8.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-29 00:00:00', 10.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-30 00:00:00', 12.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-05-31 00:00:00', 13.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-01 00:00:00', 12.3579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-02 00:00:00', 12.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-03 00:00:00', 15.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-04 00:00:00', 14.5749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-05 00:00:00', 15.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-06 00:00:00', 14.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-07 00:00:00', 14.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-08 00:00:00', 14.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-09 00:00:00', 14.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-10 00:00:00', 14.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-11 00:00:00', 16.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-12 00:00:00', 15.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-13 00:00:00', 10.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-14 00:00:00', 9.15400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-15 00:00:00', 12.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-16 00:00:00', 13.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-17 00:00:00', 13.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-18 00:00:00', 16.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-19 00:00:00', 19.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-20 00:00:00', 21.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-21 00:00:00', 15.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-22 00:00:00', 16.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-23 00:00:00', 15.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-24 00:00:00', 15.9300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-25 00:00:00', 17.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-26 00:00:00', 18.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-27 00:00:00', 19.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-28 00:00:00', 18.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-29 00:00:00', 17.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-06-30 00:00:00', 17.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-01 00:00:00', 17.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-02 00:00:00', 15.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-03 00:00:00', 16.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-04 00:00:00', 19.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-05 00:00:00', 20.5330009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-06 00:00:00', 22.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-07 00:00:00', 22.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-08 00:00:00', 19.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-09 00:00:00', 19.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-10 00:00:00', 22.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-11 00:00:00', 22.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-12 00:00:00', 18.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-13 00:00:00', 18.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-14 00:00:00', 15.5719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-15 00:00:00', 18.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-16 00:00:00', 19.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-17 00:00:00', 20.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-18 00:00:00', 21.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-19 00:00:00', 22.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-20 00:00:00', 22.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-21 00:00:00', 22.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-22 00:00:00', 23.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-23 00:00:00', 22.1420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-24 00:00:00', 22.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-25 00:00:00', 22.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-26 00:00:00', 23.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-27 00:00:00', 24.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-28 00:00:00', 23.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-29 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-30 00:00:00', 18.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-07-31 00:00:00', 20.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-01 00:00:00', 23.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-02 00:00:00', 25.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-03 00:00:00', 23.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-04 00:00:00', 21.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-05 00:00:00', 19.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-06 00:00:00', 16.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-07 00:00:00', 15.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-08 00:00:00', 13.0290002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-09 00:00:00', 15.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-10 00:00:00', 16.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-11 00:00:00', 17.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-12 00:00:00', 15.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-13 00:00:00', 14.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-14 00:00:00', 18.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-15 00:00:00', 19.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-16 00:00:00', 18.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-17 00:00:00', 16.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-18 00:00:00', 17.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-19 00:00:00', 18.4209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-20 00:00:00', 18.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-21 00:00:00', 16.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-22 00:00:00', 19.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-23 00:00:00', 20.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-24 00:00:00', 20.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-25 00:00:00', 21.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-26 00:00:00', 22.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-27 00:00:00', 19.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-28 00:00:00', 16.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-29 00:00:00', 16.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-30 00:00:00', 11.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-08-31 00:00:00', 9.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-01 00:00:00', 16.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-02 00:00:00', 12.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-03 00:00:00', 9.83100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-04 00:00:00', 15.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-05 00:00:00', 14.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-06 00:00:00', 14.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-07 00:00:00', 15.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-08 00:00:00', 16.4820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-09 00:00:00', 14.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-10 00:00:00', 13.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-11 00:00:00', 14.7279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-12 00:00:00', 14.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-13 00:00:00', 14.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-14 00:00:00', 14.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-15 00:00:00', 14.0950002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-16 00:00:00', 13.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-17 00:00:00', 9.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-18 00:00:00', 13.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-19 00:00:00', 11.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-20 00:00:00', 12.6549997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-21 00:00:00', 12.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-22 00:00:00', 14.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-23 00:00:00', 14.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-24 00:00:00', 14.4329996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-25 00:00:00', 15.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-26 00:00:00', 18.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-27 00:00:00', 15.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-28 00:00:00', 16.0809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-29 00:00:00', 10.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-09-30 00:00:00', 8.42199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-01 00:00:00', 6.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-02 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-03 00:00:00', 7.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-04 00:00:00', 8.99100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-05 00:00:00', 8.81700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-06 00:00:00', 7.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-07 00:00:00', 3.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-08 00:00:00', 4.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-09 00:00:00', 7.11399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-10 00:00:00', 11.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-11 00:00:00', 13.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-12 00:00:00', 13.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-13 00:00:00', 12.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-14 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-15 00:00:00', 9.97299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-16 00:00:00', 3.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-17 00:00:00', 0.477999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-18 00:00:00', 2.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-19 00:00:00', 5.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-20 00:00:00', 8.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-21 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-22 00:00:00', 6.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-23 00:00:00', 7.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-24 00:00:00', 6.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-25 00:00:00', 7.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-26 00:00:00', 9.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-27 00:00:00', 9.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-28 00:00:00', 9.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-29 00:00:00', 9.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-30 00:00:00', 6.80800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-10-31 00:00:00', 6.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-01 00:00:00', 7.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-02 00:00:00', 5.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-03 00:00:00', 4.78599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-04 00:00:00', -0.0179999992251396179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-05 00:00:00', -0.430000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-06 00:00:00', 5.22800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-07 00:00:00', 7.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-08 00:00:00', 9.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-09 00:00:00', 7.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-10 00:00:00', 9.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-11 00:00:00', 8.14900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-12 00:00:00', 9.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-13 00:00:00', 11.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-14 00:00:00', 8.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-15 00:00:00', 7.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-16 00:00:00', 5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-17 00:00:00', 4.79400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-18 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-19 00:00:00', -2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-20 00:00:00', -2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-21 00:00:00', -1.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-22 00:00:00', 2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-23 00:00:00', 4.87200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-24 00:00:00', 3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-25 00:00:00', 3.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-26 00:00:00', 3.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-27 00:00:00', -3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-28 00:00:00', 0.68199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-29 00:00:00', -0.344000011682510376, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-11-30 00:00:00', 0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-01 00:00:00', -0.162000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-02 00:00:00', -0.0970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-03 00:00:00', -3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-04 00:00:00', -0.165000006556510925, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-05 00:00:00', -0.307999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-06 00:00:00', -2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-07 00:00:00', -1.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-08 00:00:00', -2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-09 00:00:00', -1.64699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-10 00:00:00', -1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-11 00:00:00', -6.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-12 00:00:00', -5.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-13 00:00:00', -2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-14 00:00:00', 0.221000000834465027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-15 00:00:00', 1.40699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-16 00:00:00', 1.57599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-17 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-18 00:00:00', 1.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-19 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-20 00:00:00', 1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-21 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-22 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-23 00:00:00', 0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-24 00:00:00', -4.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-25 00:00:00', -3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-26 00:00:00', -3.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-27 00:00:00', -3.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-28 00:00:00', -2.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-29 00:00:00', -4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-30 00:00:00', -4.57499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1992-12-31 00:00:00', -3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-01 00:00:00', -4.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-02 00:00:00', -4.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-03 00:00:00', -7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-04 00:00:00', -6.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-05 00:00:00', -6.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-06 00:00:00', -9.17599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-07 00:00:00', -14.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-08 00:00:00', -10.6059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-09 00:00:00', -6.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-10 00:00:00', -5.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-11 00:00:00', -8.50399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-12 00:00:00', -8.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-13 00:00:00', -9.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-14 00:00:00', -8.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-15 00:00:00', -5.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-16 00:00:00', -9.23900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-17 00:00:00', -6.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-18 00:00:00', -9.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-19 00:00:00', -10.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-20 00:00:00', -9.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-21 00:00:00', -7.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-22 00:00:00', -6.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-23 00:00:00', -5.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-24 00:00:00', -6.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-25 00:00:00', -2.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-26 00:00:00', -3.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-27 00:00:00', 1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-28 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-29 00:00:00', -1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-30 00:00:00', -1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-01-31 00:00:00', 0.319999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-01 00:00:00', -2.23099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-02 00:00:00', -1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-03 00:00:00', 2.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-04 00:00:00', 0.853999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-05 00:00:00', 0.690999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-06 00:00:00', -1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-07 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-08 00:00:00', -1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-09 00:00:00', -0.384999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-10 00:00:00', -1.80099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-11 00:00:00', -0.307999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-12 00:00:00', 0.352999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-13 00:00:00', -1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-14 00:00:00', -2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-15 00:00:00', -2.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-16 00:00:00', -4.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-17 00:00:00', -10.9409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-18 00:00:00', -10.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-19 00:00:00', -6.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-20 00:00:00', -5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-21 00:00:00', -3.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-22 00:00:00', -3.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-23 00:00:00', -4.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-24 00:00:00', -2.77900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-25 00:00:00', -6.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-26 00:00:00', -6.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-27 00:00:00', -6.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-02-28 00:00:00', -2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-01 00:00:00', -4.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-02 00:00:00', -4.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-03 00:00:00', -7.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-04 00:00:00', -1.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-05 00:00:00', -2.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-06 00:00:00', 4.00199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-07 00:00:00', 0.550000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-08 00:00:00', 1.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-09 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-10 00:00:00', 1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-11 00:00:00', -2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-12 00:00:00', -3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-13 00:00:00', -4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-14 00:00:00', -7.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-15 00:00:00', -3.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-16 00:00:00', -5.94500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-17 00:00:00', -5.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-18 00:00:00', -2.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-19 00:00:00', 0.358000010251998901, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-20 00:00:00', -2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-21 00:00:00', -1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-22 00:00:00', -0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-23 00:00:00', -3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-24 00:00:00', -7.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-25 00:00:00', -6.68200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-26 00:00:00', -2.74799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-27 00:00:00', 1.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-28 00:00:00', 3.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-29 00:00:00', 2.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-30 00:00:00', 2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-03-31 00:00:00', 1.56799995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-01 00:00:00', 0.312000006437301636, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-02 00:00:00', -0.477999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-03 00:00:00', 3.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-04 00:00:00', 6.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-05 00:00:00', 3.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-06 00:00:00', 5.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-07 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-08 00:00:00', 6.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-09 00:00:00', 10.3620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-10 00:00:00', 5.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-11 00:00:00', 7.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-12 00:00:00', 8.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-13 00:00:00', 9.44299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-14 00:00:00', 6.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-15 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-16 00:00:00', -0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-17 00:00:00', 4.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-18 00:00:00', 9.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-19 00:00:00', 10.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-20 00:00:00', 13.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-21 00:00:00', 14.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-22 00:00:00', 12.7889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-23 00:00:00', 8.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-24 00:00:00', 4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-25 00:00:00', 6.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-26 00:00:00', 8.94699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-27 00:00:00', 9.76099967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-28 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-29 00:00:00', 6.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-04-30 00:00:00', 6.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-01 00:00:00', 8.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-02 00:00:00', 9.90400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-03 00:00:00', 11.6850004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-04 00:00:00', 11.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-05 00:00:00', 8.64700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-06 00:00:00', 11.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-07 00:00:00', 10.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-08 00:00:00', 6.34499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-09 00:00:00', -0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-10 00:00:00', 2.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-11 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-12 00:00:00', 5.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-13 00:00:00', 9.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-14 00:00:00', 12.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-15 00:00:00', 6.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-16 00:00:00', 6.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-17 00:00:00', 9.82800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-18 00:00:00', 9.24899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-19 00:00:00', 10.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-20 00:00:00', 13.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-21 00:00:00', 8.62899971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-22 00:00:00', 11.2559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-23 00:00:00', 14.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-24 00:00:00', 10.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-25 00:00:00', 10.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-26 00:00:00', 12.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-27 00:00:00', 14.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-28 00:00:00', 15.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-29 00:00:00', 13.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-30 00:00:00', 8.34799957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-05-31 00:00:00', 9.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-01 00:00:00', 13.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-02 00:00:00', 7.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-03 00:00:00', 12.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-04 00:00:00', 15.5430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-05 00:00:00', 14.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-06 00:00:00', 9.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-07 00:00:00', 12.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-08 00:00:00', 14.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-09 00:00:00', 17.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-10 00:00:00', 19.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-11 00:00:00', 20.0400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-12 00:00:00', 16.4699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-13 00:00:00', 16.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-14 00:00:00', 15.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-15 00:00:00', 15.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-16 00:00:00', 16.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-17 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-18 00:00:00', 17.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-19 00:00:00', 20.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-20 00:00:00', 21.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-21 00:00:00', 21.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-22 00:00:00', 19.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-23 00:00:00', 13.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-24 00:00:00', 15.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-25 00:00:00', 16.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-26 00:00:00', 13.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-27 00:00:00', 17.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-28 00:00:00', 19.832000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-29 00:00:00', 21.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-06-30 00:00:00', 20.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-01 00:00:00', 19.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-02 00:00:00', 21.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-03 00:00:00', 22.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-04 00:00:00', 23.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-05 00:00:00', 23.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-06 00:00:00', 22.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-07 00:00:00', 22.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-08 00:00:00', 19.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-09 00:00:00', 16.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-10 00:00:00', 16.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-11 00:00:00', 17.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-12 00:00:00', 19.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-13 00:00:00', 20.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-14 00:00:00', 21.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-15 00:00:00', 18.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-16 00:00:00', 21.8209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-17 00:00:00', 22.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-18 00:00:00', 22.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-19 00:00:00', 23.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-20 00:00:00', 24.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-21 00:00:00', 21.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-22 00:00:00', 18.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-23 00:00:00', 15.8070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-24 00:00:00', 11.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-25 00:00:00', 15.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-26 00:00:00', 15.8090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-27 00:00:00', 19.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-28 00:00:00', 17.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-29 00:00:00', 18.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-30 00:00:00', 18.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-07-31 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-01 00:00:00', 19.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-02 00:00:00', 20.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-03 00:00:00', 19.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-04 00:00:00', 19.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-05 00:00:00', 19.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-06 00:00:00', 19.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-07 00:00:00', 19.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-08 00:00:00', 18.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-09 00:00:00', 17.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-10 00:00:00', 14.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-11 00:00:00', 14.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-12 00:00:00', 16.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-13 00:00:00', 18.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-14 00:00:00', 19.3889999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-15 00:00:00', 20.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-16 00:00:00', 19.707000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-17 00:00:00', 17.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-18 00:00:00', 15.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-19 00:00:00', 14.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-20 00:00:00', 16.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-21 00:00:00', 16.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-22 00:00:00', 17.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-23 00:00:00', 16.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-24 00:00:00', 13.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-25 00:00:00', 13.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-26 00:00:00', 17.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-27 00:00:00', 20.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-28 00:00:00', 20.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-29 00:00:00', 20.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-30 00:00:00', 21.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-08-31 00:00:00', 22.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-01 00:00:00', 22.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-02 00:00:00', 21.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-03 00:00:00', 18.7919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-04 00:00:00', 19.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-05 00:00:00', 19.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-06 00:00:00', 19.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-07 00:00:00', 19.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-08 00:00:00', 19.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-09 00:00:00', 19.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-10 00:00:00', 19.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-11 00:00:00', 17.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-12 00:00:00', 15.8620004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-13 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-14 00:00:00', 18.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-15 00:00:00', 19.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-16 00:00:00', 12.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-17 00:00:00', 14.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-18 00:00:00', 16.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-19 00:00:00', 17.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-20 00:00:00', 18.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-21 00:00:00', 17.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-22 00:00:00', 16.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-23 00:00:00', 12.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-24 00:00:00', 13.1689996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-25 00:00:00', 13.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-26 00:00:00', 13.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-27 00:00:00', 10.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-28 00:00:00', 9.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-29 00:00:00', 14.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-09-30 00:00:00', 15.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-01 00:00:00', 14.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-02 00:00:00', 16.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-03 00:00:00', 12.119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-04 00:00:00', 10.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-05 00:00:00', 5.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-06 00:00:00', -0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-07 00:00:00', -0.545000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-08 00:00:00', -2.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-09 00:00:00', -0.620000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-10 00:00:00', 1.22200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-11 00:00:00', 5.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-12 00:00:00', 6.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-13 00:00:00', 6.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-14 00:00:00', 6.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-15 00:00:00', 5.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-16 00:00:00', 2.4159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-17 00:00:00', 3.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-18 00:00:00', 5.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-19 00:00:00', 5.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-20 00:00:00', 4.72599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-21 00:00:00', 4.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-22 00:00:00', 2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-23 00:00:00', 3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-24 00:00:00', 3.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-25 00:00:00', 0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-26 00:00:00', 3.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-27 00:00:00', 5.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-28 00:00:00', 6.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-29 00:00:00', 8.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-30 00:00:00', 4.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-10-31 00:00:00', 7.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-01 00:00:00', 8.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-02 00:00:00', 4.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-03 00:00:00', 3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-04 00:00:00', 0.565999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-05 00:00:00', -0.143000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-06 00:00:00', -2.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-07 00:00:00', 0.488000005483627319, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-08 00:00:00', -5.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-09 00:00:00', -0.945999979972839355, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-10 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-11 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-12 00:00:00', 4.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-13 00:00:00', 2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-14 00:00:00', 7.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-15 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-16 00:00:00', 2.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-17 00:00:00', 1, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-18 00:00:00', -3.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-19 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-20 00:00:00', 1.48899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-21 00:00:00', -2, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-22 00:00:00', -8.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-23 00:00:00', -6.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-24 00:00:00', -1.20000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-25 00:00:00', -1.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-26 00:00:00', -3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-27 00:00:00', -2.88299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-28 00:00:00', -0.705999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-29 00:00:00', -0.0500000007450580597, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-11-30 00:00:00', -3.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-01 00:00:00', -7.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-02 00:00:00', -7.11700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-03 00:00:00', -7.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-04 00:00:00', -6.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-05 00:00:00', -2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-06 00:00:00', -2.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-07 00:00:00', -5.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-08 00:00:00', -1.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-09 00:00:00', -3.34400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-10 00:00:00', -2.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-11 00:00:00', -2.1659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-12 00:00:00', -2.74099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-13 00:00:00', -6.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-14 00:00:00', -0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-15 00:00:00', 1.02199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-16 00:00:00', 0.356000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-17 00:00:00', 0.686999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-18 00:00:00', -0.990000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-19 00:00:00', -0.730000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-20 00:00:00', -1.37999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-21 00:00:00', -4.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-22 00:00:00', -1.25899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-23 00:00:00', 0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-24 00:00:00', 0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-25 00:00:00', 0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-26 00:00:00', 1.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-27 00:00:00', -2.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-28 00:00:00', -3.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-29 00:00:00', -2.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-30 00:00:00', -1.86600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1993-12-31 00:00:00', -2.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-01 00:00:00', -8.08100032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-02 00:00:00', -6.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-03 00:00:00', -4.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-04 00:00:00', -4.63299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-05 00:00:00', -1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-06 00:00:00', -0.574000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-07 00:00:00', -4.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-08 00:00:00', -6.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-09 00:00:00', -7.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-10 00:00:00', -11.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-11 00:00:00', -4.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-12 00:00:00', -2.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-13 00:00:00', -2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-14 00:00:00', -6.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-15 00:00:00', -7.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-16 00:00:00', -4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-17 00:00:00', -2.87899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-18 00:00:00', -6.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-19 00:00:00', -9.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-20 00:00:00', -7.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-21 00:00:00', -5.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-22 00:00:00', -8.06700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-23 00:00:00', -1.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-24 00:00:00', -3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-25 00:00:00', 0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-26 00:00:00', -0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-27 00:00:00', -5.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-28 00:00:00', -5.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-29 00:00:00', -3.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-30 00:00:00', -3.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-01-31 00:00:00', -4.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-01 00:00:00', -1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-02 00:00:00', -3.17499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-03 00:00:00', -3.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-04 00:00:00', -9.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-05 00:00:00', -8.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-06 00:00:00', -4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-07 00:00:00', -8.11200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-08 00:00:00', -7.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-09 00:00:00', -8.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-10 00:00:00', -10.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-11 00:00:00', -11.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-12 00:00:00', -5.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-13 00:00:00', -5.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-14 00:00:00', -4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-15 00:00:00', -5.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-16 00:00:00', -10.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-17 00:00:00', -8.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-18 00:00:00', -7.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-19 00:00:00', -5.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-20 00:00:00', -7.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-21 00:00:00', -8.07400035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-22 00:00:00', -4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-23 00:00:00', -5.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-24 00:00:00', -3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-25 00:00:00', -2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-26 00:00:00', -5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-27 00:00:00', -4.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-02-28 00:00:00', -1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-01 00:00:00', -2.38499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-02 00:00:00', -0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-03 00:00:00', -3.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-04 00:00:00', -3.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-05 00:00:00', -1.51800000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-06 00:00:00', -0.856000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-07 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-08 00:00:00', 1.27799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-09 00:00:00', 0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-10 00:00:00', -1.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-11 00:00:00', 0.889999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-12 00:00:00', 0.785000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-13 00:00:00', 1.79499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-14 00:00:00', -3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-15 00:00:00', -0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-16 00:00:00', 0.280999988317489624, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-17 00:00:00', -0.107000000774860382, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-18 00:00:00', -1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-19 00:00:00', 0.519999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-20 00:00:00', -0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-21 00:00:00', -0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-22 00:00:00', 1.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-23 00:00:00', 4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-24 00:00:00', 4.60699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-25 00:00:00', -0.635999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-26 00:00:00', 1.48800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-27 00:00:00', 5.53299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-28 00:00:00', 2.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-29 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-30 00:00:00', 1.30099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-03-31 00:00:00', 2.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-01 00:00:00', 2.9440000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-02 00:00:00', 6.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-03 00:00:00', 3.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-04 00:00:00', -1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-05 00:00:00', -7.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-06 00:00:00', -8.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-07 00:00:00', -4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-08 00:00:00', -3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-09 00:00:00', -2.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-10 00:00:00', 1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-11 00:00:00', 3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-12 00:00:00', 4.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-13 00:00:00', 1.04700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-14 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-15 00:00:00', 1.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-16 00:00:00', 0.517000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-17 00:00:00', 4.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-18 00:00:00', 5.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-19 00:00:00', 4.56699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-20 00:00:00', 4.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-21 00:00:00', 4.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-22 00:00:00', 5.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-23 00:00:00', 7.5689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-24 00:00:00', 9.96800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-25 00:00:00', 12.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-26 00:00:00', 12.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-27 00:00:00', 14.560999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-28 00:00:00', 12.3769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-29 00:00:00', 4.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-04-30 00:00:00', 4.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-01 00:00:00', 8.97999954223632812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-02 00:00:00', 9.35000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-03 00:00:00', 11.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-04 00:00:00', 11.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-05 00:00:00', 12.3350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-06 00:00:00', 12.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-07 00:00:00', 9.12199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-08 00:00:00', 5.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-09 00:00:00', 7.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-10 00:00:00', 8.90900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-11 00:00:00', 11.6610002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-12 00:00:00', 11.814000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-13 00:00:00', 12.8879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-14 00:00:00', 14.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-15 00:00:00', 16.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-16 00:00:00', 15.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-17 00:00:00', 13.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-18 00:00:00', 10.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-19 00:00:00', 7.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-20 00:00:00', 11.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-21 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-22 00:00:00', 12.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-23 00:00:00', 9.88799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-24 00:00:00', 8.27700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-25 00:00:00', 12.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-26 00:00:00', 11.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-27 00:00:00', 15.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-28 00:00:00', 16.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-29 00:00:00', 16.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-30 00:00:00', 15.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-05-31 00:00:00', 15.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-01 00:00:00', 16.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-02 00:00:00', 15.4779996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-03 00:00:00', 16.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-04 00:00:00', 18.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-05 00:00:00', 16.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-06 00:00:00', 18.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-07 00:00:00', 16.8279991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-08 00:00:00', 13.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-09 00:00:00', 12.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-10 00:00:00', 13.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-11 00:00:00', 11.4250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-12 00:00:00', 11.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-13 00:00:00', 14.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-14 00:00:00', 16.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-15 00:00:00', 16.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-16 00:00:00', 18.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-17 00:00:00', 19.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-18 00:00:00', 19.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-19 00:00:00', 19.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-20 00:00:00', 20.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-21 00:00:00', 20.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-22 00:00:00', 20.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-23 00:00:00', 21.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-24 00:00:00', 18.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-25 00:00:00', 20.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-26 00:00:00', 20.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-27 00:00:00', 20.1620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-28 00:00:00', 22.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-29 00:00:00', 22.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-06-30 00:00:00', 25.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-01 00:00:00', 25.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-02 00:00:00', 20.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-03 00:00:00', 18.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-04 00:00:00', 21.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-05 00:00:00', 23.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-06 00:00:00', 23.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-07 00:00:00', 24.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-08 00:00:00', 25.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-09 00:00:00', 25.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-10 00:00:00', 23.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-11 00:00:00', 19.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-12 00:00:00', 20.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-13 00:00:00', 18.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-14 00:00:00', 17.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-15 00:00:00', 20.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-16 00:00:00', 20.9039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-17 00:00:00', 23.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-18 00:00:00', 24.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-19 00:00:00', 23.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-20 00:00:00', 23.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-21 00:00:00', 24.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-22 00:00:00', 25.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-23 00:00:00', 23.4190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-24 00:00:00', 21.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-25 00:00:00', 23.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-26 00:00:00', 23.1189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-27 00:00:00', 23.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-28 00:00:00', 23.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-29 00:00:00', 22.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-30 00:00:00', 23.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-07-31 00:00:00', 24.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-01 00:00:00', 26.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-02 00:00:00', 27.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-03 00:00:00', 27.9640007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-04 00:00:00', 26.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-05 00:00:00', 26.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-06 00:00:00', 25.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-07 00:00:00', 23.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-08 00:00:00', 20.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-09 00:00:00', 18.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-10 00:00:00', 18.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-11 00:00:00', 21.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-12 00:00:00', 23.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-13 00:00:00', 24.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-14 00:00:00', 23.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-15 00:00:00', 20.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-16 00:00:00', 19.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-17 00:00:00', 19.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-18 00:00:00', 22.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-19 00:00:00', 22.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-20 00:00:00', 23.3530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-21 00:00:00', 23.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-22 00:00:00', 23.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-23 00:00:00', 23.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-24 00:00:00', 23.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-25 00:00:00', 23.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-26 00:00:00', 21.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-27 00:00:00', 21.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-28 00:00:00', 20.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-29 00:00:00', 20.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-30 00:00:00', 21.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-08-31 00:00:00', 19.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-01 00:00:00', 20.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-02 00:00:00', 19.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-03 00:00:00', 19.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-04 00:00:00', 15.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-05 00:00:00', 13.3909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-06 00:00:00', 10.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-07 00:00:00', 12.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-08 00:00:00', 14.425999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-09 00:00:00', 14.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-10 00:00:00', 13.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-11 00:00:00', 14.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-12 00:00:00', 14.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-13 00:00:00', 13.9770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-14 00:00:00', 13.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-15 00:00:00', 11.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-16 00:00:00', 11.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-17 00:00:00', 10.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-18 00:00:00', 4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-19 00:00:00', 2.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-20 00:00:00', 2.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-21 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-22 00:00:00', 8.38500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-23 00:00:00', 8.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-24 00:00:00', 8.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-25 00:00:00', 10.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-26 00:00:00', 11.8660001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-27 00:00:00', 13.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-28 00:00:00', 14.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-29 00:00:00', 13.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-09-30 00:00:00', 12.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-01 00:00:00', 11.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-02 00:00:00', 11.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-03 00:00:00', 10.9549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-04 00:00:00', 9.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-05 00:00:00', 8.75800037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-06 00:00:00', 6.63500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-07 00:00:00', 8.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-08 00:00:00', 9.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-09 00:00:00', 8.10999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-10 00:00:00', 6.65500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-11 00:00:00', 6.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-12 00:00:00', 5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-13 00:00:00', 5.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-14 00:00:00', 5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-15 00:00:00', 8.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-16 00:00:00', 7.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-17 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-18 00:00:00', 8.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-19 00:00:00', 7.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-20 00:00:00', 10.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-21 00:00:00', 10.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-22 00:00:00', 9.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-23 00:00:00', 6.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-24 00:00:00', 3.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-25 00:00:00', 1.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-26 00:00:00', -1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-27 00:00:00', 2.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-28 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-29 00:00:00', 4.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-30 00:00:00', 3.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-10-31 00:00:00', 5.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-01 00:00:00', 3.75900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-02 00:00:00', 0.42300000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-03 00:00:00', 3.52399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-04 00:00:00', 3.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-05 00:00:00', 6.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-06 00:00:00', 5.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-07 00:00:00', 4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-08 00:00:00', 6.87900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-09 00:00:00', 7.13399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-10 00:00:00', 4.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-11 00:00:00', 0.114000000059604645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-12 00:00:00', 0.245000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-13 00:00:00', 1.85300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-14 00:00:00', 0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-15 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-16 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-17 00:00:00', 2.64199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-18 00:00:00', 3.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-19 00:00:00', 0.462000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-20 00:00:00', 3.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-21 00:00:00', 4.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-22 00:00:00', 3.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-23 00:00:00', 4.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-24 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-25 00:00:00', 0.300999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-26 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-27 00:00:00', 0.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-28 00:00:00', 3.8059999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-29 00:00:00', 1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-11-30 00:00:00', 0.870000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-01 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-02 00:00:00', -0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-03 00:00:00', 2.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-04 00:00:00', -0.171000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-05 00:00:00', 0.206000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-06 00:00:00', -5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-07 00:00:00', -8.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-08 00:00:00', -13.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-09 00:00:00', -9.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-10 00:00:00', -8.84300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-11 00:00:00', -6.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-12 00:00:00', -3.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-13 00:00:00', -5.04300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-14 00:00:00', -3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-15 00:00:00', -3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-16 00:00:00', -1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-17 00:00:00', 0.414000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-18 00:00:00', -1.28400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-19 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-20 00:00:00', -0.0160000007599592209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-21 00:00:00', -0.799000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-22 00:00:00', -6.83699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-23 00:00:00', -9.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-24 00:00:00', -10.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-25 00:00:00', -7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-26 00:00:00', -7.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-27 00:00:00', -6.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-28 00:00:00', -9.14000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-29 00:00:00', -8.88799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-30 00:00:00', -4.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1994-12-31 00:00:00', -2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-01 00:00:00', -0.0810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-02 00:00:00', -0.460999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-03 00:00:00', -3.52300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-04 00:00:00', -3.04800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-05 00:00:00', -1.59700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-06 00:00:00', -3.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-07 00:00:00', -6.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-08 00:00:00', -7.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-09 00:00:00', -7.58900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-10 00:00:00', -7.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-11 00:00:00', -4.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-12 00:00:00', -3.86599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-13 00:00:00', -5.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-14 00:00:00', -6.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-15 00:00:00', -7.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-16 00:00:00', -7.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-17 00:00:00', -1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-18 00:00:00', -3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-19 00:00:00', -6.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-20 00:00:00', -6.97100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-21 00:00:00', -7.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-22 00:00:00', -5.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-23 00:00:00', -6.25400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-24 00:00:00', -6.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-25 00:00:00', -9.21599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-26 00:00:00', -4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-27 00:00:00', -4.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-28 00:00:00', -6.29899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-29 00:00:00', -3.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-30 00:00:00', -0.155000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-01-31 00:00:00', -0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-01 00:00:00', -2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-02 00:00:00', -1.61399996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-03 00:00:00', -1.71200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-04 00:00:00', -1.95500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-05 00:00:00', -1.70299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-06 00:00:00', -1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-07 00:00:00', -0.828000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-08 00:00:00', -1.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-09 00:00:00', 0.856000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-10 00:00:00', 0.0320000015199184418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-11 00:00:00', -3.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-12 00:00:00', -5.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-13 00:00:00', -3.86500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-14 00:00:00', -4.58799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-15 00:00:00', -4.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-16 00:00:00', -4.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-17 00:00:00', -8.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-18 00:00:00', -11.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-19 00:00:00', -10.3879995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-20 00:00:00', -5.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-21 00:00:00', -5.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-22 00:00:00', -5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-23 00:00:00', -3.58999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-24 00:00:00', -1.20099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-25 00:00:00', -6.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-26 00:00:00', -6.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-27 00:00:00', -8.08600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-02-28 00:00:00', -8.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-01 00:00:00', -5.89599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-02 00:00:00', -3.90599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-03 00:00:00', -7.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-04 00:00:00', -8.02900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-05 00:00:00', -4.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-06 00:00:00', -3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-07 00:00:00', -3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-08 00:00:00', -3.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-09 00:00:00', -5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-10 00:00:00', -4.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-11 00:00:00', -4.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-12 00:00:00', -3.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-13 00:00:00', -1.97699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-14 00:00:00', -1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-15 00:00:00', -0.563000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-16 00:00:00', 0.444000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-17 00:00:00', 0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-18 00:00:00', 1.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-19 00:00:00', -0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-20 00:00:00', 0.270999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-21 00:00:00', 0.216000005602836609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-22 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-23 00:00:00', 0.316000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-24 00:00:00', -0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-25 00:00:00', 1.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-26 00:00:00', 5.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-27 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-28 00:00:00', -1.16600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-29 00:00:00', -2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-30 00:00:00', -2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-03-31 00:00:00', -0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-01 00:00:00', -2.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-02 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-03 00:00:00', 4.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-04 00:00:00', 5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-05 00:00:00', 7.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-06 00:00:00', 3.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-07 00:00:00', 1.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-08 00:00:00', -1.40900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-09 00:00:00', 2.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-10 00:00:00', 3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-11 00:00:00', 6.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-12 00:00:00', 8.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-13 00:00:00', 10.1899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-14 00:00:00', 9.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-15 00:00:00', 6.93599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-16 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-17 00:00:00', 9.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-18 00:00:00', 6.54199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-19 00:00:00', 5.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-20 00:00:00', 6.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-21 00:00:00', 7.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-22 00:00:00', 7.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-23 00:00:00', 8.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-24 00:00:00', 8.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-25 00:00:00', 10.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-26 00:00:00', 4.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-27 00:00:00', 4.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-28 00:00:00', 6.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-29 00:00:00', 10.2869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-04-30 00:00:00', 9.01299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-01 00:00:00', 11.5159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-02 00:00:00', 12.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-03 00:00:00', 13.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-04 00:00:00', 12.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-05 00:00:00', 14.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-06 00:00:00', 17.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-07 00:00:00', 18.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-08 00:00:00', 18.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-09 00:00:00', 17.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-10 00:00:00', 13.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-11 00:00:00', 12.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-12 00:00:00', 13.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-13 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-14 00:00:00', 14.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-15 00:00:00', 15.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-16 00:00:00', 14.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-17 00:00:00', 10.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-18 00:00:00', 11.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-19 00:00:00', 9.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-20 00:00:00', 10.5539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-21 00:00:00', 10.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-22 00:00:00', 10.1339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-23 00:00:00', 9.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-24 00:00:00', 8.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-25 00:00:00', 6.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-26 00:00:00', 3.2349998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-27 00:00:00', 8.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-28 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-29 00:00:00', 7.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-30 00:00:00', 10.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-05-31 00:00:00', 11.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-01 00:00:00', 12.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-02 00:00:00', 11.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-03 00:00:00', 10.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-04 00:00:00', 15.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-05 00:00:00', 16.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-06 00:00:00', 17.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-07 00:00:00', 13.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-08 00:00:00', 16.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-09 00:00:00', 15.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-10 00:00:00', 12.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-11 00:00:00', 16.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-12 00:00:00', 17.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-13 00:00:00', 11.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-14 00:00:00', 19.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-15 00:00:00', 21.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-16 00:00:00', 22.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-17 00:00:00', 20.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-18 00:00:00', 19.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-19 00:00:00', 17.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-20 00:00:00', 14.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-21 00:00:00', 13.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-22 00:00:00', 15.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-23 00:00:00', 18.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-24 00:00:00', 12.3280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-25 00:00:00', 14.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-26 00:00:00', 14.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-27 00:00:00', 15.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-28 00:00:00', 8.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-29 00:00:00', 5.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-06-30 00:00:00', 5.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-01 00:00:00', 6.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-02 00:00:00', 6.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-03 00:00:00', 19.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-04 00:00:00', 19.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-05 00:00:00', 18.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-06 00:00:00', 19.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-07 00:00:00', 13.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-08 00:00:00', 15.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-09 00:00:00', 16.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-10 00:00:00', 18.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-11 00:00:00', 18.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-12 00:00:00', 20.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-13 00:00:00', 21.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-14 00:00:00', 21.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-15 00:00:00', 22.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-16 00:00:00', 24.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-17 00:00:00', 26.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-18 00:00:00', 26.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-19 00:00:00', 14.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-20 00:00:00', 9.03899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-21 00:00:00', 21.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-22 00:00:00', 22.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-23 00:00:00', 22.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-24 00:00:00', 16.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-25 00:00:00', 16.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-26 00:00:00', 18.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-27 00:00:00', 21.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-28 00:00:00', 21.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-29 00:00:00', 21.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-30 00:00:00', 22.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-07-31 00:00:00', 24.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-01 00:00:00', 24.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-02 00:00:00', 22.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-03 00:00:00', 22.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-04 00:00:00', 20.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-05 00:00:00', 19.3220005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-06 00:00:00', 18.2940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-07 00:00:00', 17.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-08 00:00:00', 16.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-09 00:00:00', 18.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-10 00:00:00', 24.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-11 00:00:00', 17.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-12 00:00:00', 24.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-13 00:00:00', 25.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-14 00:00:00', 23.8419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-15 00:00:00', 22.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-16 00:00:00', 21.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-17 00:00:00', 21.6170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-18 00:00:00', 21.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-19 00:00:00', 22.8139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-20 00:00:00', 21.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-21 00:00:00', 19.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-22 00:00:00', 20.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-23 00:00:00', 22.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-24 00:00:00', 21.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-25 00:00:00', 18.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-26 00:00:00', 20.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-27 00:00:00', 20.8729991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-28 00:00:00', 19.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-29 00:00:00', 9.21300029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-30 00:00:00', 6.6810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-08-31 00:00:00', 5.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-01 00:00:00', 14.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-02 00:00:00', 12.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-03 00:00:00', 10.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-04 00:00:00', 10.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-05 00:00:00', 11.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-06 00:00:00', 13.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-07 00:00:00', 14.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-08 00:00:00', 15.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-09 00:00:00', 16.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-10 00:00:00', 16.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-11 00:00:00', 15.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-12 00:00:00', 15.1239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-13 00:00:00', 14.5780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-14 00:00:00', 15.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-15 00:00:00', 14.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-16 00:00:00', 15.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-17 00:00:00', 16.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-18 00:00:00', 16.8939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-19 00:00:00', 18.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-20 00:00:00', 19.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-21 00:00:00', 20.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-22 00:00:00', 12.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-23 00:00:00', 10.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-24 00:00:00', 14.5600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-25 00:00:00', 16.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-26 00:00:00', 17.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-27 00:00:00', 15.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-28 00:00:00', 8.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-29 00:00:00', 10.6510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-09-30 00:00:00', 9.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-01 00:00:00', 5.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-02 00:00:00', 2.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-03 00:00:00', 2.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-04 00:00:00', 2.24099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-05 00:00:00', 11.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-06 00:00:00', 12.8559999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-07 00:00:00', 13.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-08 00:00:00', 12.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-09 00:00:00', 7.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-10 00:00:00', 6.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-11 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-12 00:00:00', 4.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-13 00:00:00', 4.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-14 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-15 00:00:00', 1.63399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-16 00:00:00', 1.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-17 00:00:00', 0.400999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-18 00:00:00', -4.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-19 00:00:00', -1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-20 00:00:00', -0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-21 00:00:00', 0.137999996542930603, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-22 00:00:00', 1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-23 00:00:00', 5.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-24 00:00:00', 2.60100007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-25 00:00:00', -0.395999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-26 00:00:00', 1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-27 00:00:00', 1.88600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-28 00:00:00', 1.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-29 00:00:00', 1.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-30 00:00:00', 2.67000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-10-31 00:00:00', 4.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-01 00:00:00', 5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-02 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-03 00:00:00', 8.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-04 00:00:00', 7.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-05 00:00:00', 7.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-06 00:00:00', 4.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-07 00:00:00', 5.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-08 00:00:00', 6.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-09 00:00:00', 7.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-10 00:00:00', 7.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-11 00:00:00', 7.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-12 00:00:00', 6.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-13 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-14 00:00:00', 3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-15 00:00:00', 0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-16 00:00:00', 0.344999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-17 00:00:00', 1.70200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-18 00:00:00', 1.7929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-19 00:00:00', 0.13500000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-20 00:00:00', 1.47899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-21 00:00:00', 0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-22 00:00:00', -0.291000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-23 00:00:00', -0.257999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-24 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-25 00:00:00', 1.80400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-26 00:00:00', 2.0429999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-27 00:00:00', -4.60599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-28 00:00:00', -7.73199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-29 00:00:00', -5.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-11-30 00:00:00', -3.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-01 00:00:00', -3.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-02 00:00:00', -3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-03 00:00:00', -4.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-04 00:00:00', -2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-05 00:00:00', -3.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-06 00:00:00', -1.77100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-07 00:00:00', -3.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-08 00:00:00', -4.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-09 00:00:00', -7.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-10 00:00:00', -9.48299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-11 00:00:00', -9.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-12 00:00:00', -6.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-13 00:00:00', -6.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-14 00:00:00', -8.23499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-15 00:00:00', -9.35999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-16 00:00:00', -5.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-17 00:00:00', -3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-18 00:00:00', -3.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-19 00:00:00', -6.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-20 00:00:00', -6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-21 00:00:00', -4.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-22 00:00:00', -2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-23 00:00:00', -3.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-24 00:00:00', -5.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-25 00:00:00', -0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-26 00:00:00', 0.544000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-27 00:00:00', -0.722999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-28 00:00:00', -0.272000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-29 00:00:00', 0.236000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-30 00:00:00', 0.0890000015497207642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1995-12-31 00:00:00', -0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-01 00:00:00', 0.386999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-02 00:00:00', -1.66999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-03 00:00:00', -1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-04 00:00:00', -0.230000004172325134, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-05 00:00:00', -0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-06 00:00:00', -1.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-07 00:00:00', -0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-08 00:00:00', -3.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-09 00:00:00', -5.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-10 00:00:00', -13.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-11 00:00:00', -12.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-12 00:00:00', -7.81799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-13 00:00:00', -9.15200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-14 00:00:00', -11.0889997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-15 00:00:00', -13.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-16 00:00:00', -11.7559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-17 00:00:00', -7.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-18 00:00:00', -4.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-19 00:00:00', -6.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-20 00:00:00', -6.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-21 00:00:00', -9.36200046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-22 00:00:00', -8.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-23 00:00:00', -5.50299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-24 00:00:00', -5.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-25 00:00:00', -6.9310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-26 00:00:00', -7.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-27 00:00:00', -8.24899959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-28 00:00:00', -9.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-29 00:00:00', -4.03700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-30 00:00:00', -3.46300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-01-31 00:00:00', -3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-01 00:00:00', -2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-02 00:00:00', -0.861000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-03 00:00:00', -3.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-04 00:00:00', -4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-05 00:00:00', -0.624000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-06 00:00:00', 0.533999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-07 00:00:00', -2.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-08 00:00:00', -2.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-09 00:00:00', -1.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-10 00:00:00', -0.418999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-11 00:00:00', -0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-12 00:00:00', -0.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-13 00:00:00', -6.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-14 00:00:00', -10.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-15 00:00:00', -12.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-16 00:00:00', -5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-17 00:00:00', -4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-18 00:00:00', -1.52400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-19 00:00:00', -0.908999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-20 00:00:00', -1.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-21 00:00:00', -2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-22 00:00:00', -3.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-23 00:00:00', -2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-24 00:00:00', -7.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-25 00:00:00', -5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-26 00:00:00', -8.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-27 00:00:00', -9.41699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-28 00:00:00', -6.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-02-29 00:00:00', -1.4570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-01 00:00:00', -3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-02 00:00:00', -3.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-03 00:00:00', -0.86799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-04 00:00:00', 0.523999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-05 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-06 00:00:00', -1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-07 00:00:00', -3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-08 00:00:00', 0.182999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-09 00:00:00', 0.451000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-10 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-11 00:00:00', 1.32500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-12 00:00:00', -0.375999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-13 00:00:00', 3.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-14 00:00:00', 1.27199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-15 00:00:00', -1.21099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-16 00:00:00', -4.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-17 00:00:00', -4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-18 00:00:00', -6.20699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-19 00:00:00', -6.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-20 00:00:00', -5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-21 00:00:00', -5.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-22 00:00:00', -2.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-23 00:00:00', 0.0419999994337558746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-24 00:00:00', -1.52100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-25 00:00:00', -0.187999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-26 00:00:00', 0.847000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-27 00:00:00', 0.904999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-28 00:00:00', -5.28000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-29 00:00:00', -4.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-30 00:00:00', -5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-03-31 00:00:00', -2.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-01 00:00:00', -0.778999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-02 00:00:00', -1.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-03 00:00:00', -1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-04 00:00:00', -2.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-05 00:00:00', -5.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-06 00:00:00', -3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-07 00:00:00', -2.57500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-08 00:00:00', -0.421999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-09 00:00:00', -0.959999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-10 00:00:00', 1.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-11 00:00:00', 0.740999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-12 00:00:00', 0.305000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-13 00:00:00', 2.85899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-14 00:00:00', 10.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-15 00:00:00', 9.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-16 00:00:00', 5.79899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-17 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-18 00:00:00', 7.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-19 00:00:00', 8.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-20 00:00:00', 6.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-21 00:00:00', 9.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-22 00:00:00', 9.90499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-23 00:00:00', 4.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-24 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-25 00:00:00', 7.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-26 00:00:00', 4.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-27 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-28 00:00:00', 7.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-29 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-04-30 00:00:00', 5.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-01 00:00:00', 1.72599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-02 00:00:00', 3.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-03 00:00:00', 4.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-04 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-05 00:00:00', 0.635999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-06 00:00:00', 3.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-07 00:00:00', 3.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-08 00:00:00', 2.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-09 00:00:00', 5.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-10 00:00:00', 6.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-11 00:00:00', 6.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-12 00:00:00', 7.88199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-13 00:00:00', 10.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-14 00:00:00', 10.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-15 00:00:00', 9.62100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-16 00:00:00', 10.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-17 00:00:00', 12.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-18 00:00:00', 13.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-19 00:00:00', 12.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-20 00:00:00', 8.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-21 00:00:00', 10.7060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-22 00:00:00', 10.380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-23 00:00:00', 10.4219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-24 00:00:00', 10.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-25 00:00:00', 11.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-26 00:00:00', 11.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-27 00:00:00', 7.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-28 00:00:00', 3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-29 00:00:00', 7.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-30 00:00:00', 12.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-05-31 00:00:00', 13.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-01 00:00:00', 14.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-02 00:00:00', 16.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-03 00:00:00', 15.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-04 00:00:00', 15.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-05 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-06 00:00:00', 18.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-07 00:00:00', 19.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-08 00:00:00', 18.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-09 00:00:00', 18.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-10 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-11 00:00:00', 19.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-12 00:00:00', 15.3070001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-13 00:00:00', 14.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-14 00:00:00', 13.9849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-15 00:00:00', 12.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-16 00:00:00', 8.52900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-17 00:00:00', 8.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-18 00:00:00', 11.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-19 00:00:00', 13.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-20 00:00:00', 15.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-21 00:00:00', 17.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-22 00:00:00', 19.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-23 00:00:00', 19.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-24 00:00:00', 19.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-25 00:00:00', 18.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-26 00:00:00', 18.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-27 00:00:00', 16.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-28 00:00:00', 15.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-29 00:00:00', 14.5190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-06-30 00:00:00', 17.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-01 00:00:00', 20.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-02 00:00:00', 17.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-03 00:00:00', 17.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-04 00:00:00', 17.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-05 00:00:00', 18.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-06 00:00:00', 19.9419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-07 00:00:00', 21.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-08 00:00:00', 21.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-09 00:00:00', 21.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-10 00:00:00', 19.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-11 00:00:00', 18.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-12 00:00:00', 19.0729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-13 00:00:00', 15.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-14 00:00:00', 13.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-15 00:00:00', 13.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-16 00:00:00', 13.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-17 00:00:00', 14.9499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-18 00:00:00', 18.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-19 00:00:00', 19.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-20 00:00:00', 16.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-21 00:00:00', 16.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-22 00:00:00', 19.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-23 00:00:00', 19.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-24 00:00:00', 22.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-25 00:00:00', 22.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-26 00:00:00', 23.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-27 00:00:00', 24.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-28 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-29 00:00:00', 23.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-30 00:00:00', 24.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-07-31 00:00:00', 21.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-01 00:00:00', 22.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-02 00:00:00', 20.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-03 00:00:00', 22.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-04 00:00:00', 21.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-05 00:00:00', 23.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-06 00:00:00', 23.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-07 00:00:00', 23.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-08 00:00:00', 22.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-09 00:00:00', 23.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-10 00:00:00', 23.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-11 00:00:00', 24.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-12 00:00:00', 25.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-13 00:00:00', 24.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-14 00:00:00', 22.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-15 00:00:00', 18.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-16 00:00:00', 16.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-17 00:00:00', 16.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-18 00:00:00', 16.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-19 00:00:00', 16.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-20 00:00:00', 15.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-21 00:00:00', 17.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-22 00:00:00', 18.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-23 00:00:00', 18.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-24 00:00:00', 19.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-25 00:00:00', 18.9930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-26 00:00:00', 19.9260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-27 00:00:00', 21.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-28 00:00:00', 22.6299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-29 00:00:00', 17.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-30 00:00:00', 14.1920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-08-31 00:00:00', 12.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-01 00:00:00', 13.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-02 00:00:00', 13.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-03 00:00:00', 14.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-04 00:00:00', 14.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-05 00:00:00', 16.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-06 00:00:00', 17.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-07 00:00:00', 18.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-08 00:00:00', 19.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-09 00:00:00', 22.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-10 00:00:00', 23.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-11 00:00:00', 22.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-12 00:00:00', 21.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-13 00:00:00', 21.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-14 00:00:00', 21.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-15 00:00:00', 18.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-16 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-17 00:00:00', 16.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-18 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-19 00:00:00', 18.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-20 00:00:00', 16.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-21 00:00:00', 17.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-22 00:00:00', 20.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-23 00:00:00', 18.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-24 00:00:00', 13.7349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-25 00:00:00', 11.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-26 00:00:00', 8.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-27 00:00:00', 10.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-28 00:00:00', 11.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-29 00:00:00', 13.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-09-30 00:00:00', 14.2510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-01 00:00:00', 9.30099964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-02 00:00:00', 2.43300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-03 00:00:00', 5.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-04 00:00:00', 7.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-05 00:00:00', 6.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-06 00:00:00', 6.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-07 00:00:00', 7.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-08 00:00:00', 3.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-09 00:00:00', 6.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-10 00:00:00', 5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-11 00:00:00', 5.38899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-12 00:00:00', 6.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-13 00:00:00', 3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-14 00:00:00', 4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-15 00:00:00', 3.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-16 00:00:00', 1.95299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-17 00:00:00', 0.990000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-18 00:00:00', 1.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-19 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-20 00:00:00', -0.0579999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-21 00:00:00', 0.864000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-22 00:00:00', 2.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-23 00:00:00', 3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-24 00:00:00', 5.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-25 00:00:00', 6.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-26 00:00:00', 7.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-27 00:00:00', 4.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-28 00:00:00', 5.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-29 00:00:00', 4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-30 00:00:00', 4.40500020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-10-31 00:00:00', 7.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-01 00:00:00', -0.335999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-02 00:00:00', 4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-03 00:00:00', 2.81100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-04 00:00:00', 0.0390000008046627045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-05 00:00:00', 1.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-06 00:00:00', 0.707000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-07 00:00:00', 3.02300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-08 00:00:00', 4.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-09 00:00:00', 5.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-10 00:00:00', 4.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-11 00:00:00', 0.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-12 00:00:00', -2.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-13 00:00:00', -5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-14 00:00:00', -6.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-15 00:00:00', -1.30400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-16 00:00:00', -0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-17 00:00:00', -3.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-18 00:00:00', -5.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-19 00:00:00', -6.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-20 00:00:00', -4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-21 00:00:00', -2.5969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-22 00:00:00', -3.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-23 00:00:00', -0.856999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-24 00:00:00', -1.50800001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-25 00:00:00', -2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-26 00:00:00', -2.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-27 00:00:00', -2.47000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-28 00:00:00', -1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-29 00:00:00', -0.32699999213218689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-11-30 00:00:00', -2.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-01 00:00:00', -4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-02 00:00:00', -4.20599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-03 00:00:00', -5.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-04 00:00:00', -7.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-05 00:00:00', -7.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-06 00:00:00', -8.85299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-07 00:00:00', -7.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-08 00:00:00', -6.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-09 00:00:00', -4.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-10 00:00:00', -0.578000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-11 00:00:00', 0.052000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-12 00:00:00', -1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-13 00:00:00', -2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-14 00:00:00', -1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-15 00:00:00', 0.337000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-16 00:00:00', 0.127000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-17 00:00:00', -1.08700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-18 00:00:00', -2.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-19 00:00:00', -0.874000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-20 00:00:00', -0.442999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-21 00:00:00', -1.20299994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-22 00:00:00', -0.372999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-23 00:00:00', 0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-24 00:00:00', -1.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-25 00:00:00', -1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-26 00:00:00', -0.750999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-27 00:00:00', -0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-28 00:00:00', -0.064999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-29 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-30 00:00:00', 1.96800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1996-12-31 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-01 00:00:00', -0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-02 00:00:00', 2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-03 00:00:00', -0.201000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-04 00:00:00', -4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-05 00:00:00', -5.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-06 00:00:00', -2.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-07 00:00:00', -1.89100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-08 00:00:00', -2.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-09 00:00:00', -0.80699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-10 00:00:00', -0.558000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-11 00:00:00', -1.58700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-12 00:00:00', -4.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-13 00:00:00', -5.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-14 00:00:00', -7.61499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-15 00:00:00', -5.48400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-16 00:00:00', -2.04399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-17 00:00:00', -2.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-18 00:00:00', -3.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-19 00:00:00', -14.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-20 00:00:00', -10.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-21 00:00:00', -7.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-22 00:00:00', -4.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-23 00:00:00', -8.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-24 00:00:00', -9.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-25 00:00:00', -4.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-26 00:00:00', -0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-27 00:00:00', -4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-28 00:00:00', -2.56800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-29 00:00:00', -6.02600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-30 00:00:00', -4.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-01-31 00:00:00', -4.85599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-01 00:00:00', -5.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-02 00:00:00', -10.8809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-03 00:00:00', -6.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-04 00:00:00', -5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-05 00:00:00', -4.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-06 00:00:00', -3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-07 00:00:00', -6.72499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-08 00:00:00', -12.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-09 00:00:00', -11.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-10 00:00:00', -8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-11 00:00:00', -9.29599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-12 00:00:00', -6.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-13 00:00:00', -4.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-14 00:00:00', -5.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-15 00:00:00', -2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-16 00:00:00', -2.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-17 00:00:00', -3.10700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-18 00:00:00', -2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-19 00:00:00', -1.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-20 00:00:00', -5.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-21 00:00:00', -5.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-22 00:00:00', -1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-23 00:00:00', -0.665000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-24 00:00:00', -1.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-25 00:00:00', -5.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-26 00:00:00', -3.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-27 00:00:00', 0.272000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-02-28 00:00:00', -0.215000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-01 00:00:00', -1.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-02 00:00:00', -5.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-03 00:00:00', -4.50199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-04 00:00:00', -0.0630000010132789612, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-05 00:00:00', -1.02100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-06 00:00:00', -0.529999971389770508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-07 00:00:00', -0.526000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-08 00:00:00', 0.561999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-09 00:00:00', -3.4030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-10 00:00:00', -4.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-11 00:00:00', -6.85699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-12 00:00:00', -5.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-13 00:00:00', -1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-14 00:00:00', -4.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-15 00:00:00', -4.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-16 00:00:00', -2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-17 00:00:00', -0.566999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-18 00:00:00', -1.01499998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-19 00:00:00', -2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-20 00:00:00', -0.745999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-21 00:00:00', -0.968999981880187988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-22 00:00:00', -4.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-23 00:00:00', -1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-24 00:00:00', 2.85800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-25 00:00:00', 7.01200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-26 00:00:00', 5.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-27 00:00:00', 0.902999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-28 00:00:00', -0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-29 00:00:00', 0.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-30 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-03-31 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-01 00:00:00', 0.916000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-02 00:00:00', -0.381999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-03 00:00:00', -0.0370000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-04 00:00:00', 1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-05 00:00:00', 5.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-06 00:00:00', 1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-07 00:00:00', 4.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-08 00:00:00', 3.17600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-09 00:00:00', 3.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-10 00:00:00', 7.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-11 00:00:00', 7.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-12 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-13 00:00:00', -0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-14 00:00:00', -0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-15 00:00:00', -0.477999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-16 00:00:00', 5.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-17 00:00:00', 7.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-18 00:00:00', 5.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-19 00:00:00', 3.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-20 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-21 00:00:00', 2.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-22 00:00:00', 8.61400032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-23 00:00:00', 11.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-24 00:00:00', 9.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-25 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-26 00:00:00', 11.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-27 00:00:00', 11.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-28 00:00:00', 9.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-29 00:00:00', 11.6400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-04-30 00:00:00', 7.46500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-01 00:00:00', 8.94799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-02 00:00:00', 6.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-03 00:00:00', 7.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-04 00:00:00', 10.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-05 00:00:00', 13.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-06 00:00:00', 7.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-07 00:00:00', -0.532999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-08 00:00:00', 0.851999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-09 00:00:00', 4.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-10 00:00:00', 6.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-11 00:00:00', 2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-12 00:00:00', 2.66899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-13 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-14 00:00:00', 8.03600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-15 00:00:00', 8.43200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-16 00:00:00', 4.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-17 00:00:00', 4.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-18 00:00:00', 9.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-19 00:00:00', 11.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-20 00:00:00', 12.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-21 00:00:00', 12.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-22 00:00:00', 12.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-23 00:00:00', 14.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-24 00:00:00', 14.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-25 00:00:00', 13.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-26 00:00:00', 13.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-27 00:00:00', 12.5129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-28 00:00:00', 14.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-29 00:00:00', 15.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-30 00:00:00', 16.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-05-31 00:00:00', 16.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-01 00:00:00', 15.8809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-02 00:00:00', 15.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-03 00:00:00', 15.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-04 00:00:00', 12.6750001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-05 00:00:00', 14.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-06 00:00:00', 15.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-07 00:00:00', 16.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-08 00:00:00', 17.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-09 00:00:00', 16.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-10 00:00:00', 16.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-11 00:00:00', 13.4940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-12 00:00:00', 13.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-13 00:00:00', 15.8529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-14 00:00:00', 16.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-15 00:00:00', 18.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-16 00:00:00', 18.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-17 00:00:00', 18.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-18 00:00:00', 17.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-19 00:00:00', 13.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-20 00:00:00', 16.5659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-21 00:00:00', 16.5470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-22 00:00:00', 16.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-23 00:00:00', 18.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-24 00:00:00', 20.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-25 00:00:00', 20.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-26 00:00:00', 21.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-27 00:00:00', 19.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-28 00:00:00', 18.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-29 00:00:00', 15.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-06-30 00:00:00', 15.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-01 00:00:00', 17.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-02 00:00:00', 19.9740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-03 00:00:00', 20.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-04 00:00:00', 20.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-05 00:00:00', 19.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-06 00:00:00', 21.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-07 00:00:00', 22.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-08 00:00:00', 21.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-09 00:00:00', 18.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-10 00:00:00', 18.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-11 00:00:00', 20.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-12 00:00:00', 21.5849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-13 00:00:00', 21.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-14 00:00:00', 22.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-15 00:00:00', 24.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-16 00:00:00', 27.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-17 00:00:00', 27.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-18 00:00:00', 28.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-19 00:00:00', 28.0909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-20 00:00:00', 25.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-21 00:00:00', 22.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-22 00:00:00', 20.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-23 00:00:00', 22.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-24 00:00:00', 23.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-25 00:00:00', 23.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-26 00:00:00', 25.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-27 00:00:00', 26.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-28 00:00:00', 26.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-29 00:00:00', 23.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-30 00:00:00', 22.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-07-31 00:00:00', 21.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-01 00:00:00', 18.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-02 00:00:00', 15.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-03 00:00:00', 16.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-04 00:00:00', 18.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-05 00:00:00', 20.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-06 00:00:00', 22.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-07 00:00:00', 24.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-08 00:00:00', 25.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-09 00:00:00', 25.4039993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-10 00:00:00', 24.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-11 00:00:00', 23.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-12 00:00:00', 20.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-13 00:00:00', 21.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-14 00:00:00', 23.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-15 00:00:00', 25.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-16 00:00:00', 25.5359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-17 00:00:00', 25.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-18 00:00:00', 26.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-19 00:00:00', 27.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-20 00:00:00', 27.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-21 00:00:00', 25.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-22 00:00:00', 25.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-23 00:00:00', 23.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-24 00:00:00', 19.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-25 00:00:00', 17.3449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-26 00:00:00', 17.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-27 00:00:00', 17.5900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-28 00:00:00', 18.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-29 00:00:00', 19.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-30 00:00:00', 19.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-08-31 00:00:00', 20.8610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-01 00:00:00', 21.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-02 00:00:00', 23.7439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-03 00:00:00', 23.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-04 00:00:00', 23.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-05 00:00:00', 21.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-06 00:00:00', 18.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-07 00:00:00', 15.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-08 00:00:00', 13.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-09 00:00:00', 14.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-10 00:00:00', 16.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-11 00:00:00', 18.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-12 00:00:00', 18.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-13 00:00:00', 18.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-14 00:00:00', 19.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-15 00:00:00', 17.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-16 00:00:00', 14.9809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-17 00:00:00', 16.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-18 00:00:00', 16.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-19 00:00:00', 14.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-20 00:00:00', 13.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-21 00:00:00', 13.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-22 00:00:00', 14.8179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-23 00:00:00', 15.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-24 00:00:00', 17.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-25 00:00:00', 17.4389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-26 00:00:00', 16.7229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-27 00:00:00', 15.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-28 00:00:00', 15.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-29 00:00:00', 15.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-09-30 00:00:00', 15.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-01 00:00:00', 15.8520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-02 00:00:00', 16.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-03 00:00:00', 16.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-04 00:00:00', 16.5739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-05 00:00:00', 14.8280000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-06 00:00:00', 12.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-07 00:00:00', 14.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-08 00:00:00', 8.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-09 00:00:00', 9.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-10 00:00:00', 8.75899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-11 00:00:00', 10.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-12 00:00:00', 10.8030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-13 00:00:00', 11.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-14 00:00:00', 11.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-15 00:00:00', 8.00399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-16 00:00:00', 10.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-17 00:00:00', 10.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-18 00:00:00', 9.18799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-19 00:00:00', 9.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-20 00:00:00', 9.42599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-21 00:00:00', 7.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-22 00:00:00', 7.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-23 00:00:00', 9.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-24 00:00:00', 9.81200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-25 00:00:00', 8.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-26 00:00:00', 4.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-27 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-28 00:00:00', 6.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-29 00:00:00', 6.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-30 00:00:00', 6.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-10-31 00:00:00', 6.52899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-01 00:00:00', 6.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-02 00:00:00', -0.349999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-03 00:00:00', 5.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-04 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-05 00:00:00', 6.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-06 00:00:00', 4.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-07 00:00:00', -0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-08 00:00:00', -1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-09 00:00:00', -3.05500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-10 00:00:00', 0.158000007271766663, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-11 00:00:00', 0.368000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-12 00:00:00', 3.61400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-13 00:00:00', 4.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-14 00:00:00', 0.569999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-15 00:00:00', -1.78400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-16 00:00:00', -1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-17 00:00:00', -0.745000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-18 00:00:00', -0.280999988317489624, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-19 00:00:00', -0.195999994874000549, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-20 00:00:00', -0.291000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-21 00:00:00', 0.171000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-22 00:00:00', 0.24400000274181366, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-23 00:00:00', -0.690999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-24 00:00:00', -2.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-25 00:00:00', -4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-26 00:00:00', -5.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-27 00:00:00', -4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-28 00:00:00', -3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-29 00:00:00', -4.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-11-30 00:00:00', -3.15499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-01 00:00:00', -0.493999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-02 00:00:00', -5.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-03 00:00:00', -4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-04 00:00:00', -3.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-05 00:00:00', -3.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-06 00:00:00', -3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-07 00:00:00', -0.839999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-08 00:00:00', -1.60699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-09 00:00:00', -0.694000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-10 00:00:00', -1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-11 00:00:00', 0.104000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-12 00:00:00', -1.87699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-13 00:00:00', -4.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-14 00:00:00', -3.06800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-15 00:00:00', -1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-16 00:00:00', -2.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-17 00:00:00', -3.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-18 00:00:00', -6.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-19 00:00:00', -6.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-20 00:00:00', -5.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-21 00:00:00', -3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-22 00:00:00', -3.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-23 00:00:00', -7.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-24 00:00:00', -4.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-25 00:00:00', -5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-26 00:00:00', -5.85300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-27 00:00:00', -5.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-28 00:00:00', -10.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-29 00:00:00', -8.54399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-30 00:00:00', -3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1997-12-31 00:00:00', -6.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-01 00:00:00', -3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-02 00:00:00', -3.0559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-03 00:00:00', -3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-04 00:00:00', -6.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-05 00:00:00', -4.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-06 00:00:00', -0.629000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-07 00:00:00', -2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-08 00:00:00', -7.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-09 00:00:00', -5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-10 00:00:00', -2.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-11 00:00:00', -5.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-12 00:00:00', -4.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-13 00:00:00', -3.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-14 00:00:00', -5.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-15 00:00:00', -10.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-16 00:00:00', -8.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-17 00:00:00', -11.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-18 00:00:00', -9.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-19 00:00:00', -8.71399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-20 00:00:00', -10.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-21 00:00:00', -6.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-22 00:00:00', -7.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-23 00:00:00', -10.6709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-24 00:00:00', -7.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-25 00:00:00', -6.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-26 00:00:00', -4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-27 00:00:00', -3.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-28 00:00:00', -5.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-29 00:00:00', -2.97000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-30 00:00:00', -1.97599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-01-31 00:00:00', -3.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-01 00:00:00', -4.88600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-02 00:00:00', -6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-03 00:00:00', -5.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-04 00:00:00', -2.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-05 00:00:00', -5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-06 00:00:00', -3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-07 00:00:00', -1.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-08 00:00:00', -0.976000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-09 00:00:00', -0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-10 00:00:00', 0.55699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-11 00:00:00', -5.58699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-12 00:00:00', -0.156000003218650818, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-13 00:00:00', -1.38399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-14 00:00:00', -3.4179999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-15 00:00:00', -5.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-16 00:00:00', -5.51100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-17 00:00:00', -9.09300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-18 00:00:00', -8.29599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-19 00:00:00', -2.91199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-20 00:00:00', -5.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-21 00:00:00', -6.48899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-22 00:00:00', -8.53800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-23 00:00:00', -10.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-24 00:00:00', -6.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-25 00:00:00', -4.67600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-26 00:00:00', -1.27799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-27 00:00:00', -5.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-02-28 00:00:00', -2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-01 00:00:00', -5.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-02 00:00:00', -3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-03 00:00:00', -5.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-04 00:00:00', -6.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-05 00:00:00', -5.87400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-06 00:00:00', -8.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-07 00:00:00', -9.62399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-08 00:00:00', -5.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-09 00:00:00', -3.20199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-10 00:00:00', -1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-11 00:00:00', -1.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-12 00:00:00', -2.60700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-13 00:00:00', -2.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-14 00:00:00', -3.07599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-15 00:00:00', -0.305000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-16 00:00:00', -0.29800000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-17 00:00:00', -1.1260000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-18 00:00:00', 1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-19 00:00:00', 0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-20 00:00:00', 0.432000011205673218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-21 00:00:00', -1.12699997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-22 00:00:00', -2.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-23 00:00:00', -0.884000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-24 00:00:00', 0.74299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-25 00:00:00', 4.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-26 00:00:00', 1.83800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-27 00:00:00', 1.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-28 00:00:00', 2.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-29 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-30 00:00:00', 2.63700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-03-31 00:00:00', 5.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-01 00:00:00', 2.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-02 00:00:00', 0.741999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-03 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-04 00:00:00', 4.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-05 00:00:00', 7.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-06 00:00:00', 6.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-07 00:00:00', 4.47599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-08 00:00:00', 3.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-09 00:00:00', 3.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-10 00:00:00', 6.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-11 00:00:00', 7.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-12 00:00:00', 7.51800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-13 00:00:00', 8.31000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-14 00:00:00', 12.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-15 00:00:00', 12.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-16 00:00:00', 13.2760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-17 00:00:00', 13.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-18 00:00:00', 13.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-19 00:00:00', 14.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-20 00:00:00', 8.03400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-21 00:00:00', 5.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-22 00:00:00', 11.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-23 00:00:00', 13.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-24 00:00:00', 7.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-25 00:00:00', 3.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-26 00:00:00', 0.289000004529953003, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-27 00:00:00', 4.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-28 00:00:00', 8.57199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-29 00:00:00', 11.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-04-30 00:00:00', 6.84100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-01 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-02 00:00:00', 4.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-03 00:00:00', 2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-04 00:00:00', 5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-05 00:00:00', 3.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-06 00:00:00', 1.32899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-07 00:00:00', 4.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-08 00:00:00', 9.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-09 00:00:00', 7.12799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-10 00:00:00', 3.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-11 00:00:00', 6.18699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-12 00:00:00', 6.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-13 00:00:00', 6.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-14 00:00:00', 14.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-15 00:00:00', 8.55799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-16 00:00:00', 5.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-17 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-18 00:00:00', 3.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-19 00:00:00', 9.01500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-20 00:00:00', 11.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-21 00:00:00', 10.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-22 00:00:00', 15.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-23 00:00:00', 16.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-24 00:00:00', 14.4560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-25 00:00:00', 14.7370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-26 00:00:00', 10.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-27 00:00:00', 9.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-28 00:00:00', 6.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-29 00:00:00', 8.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-30 00:00:00', 11.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-05-31 00:00:00', 9.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-01 00:00:00', 11.5649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-02 00:00:00', 11.6960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-03 00:00:00', 6.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-04 00:00:00', 11.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-05 00:00:00', 11.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-06 00:00:00', 9.43599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-07 00:00:00', 8.05500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-08 00:00:00', 14.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-09 00:00:00', 15.1120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-10 00:00:00', 8.66199970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-11 00:00:00', 9.90200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-12 00:00:00', 11.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-13 00:00:00', 11.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-14 00:00:00', 9.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-15 00:00:00', 14.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-16 00:00:00', 15.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-17 00:00:00', 14.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-18 00:00:00', 14.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-19 00:00:00', 16.2759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-20 00:00:00', 17.5610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-21 00:00:00', 15.1280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-22 00:00:00', 14.1969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-23 00:00:00', 15.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-24 00:00:00', 17.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-25 00:00:00', 18.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-26 00:00:00', 19.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-27 00:00:00', 19.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-28 00:00:00', 19.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-29 00:00:00', 21.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-06-30 00:00:00', 16.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-01 00:00:00', 16.5349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-02 00:00:00', 17.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-03 00:00:00', 18.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-04 00:00:00', 19.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-05 00:00:00', 20.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-06 00:00:00', 23.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-07 00:00:00', 25.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-08 00:00:00', 25.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-09 00:00:00', 25.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-10 00:00:00', 25.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-11 00:00:00', 22.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-12 00:00:00', 19.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-13 00:00:00', 21.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-14 00:00:00', 22.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-15 00:00:00', 22.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-16 00:00:00', 19.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-17 00:00:00', 20.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-18 00:00:00', 21.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-19 00:00:00', 20.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-20 00:00:00', 19.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-21 00:00:00', 19.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-22 00:00:00', 20.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-23 00:00:00', 16.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-24 00:00:00', 18.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-25 00:00:00', 16.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-26 00:00:00', 13.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-27 00:00:00', 16.7520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-28 00:00:00', 17.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-29 00:00:00', 17.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-30 00:00:00', 17.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-07-31 00:00:00', 20.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-01 00:00:00', 19.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-02 00:00:00', 20.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-03 00:00:00', 20.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-04 00:00:00', 19.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-05 00:00:00', 16.1170005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-06 00:00:00', 15.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-07 00:00:00', 15.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-08 00:00:00', 15.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-09 00:00:00', 16.9629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-10 00:00:00', 20.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-11 00:00:00', 22.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-12 00:00:00', 22.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-13 00:00:00', 22.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-14 00:00:00', 21.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-15 00:00:00', 19.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-16 00:00:00', 19.4249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-17 00:00:00', 19.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-18 00:00:00', 20.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-19 00:00:00', 18.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-20 00:00:00', 18.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-21 00:00:00', 18.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-22 00:00:00', 18.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-23 00:00:00', 18.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-24 00:00:00', 19.2420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-25 00:00:00', 18.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-26 00:00:00', 19.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-27 00:00:00', 20.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-28 00:00:00', 20.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-29 00:00:00', 20.1030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-30 00:00:00', 18.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-08-31 00:00:00', 20.5200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-01 00:00:00', 21.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-02 00:00:00', 22.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-03 00:00:00', 23.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-04 00:00:00', 22.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-05 00:00:00', 22.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-06 00:00:00', 22.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-07 00:00:00', 21.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-08 00:00:00', 19.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-09 00:00:00', 17.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-10 00:00:00', 17.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-11 00:00:00', 16.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-12 00:00:00', 8.80500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-13 00:00:00', 6.59499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-14 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-15 00:00:00', 4.69500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-16 00:00:00', 6.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-17 00:00:00', 9.84200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-18 00:00:00', 5.22100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-19 00:00:00', 12.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-20 00:00:00', 11.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-21 00:00:00', 13.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-22 00:00:00', 12.3389997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-23 00:00:00', 14.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-24 00:00:00', 16.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-25 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-26 00:00:00', 19.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-27 00:00:00', 17.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-28 00:00:00', 14.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-29 00:00:00', 12.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-09-30 00:00:00', 13.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-01 00:00:00', 14.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-02 00:00:00', 15.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-03 00:00:00', 11.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-04 00:00:00', 13.2060003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-05 00:00:00', 12.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-06 00:00:00', 11.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-07 00:00:00', 12.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-08 00:00:00', 13.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-09 00:00:00', 7.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-10 00:00:00', 0.955999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-11 00:00:00', 5.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-12 00:00:00', 10.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-13 00:00:00', 9.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-14 00:00:00', 7.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-15 00:00:00', 9.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-16 00:00:00', 9.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-17 00:00:00', 10.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-18 00:00:00', 9.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-19 00:00:00', 9.64799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-20 00:00:00', 9.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-21 00:00:00', 8.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-22 00:00:00', 7.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-23 00:00:00', 6.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-24 00:00:00', 3.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-25 00:00:00', 0.467000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-26 00:00:00', 0.56800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-27 00:00:00', 1.64100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-28 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-29 00:00:00', 3.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-30 00:00:00', 7.17100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-10-31 00:00:00', 10.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-01 00:00:00', 11.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-02 00:00:00', 9.93900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-03 00:00:00', 8.63300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-04 00:00:00', 8.85200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-05 00:00:00', 7.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-06 00:00:00', 7.31300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-07 00:00:00', 6.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-08 00:00:00', 5.07999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-09 00:00:00', 7.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-10 00:00:00', 6.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-11 00:00:00', 7.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-12 00:00:00', 4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-13 00:00:00', 2.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-14 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-15 00:00:00', 6.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-16 00:00:00', 6.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-17 00:00:00', 1.52199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-18 00:00:00', 3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-19 00:00:00', 5.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-20 00:00:00', 5.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-21 00:00:00', 3.95799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-22 00:00:00', 4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-23 00:00:00', 0.870999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-24 00:00:00', 0.193000003695487976, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-25 00:00:00', -0.384000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-26 00:00:00', 0.26600000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-27 00:00:00', -0.163000002503395081, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-28 00:00:00', -2.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-29 00:00:00', -3.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-11-30 00:00:00', -4.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-01 00:00:00', 0.577000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-02 00:00:00', 0.492000013589859009, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-03 00:00:00', -1.55799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-04 00:00:00', 0.29800000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-05 00:00:00', 1.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-06 00:00:00', 0.0920000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-07 00:00:00', -0.340000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-08 00:00:00', 0.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-09 00:00:00', 2.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-10 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-11 00:00:00', 2.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-12 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-13 00:00:00', 2.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-14 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-15 00:00:00', -0.739000022411346436, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-16 00:00:00', 0.973999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-17 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-18 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-19 00:00:00', 0.535000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-20 00:00:00', -2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-21 00:00:00', -0.13500000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-22 00:00:00', -3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-23 00:00:00', -1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-24 00:00:00', -0.212999999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-25 00:00:00', -2.14100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-26 00:00:00', -1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-27 00:00:00', -1.08299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-28 00:00:00', -1.37199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-29 00:00:00', -3.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-30 00:00:00', -3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1998-12-31 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-01 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-02 00:00:00', -6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-03 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-04 00:00:00', -5.1939997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-05 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-06 00:00:00', -3.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-07 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-08 00:00:00', -4.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-09 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-10 00:00:00', -4.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-11 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-12 00:00:00', -1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-13 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-14 00:00:00', -2.16899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-15 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-16 00:00:00', -0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-17 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-18 00:00:00', -1.15900003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-19 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-20 00:00:00', -0.601000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-21 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-22 00:00:00', 0.474999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-23 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-24 00:00:00', -1.02100002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-25 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-26 00:00:00', -0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-27 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-28 00:00:00', -0.898000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-29 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-30 00:00:00', -1.32700002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-01-31 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-01 00:00:00', -0.509000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-03 00:00:00', -0.138999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-04 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-05 00:00:00', 0.0130000002682209015, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-06 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-07 00:00:00', -0.171000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-08 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-09 00:00:00', -0.578999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-10 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-11 00:00:00', -0.354000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-12 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-13 00:00:00', -1.17299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-14 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-15 00:00:00', -2.99000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-16 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-17 00:00:00', -3.05699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-18 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-19 00:00:00', -2.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-20 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-21 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-22 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-23 00:00:00', -0.34299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-24 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-25 00:00:00', 0.580999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-26 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-27 00:00:00', -1.43299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-02-28 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-01 00:00:00', -0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-02 00:00:00', -99, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-03 00:00:00', 0.794000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-04 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-05 00:00:00', -2.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-06 00:00:00', -1.63300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-07 00:00:00', -1.7359999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-08 00:00:00', -2.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-09 00:00:00', -1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-10 00:00:00', 0.456000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-11 00:00:00', 1.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-12 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-13 00:00:00', 1.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-14 00:00:00', -2.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-15 00:00:00', -0.421000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-16 00:00:00', -2.43799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-17 00:00:00', -2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-18 00:00:00', -3.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-19 00:00:00', -5.02199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-20 00:00:00', -3.50300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-21 00:00:00', -0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-22 00:00:00', -0.172000005841255188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-23 00:00:00', -0.32699999213218689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-24 00:00:00', -0.540000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-25 00:00:00', 1.14699995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-26 00:00:00', 3.04200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-27 00:00:00', 3.81999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-28 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-29 00:00:00', 2.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-30 00:00:00', 1.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-03-31 00:00:00', 0.792999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-01 00:00:00', 1.06700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-02 00:00:00', 4.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-03 00:00:00', 1.91100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-04 00:00:00', 1.71500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-05 00:00:00', 1.58599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-06 00:00:00', 1.40100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-07 00:00:00', 0.800999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-08 00:00:00', 0.944000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-09 00:00:00', 2.09400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-10 00:00:00', 2.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-11 00:00:00', -0.495000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-12 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-13 00:00:00', 1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-14 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-15 00:00:00', 7.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-16 00:00:00', 8.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-17 00:00:00', 7.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-18 00:00:00', 7.32499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-19 00:00:00', 3.07800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-20 00:00:00', 6.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-21 00:00:00', 6.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-22 00:00:00', 1.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-23 00:00:00', 1.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-24 00:00:00', 4.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-25 00:00:00', 1.94299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-26 00:00:00', 2.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-27 00:00:00', 2.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-28 00:00:00', 3.40899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-29 00:00:00', 4.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-04-30 00:00:00', 7.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-01 00:00:00', 10.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-02 00:00:00', 8.08899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-03 00:00:00', 10.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-04 00:00:00', 9.13500022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-05 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-06 00:00:00', 11.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-07 00:00:00', 13.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-08 00:00:00', 15.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-09 00:00:00', 14.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-10 00:00:00', 14.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-11 00:00:00', 14.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-12 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-13 00:00:00', 10.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-14 00:00:00', 13.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-15 00:00:00', 16.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-16 00:00:00', 13.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-17 00:00:00', 17.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-18 00:00:00', 18.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-19 00:00:00', 18.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-20 00:00:00', 18.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-21 00:00:00', 20.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-22 00:00:00', 10.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-23 00:00:00', 5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-24 00:00:00', 7.63600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-25 00:00:00', 8.72299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-26 00:00:00', 7.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-27 00:00:00', 12.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-28 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-29 00:00:00', 14.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-30 00:00:00', 14.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-05-31 00:00:00', 15.1540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-01 00:00:00', 13.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-02 00:00:00', 14.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-03 00:00:00', 15.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-04 00:00:00', 15.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-05 00:00:00', 16.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-06 00:00:00', 19.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-07 00:00:00', 18.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-08 00:00:00', 17.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-09 00:00:00', 15.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-10 00:00:00', 14.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-11 00:00:00', 14.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-12 00:00:00', 15.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-13 00:00:00', 17.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-14 00:00:00', 19.9899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-15 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-16 00:00:00', 18.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-17 00:00:00', 16.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-18 00:00:00', 18.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-19 00:00:00', 18.8579998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-20 00:00:00', 18.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-21 00:00:00', 17.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-22 00:00:00', 17.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-23 00:00:00', 13.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-24 00:00:00', 12.2460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-25 00:00:00', 19.8490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-26 00:00:00', 23.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-27 00:00:00', 25.3959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-28 00:00:00', 23.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-29 00:00:00', 22.9500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-06-30 00:00:00', 23.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-01 00:00:00', 22.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-02 00:00:00', 20.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-03 00:00:00', 19.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-04 00:00:00', 19.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-05 00:00:00', 21.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-06 00:00:00', 19.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-07 00:00:00', 19.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-08 00:00:00', 21.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-09 00:00:00', 23.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-10 00:00:00', 20.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-11 00:00:00', 14.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-12 00:00:00', 12.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-13 00:00:00', 11.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-14 00:00:00', 17.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-15 00:00:00', 19.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-16 00:00:00', 22.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-17 00:00:00', 23.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-18 00:00:00', 21.1340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-19 00:00:00', 20.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-20 00:00:00', 20.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-21 00:00:00', 19.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-22 00:00:00', 20.5300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-23 00:00:00', 20.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-24 00:00:00', 19.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-25 00:00:00', 18.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-26 00:00:00', 18.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-27 00:00:00', 15.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-28 00:00:00', 15.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-29 00:00:00', 14.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-30 00:00:00', 19.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-07-31 00:00:00', 20.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-01 00:00:00', 21.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-02 00:00:00', 20.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-03 00:00:00', 20.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-04 00:00:00', 23.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-05 00:00:00', 24.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-06 00:00:00', 24.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-07 00:00:00', 24.6889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-08 00:00:00', 24.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-09 00:00:00', 23.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-10 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-11 00:00:00', 21.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-12 00:00:00', 18.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-13 00:00:00', 16.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-14 00:00:00', 18.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-15 00:00:00', 20.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-16 00:00:00', 21.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-17 00:00:00', 21.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-18 00:00:00', 21.6650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-19 00:00:00', 23.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-20 00:00:00', 23.9050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-21 00:00:00', 23.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-22 00:00:00', 23.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-23 00:00:00', 23.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-24 00:00:00', 23.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-25 00:00:00', 23.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-26 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-27 00:00:00', 21.9529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-28 00:00:00', 23.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-29 00:00:00', 23.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-30 00:00:00', 22.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-08-31 00:00:00', 20.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-01 00:00:00', 18.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-02 00:00:00', 17.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-03 00:00:00', 17.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-04 00:00:00', 18.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-05 00:00:00', 15.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-06 00:00:00', 16.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-07 00:00:00', 17.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-08 00:00:00', 17.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-09 00:00:00', 17.8810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-10 00:00:00', 18.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-11 00:00:00', 17.9829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-12 00:00:00', 19.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-13 00:00:00', 21.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-14 00:00:00', 22.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-15 00:00:00', 22.2059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-16 00:00:00', 21.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-17 00:00:00', 22.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-18 00:00:00', 20.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-19 00:00:00', 19.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-20 00:00:00', 18.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-21 00:00:00', 18.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-22 00:00:00', 19.1060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-23 00:00:00', 19.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-24 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-25 00:00:00', 12.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-26 00:00:00', 13.1569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-27 00:00:00', 12.9910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-28 00:00:00', 13.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-29 00:00:00', 5.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-09-30 00:00:00', 7.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-01 00:00:00', 8.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-02 00:00:00', 11.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-03 00:00:00', 13.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-04 00:00:00', 11.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-05 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-06 00:00:00', 10.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-07 00:00:00', 9.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-08 00:00:00', 8.54599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-09 00:00:00', 8.67300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-10 00:00:00', 9.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-11 00:00:00', 10.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-12 00:00:00', 10.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-13 00:00:00', 11.5530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-14 00:00:00', 7.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-15 00:00:00', 10.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-16 00:00:00', 13.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-17 00:00:00', 12.7969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-18 00:00:00', 12.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-19 00:00:00', 12.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-20 00:00:00', 12.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-21 00:00:00', 10.4180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-22 00:00:00', 10.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-23 00:00:00', 11.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-24 00:00:00', 11.5240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-25 00:00:00', 12.7440004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-26 00:00:00', 5.31099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-27 00:00:00', 2.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-28 00:00:00', 1.23899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-29 00:00:00', 5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-30 00:00:00', 5.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-10-31 00:00:00', 6.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-01 00:00:00', 6.42299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-02 00:00:00', 2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-03 00:00:00', -1.34000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-04 00:00:00', -1.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-05 00:00:00', -2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-06 00:00:00', -0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-07 00:00:00', -1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-08 00:00:00', 0.851999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-09 00:00:00', 0.0560000017285346985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-10 00:00:00', -0.190999999642372131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-11 00:00:00', -1.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-12 00:00:00', -0.791000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-13 00:00:00', -2.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-14 00:00:00', -1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-15 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-16 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-17 00:00:00', 1.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-18 00:00:00', -0.358000010251998901, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-19 00:00:00', -1.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-20 00:00:00', -1.62800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-21 00:00:00', -3.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-22 00:00:00', -4.74100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-23 00:00:00', -1.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-24 00:00:00', -1.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-25 00:00:00', -1.03499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-26 00:00:00', -1.14600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-27 00:00:00', 0.360000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-28 00:00:00', 0.551999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-29 00:00:00', -1.08899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-11-30 00:00:00', -4.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-01 00:00:00', -7.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-02 00:00:00', -1.93200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-03 00:00:00', 1.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-04 00:00:00', 0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-05 00:00:00', -2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-06 00:00:00', -1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-07 00:00:00', 0.816999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-08 00:00:00', 0.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-09 00:00:00', -2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-10 00:00:00', -0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-11 00:00:00', -4.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-12 00:00:00', -0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-13 00:00:00', 0.29800000786781311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-14 00:00:00', 0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-15 00:00:00', 0.88200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-16 00:00:00', 1.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-17 00:00:00', 0.768999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-18 00:00:00', -2.92000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-19 00:00:00', -4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-20 00:00:00', -1.96399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-21 00:00:00', -0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-22 00:00:00', 0.200000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-23 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-24 00:00:00', -1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-25 00:00:00', -4.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-26 00:00:00', -2.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-27 00:00:00', 0.666999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-28 00:00:00', 0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-29 00:00:00', -0.416000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-30 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '1999-12-31 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-01 00:00:00', -0.145999997854232788, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-02 00:00:00', 2.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-03 00:00:00', 3.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-04 00:00:00', 3.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-05 00:00:00', 0.702000021934509277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-06 00:00:00', 0.324000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-07 00:00:00', -1.06500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-08 00:00:00', -2.39899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-09 00:00:00', -9.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-10 00:00:00', -6.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-11 00:00:00', -5.96000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-12 00:00:00', -6.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-13 00:00:00', -10.7559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-14 00:00:00', -10.7489995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-15 00:00:00', -10.5109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-16 00:00:00', -6.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-17 00:00:00', -3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-18 00:00:00', -4.60300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-19 00:00:00', -5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-20 00:00:00', -2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-21 00:00:00', -0.978999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-22 00:00:00', -3.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-23 00:00:00', -3.48200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-24 00:00:00', -4.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-25 00:00:00', -6.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-26 00:00:00', -5.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-27 00:00:00', -3.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-28 00:00:00', -1.68200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-29 00:00:00', -0.652999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-30 00:00:00', -0.851000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-01-31 00:00:00', -5.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-01 00:00:00', -5.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-02 00:00:00', -4.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-03 00:00:00', -6.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-04 00:00:00', -4.73400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-05 00:00:00', -2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-06 00:00:00', -3.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-07 00:00:00', -1.20200002193450928, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-08 00:00:00', -2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-09 00:00:00', -6.80299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-10 00:00:00', -8.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-11 00:00:00', -8.69699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-12 00:00:00', -5.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-13 00:00:00', -4.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-14 00:00:00', -1.90299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-15 00:00:00', -3.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-16 00:00:00', -7.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-17 00:00:00', -6.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-18 00:00:00', -5.23199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-19 00:00:00', -5.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-20 00:00:00', -4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-21 00:00:00', -3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-22 00:00:00', -4.28299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-23 00:00:00', -3.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-24 00:00:00', -2.6099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-25 00:00:00', -2.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-26 00:00:00', -1.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-27 00:00:00', -5.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-28 00:00:00', -2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-02-29 00:00:00', -4.38600015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-01 00:00:00', -4.74700021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-02 00:00:00', -5.53599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-03 00:00:00', -2.88599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-04 00:00:00', -7.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-05 00:00:00', -5.83799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-06 00:00:00', -4.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-07 00:00:00', -2.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-08 00:00:00', -1.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-09 00:00:00', -0.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-10 00:00:00', -2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-11 00:00:00', -2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-12 00:00:00', -1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-13 00:00:00', -1.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-14 00:00:00', -0.472000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-15 00:00:00', -0.282999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-16 00:00:00', -5.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-17 00:00:00', -5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-18 00:00:00', -3.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-19 00:00:00', 0.666999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-20 00:00:00', 0.561999976634979248, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-21 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-22 00:00:00', 0.606999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-23 00:00:00', 1.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-24 00:00:00', 1.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-25 00:00:00', 3.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-26 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-27 00:00:00', 0.732999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-28 00:00:00', 0.273000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-29 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-30 00:00:00', -0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-03-31 00:00:00', 3.32699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-01 00:00:00', 3.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-02 00:00:00', 1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-03 00:00:00', -0.754000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-04 00:00:00', 0.382999986410140991, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-05 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-06 00:00:00', 2.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-07 00:00:00', 5.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-08 00:00:00', 6.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-09 00:00:00', 10.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-10 00:00:00', 11.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-11 00:00:00', 13.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-12 00:00:00', 11.4270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-13 00:00:00', 6.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-14 00:00:00', 6.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-15 00:00:00', 7.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-16 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-17 00:00:00', 11.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-18 00:00:00', 11.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-19 00:00:00', 11.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-20 00:00:00', 11.5810003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-21 00:00:00', 13.4060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-22 00:00:00', 14.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-23 00:00:00', 7.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-24 00:00:00', 6.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-25 00:00:00', 10.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-26 00:00:00', 5.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-27 00:00:00', 8.18700027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-28 00:00:00', 6.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-29 00:00:00', 7.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-04-30 00:00:00', 11.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-01 00:00:00', 16.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-02 00:00:00', 16.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-03 00:00:00', 15.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-04 00:00:00', 15.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-05 00:00:00', 16.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-06 00:00:00', 16.5340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-07 00:00:00', 19.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-08 00:00:00', 18.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-09 00:00:00', 22.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-10 00:00:00', 19.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-11 00:00:00', 16.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-12 00:00:00', 14.6719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-13 00:00:00', 15.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-14 00:00:00', 16.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-15 00:00:00', 15.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-16 00:00:00', 18.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-17 00:00:00', 19.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-18 00:00:00', 18.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-19 00:00:00', 19.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-20 00:00:00', 20.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-21 00:00:00', 17.9610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-22 00:00:00', 14.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-23 00:00:00', 15.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-24 00:00:00', 15.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-25 00:00:00', 16.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-26 00:00:00', 16.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-27 00:00:00', 18.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-28 00:00:00', 21.5639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-29 00:00:00', 17.4500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-30 00:00:00', 15.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-05-31 00:00:00', 16.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-01 00:00:00', 15.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-02 00:00:00', 13.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-03 00:00:00', 14.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-04 00:00:00', 16.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-05 00:00:00', 17.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-06 00:00:00', 19.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-07 00:00:00', 19.305999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-08 00:00:00', 19.6350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-09 00:00:00', 17.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-10 00:00:00', 18.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-11 00:00:00', 19.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-12 00:00:00', 20.5060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-13 00:00:00', 18.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-14 00:00:00', 13.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-15 00:00:00', 17.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-16 00:00:00', 15.814000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-17 00:00:00', 18.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-18 00:00:00', 20.8670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-19 00:00:00', 20.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-20 00:00:00', 18.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-21 00:00:00', 20.5049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-22 00:00:00', 21.4769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-23 00:00:00', 22.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-24 00:00:00', 24.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-25 00:00:00', 25.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-26 00:00:00', 24.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-27 00:00:00', 22.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-28 00:00:00', 22.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-29 00:00:00', 21.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-06-30 00:00:00', 21.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-01 00:00:00', 21.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-02 00:00:00', 22.2490005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-03 00:00:00', 21.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-04 00:00:00', 21.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-05 00:00:00', 21.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-06 00:00:00', 22.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-07 00:00:00', 23.3199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-08 00:00:00', 24.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-09 00:00:00', 24.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-10 00:00:00', 24.0919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-11 00:00:00', 23.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-12 00:00:00', 23.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-13 00:00:00', 22.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-14 00:00:00', 19.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-15 00:00:00', 20.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-16 00:00:00', 17.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-17 00:00:00', 14.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-18 00:00:00', 14.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-19 00:00:00', 18.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-20 00:00:00', 19.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-21 00:00:00', 19.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-22 00:00:00', 18.7700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-23 00:00:00', 18.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-24 00:00:00', 20.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-25 00:00:00', 18.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-26 00:00:00', 19.9540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-27 00:00:00', 21.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-28 00:00:00', 23.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-29 00:00:00', 24.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-30 00:00:00', 24.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-07-31 00:00:00', 24.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-01 00:00:00', 24.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-02 00:00:00', 22.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-03 00:00:00', 23.9080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-04 00:00:00', 23.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-05 00:00:00', 23.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-06 00:00:00', 23.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-07 00:00:00', 23.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-08 00:00:00', 22.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-09 00:00:00', 20.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-10 00:00:00', 22.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-11 00:00:00', 23.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-12 00:00:00', 22.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-13 00:00:00', 22.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-14 00:00:00', 22.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-15 00:00:00', 22.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-16 00:00:00', 21.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-17 00:00:00', 18.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-18 00:00:00', 18.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-19 00:00:00', 19.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-20 00:00:00', 19.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-21 00:00:00', 19.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-22 00:00:00', 20.9120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-23 00:00:00', 20.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-24 00:00:00', 22.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-25 00:00:00', 22.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-26 00:00:00', 22.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-27 00:00:00', 24.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-28 00:00:00', 24.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-29 00:00:00', 24.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-30 00:00:00', 22.6200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-08-31 00:00:00', 22.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-01 00:00:00', 21.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-02 00:00:00', 21.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-03 00:00:00', 21.3330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-04 00:00:00', 21.7269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-05 00:00:00', 19.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-06 00:00:00', 19.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-07 00:00:00', 18.5540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-08 00:00:00', 18.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-09 00:00:00', 18.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-10 00:00:00', 17.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-11 00:00:00', 17.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-12 00:00:00', 17.4850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-13 00:00:00', 19.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-14 00:00:00', 19.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-15 00:00:00', 20.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-16 00:00:00', 21.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-17 00:00:00', 22.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-18 00:00:00', 20.6840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-19 00:00:00', 19.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-20 00:00:00', 12.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-21 00:00:00', 13.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-22 00:00:00', 12.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-23 00:00:00', 14.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-24 00:00:00', 14.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-25 00:00:00', 5.95100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-26 00:00:00', 8.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-27 00:00:00', 10.8769998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-28 00:00:00', 12.9079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-29 00:00:00', 12.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-09-30 00:00:00', 10.8809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-01 00:00:00', 12.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-02 00:00:00', 7.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-03 00:00:00', 10.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-04 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-05 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-06 00:00:00', 5.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-07 00:00:00', 3.6679999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-08 00:00:00', 4.97800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-09 00:00:00', 4.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-10 00:00:00', 5.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-11 00:00:00', 7.13000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-12 00:00:00', 9.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-13 00:00:00', 10.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-14 00:00:00', 9.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-15 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-16 00:00:00', 2.30699992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-17 00:00:00', 7.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-18 00:00:00', 2.4849998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-19 00:00:00', 7.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-20 00:00:00', 8.23200035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-21 00:00:00', 7.42000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-22 00:00:00', 5.17299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-23 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-24 00:00:00', 5.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-25 00:00:00', 6.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-26 00:00:00', 9.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-27 00:00:00', 13.0989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-28 00:00:00', 12.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-29 00:00:00', 12.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-30 00:00:00', 8.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-10-31 00:00:00', 9.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-01 00:00:00', 6.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-02 00:00:00', 7.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-03 00:00:00', 8.94299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-04 00:00:00', 8.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-05 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-06 00:00:00', 5.27600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-07 00:00:00', 1.8049999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-08 00:00:00', -2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-09 00:00:00', 1.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-10 00:00:00', 3.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-11 00:00:00', -1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-12 00:00:00', -5.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-13 00:00:00', -2.72600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-14 00:00:00', 0.597999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-15 00:00:00', -0.56400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-16 00:00:00', -5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-17 00:00:00', -7.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-18 00:00:00', -1.28499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-19 00:00:00', 0.606999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-20 00:00:00', 0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-21 00:00:00', -0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-22 00:00:00', -1.1109999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-23 00:00:00', -1.07400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-24 00:00:00', -1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-25 00:00:00', -1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-26 00:00:00', -1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-27 00:00:00', -2.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-28 00:00:00', -1.98800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-29 00:00:00', -5.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-11-30 00:00:00', -4.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-01 00:00:00', -1.02400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-02 00:00:00', -3.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-03 00:00:00', -3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-04 00:00:00', -4.01100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-05 00:00:00', -4.44500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-06 00:00:00', -3.21900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-07 00:00:00', -3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-08 00:00:00', -3.03500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-09 00:00:00', -3.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-10 00:00:00', -5.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-11 00:00:00', -0.967000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-12 00:00:00', -0.66100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-13 00:00:00', -1.77199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-14 00:00:00', -2.2929999828338623, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-15 00:00:00', -0.405000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-16 00:00:00', -1.30799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-17 00:00:00', -3.87199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-18 00:00:00', -2.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-19 00:00:00', -1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-20 00:00:00', 0.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-21 00:00:00', 1.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-22 00:00:00', 0.887000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-23 00:00:00', -0.669000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-24 00:00:00', -0.797999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-25 00:00:00', -1.92200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-26 00:00:00', 0.115999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-27 00:00:00', -1.89600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-28 00:00:00', -4.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-29 00:00:00', -3.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-30 00:00:00', -2.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2000-12-31 00:00:00', -1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-01 00:00:00', 0.187999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-02 00:00:00', -2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-03 00:00:00', -5.46299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-04 00:00:00', -1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-05 00:00:00', 0.144999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-06 00:00:00', -3.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-07 00:00:00', -4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-08 00:00:00', -4.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-09 00:00:00', -5.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-10 00:00:00', -4.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-11 00:00:00', 0.453000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-12 00:00:00', -1.08099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-13 00:00:00', -2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-14 00:00:00', -2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-15 00:00:00', -2.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-16 00:00:00', -7.93699979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-17 00:00:00', -7.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-18 00:00:00', -4.3060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-19 00:00:00', -4.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-20 00:00:00', -4.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-21 00:00:00', -7.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-22 00:00:00', -12.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-23 00:00:00', -10.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-24 00:00:00', -8.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-25 00:00:00', -9.16100025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-26 00:00:00', -9.97500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-27 00:00:00', -7.65199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-28 00:00:00', -3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-29 00:00:00', -9.04599952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-30 00:00:00', -8.82699966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-01-31 00:00:00', -7.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-01 00:00:00', -6.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-02 00:00:00', -2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-03 00:00:00', -2.40700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-04 00:00:00', -4.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-05 00:00:00', -5.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-06 00:00:00', -5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-07 00:00:00', -5.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-08 00:00:00', -3.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-09 00:00:00', -5.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-10 00:00:00', -9.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-11 00:00:00', -8.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-12 00:00:00', -2.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-13 00:00:00', -1.88100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-14 00:00:00', -2.70499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-15 00:00:00', -0.317000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-16 00:00:00', -3.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-17 00:00:00', -5.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-18 00:00:00', -2.29399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-19 00:00:00', -0.231000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-20 00:00:00', -2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-21 00:00:00', 0.034000001847743988, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-22 00:00:00', -1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-23 00:00:00', -3.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-24 00:00:00', -2.05299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-25 00:00:00', -2.31800007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-26 00:00:00', -0.433999985456466675, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-27 00:00:00', -1.10699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-02-28 00:00:00', -0.592000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-01 00:00:00', 1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-02 00:00:00', 1.38699996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-03 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-04 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-05 00:00:00', 0.839999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-06 00:00:00', 0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-07 00:00:00', 2.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-08 00:00:00', 3.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-09 00:00:00', 4.82499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-10 00:00:00', 2.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-11 00:00:00', 1.18799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-12 00:00:00', -3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-13 00:00:00', -6.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-14 00:00:00', -1.61600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-15 00:00:00', 1.82400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-16 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-17 00:00:00', 2.94600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-18 00:00:00', 0.884999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-19 00:00:00', -2.3469998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-20 00:00:00', -0.0359999984502792358, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-21 00:00:00', 0.635999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-22 00:00:00', 1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-23 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-24 00:00:00', 4.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-25 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-26 00:00:00', 2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-27 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-28 00:00:00', 0.280000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-29 00:00:00', -0.00899999961256980896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-30 00:00:00', 4.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-03-31 00:00:00', 4.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-01 00:00:00', 5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-02 00:00:00', 3.00999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-03 00:00:00', 5.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-04 00:00:00', 10.7480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-05 00:00:00', 8.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-06 00:00:00', 11.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-07 00:00:00', 14.6269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-08 00:00:00', 16.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-09 00:00:00', 13.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-10 00:00:00', 13.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-11 00:00:00', 11.9969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-12 00:00:00', 12.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-13 00:00:00', 13.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-14 00:00:00', 11.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-15 00:00:00', 10.4340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-16 00:00:00', 11.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-17 00:00:00', 7.71299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-18 00:00:00', 9.1660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-19 00:00:00', 3.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-20 00:00:00', 8.18000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-21 00:00:00', 11.185999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-22 00:00:00', 12.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-23 00:00:00', 9.13599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-24 00:00:00', 11.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-25 00:00:00', 12.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-26 00:00:00', 12.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-27 00:00:00', 15.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-28 00:00:00', 14.9010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-29 00:00:00', 14.7200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-04-30 00:00:00', 14.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-01 00:00:00', 12.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-02 00:00:00', 13.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-03 00:00:00', 16.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-04 00:00:00', 17.8040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-05 00:00:00', 18.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-06 00:00:00', 19.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-07 00:00:00', 15.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-08 00:00:00', 15.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-09 00:00:00', 16.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-10 00:00:00', 20.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-11 00:00:00', 20.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-12 00:00:00', 21.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-13 00:00:00', 19.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-14 00:00:00', 19.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-15 00:00:00', 21.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-16 00:00:00', 22.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-17 00:00:00', 23.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-18 00:00:00', 20.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-19 00:00:00', 15.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-20 00:00:00', 14.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-21 00:00:00', 15.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-22 00:00:00', 16.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-23 00:00:00', 17.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-24 00:00:00', 15.7069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-25 00:00:00', 17.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-26 00:00:00', 20.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-27 00:00:00', 21.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-28 00:00:00', 16.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-29 00:00:00', 17.4519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-30 00:00:00', 22.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-05-31 00:00:00', 22.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-01 00:00:00', 22.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-02 00:00:00', 19.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-03 00:00:00', 20.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-04 00:00:00', 19.1539993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-05 00:00:00', 19.7040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-06 00:00:00', 20.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-07 00:00:00', 20.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-08 00:00:00', 22.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-09 00:00:00', 23.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-10 00:00:00', 23.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-11 00:00:00', 22.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-12 00:00:00', 22.0440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-13 00:00:00', 22.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-14 00:00:00', 16.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-15 00:00:00', 18.5259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-16 00:00:00', 18.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-17 00:00:00', 19.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-18 00:00:00', 21.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-19 00:00:00', 23.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-20 00:00:00', 23.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-21 00:00:00', 20.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-22 00:00:00', 16.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-23 00:00:00', 21.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-24 00:00:00', 23.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-25 00:00:00', 23.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-26 00:00:00', 24.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-27 00:00:00', 27.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-28 00:00:00', 27.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-29 00:00:00', 28.6480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-06-30 00:00:00', 27.9780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-01 00:00:00', 25.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-02 00:00:00', 22.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-03 00:00:00', 22.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-04 00:00:00', 21.4130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-05 00:00:00', 19.9750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-06 00:00:00', 20.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-07 00:00:00', 21.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-08 00:00:00', 22.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-09 00:00:00', 24.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-10 00:00:00', 26.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-11 00:00:00', 27.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-12 00:00:00', 27.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-13 00:00:00', 26.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-14 00:00:00', 25.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-15 00:00:00', 21.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-16 00:00:00', 19.6369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-17 00:00:00', 17.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-18 00:00:00', 19.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-19 00:00:00', 24.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-20 00:00:00', 20.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-21 00:00:00', 21.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-22 00:00:00', 21.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-23 00:00:00', 20.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-24 00:00:00', 18.5709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-25 00:00:00', 22.5179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-26 00:00:00', 23.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-27 00:00:00', 21.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-28 00:00:00', 17.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-29 00:00:00', 17.2560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-30 00:00:00', 17.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-07-31 00:00:00', 19.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-01 00:00:00', 21.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-02 00:00:00', 22.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-03 00:00:00', 22.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-04 00:00:00', 23.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-05 00:00:00', 24.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-06 00:00:00', 21.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-07 00:00:00', 23.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-08 00:00:00', 21.1469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-09 00:00:00', 21.7080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-10 00:00:00', 21.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-11 00:00:00', 21.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-12 00:00:00', 20.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-13 00:00:00', 18.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-14 00:00:00', 12.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-15 00:00:00', 15.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-16 00:00:00', 19.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-17 00:00:00', 20.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-18 00:00:00', 20.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-19 00:00:00', 19.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-20 00:00:00', 21.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-21 00:00:00', 21.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-22 00:00:00', 20.7660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-23 00:00:00', 20.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-24 00:00:00', 20.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-25 00:00:00', 20.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-26 00:00:00', 17.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-27 00:00:00', 20.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-28 00:00:00', 16.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-29 00:00:00', 16.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-30 00:00:00', 17.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-08-31 00:00:00', 19.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-01 00:00:00', 22.417999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-02 00:00:00', 19.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-03 00:00:00', 18.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-04 00:00:00', 17.7290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-05 00:00:00', 18.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-06 00:00:00', 18.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-07 00:00:00', 19.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-08 00:00:00', 21.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-09 00:00:00', 21.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-10 00:00:00', 18.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-11 00:00:00', 17.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-12 00:00:00', 14.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-13 00:00:00', 13.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-14 00:00:00', 13.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-15 00:00:00', 14.3090000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-16 00:00:00', 14.2100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-17 00:00:00', 15.0059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-18 00:00:00', 13.1510000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-19 00:00:00', 9.28100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-20 00:00:00', 7.4439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-21 00:00:00', 10.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-22 00:00:00', 8.72000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-23 00:00:00', 10.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-24 00:00:00', 12.0329999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-25 00:00:00', 11.0710000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-26 00:00:00', 12.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-27 00:00:00', 16.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-28 00:00:00', 16.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-29 00:00:00', 17.3379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-09-30 00:00:00', 17.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-01 00:00:00', 17.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-02 00:00:00', 15.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-03 00:00:00', 10.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-04 00:00:00', 10.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-05 00:00:00', 9.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-06 00:00:00', 12.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-07 00:00:00', 17.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-08 00:00:00', 14.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-09 00:00:00', 8.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-10 00:00:00', 4.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-11 00:00:00', 4.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-12 00:00:00', 10.300999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-13 00:00:00', 9.93799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-14 00:00:00', 11.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-15 00:00:00', 10.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-16 00:00:00', 11.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-17 00:00:00', 7.38399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-18 00:00:00', 6.82000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-19 00:00:00', 10.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-20 00:00:00', 11.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-21 00:00:00', 9.64700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-22 00:00:00', 8.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-23 00:00:00', 5.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-24 00:00:00', 8.74199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-25 00:00:00', 11.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-26 00:00:00', 13.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-27 00:00:00', 6.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-28 00:00:00', 4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-29 00:00:00', 5.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-30 00:00:00', 5.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-10-31 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-01 00:00:00', 4.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-02 00:00:00', 0.00400000018998980522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-03 00:00:00', -0.497999995946884155, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-04 00:00:00', 1.08700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-05 00:00:00', 0.0240000002086162567, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-06 00:00:00', 0.912999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-07 00:00:00', 2.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-08 00:00:00', 4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-09 00:00:00', 2.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-10 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-11 00:00:00', 1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-12 00:00:00', 5.0409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-13 00:00:00', 8.27099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-14 00:00:00', 7.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-15 00:00:00', 3.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-16 00:00:00', 6.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-17 00:00:00', 8.09500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-18 00:00:00', 8.03499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-19 00:00:00', 8.02499961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-20 00:00:00', 2.4719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-21 00:00:00', 3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-22 00:00:00', 4.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-23 00:00:00', 8.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-24 00:00:00', 5.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-25 00:00:00', 2.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-26 00:00:00', -0.180999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-27 00:00:00', 0.0560000017285346985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-28 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-29 00:00:00', -3.13499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-11-30 00:00:00', -2.64499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-01 00:00:00', -3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-02 00:00:00', -3.55100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-03 00:00:00', -3.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-04 00:00:00', -4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-05 00:00:00', 0.224000006914138794, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-06 00:00:00', -0.736999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-07 00:00:00', -1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-08 00:00:00', -2.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-09 00:00:00', -1.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-10 00:00:00', -4.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-11 00:00:00', -5.43800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-12 00:00:00', -1.66299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-13 00:00:00', -3.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-14 00:00:00', -2.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-15 00:00:00', -1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-16 00:00:00', -1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-17 00:00:00', -1.39600002765655518, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-18 00:00:00', -4.89499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-19 00:00:00', -1.21500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-20 00:00:00', 0.368000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-21 00:00:00', 1.08800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-22 00:00:00', -2.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-23 00:00:00', -3.24000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-24 00:00:00', -1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-25 00:00:00', -0.305000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-26 00:00:00', -0.0189999993890523911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-27 00:00:00', 0.293999999761581421, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-28 00:00:00', -0.746999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-29 00:00:00', -0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-30 00:00:00', 0.541000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2001-12-31 00:00:00', -0.14699999988079071, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-01 00:00:00', 0.14699999988079071, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-02 00:00:00', 1.00899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-03 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-04 00:00:00', 1.05400002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-05 00:00:00', 0.505999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-06 00:00:00', -0.458999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-07 00:00:00', 0.155000001192092896, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-08 00:00:00', 1.09700000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-09 00:00:00', 0.954999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-10 00:00:00', -2.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-11 00:00:00', -2.03699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-12 00:00:00', -1.60899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-13 00:00:00', -3.6380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-14 00:00:00', -9.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-15 00:00:00', -11.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-16 00:00:00', -9.82900047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-17 00:00:00', -9.05500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-18 00:00:00', -6.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-19 00:00:00', -5.74200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-20 00:00:00', -4.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-21 00:00:00', -5.51700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-22 00:00:00', -4.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-23 00:00:00', -6.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-24 00:00:00', -5.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-25 00:00:00', -7.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-26 00:00:00', -7.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-27 00:00:00', -6.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-28 00:00:00', -4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-29 00:00:00', -0.734000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-30 00:00:00', -2.6940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-01-31 00:00:00', -4.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-01 00:00:00', -5.34399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-02 00:00:00', -9.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-03 00:00:00', -5.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-04 00:00:00', -7.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-05 00:00:00', -10.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-06 00:00:00', -12.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-07 00:00:00', -7.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-08 00:00:00', -4.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-09 00:00:00', -3.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-10 00:00:00', -1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-11 00:00:00', -2.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-12 00:00:00', -4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-13 00:00:00', -1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-14 00:00:00', 0.670000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-15 00:00:00', -0.870999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-16 00:00:00', -0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-17 00:00:00', -1.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-18 00:00:00', -2.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-19 00:00:00', -4.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-20 00:00:00', -1.04499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-21 00:00:00', 0.527000010013580322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-22 00:00:00', -0.875999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-23 00:00:00', -3.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-24 00:00:00', -1.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-25 00:00:00', -1.48500001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-26 00:00:00', -1.60099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-27 00:00:00', 0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-02-28 00:00:00', -0.0780000016093254089, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-01 00:00:00', -3.89700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-02 00:00:00', -3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-03 00:00:00', -1.39999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-04 00:00:00', 0.0599999986588954926, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-05 00:00:00', 0.841000020503997803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-06 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-07 00:00:00', -3.51600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-08 00:00:00', -3.05100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-09 00:00:00', -0.560000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-10 00:00:00', -0.933000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-11 00:00:00', -8.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-12 00:00:00', -2.06399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-13 00:00:00', -0.32699999213218689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-14 00:00:00', 0.550999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-15 00:00:00', 1.24199998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-16 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-17 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-18 00:00:00', 2.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-19 00:00:00', 5.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-20 00:00:00', 3.36599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-21 00:00:00', 1.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-22 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-23 00:00:00', 0.69300001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-24 00:00:00', -0.677999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-25 00:00:00', 0.181999996304512024, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-26 00:00:00', 0.700999975204467773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-27 00:00:00', 2.8190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-28 00:00:00', 8.71899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-29 00:00:00', 7.58300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-30 00:00:00', 3.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-03-31 00:00:00', 0.128000006079673767, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-01 00:00:00', 0.578999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-02 00:00:00', 2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-03 00:00:00', 5.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-04 00:00:00', 3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-05 00:00:00', 2.92400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-06 00:00:00', 3.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-07 00:00:00', 5.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-08 00:00:00', 8.57199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-09 00:00:00', 10.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-10 00:00:00', 11.633000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-11 00:00:00', 11.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-12 00:00:00', 6.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-13 00:00:00', 8.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-14 00:00:00', 5.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-15 00:00:00', 3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-16 00:00:00', 7.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-17 00:00:00', 5.59600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-18 00:00:00', 11.8170003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-19 00:00:00', 13.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-20 00:00:00', 15.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-21 00:00:00', 14.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-22 00:00:00', 7.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-23 00:00:00', 3.33299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-24 00:00:00', 4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-25 00:00:00', 1.74000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-26 00:00:00', 2.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-27 00:00:00', -0.481000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-28 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-29 00:00:00', 5.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-04-30 00:00:00', 4.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-01 00:00:00', 7.76599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-02 00:00:00', 6.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-03 00:00:00', 9.55799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-04 00:00:00', 10.8219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-05 00:00:00', 9.83600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-06 00:00:00', 7.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-07 00:00:00', 11.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-08 00:00:00', 14.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-09 00:00:00', 12.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-10 00:00:00', 14.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-11 00:00:00', 17.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-12 00:00:00', 16.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-13 00:00:00', 9.56599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-14 00:00:00', 6.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-15 00:00:00', 8.84300041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-16 00:00:00', 13.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-17 00:00:00', 11.6490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-18 00:00:00', 10.0089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-19 00:00:00', 9.08800029754638672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-20 00:00:00', 9.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-21 00:00:00', 12.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-22 00:00:00', 12.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-23 00:00:00', 13.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-24 00:00:00', 15.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-25 00:00:00', 18.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-26 00:00:00', 18.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-27 00:00:00', 13.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-28 00:00:00', 14.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-29 00:00:00', 15.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-30 00:00:00', 17.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-05-31 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-01 00:00:00', 19.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-02 00:00:00', 20.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-03 00:00:00', 18.8869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-04 00:00:00', 19.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-05 00:00:00', 15.1780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-06 00:00:00', 15.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-07 00:00:00', 21.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-08 00:00:00', 15.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-09 00:00:00', 14.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-10 00:00:00', 15.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-11 00:00:00', 17.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-12 00:00:00', 19.1889991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-13 00:00:00', 20.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-14 00:00:00', 21.9810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-15 00:00:00', 17.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-16 00:00:00', 15.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-17 00:00:00', 15.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-18 00:00:00', 17.7320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-19 00:00:00', 18.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-20 00:00:00', 19.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-21 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-22 00:00:00', 21.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-23 00:00:00', 16.6310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-24 00:00:00', 15.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-25 00:00:00', 18.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-26 00:00:00', 21.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-27 00:00:00', 23.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-28 00:00:00', 23.9559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-29 00:00:00', 20.9979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-06-30 00:00:00', 21.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-01 00:00:00', 17.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-02 00:00:00', 19.2280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-03 00:00:00', 19.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-04 00:00:00', 19.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-05 00:00:00', 18.7689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-06 00:00:00', 16.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-07 00:00:00', 18.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-08 00:00:00', 18.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-09 00:00:00', 14.9989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-10 00:00:00', 18.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-11 00:00:00', 17.9400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-12 00:00:00', 19.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-13 00:00:00', 21.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-14 00:00:00', 21.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-15 00:00:00', 22.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-16 00:00:00', 22.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-17 00:00:00', 23.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-18 00:00:00', 24.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-19 00:00:00', 24.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-20 00:00:00', 24.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-21 00:00:00', 19.0709991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-22 00:00:00', 18.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-23 00:00:00', 20.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-24 00:00:00', 22.3409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-25 00:00:00', 23.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-26 00:00:00', 24.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-27 00:00:00', 22.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-28 00:00:00', 21.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-29 00:00:00', 19.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-30 00:00:00', 17.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-07-31 00:00:00', 18.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-01 00:00:00', 21.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-02 00:00:00', 20.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-03 00:00:00', 20.3369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-04 00:00:00', 21.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-05 00:00:00', 24.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-06 00:00:00', 24.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-07 00:00:00', 25.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-08 00:00:00', 26.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-09 00:00:00', 26.9470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-10 00:00:00', 27.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-11 00:00:00', 27.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-12 00:00:00', 23.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-13 00:00:00', 19.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-14 00:00:00', 14.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-15 00:00:00', 18.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-16 00:00:00', 21.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-17 00:00:00', 22.9939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-18 00:00:00', 22.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-19 00:00:00', 23.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-20 00:00:00', 23.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-21 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-22 00:00:00', 22.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-23 00:00:00', 24.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-24 00:00:00', 24.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-25 00:00:00', 24.8630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-26 00:00:00', 23.48699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-27 00:00:00', 24.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-28 00:00:00', 24.1070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-29 00:00:00', 23.3910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-30 00:00:00', 22.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-08-31 00:00:00', 21.0650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-01 00:00:00', 18.1720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-02 00:00:00', 15.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-03 00:00:00', 15.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-04 00:00:00', 14.7869997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-05 00:00:00', 15.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-06 00:00:00', 15.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-07 00:00:00', 16.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-08 00:00:00', 17.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-09 00:00:00', 17.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-10 00:00:00', 17.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-11 00:00:00', 18.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-12 00:00:00', 20.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-13 00:00:00', 21.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-14 00:00:00', 21.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-15 00:00:00', 21.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-16 00:00:00', 19.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-17 00:00:00', 16.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-18 00:00:00', 17.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-19 00:00:00', 17.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-20 00:00:00', 18.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-21 00:00:00', 18.9839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-22 00:00:00', 18.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-23 00:00:00', 15.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-24 00:00:00', 14.9530000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-25 00:00:00', 13.9350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-26 00:00:00', 13.4680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-27 00:00:00', 13.1499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-28 00:00:00', 13.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-29 00:00:00', 15.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-09-30 00:00:00', 15.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-01 00:00:00', 16.3950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-02 00:00:00', 16.7199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-03 00:00:00', 16.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-04 00:00:00', 18.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-05 00:00:00', 19.8509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-06 00:00:00', 18.5279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-07 00:00:00', 17.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-08 00:00:00', 16.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-09 00:00:00', 15.4379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-10 00:00:00', 15.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-11 00:00:00', 15.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-12 00:00:00', 14.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-13 00:00:00', 13.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-14 00:00:00', 12.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-15 00:00:00', 11.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-16 00:00:00', 11.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-17 00:00:00', 11.6339998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-18 00:00:00', 9.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-19 00:00:00', 9.89000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-20 00:00:00', 10.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-21 00:00:00', 10.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-22 00:00:00', 11.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-23 00:00:00', 9.22399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-24 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-25 00:00:00', 7.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-26 00:00:00', 8.78400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-27 00:00:00', 9.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-28 00:00:00', 9.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-29 00:00:00', 9.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-30 00:00:00', 10.4989995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-10-31 00:00:00', 11.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-01 00:00:00', 10.6540002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-02 00:00:00', 11.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-03 00:00:00', 6.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-04 00:00:00', 4.51599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-05 00:00:00', 4.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-06 00:00:00', 5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-07 00:00:00', 6.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-08 00:00:00', 4.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-09 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-10 00:00:00', 4.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-11 00:00:00', 5.07700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-12 00:00:00', 4.66699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-13 00:00:00', 7.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-14 00:00:00', 3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-15 00:00:00', 2.25500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-16 00:00:00', 0.981999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-17 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-18 00:00:00', -0.150000005960464478, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-19 00:00:00', 1.23300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-20 00:00:00', 3.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-21 00:00:00', 3.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-22 00:00:00', 3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-23 00:00:00', 2.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-24 00:00:00', 3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-25 00:00:00', 4.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-26 00:00:00', 3.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-27 00:00:00', -1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-28 00:00:00', -1.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-29 00:00:00', -0.425000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-11-30 00:00:00', -2.6659998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-01 00:00:00', -0.305999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-02 00:00:00', -3.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-03 00:00:00', -8.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-04 00:00:00', -14.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-05 00:00:00', -10.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-06 00:00:00', -3.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-07 00:00:00', -1.08000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-08 00:00:00', -1.88499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-09 00:00:00', -0.333000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-10 00:00:00', -0.726999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-11 00:00:00', -1.09300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-12 00:00:00', -1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-13 00:00:00', -0.819999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-14 00:00:00', -1.35300004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-15 00:00:00', -4.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-16 00:00:00', -2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-17 00:00:00', -4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-18 00:00:00', -6.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-19 00:00:00', -6.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-20 00:00:00', -6.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-21 00:00:00', -1.04799997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-22 00:00:00', 0.518000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-23 00:00:00', -2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-24 00:00:00', -6.00400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-25 00:00:00', -2.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-26 00:00:00', -5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-27 00:00:00', -7.80200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-28 00:00:00', -7.97900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-29 00:00:00', -5.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-30 00:00:00', -7.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2002-12-31 00:00:00', -1.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-01 00:00:00', -0.665000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-02 00:00:00', -1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-03 00:00:00', -1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-04 00:00:00', -0.35899999737739563, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-05 00:00:00', -0.842000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-06 00:00:00', -3.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-07 00:00:00', -3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-08 00:00:00', -4.11899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-09 00:00:00', -3.00900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-10 00:00:00', -1.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-11 00:00:00', -4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-12 00:00:00', -3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-13 00:00:00', -2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-14 00:00:00', -0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-15 00:00:00', -0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-16 00:00:00', -0.573000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-17 00:00:00', -1.07500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-18 00:00:00', 0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-19 00:00:00', -2.90700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-20 00:00:00', -0.187999993562698364, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-21 00:00:00', -3.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-22 00:00:00', -5.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-23 00:00:00', -5.91900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-24 00:00:00', -5.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-25 00:00:00', -5.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-26 00:00:00', -4.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-27 00:00:00', -6.0970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-28 00:00:00', -4.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-29 00:00:00', -5.2369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-30 00:00:00', -5.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-01-31 00:00:00', -6.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-01 00:00:00', -3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-02 00:00:00', -0.634000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-03 00:00:00', -0.773000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-04 00:00:00', -0.10599999874830246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-05 00:00:00', 0.331000000238418579, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-06 00:00:00', -0.481999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-07 00:00:00', -5.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-08 00:00:00', -4.10799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-09 00:00:00', -3.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-10 00:00:00', -0.873000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-11 00:00:00', -0.432999998331069946, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-12 00:00:00', -3.68700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-13 00:00:00', -7.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-14 00:00:00', -3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-15 00:00:00', -2.93000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-16 00:00:00', -2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-17 00:00:00', -5.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-18 00:00:00', -9.26500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-19 00:00:00', -6.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-20 00:00:00', -5.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-21 00:00:00', -3.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-22 00:00:00', -2.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-23 00:00:00', -3.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-24 00:00:00', -4.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-25 00:00:00', -3.53500008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-26 00:00:00', -1.56700003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-27 00:00:00', -2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-02-28 00:00:00', -5.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-01 00:00:00', -6.50500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-02 00:00:00', -11.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-03 00:00:00', -13.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-04 00:00:00', -8.50599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-05 00:00:00', -5.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-06 00:00:00', -4.44199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-07 00:00:00', -2.93799996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-08 00:00:00', -0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-09 00:00:00', -1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-10 00:00:00', -3.74499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-11 00:00:00', -1.53400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-12 00:00:00', -0.246000006794929504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-13 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-14 00:00:00', 0.644999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-15 00:00:00', -5.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-16 00:00:00', -4.34200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-17 00:00:00', -0.0920000001788139343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-18 00:00:00', -0.740999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-19 00:00:00', -0.268000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-20 00:00:00', 1.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-21 00:00:00', 2.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-22 00:00:00', 1.46500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-23 00:00:00', 2.29200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-24 00:00:00', 1.61300003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-25 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-26 00:00:00', 7.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-27 00:00:00', 2.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-28 00:00:00', 0.555000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-29 00:00:00', 0.289999991655349731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-30 00:00:00', 1.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-03-31 00:00:00', -3.58800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-01 00:00:00', -1.90600001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-02 00:00:00', -0.885999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-03 00:00:00', -1.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-04 00:00:00', 0.136000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-05 00:00:00', 0.266999989748001099, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-06 00:00:00', 2.75699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-07 00:00:00', 10.8549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-08 00:00:00', 12.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-09 00:00:00', 12.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-10 00:00:00', 11.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-11 00:00:00', 12.3529996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-12 00:00:00', 13.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-13 00:00:00', 12.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-14 00:00:00', 6.38299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-15 00:00:00', 3.27999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-16 00:00:00', -0.917999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-17 00:00:00', 5.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-18 00:00:00', 3.94899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-19 00:00:00', -3.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-20 00:00:00', 1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-21 00:00:00', 8.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-22 00:00:00', 11.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-23 00:00:00', 12.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-24 00:00:00', 6.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-25 00:00:00', 7.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-26 00:00:00', 11.1099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-27 00:00:00', 14.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-28 00:00:00', 15.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-29 00:00:00', 15.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-04-30 00:00:00', 8.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-01 00:00:00', 0.986000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-02 00:00:00', -1.24600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-03 00:00:00', 2.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-04 00:00:00', 5.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-05 00:00:00', 4.49800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-06 00:00:00', 10.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-07 00:00:00', 13.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-08 00:00:00', 14.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-09 00:00:00', 13.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-10 00:00:00', 7.75099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-11 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-12 00:00:00', 5.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-13 00:00:00', 9.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-14 00:00:00', 6.65899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-15 00:00:00', 7.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-16 00:00:00', 10.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-17 00:00:00', 12.9219999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-18 00:00:00', 12.7790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-19 00:00:00', 12.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-20 00:00:00', 13.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-21 00:00:00', 13.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-22 00:00:00', 13.1870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-23 00:00:00', 13.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-24 00:00:00', 15.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-25 00:00:00', 11.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-26 00:00:00', 10.1400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-27 00:00:00', 3.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-28 00:00:00', 8.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-29 00:00:00', 12.2930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-30 00:00:00', 16.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-05-31 00:00:00', 14.8649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-01 00:00:00', 16.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-02 00:00:00', 18.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-03 00:00:00', 16.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-04 00:00:00', 17.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-05 00:00:00', 19.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-06 00:00:00', 17.9650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-07 00:00:00', 12.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-08 00:00:00', 13.1920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-09 00:00:00', 15.5679998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-10 00:00:00', 16.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-11 00:00:00', 12.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-12 00:00:00', 11.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-13 00:00:00', 16.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-14 00:00:00', 17.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-15 00:00:00', 17.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-16 00:00:00', 18.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-17 00:00:00', 19.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-18 00:00:00', 20.0270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-19 00:00:00', 19.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-20 00:00:00', 18.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-21 00:00:00', 14.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-22 00:00:00', 16.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-23 00:00:00', 19.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-24 00:00:00', 20.5729999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-25 00:00:00', 22.5669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-26 00:00:00', 19.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-27 00:00:00', 20.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-28 00:00:00', 19.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-29 00:00:00', 18.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-06-30 00:00:00', 18.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-01 00:00:00', 21.4829998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-02 00:00:00', 24.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-03 00:00:00', 26.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-04 00:00:00', 22.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-05 00:00:00', 20.4319992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-06 00:00:00', 21.2390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-07 00:00:00', 22.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-08 00:00:00', 22.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-09 00:00:00', 21.5650005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-10 00:00:00', 23.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-11 00:00:00', 22.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-12 00:00:00', 21.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-13 00:00:00', 20.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-14 00:00:00', 22.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-15 00:00:00', 23.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-16 00:00:00', 23.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-17 00:00:00', 23.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-18 00:00:00', 26.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-19 00:00:00', 27.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-20 00:00:00', 28.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-21 00:00:00', 27.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-22 00:00:00', 24.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-23 00:00:00', 21.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-24 00:00:00', 21.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-25 00:00:00', 22.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-26 00:00:00', 23.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-27 00:00:00', 23.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-28 00:00:00', 24.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-29 00:00:00', 23.7609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-30 00:00:00', 23.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-07-31 00:00:00', 25.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-01 00:00:00', 25.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-02 00:00:00', 23.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-03 00:00:00', 20.3010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-04 00:00:00', 17.5790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-05 00:00:00', 17.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-06 00:00:00', 19.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-07 00:00:00', 19.1259994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-08 00:00:00', 20.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-09 00:00:00', 20.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-10 00:00:00', 20.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-11 00:00:00', 21.3680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-12 00:00:00', 21.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-13 00:00:00', 21.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-14 00:00:00', 23.6909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-15 00:00:00', 25.5170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-16 00:00:00', 26.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-17 00:00:00', 26.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-18 00:00:00', 24.9349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-19 00:00:00', 22.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-20 00:00:00', 18.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-21 00:00:00', 16.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-22 00:00:00', 17.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-23 00:00:00', 19.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-24 00:00:00', 20.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-25 00:00:00', 20.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-26 00:00:00', 18.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-27 00:00:00', 20.3250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-28 00:00:00', 21.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-29 00:00:00', 20.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-30 00:00:00', 18.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-08-31 00:00:00', 20.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-01 00:00:00', 21.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-02 00:00:00', 21.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-03 00:00:00', 20.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-04 00:00:00', 18.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-05 00:00:00', 16.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-06 00:00:00', 15.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-07 00:00:00', 19.3050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-08 00:00:00', 19.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-09 00:00:00', 21.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-10 00:00:00', 22.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-11 00:00:00', 20.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-12 00:00:00', 18.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-13 00:00:00', 16.7709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-14 00:00:00', 17.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-15 00:00:00', 14.8149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-16 00:00:00', 12.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-17 00:00:00', 15.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-18 00:00:00', 17.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-19 00:00:00', 19.5440006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-20 00:00:00', 21.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-21 00:00:00', 18.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-22 00:00:00', 16.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-23 00:00:00', 12.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-24 00:00:00', 11.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-25 00:00:00', 11.1929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-26 00:00:00', 7.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-27 00:00:00', 7.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-28 00:00:00', 8.73600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-29 00:00:00', 9.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-09-30 00:00:00', 10.189000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-01 00:00:00', 11.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-02 00:00:00', 12.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-03 00:00:00', 14.4049997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-04 00:00:00', 15.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-05 00:00:00', 14.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-06 00:00:00', 10.8380002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-07 00:00:00', 5.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-08 00:00:00', 6.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-09 00:00:00', 7.61399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-10 00:00:00', 8.20400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-11 00:00:00', 9.10900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-12 00:00:00', 7.66900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-13 00:00:00', 7.93800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-14 00:00:00', 8.77999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-15 00:00:00', 8.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-16 00:00:00', 7.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-17 00:00:00', 9.39400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-18 00:00:00', 11.1920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-19 00:00:00', 11.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-20 00:00:00', 12.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-21 00:00:00', 8.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-22 00:00:00', 10.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-23 00:00:00', 9.91399955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-24 00:00:00', 10.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-25 00:00:00', 12.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-26 00:00:00', 12.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-27 00:00:00', 12.4119997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-28 00:00:00', 11.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-29 00:00:00', 14.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-30 00:00:00', 14.6110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-10-31 00:00:00', 14.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-01 00:00:00', 11.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-02 00:00:00', 8.50300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-03 00:00:00', 10.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-04 00:00:00', 5.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-05 00:00:00', -2.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-06 00:00:00', -2.5280001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-07 00:00:00', -4.03800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-08 00:00:00', -3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-09 00:00:00', 1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-10 00:00:00', 1.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-11 00:00:00', 3.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-12 00:00:00', 2.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-13 00:00:00', 0.815999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-14 00:00:00', 0.409000009298324585, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-15 00:00:00', 0.569000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-16 00:00:00', -3.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-17 00:00:00', -6.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-18 00:00:00', -4.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-19 00:00:00', -3.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-20 00:00:00', -0.667999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-21 00:00:00', -0.869000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-22 00:00:00', -1.37800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-23 00:00:00', -5.18499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-24 00:00:00', -2.3900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-25 00:00:00', -0.0379999987781047821, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-26 00:00:00', -0.209999993443489075, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-27 00:00:00', -0.0529999993741512299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-28 00:00:00', 0.469999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-29 00:00:00', -0.268999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-11-30 00:00:00', -1.35399997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-01 00:00:00', -2.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-02 00:00:00', -2.16000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-03 00:00:00', -2.1530001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-04 00:00:00', -2.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-05 00:00:00', -3.41899991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-06 00:00:00', -0.501999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-07 00:00:00', 0.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-08 00:00:00', -0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-09 00:00:00', -1.36800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-10 00:00:00', -1.12899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-11 00:00:00', -3.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-12 00:00:00', -9.85900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-13 00:00:00', -13.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-14 00:00:00', -9.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-15 00:00:00', -3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-16 00:00:00', -0.513999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-17 00:00:00', -0.671999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-18 00:00:00', -1.77499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-19 00:00:00', -0.317999988794326782, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-20 00:00:00', 0.638999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-21 00:00:00', -0.340999990701675415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-22 00:00:00', -5.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-23 00:00:00', -10.7010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-24 00:00:00', -6.24800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-25 00:00:00', -5.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-26 00:00:00', -7.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-27 00:00:00', -5.05800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-28 00:00:00', -3.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-29 00:00:00', -5.11999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-30 00:00:00', -7.5560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2003-12-31 00:00:00', -8.13599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-01 00:00:00', -9.62199974060058594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-02 00:00:00', -10.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-03 00:00:00', -8.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-04 00:00:00', -4.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-05 00:00:00', -6.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-06 00:00:00', -4.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-07 00:00:00', -5.39200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-08 00:00:00', -2.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-09 00:00:00', -0.0560000017285346985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-10 00:00:00', 0.118000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-11 00:00:00', -0.476999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-12 00:00:00', -2.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-13 00:00:00', -2.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-14 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-15 00:00:00', 0.0230000000447034836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-16 00:00:00', 0.175999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-17 00:00:00', -2.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-18 00:00:00', -0.783999979496002197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-19 00:00:00', 0.256999999284744263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-20 00:00:00', -3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-21 00:00:00', -5.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-22 00:00:00', -4.76900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-23 00:00:00', -4.15999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-24 00:00:00', -2.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-25 00:00:00', -2.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-26 00:00:00', -3.43600010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-27 00:00:00', -2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-28 00:00:00', -3.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-29 00:00:00', -6.00500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-30 00:00:00', -6.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-01-31 00:00:00', -7.78200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-01 00:00:00', -7.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-02 00:00:00', -5.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-03 00:00:00', -1.79100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-04 00:00:00', -5.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-05 00:00:00', -4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-06 00:00:00', -3.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-07 00:00:00', -3.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-08 00:00:00', -3.11299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-09 00:00:00', -2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-10 00:00:00', -1.3760000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-11 00:00:00', 0.93199998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-12 00:00:00', 1.82099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-13 00:00:00', -0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-14 00:00:00', 1.67599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-15 00:00:00', 2.95199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-16 00:00:00', 1.88399994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-17 00:00:00', -4.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-18 00:00:00', -4.16900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-19 00:00:00', -3.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-20 00:00:00', -0.81800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-21 00:00:00', -2.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-22 00:00:00', -0.231000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-23 00:00:00', 0.734000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-24 00:00:00', 0.819999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-25 00:00:00', -0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-26 00:00:00', -1.61500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-27 00:00:00', -1.53100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-28 00:00:00', -1.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-02-29 00:00:00', -1.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-01 00:00:00', -2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-02 00:00:00', -0.303999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-03 00:00:00', -0.535000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-04 00:00:00', -0.55699998140335083, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-05 00:00:00', 0.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-06 00:00:00', 5.9850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-07 00:00:00', 10.3120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-08 00:00:00', 6.62900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-09 00:00:00', 2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-10 00:00:00', 1.71300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-11 00:00:00', 3.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-12 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-13 00:00:00', 6.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-14 00:00:00', 3.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-15 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-16 00:00:00', 5.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-17 00:00:00', -1.64300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-18 00:00:00', 0.800999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-19 00:00:00', 2.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-20 00:00:00', 0.202999994158744812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-21 00:00:00', -1.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-22 00:00:00', -2.18899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-23 00:00:00', -0.504000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-24 00:00:00', 2.8340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-25 00:00:00', 3.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-26 00:00:00', 5.98899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-27 00:00:00', 5.85799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-28 00:00:00', 6.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-29 00:00:00', 8.52900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-30 00:00:00', 9.72900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-03-31 00:00:00', 10.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-01 00:00:00', 7.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-02 00:00:00', 5.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-03 00:00:00', 6.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-04 00:00:00', 10.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-05 00:00:00', 12.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-06 00:00:00', 4.75799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-07 00:00:00', 1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-08 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-09 00:00:00', 2.97600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-10 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-11 00:00:00', 5.89900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-12 00:00:00', 6.82999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-13 00:00:00', 7.87300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-14 00:00:00', 9.95400047302246094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-15 00:00:00', 11.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-16 00:00:00', 9.29800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-17 00:00:00', 10.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-18 00:00:00', 8.96599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-19 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-20 00:00:00', 10.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-21 00:00:00', 11.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-22 00:00:00', 3.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-23 00:00:00', 10.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-24 00:00:00', 15.7130002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-25 00:00:00', 12.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-26 00:00:00', 10.9630002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-27 00:00:00', 7.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-28 00:00:00', 7.21799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-29 00:00:00', 1.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-04-30 00:00:00', 4.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-01 00:00:00', 7.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-02 00:00:00', 9.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-03 00:00:00', 11.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-04 00:00:00', 13.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-05 00:00:00', 15.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-06 00:00:00', 11.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-07 00:00:00', 6.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-08 00:00:00', 10.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-09 00:00:00', 12.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-10 00:00:00', 13.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-11 00:00:00', 14.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-12 00:00:00', 17.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-13 00:00:00', 19.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-14 00:00:00', 20.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-15 00:00:00', 20.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-16 00:00:00', 17.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-17 00:00:00', 18.6620006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-18 00:00:00', 19.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-19 00:00:00', 13.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-20 00:00:00', 12.4809999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-21 00:00:00', 15.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-22 00:00:00', 8.99199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-23 00:00:00', 9.35999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-24 00:00:00', 14.0719995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-25 00:00:00', 15.6829996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-26 00:00:00', 14.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-27 00:00:00', 11.0129995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-28 00:00:00', 13.7019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-29 00:00:00', 13.8900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-30 00:00:00', 14.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-05-31 00:00:00', 13.8489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-01 00:00:00', 15.2729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-02 00:00:00', 14.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-03 00:00:00', 18.930999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-04 00:00:00', 18.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-05 00:00:00', 18.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-06 00:00:00', 15.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-07 00:00:00', 15.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-08 00:00:00', 16.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-09 00:00:00', 17.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-10 00:00:00', 19.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-11 00:00:00', 20.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-12 00:00:00', 22.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-13 00:00:00', 22.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-14 00:00:00', 16.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-15 00:00:00', 19.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-16 00:00:00', 21.2700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-17 00:00:00', 22.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-18 00:00:00', 22.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-19 00:00:00', 22.3080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-20 00:00:00', 21.8560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-21 00:00:00', 21.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-22 00:00:00', 21.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-23 00:00:00', 20.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-24 00:00:00', 20.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-25 00:00:00', 20.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-26 00:00:00', 19.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-27 00:00:00', 19.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-28 00:00:00', 21.1019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-29 00:00:00', 22.1790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-06-30 00:00:00', 21.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-01 00:00:00', 22.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-02 00:00:00', 22.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-03 00:00:00', 23.5319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-04 00:00:00', 23.3269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-05 00:00:00', 19.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-06 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-07 00:00:00', 20.6410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-08 00:00:00', 18.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-09 00:00:00', 20.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-10 00:00:00', 21.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-11 00:00:00', 22.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-12 00:00:00', 20.1919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-13 00:00:00', 16.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-14 00:00:00', 17.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-15 00:00:00', 15.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-16 00:00:00', 14.5089998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-17 00:00:00', 12.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-18 00:00:00', 12.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-19 00:00:00', 9.01500034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-20 00:00:00', 11.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-21 00:00:00', 13.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-22 00:00:00', 16.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-23 00:00:00', 19.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-24 00:00:00', 21.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-25 00:00:00', 22.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-26 00:00:00', 22.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-27 00:00:00', 22.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-28 00:00:00', 22.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-29 00:00:00', 21.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-30 00:00:00', 18.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-07-31 00:00:00', 19.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-01 00:00:00', 14.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-02 00:00:00', 15.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-03 00:00:00', 16.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-04 00:00:00', 20.5119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-05 00:00:00', 23.2290000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-06 00:00:00', 21.4290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-07 00:00:00', 19.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-08 00:00:00', 18.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-09 00:00:00', 19.0610008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-10 00:00:00', 19.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-11 00:00:00', 19.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-12 00:00:00', 21.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-13 00:00:00', 24.1930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-14 00:00:00', 26.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-15 00:00:00', 25.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-16 00:00:00', 23.7830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-17 00:00:00', 21.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-18 00:00:00', 22.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-19 00:00:00', 21.5529994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-20 00:00:00', 19.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-21 00:00:00', 19.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-22 00:00:00', 22.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-23 00:00:00', 23.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-24 00:00:00', 23.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-25 00:00:00', 21.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-26 00:00:00', 19.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-27 00:00:00', 19.1580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-28 00:00:00', 18.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-29 00:00:00', 18.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-30 00:00:00', 15.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-08-31 00:00:00', 17.3829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-01 00:00:00', 16.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-02 00:00:00', 16.4549999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-03 00:00:00', 17.0550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-04 00:00:00', 16.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-05 00:00:00', 17.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-06 00:00:00', 19.9729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-07 00:00:00', 23.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-08 00:00:00', 21.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-09 00:00:00', 19.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-10 00:00:00', 21.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-11 00:00:00', 23.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-12 00:00:00', 21.4599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-13 00:00:00', 21.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-14 00:00:00', 18.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-15 00:00:00', 13.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-16 00:00:00', 11.9399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-17 00:00:00', 12.7159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-18 00:00:00', 15.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-19 00:00:00', 15.0920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-20 00:00:00', 12.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-21 00:00:00', 10.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-22 00:00:00', 11.5019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-23 00:00:00', 14.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-24 00:00:00', 15.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-25 00:00:00', 15.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-26 00:00:00', 15.9700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-27 00:00:00', 16.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-28 00:00:00', 15.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-29 00:00:00', 15.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-09-30 00:00:00', 15.3249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-01 00:00:00', 13.7180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-02 00:00:00', 13.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-03 00:00:00', 13.8350000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-04 00:00:00', 15.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-05 00:00:00', 15.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-06 00:00:00', 11.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-07 00:00:00', 7.03599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-08 00:00:00', 2.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-09 00:00:00', 4.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-10 00:00:00', 5.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-11 00:00:00', 8.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-12 00:00:00', 6.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-13 00:00:00', 9.94699954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-14 00:00:00', 10.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-15 00:00:00', 4.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-16 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-17 00:00:00', 5.31500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-18 00:00:00', 1.8890000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-19 00:00:00', 2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-20 00:00:00', 4.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-21 00:00:00', 8.29399967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-22 00:00:00', 11.7720003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-23 00:00:00', 12.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-24 00:00:00', 4.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-25 00:00:00', 5.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-26 00:00:00', 6.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-27 00:00:00', 0.446000009775161743, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-28 00:00:00', 3.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-29 00:00:00', 7.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-30 00:00:00', 7.13199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-10-31 00:00:00', 6.18800020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-01 00:00:00', 5.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-02 00:00:00', 6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-03 00:00:00', 7.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-04 00:00:00', 8.97000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-05 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-06 00:00:00', 6.25099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-07 00:00:00', 6.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-08 00:00:00', 5.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-09 00:00:00', 3.24699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-10 00:00:00', 2.66400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-11 00:00:00', 3.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-12 00:00:00', 3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-13 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-14 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-15 00:00:00', 3.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-16 00:00:00', 0.804000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-17 00:00:00', 4.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-18 00:00:00', 2.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-19 00:00:00', 1.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-20 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-21 00:00:00', 2.92899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-22 00:00:00', 2.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-23 00:00:00', 4.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-24 00:00:00', 2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-25 00:00:00', -0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-26 00:00:00', 0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-27 00:00:00', 1.25899994373321533, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-28 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-29 00:00:00', -1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-11-30 00:00:00', -4.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-01 00:00:00', -3.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-02 00:00:00', -0.883000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-03 00:00:00', -4.40600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-04 00:00:00', -4.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-05 00:00:00', -0.298999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-06 00:00:00', -1.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-07 00:00:00', -3.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-08 00:00:00', -0.848999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-09 00:00:00', -0.370999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-10 00:00:00', 0.970000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-11 00:00:00', 0.109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-12 00:00:00', -0.607999980449676514, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-13 00:00:00', -0.22800000011920929, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-14 00:00:00', -0.616999983787536621, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-15 00:00:00', -0.46399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-16 00:00:00', 0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-17 00:00:00', 0.609000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-18 00:00:00', -1.46800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-19 00:00:00', -9.49199962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-20 00:00:00', -5.36100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-21 00:00:00', -5.58199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-22 00:00:00', -5.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-23 00:00:00', -7.19299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-24 00:00:00', -5.97599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-25 00:00:00', -5.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-26 00:00:00', -0.522000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-27 00:00:00', -4.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-28 00:00:00', -4.13299989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-29 00:00:00', -6.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-30 00:00:00', -5.3619999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2004-12-31 00:00:00', -1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-01 00:00:00', -5.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-02 00:00:00', -5.16099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-03 00:00:00', -2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-04 00:00:00', -2.38400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-05 00:00:00', -4.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-06 00:00:00', -1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-07 00:00:00', -4.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-08 00:00:00', -5.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-09 00:00:00', -6.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-10 00:00:00', -6.2350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-11 00:00:00', -0.218999996781349182, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-12 00:00:00', -5.37200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-13 00:00:00', -6.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-14 00:00:00', -8.16899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-15 00:00:00', -7.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-16 00:00:00', -6.87599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-17 00:00:00', -9.85299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-18 00:00:00', -6.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-19 00:00:00', -5.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-20 00:00:00', -1.66600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-21 00:00:00', -6.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-22 00:00:00', -8.48900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-23 00:00:00', -3.72699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-24 00:00:00', -6.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-25 00:00:00', -3.89299988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-26 00:00:00', -5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-27 00:00:00', -9.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-28 00:00:00', -11.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-29 00:00:00', -9.25100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-30 00:00:00', -10.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-01-31 00:00:00', -6.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-01 00:00:00', -5.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-02 00:00:00', -3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-03 00:00:00', -5.45399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-04 00:00:00', -7.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-05 00:00:00', -7.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-06 00:00:00', -7.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-07 00:00:00', -8.11800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-08 00:00:00', -6.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-09 00:00:00', -2.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-10 00:00:00', -3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-11 00:00:00', -6.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-12 00:00:00', -8.28400039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-13 00:00:00', -8.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-14 00:00:00', -6.57000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-15 00:00:00', -8.53899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-16 00:00:00', -12.0539999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-17 00:00:00', -11.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-18 00:00:00', -8.82199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-19 00:00:00', -4.45699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-20 00:00:00', -1.4869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-21 00:00:00', -0.0280000008642673492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-22 00:00:00', -0.243000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-23 00:00:00', -4.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-24 00:00:00', -6.59200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-25 00:00:00', -4.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-26 00:00:00', -1.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-27 00:00:00', -1.42599999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-02-28 00:00:00', -0.61799997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-01 00:00:00', 1.75999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-02 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-03 00:00:00', 1.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-04 00:00:00', 3.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-05 00:00:00', 5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-06 00:00:00', 4.40999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-07 00:00:00', 3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-08 00:00:00', 3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-09 00:00:00', 0.978999972343444824, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-10 00:00:00', 1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-11 00:00:00', 4.2909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-12 00:00:00', 9.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-13 00:00:00', 8.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-14 00:00:00', 4.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-15 00:00:00', 6.44999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-16 00:00:00', 1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-17 00:00:00', -0.0489999987185001373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-18 00:00:00', 0.120999999344348907, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-19 00:00:00', -0.947000026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-20 00:00:00', 2.26399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-21 00:00:00', 2.97099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-22 00:00:00', 3.60500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-23 00:00:00', 3.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-24 00:00:00', 4.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-25 00:00:00', 1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-26 00:00:00', -0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-27 00:00:00', -5.84600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-28 00:00:00', -2.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-29 00:00:00', -0.13099999725818634, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-30 00:00:00', 2.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-03-31 00:00:00', 6.62300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-01 00:00:00', 6.03000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-02 00:00:00', 3.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-03 00:00:00', 4.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-04 00:00:00', 3.98300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-05 00:00:00', 0.790000021457672119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-06 00:00:00', -4.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-07 00:00:00', -3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-08 00:00:00', -4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-09 00:00:00', -3.62400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-10 00:00:00', -1.35000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-11 00:00:00', 1.97200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-12 00:00:00', 0.495999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-13 00:00:00', 3.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-14 00:00:00', 4.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-15 00:00:00', 7.86399984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-16 00:00:00', 9.68999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-17 00:00:00', 3.48600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-18 00:00:00', 5.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-19 00:00:00', 3.78699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-20 00:00:00', 3.54399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-21 00:00:00', 4.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-22 00:00:00', 4.21500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-23 00:00:00', 3.84899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-24 00:00:00', 3.24799990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-25 00:00:00', 2.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-26 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-27 00:00:00', 2.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-28 00:00:00', 3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-29 00:00:00', 3.95099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-04-30 00:00:00', 10.5959997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-01 00:00:00', 5.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-02 00:00:00', 7.6399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-03 00:00:00', 7.54899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-04 00:00:00', 11.383000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-05 00:00:00', 10.6949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-06 00:00:00', 13.2589998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-07 00:00:00', 7.26100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-08 00:00:00', 2.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-09 00:00:00', 7.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-10 00:00:00', 10.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-11 00:00:00', 10.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-12 00:00:00', 8.30300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-13 00:00:00', 6.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-14 00:00:00', 8.84500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-15 00:00:00', 9.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-16 00:00:00', 11.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-17 00:00:00', 11.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-18 00:00:00', 3.88400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-19 00:00:00', 1.8200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-20 00:00:00', 1.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-21 00:00:00', 7.83099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-22 00:00:00', 7.73299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-23 00:00:00', 6.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-24 00:00:00', 2.96300005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-25 00:00:00', 6.67799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-26 00:00:00', 6.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-27 00:00:00', 9.13300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-28 00:00:00', 11.3179998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-29 00:00:00', 14.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-30 00:00:00', 12.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-05-31 00:00:00', 13.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-01 00:00:00', 14.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-02 00:00:00', 16.1979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-03 00:00:00', 16.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-04 00:00:00', 17.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-05 00:00:00', 16.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-06 00:00:00', 16.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-07 00:00:00', 18.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-08 00:00:00', 18.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-09 00:00:00', 12.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-10 00:00:00', 9.27700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-11 00:00:00', 10.505000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-12 00:00:00', 13.7100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-13 00:00:00', 12.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-14 00:00:00', 16.2350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-15 00:00:00', 20.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-16 00:00:00', 21.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-17 00:00:00', 21.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-18 00:00:00', 21.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-19 00:00:00', 20.3630008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-20 00:00:00', 21.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-21 00:00:00', 22.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-22 00:00:00', 25.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-23 00:00:00', 26.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-24 00:00:00', 21.6900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-25 00:00:00', 18.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-26 00:00:00', 19.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-27 00:00:00', 21.3239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-28 00:00:00', 20.4139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-29 00:00:00', 20.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-06-30 00:00:00', 20.7169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-01 00:00:00', 20.9209995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-02 00:00:00', 19.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-03 00:00:00', 20.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-04 00:00:00', 20.5499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-05 00:00:00', 21.2709999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-06 00:00:00', 22.207000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-07 00:00:00', 23.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-08 00:00:00', 25.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-09 00:00:00', 25.1359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-10 00:00:00', 24.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-11 00:00:00', 22.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-12 00:00:00', 22.3780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-13 00:00:00', 22.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-14 00:00:00', 20.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-15 00:00:00', 20.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-16 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-17 00:00:00', 19.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-18 00:00:00', 21.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-19 00:00:00', 21.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-20 00:00:00', 22.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-21 00:00:00', 22.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-22 00:00:00', 20.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-23 00:00:00', 20.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-24 00:00:00', 21.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-25 00:00:00', 21.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-26 00:00:00', 21.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-27 00:00:00', 22.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-28 00:00:00', 22.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-29 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-30 00:00:00', 20.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-07-31 00:00:00', 20.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-01 00:00:00', 19.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-02 00:00:00', 18.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-03 00:00:00', 19.4150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-04 00:00:00', 20.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-05 00:00:00', 18.6399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-06 00:00:00', 22.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-07 00:00:00', 20.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-08 00:00:00', 20.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-09 00:00:00', 21.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-10 00:00:00', 20.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-11 00:00:00', 15.7729997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-12 00:00:00', 14.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-13 00:00:00', 17.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-14 00:00:00', 20.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-15 00:00:00', 19.0160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-16 00:00:00', 17.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-17 00:00:00', 18.8449993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-18 00:00:00', 19.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-19 00:00:00', 20.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-20 00:00:00', 20.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-21 00:00:00', 20.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-22 00:00:00', 19.7509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-23 00:00:00', 19.1749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-24 00:00:00', 16.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-25 00:00:00', 16.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-26 00:00:00', 16.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-27 00:00:00', 11.3520002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-28 00:00:00', 13.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-29 00:00:00', 13.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-30 00:00:00', 13.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-08-31 00:00:00', 15.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-01 00:00:00', 17.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-02 00:00:00', 20.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-03 00:00:00', 20.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-04 00:00:00', 22.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-05 00:00:00', 24.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-06 00:00:00', 23.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-07 00:00:00', 21.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-08 00:00:00', 19.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-09 00:00:00', 18.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-10 00:00:00', 15.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-11 00:00:00', 17.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-12 00:00:00', 17.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-13 00:00:00', 18.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-14 00:00:00', 18.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-15 00:00:00', 20.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-16 00:00:00', 21.3500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-17 00:00:00', 19.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-18 00:00:00', 15.8479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-19 00:00:00', 15.6409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-20 00:00:00', 16.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-21 00:00:00', 17.4669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-22 00:00:00', 16.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-23 00:00:00', 15.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-24 00:00:00', 15.0900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-25 00:00:00', 13.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-26 00:00:00', 13.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-27 00:00:00', 13.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-28 00:00:00', 13.1680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-29 00:00:00', 14.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-09-30 00:00:00', 15.1260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-01 00:00:00', 17.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-02 00:00:00', 15.2340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-03 00:00:00', 10.5620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-04 00:00:00', 11.6780004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-05 00:00:00', 12.6289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-06 00:00:00', 15.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-07 00:00:00', 16.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-08 00:00:00', 13.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-09 00:00:00', 13.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-10 00:00:00', 13.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-11 00:00:00', 10.310999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-12 00:00:00', 7.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-13 00:00:00', 6.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-14 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-15 00:00:00', 3.44000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-16 00:00:00', 4.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-17 00:00:00', 7.36299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-18 00:00:00', 10.0019998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-19 00:00:00', 12.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-20 00:00:00', 13.2629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-21 00:00:00', 14.2379999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-22 00:00:00', 14.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-23 00:00:00', 6.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-24 00:00:00', 1.24500000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-25 00:00:00', 3.7070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-26 00:00:00', 6.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-27 00:00:00', 5.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-28 00:00:00', 9.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-29 00:00:00', 10.0530004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-30 00:00:00', 9.23499965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-10-31 00:00:00', 5.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-01 00:00:00', 4.6119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-02 00:00:00', 4.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-03 00:00:00', 6.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-04 00:00:00', 6.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-05 00:00:00', 6.25199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-06 00:00:00', 6.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-07 00:00:00', 2.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-08 00:00:00', 3.68899989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-09 00:00:00', 2.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-10 00:00:00', 0.0759999975562095642, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-11 00:00:00', -3.23200011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-12 00:00:00', -0.663999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-13 00:00:00', -1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-14 00:00:00', -1.8320000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-15 00:00:00', -2.85299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-16 00:00:00', -3.26600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-17 00:00:00', 0.476000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-18 00:00:00', 1.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-19 00:00:00', 1.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-20 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-21 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-22 00:00:00', 0.920000016689300537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-23 00:00:00', 1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-24 00:00:00', -2.17799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-25 00:00:00', -4.45599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-26 00:00:00', -4.30700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-27 00:00:00', -3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-28 00:00:00', -4.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-29 00:00:00', -3.35899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-11-30 00:00:00', -3.11599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-01 00:00:00', -0.99299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-02 00:00:00', -1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-03 00:00:00', -3.29800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-04 00:00:00', -1.27799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-05 00:00:00', -2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-06 00:00:00', 0.465000003576278687, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-07 00:00:00', -0.231000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-08 00:00:00', -3.63199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-09 00:00:00', -3.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-10 00:00:00', -0.398999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-11 00:00:00', 0.143999993801116943, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-12 00:00:00', -0.921000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-13 00:00:00', -0.81800001859664917, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-14 00:00:00', -6.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-15 00:00:00', -2.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-16 00:00:00', 0.0120000001043081284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-17 00:00:00', 0.823000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-18 00:00:00', 1.76100003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-19 00:00:00', 0.986999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-20 00:00:00', 0.137999996542930603, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-21 00:00:00', -0.252999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-22 00:00:00', -1.33700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-23 00:00:00', -1.11600005626678467, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-24 00:00:00', -0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-25 00:00:00', -0.254000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-26 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-27 00:00:00', -1.23399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-28 00:00:00', -8.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-29 00:00:00', -9.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-30 00:00:00', -9.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2005-12-31 00:00:00', -9.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-01 00:00:00', -10.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-02 00:00:00', -13.008000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-03 00:00:00', -15.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-04 00:00:00', -14.1129999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-05 00:00:00', -13.3850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-06 00:00:00', -9.23700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-07 00:00:00', -4.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-08 00:00:00', -2.25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-09 00:00:00', -3.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-10 00:00:00', -7.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-11 00:00:00', -6.49300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-12 00:00:00', -6.40399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-13 00:00:00', -4.31400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-14 00:00:00', -5.55700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-15 00:00:00', -6.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-16 00:00:00', -8.33600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-17 00:00:00', -9.52600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-18 00:00:00', -7.37099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-19 00:00:00', -8.03199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-20 00:00:00', -7.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-21 00:00:00', -5.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-22 00:00:00', -4.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-23 00:00:00', -7.53499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-24 00:00:00', -3.21700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-25 00:00:00', -4.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-26 00:00:00', -2.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-27 00:00:00', -3.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-28 00:00:00', -4.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-29 00:00:00', -5.7649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-30 00:00:00', -1.59300005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-01-31 00:00:00', -3.72799992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-01 00:00:00', -2.65100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-02 00:00:00', -2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-03 00:00:00', -0.324999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-04 00:00:00', 1.59099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-05 00:00:00', 1.61899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-06 00:00:00', -0.791999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-07 00:00:00', 0.446999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-08 00:00:00', 0.41100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-09 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-10 00:00:00', 1.46200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-11 00:00:00', -1.12800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-12 00:00:00', 0.582000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-13 00:00:00', 0.458000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-14 00:00:00', 0.828999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-15 00:00:00', 0.0769999995827674866, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-16 00:00:00', -0.615999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-17 00:00:00', 0.589999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-18 00:00:00', -1.33099997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-19 00:00:00', -3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-20 00:00:00', -1.96200001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-21 00:00:00', -2.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-22 00:00:00', -1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-23 00:00:00', -3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-24 00:00:00', -2.8599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-25 00:00:00', -4.77500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-26 00:00:00', -1.57099997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-27 00:00:00', -0.765999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-02-28 00:00:00', 0.317000001668930054, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-01 00:00:00', 0.0109999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-02 00:00:00', -0.0839999988675117493, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-03 00:00:00', 0.919000029563903809, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-04 00:00:00', -0.377999991178512573, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-05 00:00:00', -0.0610000006854534149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-06 00:00:00', -0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-07 00:00:00', -1.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-08 00:00:00', 0.153999999165534973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-09 00:00:00', 1.03199994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-10 00:00:00', 2.00099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-11 00:00:00', 3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-12 00:00:00', 2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-13 00:00:00', -2.54200005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-14 00:00:00', -3.01099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-15 00:00:00', -4.47100019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-16 00:00:00', -2.06100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-17 00:00:00', 0.328000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-18 00:00:00', -0.216999992728233337, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-19 00:00:00', 0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-20 00:00:00', 1.16400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-21 00:00:00', 0.833000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-22 00:00:00', -0.550000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-23 00:00:00', 0.712000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-24 00:00:00', 3.64800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-25 00:00:00', 4.81199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-26 00:00:00', 1.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-27 00:00:00', 3.0969998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-28 00:00:00', 5.97399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-29 00:00:00', 7.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-30 00:00:00', 6.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-03-31 00:00:00', 2.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-01 00:00:00', -0.296999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-02 00:00:00', 0.736000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-03 00:00:00', 1.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-04 00:00:00', 2.53600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-05 00:00:00', 2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-06 00:00:00', 6.16499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-07 00:00:00', 9.10999965667724609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-08 00:00:00', 5.95800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-09 00:00:00', 1.05099999904632568, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-10 00:00:00', -2.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-11 00:00:00', 1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-12 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-13 00:00:00', 1.13600003719329834, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-14 00:00:00', 1.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-15 00:00:00', 4.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-16 00:00:00', 6.29500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-17 00:00:00', 7.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-18 00:00:00', 8.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-19 00:00:00', 11.7670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-20 00:00:00', 7.21600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-21 00:00:00', 4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-22 00:00:00', 7.50400018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-23 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-24 00:00:00', 13.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-25 00:00:00', 14.5010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-26 00:00:00', 18.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-27 00:00:00', 17.1860008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-28 00:00:00', 13.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-29 00:00:00', 11.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-04-30 00:00:00', 9.56299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-01 00:00:00', 10.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-02 00:00:00', 9.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-03 00:00:00', 12.4300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-04 00:00:00', 10.3970003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-05 00:00:00', 12.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-06 00:00:00', 9.50100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-07 00:00:00', 11.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-08 00:00:00', 13.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-09 00:00:00', 14.7170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-10 00:00:00', 15.3870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-11 00:00:00', 18.0669994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-12 00:00:00', 17.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-13 00:00:00', 18.5520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-14 00:00:00', 19.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-15 00:00:00', 18.6009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-16 00:00:00', 20.4080009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-17 00:00:00', 15.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-18 00:00:00', 16.3689994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-19 00:00:00', 16.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-20 00:00:00', 16.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-21 00:00:00', 14.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-22 00:00:00', 16.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-23 00:00:00', 15.0150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-24 00:00:00', 13.9069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-25 00:00:00', 13.6230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-26 00:00:00', 13.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-27 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-28 00:00:00', 12.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-29 00:00:00', 13.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-30 00:00:00', 13.3629999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-05-31 00:00:00', 11.1020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-01 00:00:00', 12.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-02 00:00:00', 15.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-03 00:00:00', 14.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-04 00:00:00', 15.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-05 00:00:00', 16.7129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-06 00:00:00', 16.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-07 00:00:00', 14.0010004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-08 00:00:00', 13.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-09 00:00:00', 13.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-10 00:00:00', 12.3489999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-11 00:00:00', 12.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-12 00:00:00', 15.1230001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-13 00:00:00', 18.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-14 00:00:00', 20.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-15 00:00:00', 18.8390007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-16 00:00:00', 19.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-17 00:00:00', 20.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-18 00:00:00', 21.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-19 00:00:00', 23.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-20 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-21 00:00:00', 22.6599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-22 00:00:00', 21.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-23 00:00:00', 21.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-24 00:00:00', 22.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-25 00:00:00', 22.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-26 00:00:00', 22.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-27 00:00:00', 20.8099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-28 00:00:00', 20.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-29 00:00:00', 20.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-06-30 00:00:00', 18.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-01 00:00:00', 16.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-02 00:00:00', 15.508000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-03 00:00:00', 18.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-04 00:00:00', 16.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-05 00:00:00', 20.6609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-06 00:00:00', 23.1110000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-07 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-08 00:00:00', 24.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-09 00:00:00', 25.9150009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-10 00:00:00', 24.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-11 00:00:00', 21.2150001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-12 00:00:00', 15.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-13 00:00:00', 13.3079996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-14 00:00:00', 14.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-15 00:00:00', 16.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-16 00:00:00', 19.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-17 00:00:00', 21.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-18 00:00:00', 20.3840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-19 00:00:00', 21.2339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-20 00:00:00', 23.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-21 00:00:00', 25.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-22 00:00:00', 26.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-23 00:00:00', 26.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-24 00:00:00', 27.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-25 00:00:00', 26.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-26 00:00:00', 25.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-27 00:00:00', 24.6079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-28 00:00:00', 22.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-29 00:00:00', 24.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-30 00:00:00', 27.2859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-07-31 00:00:00', 26.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-01 00:00:00', 26.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-02 00:00:00', 26.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-03 00:00:00', 25.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-04 00:00:00', 24.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-05 00:00:00', 23.9389991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-06 00:00:00', 22.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-07 00:00:00', 23.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-08 00:00:00', 23.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-09 00:00:00', 24.4330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-10 00:00:00', 25.1130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-11 00:00:00', 25.3099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-12 00:00:00', 24.8460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-13 00:00:00', 25.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-14 00:00:00', 25.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-15 00:00:00', 21.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-16 00:00:00', 20.0060005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-17 00:00:00', 19.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-18 00:00:00', 21.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-19 00:00:00', 22.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-20 00:00:00', 23.0659999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-21 00:00:00', 21.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-22 00:00:00', 21.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-23 00:00:00', 22.2329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-24 00:00:00', 22.3169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-25 00:00:00', 23.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-26 00:00:00', 22.4220008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-27 00:00:00', 21.1480007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-28 00:00:00', 20.0349998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-29 00:00:00', 18.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-30 00:00:00', 21.4899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-08-31 00:00:00', 21.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-01 00:00:00', 19.5580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-02 00:00:00', 18.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-03 00:00:00', 16.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-04 00:00:00', 13.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-05 00:00:00', 14.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-06 00:00:00', 16.805999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-07 00:00:00', 19.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-08 00:00:00', 20.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-09 00:00:00', 20.2199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-10 00:00:00', 18.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-11 00:00:00', 17.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-12 00:00:00', 17.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-13 00:00:00', 17.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-14 00:00:00', 14.2939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-15 00:00:00', 15.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-16 00:00:00', 19.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-17 00:00:00', 19.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-18 00:00:00', 12.3940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-19 00:00:00', 10.1920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-20 00:00:00', 11.074000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-21 00:00:00', 12.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-22 00:00:00', 13.680999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-23 00:00:00', 14.0360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-24 00:00:00', 13.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-25 00:00:00', 12.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-26 00:00:00', 13.9680004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-27 00:00:00', 16.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-28 00:00:00', 15.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-29 00:00:00', 10.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-09-30 00:00:00', 13.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-01 00:00:00', 13.880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-02 00:00:00', 13.9469995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-03 00:00:00', 15.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-04 00:00:00', 15.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-05 00:00:00', 14.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-06 00:00:00', 13.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-07 00:00:00', 14.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-08 00:00:00', 14.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-09 00:00:00', 15.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-10 00:00:00', 14.8599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-11 00:00:00', 14.758000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-12 00:00:00', 13.5939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-13 00:00:00', 11.800999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-14 00:00:00', 7.9869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-15 00:00:00', 8.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-16 00:00:00', 13.4540004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-17 00:00:00', 13.5920000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-18 00:00:00', 10.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-19 00:00:00', 10.5830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-20 00:00:00', 7.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-21 00:00:00', 7.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-22 00:00:00', 10.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-23 00:00:00', 7.51999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-24 00:00:00', 5.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-25 00:00:00', 3.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-26 00:00:00', 6.91099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-27 00:00:00', 7.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-28 00:00:00', 8.54500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-29 00:00:00', 8.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-30 00:00:00', 9.80700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-10-31 00:00:00', 12.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-01 00:00:00', 10.6820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-02 00:00:00', 10.4189996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-03 00:00:00', 11.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-04 00:00:00', 12.6969995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-05 00:00:00', 12.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-06 00:00:00', 11.4960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-07 00:00:00', 11.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-08 00:00:00', 11.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-09 00:00:00', 6.62200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-10 00:00:00', 2.22600007057189941, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-11 00:00:00', 3.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-12 00:00:00', 1.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-13 00:00:00', 0.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-14 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-15 00:00:00', 0.515999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-16 00:00:00', 0.906000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-17 00:00:00', -0.451000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-18 00:00:00', 0.377000004053115845, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-19 00:00:00', 0.479000002145767212, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-20 00:00:00', -2.02500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-21 00:00:00', -4.14099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-22 00:00:00', -8.40900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-23 00:00:00', -5.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-24 00:00:00', -3.55500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-25 00:00:00', -4.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-26 00:00:00', -6.08699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-27 00:00:00', -6.1380000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-28 00:00:00', -4.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-29 00:00:00', -6.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-11-30 00:00:00', -6.69600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-01 00:00:00', -7.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-02 00:00:00', -5.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-03 00:00:00', -4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-04 00:00:00', -7.19500017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-05 00:00:00', -9.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-06 00:00:00', -5.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-07 00:00:00', -3.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-08 00:00:00', -1.07299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-09 00:00:00', -0.240999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-10 00:00:00', -2.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-11 00:00:00', -2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-12 00:00:00', -3.2219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-13 00:00:00', -2.84400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-14 00:00:00', -2.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-15 00:00:00', -2.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-16 00:00:00', -4.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-17 00:00:00', -2.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-18 00:00:00', 0.612999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-19 00:00:00', 0.921999990940093994, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-20 00:00:00', -0.386000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-21 00:00:00', -0.509999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-22 00:00:00', -1.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-23 00:00:00', -1.36699998378753662, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-24 00:00:00', -4.97700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-25 00:00:00', -5.28499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-26 00:00:00', -3.07399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-27 00:00:00', -2.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-28 00:00:00', 0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-29 00:00:00', -2.70399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-30 00:00:00', -6.95200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2006-12-31 00:00:00', -7.32999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-01 00:00:00', -11.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-02 00:00:00', -11.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-03 00:00:00', -7.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-04 00:00:00', -7.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-05 00:00:00', -4.60799980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-06 00:00:00', -1.01600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-07 00:00:00', -1.12300002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-08 00:00:00', -3.27900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-09 00:00:00', -5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-10 00:00:00', -6.28999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-11 00:00:00', -7.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-12 00:00:00', -8.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-13 00:00:00', -8.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-14 00:00:00', -6.98199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-15 00:00:00', -5.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-16 00:00:00', -6.47300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-17 00:00:00', -1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-18 00:00:00', -7.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-19 00:00:00', -8.17199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-20 00:00:00', -2.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-21 00:00:00', -1.28799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-22 00:00:00', -1.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-23 00:00:00', -1.67400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-24 00:00:00', -3.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-25 00:00:00', 0.197999998927116394, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-26 00:00:00', 0.68900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-27 00:00:00', 0.892000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-28 00:00:00', 0.910000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-29 00:00:00', 1.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-30 00:00:00', 1.14999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-01-31 00:00:00', 0.859000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-01 00:00:00', 0.351000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-02 00:00:00', 0.510999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-03 00:00:00', 0.23999999463558197, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-04 00:00:00', -2.12199997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-05 00:00:00', -1.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-06 00:00:00', -2.21499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-07 00:00:00', -0.944999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-08 00:00:00', 0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-09 00:00:00', -0.861999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-10 00:00:00', -1.29499995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-11 00:00:00', -2.15799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-12 00:00:00', -4.11600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-13 00:00:00', -3.75, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-14 00:00:00', -3.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-15 00:00:00', -2.9719998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-16 00:00:00', -2.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-17 00:00:00', -3.3190000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-18 00:00:00', -3.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-19 00:00:00', -7.35699987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-20 00:00:00', -1.54400002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-21 00:00:00', -5.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-22 00:00:00', -4.70800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-23 00:00:00', -1.2070000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-24 00:00:00', -0.620999991893768311, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-25 00:00:00', -2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-26 00:00:00', -6.8899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-27 00:00:00', -10.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-02-28 00:00:00', -7.06199979782104492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-01 00:00:00', -7.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-02 00:00:00', -3.92799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-03 00:00:00', -3.46000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-04 00:00:00', -4.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-05 00:00:00', -1.97899997234344482, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-06 00:00:00', -1.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-07 00:00:00', 0.504000008106231689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-08 00:00:00', 2.63499999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-09 00:00:00', -2.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-10 00:00:00', -2.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-11 00:00:00', -2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-12 00:00:00', -4.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-13 00:00:00', -3.48399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-14 00:00:00', -2.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-15 00:00:00', 0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-16 00:00:00', 0.639999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-17 00:00:00', 1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-18 00:00:00', 0.196999996900558472, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-19 00:00:00', -0.731000006198883057, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-20 00:00:00', 0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-21 00:00:00', 0.263000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-22 00:00:00', 2.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-23 00:00:00', 3.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-24 00:00:00', 1.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-25 00:00:00', 1.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-26 00:00:00', 1.22099995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-27 00:00:00', 2.01699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-28 00:00:00', 2.33800005912780762, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-29 00:00:00', 1.66199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-30 00:00:00', 1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-03-31 00:00:00', -0.926999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-01 00:00:00', -2.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-02 00:00:00', -0.799000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-03 00:00:00', 1.44200003147125244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-04 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-05 00:00:00', 4.92299985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-06 00:00:00', 1.53499996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-07 00:00:00', 5.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-08 00:00:00', 5.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-09 00:00:00', 9.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-10 00:00:00', 11.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-11 00:00:00', 12.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-12 00:00:00', 15.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-13 00:00:00', 16.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-14 00:00:00', 10.9840002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-15 00:00:00', 16.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-16 00:00:00', 14.2279996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-17 00:00:00', 11.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-18 00:00:00', 11.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-19 00:00:00', 12.0649995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-20 00:00:00', 15.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-21 00:00:00', 12.2519998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-22 00:00:00', 9.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-23 00:00:00', 10.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-24 00:00:00', 10.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-25 00:00:00', 14.3229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-26 00:00:00', 14.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-27 00:00:00', 12.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-28 00:00:00', 14.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-29 00:00:00', 13.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-04-30 00:00:00', 13.7410001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-01 00:00:00', 15.2880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-02 00:00:00', 14.6770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-03 00:00:00', 14.4289999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-04 00:00:00', 14.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-05 00:00:00', 15.9149999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-06 00:00:00', 13.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-07 00:00:00', 8.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-08 00:00:00', 8.14799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-09 00:00:00', 12.1630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-10 00:00:00', 14.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-11 00:00:00', 16.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-12 00:00:00', 17.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-13 00:00:00', 16.194000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-14 00:00:00', 18.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-15 00:00:00', 19.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-16 00:00:00', 10.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-17 00:00:00', 5.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-18 00:00:00', 6.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-19 00:00:00', 4.02099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-20 00:00:00', 7.67399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-21 00:00:00', 11.2370004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-22 00:00:00', 12.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-23 00:00:00', 13.1090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-24 00:00:00', 11.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-25 00:00:00', 11.2620000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-26 00:00:00', 13.3809995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-27 00:00:00', 15.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-28 00:00:00', 16.3589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-29 00:00:00', 17.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-30 00:00:00', 18.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-05-31 00:00:00', 17.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-01 00:00:00', 17.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-02 00:00:00', 17.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-03 00:00:00', 15.9580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-04 00:00:00', 14.8500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-05 00:00:00', 12.6470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-06 00:00:00', 14.7659997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-07 00:00:00', 15.6619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-08 00:00:00', 16.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-09 00:00:00', 20.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-10 00:00:00', 21.1439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-11 00:00:00', 18.8910007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-12 00:00:00', 20.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-13 00:00:00', 20.082000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-14 00:00:00', 19.4529991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-15 00:00:00', 17.5599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-16 00:00:00', 17.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-17 00:00:00', 17.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-18 00:00:00', 18.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-19 00:00:00', 20.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-20 00:00:00', 21.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-21 00:00:00', 24.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-22 00:00:00', 24.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-23 00:00:00', 25.7590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-24 00:00:00', 25.1690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-25 00:00:00', 23.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-26 00:00:00', 24.2649993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-27 00:00:00', 22.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-28 00:00:00', 21.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-29 00:00:00', 21.6669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-06-30 00:00:00', 23.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-01 00:00:00', 22.5009994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-02 00:00:00', 19.9109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-03 00:00:00', 22.8250007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-04 00:00:00', 23.6189994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-05 00:00:00', 21.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-06 00:00:00', 21.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-07 00:00:00', 19.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-08 00:00:00', 20.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-09 00:00:00', 23.1770000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-10 00:00:00', 24.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-11 00:00:00', 23.3439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-12 00:00:00', 21.957000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-13 00:00:00', 22.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-14 00:00:00', 19.9169998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-15 00:00:00', 20.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-16 00:00:00', 20.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-17 00:00:00', 21.8829994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-18 00:00:00', 24.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-19 00:00:00', 26.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-20 00:00:00', 23.7980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-21 00:00:00', 17.26300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-22 00:00:00', 18.1089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-23 00:00:00', 17.5909996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-24 00:00:00', 20.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-25 00:00:00', 21.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-26 00:00:00', 19.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-27 00:00:00', 19.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-28 00:00:00', 21.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-29 00:00:00', 23.1989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-30 00:00:00', 24.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-07-31 00:00:00', 21.6930007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-01 00:00:00', 21.11199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-02 00:00:00', 19.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-03 00:00:00', 19.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-04 00:00:00', 20.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-05 00:00:00', 20.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-06 00:00:00', 19.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-07 00:00:00', 19.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-08 00:00:00', 21.2399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-09 00:00:00', 24.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-10 00:00:00', 25.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-11 00:00:00', 21.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-12 00:00:00', 19.2849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-13 00:00:00', 19.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-14 00:00:00', 20.6790008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-15 00:00:00', 19.6970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-16 00:00:00', 20.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-17 00:00:00', 20.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-18 00:00:00', 21.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-19 00:00:00', 21.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-20 00:00:00', 21.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-21 00:00:00', 21.8840007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-22 00:00:00', 21.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-23 00:00:00', 21.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-24 00:00:00', 21.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-25 00:00:00', 21.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-26 00:00:00', 20.8379993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-27 00:00:00', 20.2590007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-28 00:00:00', 20.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-29 00:00:00', 21.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-30 00:00:00', 20.8740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-08-31 00:00:00', 21.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-01 00:00:00', 21.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-02 00:00:00', 20.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-03 00:00:00', 21.4260005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-04 00:00:00', 20.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-05 00:00:00', 18.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-06 00:00:00', 20.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-07 00:00:00', 19.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-08 00:00:00', 18.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-09 00:00:00', 19.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-10 00:00:00', 21.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-11 00:00:00', 21.7910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-12 00:00:00', 22.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-13 00:00:00', 21.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-14 00:00:00', 21.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-15 00:00:00', 20.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-16 00:00:00', 19.2110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-17 00:00:00', 20.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-18 00:00:00', 19.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-19 00:00:00', 17.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-20 00:00:00', 15.3210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-21 00:00:00', 13.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-22 00:00:00', 11.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-23 00:00:00', 12.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-24 00:00:00', 13.4670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-25 00:00:00', 13.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-26 00:00:00', 11.9379997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-27 00:00:00', 9.60299968719482422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-28 00:00:00', 7.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-29 00:00:00', 9.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-09-30 00:00:00', 10.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-01 00:00:00', 7.81699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-02 00:00:00', 7.68400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-03 00:00:00', 6.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-04 00:00:00', 7.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-05 00:00:00', 6.69199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-06 00:00:00', 6.06300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-07 00:00:00', 6.71400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-08 00:00:00', 6.98600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-09 00:00:00', 7.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-10 00:00:00', 6.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-11 00:00:00', 6.71099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-12 00:00:00', 8.28600025177001953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-13 00:00:00', 10.3990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-14 00:00:00', 11.4350004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-15 00:00:00', 11.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-16 00:00:00', 11.3149995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-17 00:00:00', 11.8039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-18 00:00:00', 12.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-19 00:00:00', 6.79799985885620117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-20 00:00:00', 6.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-21 00:00:00', 7.89699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-22 00:00:00', 8.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-23 00:00:00', 6.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-24 00:00:00', 5.65700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-25 00:00:00', 5.09399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-26 00:00:00', 4.21400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-27 00:00:00', 5.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-28 00:00:00', 7.61600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-29 00:00:00', 4.71500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-30 00:00:00', 5.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-10-31 00:00:00', 9.40400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-01 00:00:00', 11.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-02 00:00:00', 10.2010002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-03 00:00:00', 8.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-04 00:00:00', 11.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-05 00:00:00', 8.95699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-06 00:00:00', 10.8990001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-07 00:00:00', 10.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-08 00:00:00', 9.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-09 00:00:00', 5.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-10 00:00:00', 7.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-11 00:00:00', 6.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-12 00:00:00', 8.44499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-13 00:00:00', 4.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-14 00:00:00', 1.65299999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-15 00:00:00', 2.80100011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-16 00:00:00', 2.79600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-17 00:00:00', 3.92700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-18 00:00:00', 3.5150001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-19 00:00:00', 4.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-20 00:00:00', 3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-21 00:00:00', 4.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-22 00:00:00', 6.03299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-23 00:00:00', 2.58100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-24 00:00:00', 1.25300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-25 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-26 00:00:00', 3.57100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-27 00:00:00', 1.89400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-28 00:00:00', -0.162000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-29 00:00:00', 0.512000024318695068, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-11-30 00:00:00', -2.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-01 00:00:00', -4.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-02 00:00:00', -1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-03 00:00:00', 0.486000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-04 00:00:00', -1.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-05 00:00:00', -1.90100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-06 00:00:00', -0.74299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-07 00:00:00', -1.93299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-08 00:00:00', -0.0879999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-09 00:00:00', -3.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-10 00:00:00', -6.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-11 00:00:00', -7.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-12 00:00:00', -7.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-13 00:00:00', -7.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-14 00:00:00', -5.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-15 00:00:00', -2.17000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-16 00:00:00', -2.65599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-17 00:00:00', -3.28099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-18 00:00:00', -2.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-19 00:00:00', -4.63000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-20 00:00:00', -4.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-21 00:00:00', -5.64200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-22 00:00:00', -2.42400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-23 00:00:00', -7.08500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-24 00:00:00', -8.78899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-25 00:00:00', -8.28899955749511719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-26 00:00:00', -9.52400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-27 00:00:00', -10.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-28 00:00:00', -10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-29 00:00:00', -10.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-30 00:00:00', -7.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2007-12-31 00:00:00', -5.39499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-01 00:00:00', -6.05499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-02 00:00:00', -7.81099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-03 00:00:00', -6.12200021743774414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-04 00:00:00', -6.84499979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-05 00:00:00', -6.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-06 00:00:00', -6.14699983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-07 00:00:00', -3.16100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-08 00:00:00', -10.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-09 00:00:00', -8.26000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-10 00:00:00', -11.1879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-11 00:00:00', -10.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-12 00:00:00', -9.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-13 00:00:00', -12.4720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-14 00:00:00', -10.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-15 00:00:00', -6.63399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-16 00:00:00', -9.83899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-17 00:00:00', -11.935999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-18 00:00:00', -13.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-19 00:00:00', -16.7730007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-20 00:00:00', -17.3150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-21 00:00:00', -15.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-22 00:00:00', -16.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-23 00:00:00', -15.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-24 00:00:00', -14.3900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-25 00:00:00', -13.005000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-26 00:00:00', -9.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-27 00:00:00', -5.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-28 00:00:00', -9.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-29 00:00:00', -8.22500038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-30 00:00:00', -4.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-01-31 00:00:00', -0.611999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-01 00:00:00', -4.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-02 00:00:00', -5.39099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-03 00:00:00', -11.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-04 00:00:00', -10.819000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-05 00:00:00', -12.2069997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-06 00:00:00', -11.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-07 00:00:00', -9.39500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-08 00:00:00', -8.48999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-09 00:00:00', -10.5360002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-10 00:00:00', -13.2239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-11 00:00:00', -11.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-12 00:00:00', -6.15899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-13 00:00:00', -5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-14 00:00:00', -7.08099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-15 00:00:00', -3.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-16 00:00:00', -0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-17 00:00:00', -3.31299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-18 00:00:00', -0.768000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-19 00:00:00', 0.319000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-20 00:00:00', 0.45199999213218689, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-21 00:00:00', -2.13599991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-22 00:00:00', -9.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-23 00:00:00', -7.76100015640258789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-24 00:00:00', -4.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-25 00:00:00', -2.54800009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-26 00:00:00', -0.663999974727630615, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-27 00:00:00', 1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-28 00:00:00', 0.704999983310699463, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-02-29 00:00:00', 1.35699999332427979, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-01 00:00:00', -0.400999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-02 00:00:00', 0.261000007390975952, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-03 00:00:00', 0.640999972820281982, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-04 00:00:00', 0.984000027179718018, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-05 00:00:00', 1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-06 00:00:00', -1.34399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-07 00:00:00', 0.314999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-08 00:00:00', 0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-09 00:00:00', 0.0350000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-10 00:00:00', 0.930000007152557373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-11 00:00:00', 4.0560002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-12 00:00:00', 4.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-13 00:00:00', 1.70500004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-14 00:00:00', 6.83300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-15 00:00:00', 5.19199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-16 00:00:00', 5.41099977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-17 00:00:00', 2.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-18 00:00:00', 1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-19 00:00:00', 5.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-20 00:00:00', 6.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-21 00:00:00', 7.02400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-22 00:00:00', 8.27900028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-23 00:00:00', 9.14599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-24 00:00:00', 8.52700042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-25 00:00:00', 9.47099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-26 00:00:00', 4.95499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-27 00:00:00', 8.64999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-28 00:00:00', 11.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-29 00:00:00', 10.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-30 00:00:00', 6.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-03-31 00:00:00', 9.14200019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-01 00:00:00', 9.71599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-02 00:00:00', 10.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-03 00:00:00', 9.65900039672851562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-04 00:00:00', 3.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-05 00:00:00', 5.8060002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-06 00:00:00', 1.06200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-07 00:00:00', -0.234999999403953552, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-08 00:00:00', 1.96899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-09 00:00:00', 7.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-10 00:00:00', 6.7090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-11 00:00:00', 7.45800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-12 00:00:00', 5.88399982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-13 00:00:00', 5.05999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-14 00:00:00', 3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-15 00:00:00', 2.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-16 00:00:00', 6.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-17 00:00:00', 6.96799993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-18 00:00:00', 6.79699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-19 00:00:00', 6.18200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-20 00:00:00', 10.8210000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-21 00:00:00', 10.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-22 00:00:00', 5.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-23 00:00:00', 8.17099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-24 00:00:00', 10.2969999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-25 00:00:00', 13.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-26 00:00:00', 14.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-27 00:00:00', 15.9600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-28 00:00:00', 16.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-29 00:00:00', 17.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-04-30 00:00:00', 16.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-01 00:00:00', 16.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-02 00:00:00', 17.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-03 00:00:00', 16.1429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-04 00:00:00', 8.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-05 00:00:00', 8.30399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-06 00:00:00', 12.4429998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-07 00:00:00', 16.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-08 00:00:00', 16.0139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-09 00:00:00', 13.175999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-10 00:00:00', 16.7099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-11 00:00:00', 18.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-12 00:00:00', 17.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-13 00:00:00', 14.8940000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-14 00:00:00', 16.8150005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-15 00:00:00', 14.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-16 00:00:00', 14.2650003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-17 00:00:00', 17.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-18 00:00:00', 17.9769992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-19 00:00:00', 18.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-20 00:00:00', 19.9990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-21 00:00:00', 18.8920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-22 00:00:00', 16.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-23 00:00:00', 12.2690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-24 00:00:00', 10.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-25 00:00:00', 9.34500026702880859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-26 00:00:00', 8.67800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-27 00:00:00', 11.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-28 00:00:00', 16.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-29 00:00:00', 19.6700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-30 00:00:00', 20.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-05-31 00:00:00', 18.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-01 00:00:00', 18.457000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-02 00:00:00', 19.6319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-03 00:00:00', 20.6070003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-04 00:00:00', 21.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-05 00:00:00', 22.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-06 00:00:00', 21.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-07 00:00:00', 20.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-08 00:00:00', 21.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-09 00:00:00', 23.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-10 00:00:00', 22.6979999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-11 00:00:00', 23.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-12 00:00:00', 25.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-13 00:00:00', 26.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-14 00:00:00', 26.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-15 00:00:00', 21.7530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-16 00:00:00', 20.8540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-17 00:00:00', 21.0020008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-18 00:00:00', 21.2679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-19 00:00:00', 21.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-20 00:00:00', 22.2830009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-21 00:00:00', 22.5930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-22 00:00:00', 22.0739994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-23 00:00:00', 21.6469993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-24 00:00:00', 22.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-25 00:00:00', 21.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-26 00:00:00', 21.7579994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-27 00:00:00', 21.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-28 00:00:00', 20.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-29 00:00:00', 19.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-06-30 00:00:00', 19.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-01 00:00:00', 21.2019996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-02 00:00:00', 21.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-03 00:00:00', 22.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-04 00:00:00', 24.2080001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-05 00:00:00', 24.4710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-06 00:00:00', 24.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-07 00:00:00', 23.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-08 00:00:00', 21.4489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-09 00:00:00', 22.8530006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-10 00:00:00', 24.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-11 00:00:00', 23.9669990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-12 00:00:00', 24.4759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-13 00:00:00', 23.8659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-14 00:00:00', 24.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-15 00:00:00', 23.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-16 00:00:00', 21.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-17 00:00:00', 22.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-18 00:00:00', 21.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-19 00:00:00', 22.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-20 00:00:00', 17.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-21 00:00:00', 18.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-22 00:00:00', 18.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-23 00:00:00', 17.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-24 00:00:00', 19.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-25 00:00:00', 16.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-26 00:00:00', 15.8470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-27 00:00:00', 19.3159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-28 00:00:00', 22.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-29 00:00:00', 25.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-30 00:00:00', 27.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-07-31 00:00:00', 28.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-01 00:00:00', 28.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-02 00:00:00', 28.1650009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-03 00:00:00', 26.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-04 00:00:00', 23.6450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-05 00:00:00', 23.9920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-06 00:00:00', 25.3139991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-07 00:00:00', 26.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-08 00:00:00', 25.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-09 00:00:00', 26.2089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-10 00:00:00', 22.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-11 00:00:00', 21.9190006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-12 00:00:00', 21.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-13 00:00:00', 22.5760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-14 00:00:00', 22.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-15 00:00:00', 21.0680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-16 00:00:00', 16.8029994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-17 00:00:00', 14.8450002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-18 00:00:00', 20.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-19 00:00:00', 22.4090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-20 00:00:00', 21.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-21 00:00:00', 20.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-22 00:00:00', 20.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-23 00:00:00', 21.7810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-24 00:00:00', 21.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-25 00:00:00', 21.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-26 00:00:00', 20.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-27 00:00:00', 20.8069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-28 00:00:00', 21.0510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-29 00:00:00', 19.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-30 00:00:00', 18.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-08-31 00:00:00', 19.3659992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-01 00:00:00', 20.2049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-02 00:00:00', 21.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-03 00:00:00', 19.4559993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-04 00:00:00', 18.2269992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-05 00:00:00', 14.2229995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-06 00:00:00', 15.1459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-07 00:00:00', 16.3719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-08 00:00:00', 16.7619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-09 00:00:00', 17.2569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-10 00:00:00', 14.9759998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-11 00:00:00', 18.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-12 00:00:00', 20.2689990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-13 00:00:00', 18.9960002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-14 00:00:00', 20.0699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-15 00:00:00', 19.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-16 00:00:00', 17.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-17 00:00:00', 16.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-18 00:00:00', 15.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-19 00:00:00', 14.5399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-20 00:00:00', 12.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-21 00:00:00', 13.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-22 00:00:00', 12.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-23 00:00:00', 12.4010000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-24 00:00:00', 13.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-25 00:00:00', 14.741999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-26 00:00:00', 16.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-27 00:00:00', 13.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-28 00:00:00', 14.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-29 00:00:00', 15.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-09-30 00:00:00', 8.36600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-01 00:00:00', 13.8199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-02 00:00:00', 17.4370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-03 00:00:00', 16.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-04 00:00:00', 12.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-05 00:00:00', 12.9980001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-06 00:00:00', 12.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-07 00:00:00', 12.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-08 00:00:00', 10.8249998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-09 00:00:00', 11.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-10 00:00:00', 12.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-11 00:00:00', 8.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-12 00:00:00', 10.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-13 00:00:00', 5.88000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-14 00:00:00', 7.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-15 00:00:00', 7.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-16 00:00:00', 8.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-17 00:00:00', 13.3760004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-18 00:00:00', 12.3030004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-19 00:00:00', 8.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-20 00:00:00', 8.53199958801269531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-21 00:00:00', 8.91300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-22 00:00:00', 7.67100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-23 00:00:00', 8.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-24 00:00:00', 3.54600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-25 00:00:00', 4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-26 00:00:00', 8.17099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-27 00:00:00', 5.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-28 00:00:00', -0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-29 00:00:00', -0.261999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-30 00:00:00', -1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-10-31 00:00:00', -0.337000012397766113, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-01 00:00:00', -0.957000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-02 00:00:00', -0.152999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-03 00:00:00', 3.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-04 00:00:00', 7.34800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-05 00:00:00', 2.82399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-06 00:00:00', 3.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-07 00:00:00', 4.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-08 00:00:00', 2.5559999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-09 00:00:00', -0.0270000007003545761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-10 00:00:00', -2.03600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-11 00:00:00', -2.5409998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-12 00:00:00', -3.59100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-13 00:00:00', -5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-14 00:00:00', -4.44899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-15 00:00:00', -3.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-16 00:00:00', -3.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-17 00:00:00', -4.37300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-18 00:00:00', -1.3609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-19 00:00:00', -3.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-20 00:00:00', -1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-21 00:00:00', 0.595000028610229492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-22 00:00:00', -0.319999992847442627, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-23 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-24 00:00:00', 0.921000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-25 00:00:00', 1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-26 00:00:00', 2.37899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-27 00:00:00', 3.15199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-28 00:00:00', 4.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-29 00:00:00', 4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-11-30 00:00:00', 4.35200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-01 00:00:00', 3.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-02 00:00:00', 3.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-03 00:00:00', 2.42700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-04 00:00:00', 2.87800002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-05 00:00:00', 1.74699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-06 00:00:00', 1.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-07 00:00:00', 3.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-08 00:00:00', -0.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-09 00:00:00', -1.68599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-10 00:00:00', -2.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-11 00:00:00', -0.912000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-12 00:00:00', 0.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-13 00:00:00', 0.240999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-14 00:00:00', -3.40599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-15 00:00:00', 0.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-16 00:00:00', -2.68199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-17 00:00:00', -5.47700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-18 00:00:00', -4.73799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-19 00:00:00', -6.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-20 00:00:00', -8.99499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-21 00:00:00', -6.11499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-22 00:00:00', -4.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-23 00:00:00', -2.02900004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-24 00:00:00', -0.398999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-25 00:00:00', 0.551999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-26 00:00:00', 0.547999978065490723, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-27 00:00:00', -2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-28 00:00:00', -4.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-29 00:00:00', -5.15600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-30 00:00:00', -2.32599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2008-12-31 00:00:00', -2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-01 00:00:00', 0.623000025749206543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-02 00:00:00', -0.97500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-03 00:00:00', -3.36700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-04 00:00:00', -5.7909998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-05 00:00:00', -3.30800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-06 00:00:00', -1.85099995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-07 00:00:00', -2.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-08 00:00:00', 0.0540000014007091522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-09 00:00:00', -1.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-10 00:00:00', -2.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-11 00:00:00', -2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-12 00:00:00', -2.46499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-13 00:00:00', -4.43900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-14 00:00:00', -5.57800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-15 00:00:00', -3.51699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-16 00:00:00', -2.25699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-17 00:00:00', -3.31399989128112793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-18 00:00:00', -1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-19 00:00:00', -1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-20 00:00:00', 2.53099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-21 00:00:00', -1.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-22 00:00:00', 0.63200002908706665, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-23 00:00:00', 0.375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-24 00:00:00', 1.35800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-25 00:00:00', 0.0719999969005584717, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-26 00:00:00', -1.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-27 00:00:00', -1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-28 00:00:00', -2.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-29 00:00:00', -2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-30 00:00:00', -2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-01-31 00:00:00', 1.54999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-01 00:00:00', -0.136999994516372681, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-02 00:00:00', 0.493000000715255737, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-03 00:00:00', -2.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-04 00:00:00', -6.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-05 00:00:00', -8.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-06 00:00:00', -3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-07 00:00:00', 0.846000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-08 00:00:00', 2.80500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-09 00:00:00', -0.177000001072883606, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-10 00:00:00', -3.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-11 00:00:00', -0.441000014543533325, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-12 00:00:00', -0.648000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-13 00:00:00', -1.70099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-14 00:00:00', -3.32100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-15 00:00:00', -1.52999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-16 00:00:00', 0.874000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-17 00:00:00', 0.14100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-18 00:00:00', 0.0179999992251396179, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-19 00:00:00', -0.865000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-20 00:00:00', -4.64900016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-21 00:00:00', -0.303000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-22 00:00:00', 1.18700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-23 00:00:00', -1.84000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-24 00:00:00', -5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-25 00:00:00', -6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-26 00:00:00', -2.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-27 00:00:00', -0.31099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-02-28 00:00:00', 3.28699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-01 00:00:00', 1.14300000667572021, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-02 00:00:00', 1.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-03 00:00:00', 2.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-04 00:00:00', -0.112000003457069397, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-05 00:00:00', -0.985000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-06 00:00:00', -3.67300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-07 00:00:00', -4.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-08 00:00:00', -0.266999989748001099, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-09 00:00:00', 1.90400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-10 00:00:00', 5.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-11 00:00:00', 9.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-12 00:00:00', 7.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-13 00:00:00', 7.72300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-14 00:00:00', 9.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-15 00:00:00', 10.2480001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-16 00:00:00', 5.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-17 00:00:00', 7.83900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-18 00:00:00', 2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-19 00:00:00', 1.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-20 00:00:00', 3.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-21 00:00:00', 5.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-22 00:00:00', 6.04500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-23 00:00:00', 3.58299994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-24 00:00:00', 4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-25 00:00:00', 8.33600044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-26 00:00:00', 3.10800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-27 00:00:00', 1.97800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-28 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-29 00:00:00', 5.3189997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-30 00:00:00', 6.67199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-03-31 00:00:00', 8.19200038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-01 00:00:00', 4.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-02 00:00:00', 0.574999988079071045, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-03 00:00:00', 1.38199996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-04 00:00:00', 6.9029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-05 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-06 00:00:00', 0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-07 00:00:00', -1.03100001811981201, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-08 00:00:00', 3.82599997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-09 00:00:00', 6.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-10 00:00:00', 3.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-11 00:00:00', 2.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-12 00:00:00', 5.96500015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-13 00:00:00', 5.84000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-14 00:00:00', 5.50600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-15 00:00:00', 0.128999993205070496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-16 00:00:00', 4.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-17 00:00:00', 7.82200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-18 00:00:00', 11.5839996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-19 00:00:00', 9.75399971008300781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-20 00:00:00', 8.01000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-21 00:00:00', 0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-22 00:00:00', 4.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-23 00:00:00', 7.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-24 00:00:00', 10.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-25 00:00:00', 6.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-26 00:00:00', 4.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-27 00:00:00', 3.43400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-28 00:00:00', 2.77099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-29 00:00:00', 8.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-04-30 00:00:00', 12.3509998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-01 00:00:00', 9.71100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-02 00:00:00', 11.6090002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-03 00:00:00', 7.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-04 00:00:00', 7.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-05 00:00:00', 7.42600011825561523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-06 00:00:00', 7.86700010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-07 00:00:00', 12.5120000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-08 00:00:00', 9.85700035095214844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-09 00:00:00', 7.47800016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-10 00:00:00', 7.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-11 00:00:00', 9.53999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-12 00:00:00', 12.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-13 00:00:00', 13.2840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-14 00:00:00', 13.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-15 00:00:00', 11.5260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-16 00:00:00', 13.314000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-17 00:00:00', 17.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-18 00:00:00', 13.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-19 00:00:00', 9.41499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-20 00:00:00', 11.7880001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-21 00:00:00', 12.5570001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-22 00:00:00', 13.7760000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-23 00:00:00', 15.6120004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-24 00:00:00', 12.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-25 00:00:00', 15.1649999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-26 00:00:00', 16.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-27 00:00:00', 16.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-28 00:00:00', 17.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-29 00:00:00', 19.2970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-30 00:00:00', 19.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-05-31 00:00:00', 15.439000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-01 00:00:00', 10.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-02 00:00:00', 9.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-03 00:00:00', 12.5590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-04 00:00:00', 11.4849996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-05 00:00:00', 9.57199954986572266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-06 00:00:00', 9.63899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-07 00:00:00', 11.0389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-08 00:00:00', 11.8870000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-09 00:00:00', 14.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-10 00:00:00', 17.2539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-11 00:00:00', 15.9659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-12 00:00:00', 15.3310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-13 00:00:00', 14.9090003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-14 00:00:00', 17.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-15 00:00:00', 16.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-16 00:00:00', 16.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-17 00:00:00', 17.1159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-18 00:00:00', 16.7250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-19 00:00:00', 17.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-20 00:00:00', 17.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-21 00:00:00', 19.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-22 00:00:00', 19.4790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-23 00:00:00', 17.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-24 00:00:00', 15.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-25 00:00:00', 19.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-26 00:00:00', 18.9009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-27 00:00:00', 20.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-28 00:00:00', 21.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-29 00:00:00', 18.01300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-06-30 00:00:00', 18.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-01 00:00:00', 18.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-02 00:00:00', 18.1800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-03 00:00:00', 13.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-04 00:00:00', 15.824000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-05 00:00:00', 18.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-06 00:00:00', 21.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-07 00:00:00', 22.0979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-08 00:00:00', 21.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-09 00:00:00', 20.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-10 00:00:00', 21.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-11 00:00:00', 21.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-12 00:00:00', 20.7950000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-13 00:00:00', 18.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-14 00:00:00', 19.4009990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-15 00:00:00', 21.9489994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-16 00:00:00', 21.9950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-17 00:00:00', 21.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-18 00:00:00', 23.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-19 00:00:00', 23.292999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-20 00:00:00', 23.1240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-21 00:00:00', 22.8819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-22 00:00:00', 22.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-23 00:00:00', 23.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-24 00:00:00', 24.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-25 00:00:00', 25.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-26 00:00:00', 26.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-27 00:00:00', 26.3670005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-28 00:00:00', 24.1299991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-29 00:00:00', 22.9330005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-30 00:00:00', 20.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-07-31 00:00:00', 23.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-01 00:00:00', 21.0949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-02 00:00:00', 22.7970008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-03 00:00:00', 22.5410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-04 00:00:00', 20.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-05 00:00:00', 20.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-06 00:00:00', 19.917999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-07 00:00:00', 21.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-08 00:00:00', 22.6049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-09 00:00:00', 23.0119991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-10 00:00:00', 24.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-11 00:00:00', 24.4419994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-12 00:00:00', 26.4160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-13 00:00:00', 27.7719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-14 00:00:00', 26.1229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-15 00:00:00', 25.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-16 00:00:00', 22.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-17 00:00:00', 22.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-18 00:00:00', 20.5139999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-19 00:00:00', 18.9430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-20 00:00:00', 18.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-21 00:00:00', 18.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-22 00:00:00', 18.4580001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-23 00:00:00', 20.1739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-24 00:00:00', 21.4050006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-25 00:00:00', 16.3980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-26 00:00:00', 18.4200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-27 00:00:00', 19.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-28 00:00:00', 22.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-29 00:00:00', 20.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-30 00:00:00', 18.51300048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-08-31 00:00:00', 19.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-01 00:00:00', 17.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-02 00:00:00', 13.869999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-03 00:00:00', 13.6920003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-04 00:00:00', 15.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-05 00:00:00', 14.369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-06 00:00:00', 13.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-07 00:00:00', 14.2189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-08 00:00:00', 12.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-09 00:00:00', 10.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-10 00:00:00', 13.4890003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-11 00:00:00', 15.694000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-12 00:00:00', 15.675999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-13 00:00:00', 17.9139995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-14 00:00:00', 18.6720008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-15 00:00:00', 17.6959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-16 00:00:00', 14.7690000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-17 00:00:00', 15.755000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-18 00:00:00', 19.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-19 00:00:00', 18.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-20 00:00:00', 18.4470005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-21 00:00:00', 18.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-22 00:00:00', 15.9250001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-23 00:00:00', 14.8909997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-24 00:00:00', 18.2119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-25 00:00:00', 19.8050003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-26 00:00:00', 10.5880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-27 00:00:00', 12.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-28 00:00:00', 14.5249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-29 00:00:00', 15.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-09-30 00:00:00', 17.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-01 00:00:00', 18.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-02 00:00:00', 15.4460000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-03 00:00:00', 12.3590002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-04 00:00:00', 12.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-05 00:00:00', 11.8260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-06 00:00:00', 11.6479997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-07 00:00:00', 11.199000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-08 00:00:00', 9.08199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-09 00:00:00', 5.89300012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-10 00:00:00', 6.78700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-11 00:00:00', 8.64400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-12 00:00:00', 10.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-13 00:00:00', 10.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-14 00:00:00', 10.8299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-15 00:00:00', 10.7239999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-16 00:00:00', 10.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-17 00:00:00', 9.08899974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-18 00:00:00', 8.01700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-19 00:00:00', 8.10599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-20 00:00:00', 7.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-21 00:00:00', 7.60099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-22 00:00:00', 6.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-23 00:00:00', 5.8600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-24 00:00:00', 5.33799982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-25 00:00:00', 7.22700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-26 00:00:00', 6.00899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-27 00:00:00', 5.06799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-28 00:00:00', 2.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-29 00:00:00', 6.69299983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-30 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-10-31 00:00:00', 9.17500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-01 00:00:00', 9.89500045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-02 00:00:00', 5.4310002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-03 00:00:00', 10.3039999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-04 00:00:00', 9.74800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-05 00:00:00', 8.24100017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-06 00:00:00', 7.90899991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-07 00:00:00', 3.29600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-08 00:00:00', -1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-09 00:00:00', -4.97499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-10 00:00:00', -1.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-11 00:00:00', 4.86600017547607422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-12 00:00:00', 5.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-13 00:00:00', 4.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-14 00:00:00', 1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-15 00:00:00', -0.751999974250793457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-16 00:00:00', -1.47699999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-17 00:00:00', -1.75300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-18 00:00:00', 1.76999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-19 00:00:00', 5.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-20 00:00:00', 5.42500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-21 00:00:00', 2.83500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-22 00:00:00', 1.40999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-23 00:00:00', -2.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-24 00:00:00', -0.801999986171722412, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-25 00:00:00', -3.69499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-26 00:00:00', -0.0469999983906745911, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-27 00:00:00', -0.703000009059906006, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-28 00:00:00', -1.73899996280670166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-29 00:00:00', -0.460999995470046997, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-11-30 00:00:00', 1.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-01 00:00:00', -0.60000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-02 00:00:00', -2.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-03 00:00:00', -2.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-04 00:00:00', -5.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-05 00:00:00', -5.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-06 00:00:00', -2.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-07 00:00:00', -1.5820000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-08 00:00:00', -0.460000008344650269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-09 00:00:00', -2.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-10 00:00:00', -5.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-11 00:00:00', -4.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-12 00:00:00', -5.1119999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-13 00:00:00', -1.80700004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-14 00:00:00', -1.4450000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-15 00:00:00', -1.91299998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-16 00:00:00', -3.3599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-17 00:00:00', 1.07899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-18 00:00:00', 1.80799996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-19 00:00:00', 3.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-20 00:00:00', -1.2510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-21 00:00:00', -3.29900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-22 00:00:00', -1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-23 00:00:00', -0.428999990224838257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-24 00:00:00', -0.363999992609024048, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-25 00:00:00', -0.689999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-26 00:00:00', -1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-27 00:00:00', -2.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-28 00:00:00', -3.95600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-29 00:00:00', -1.49600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-30 00:00:00', 1.5700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2009-12-31 00:00:00', 0.33899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-01 00:00:00', 4.28599977493286133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-02 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-03 00:00:00', 0.0149999996647238731, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-04 00:00:00', 1.1809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-05 00:00:00', 1.41199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-06 00:00:00', -0.948000013828277588, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-07 00:00:00', -4.96099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-08 00:00:00', -6.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-09 00:00:00', -7.82100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-10 00:00:00', -7.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-11 00:00:00', -3.78399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-12 00:00:00', 0.81099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-13 00:00:00', -1.14199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-14 00:00:00', 0.605000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-15 00:00:00', 0.0740000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-16 00:00:00', 1.75199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-17 00:00:00', -2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-18 00:00:00', -3.99099993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-19 00:00:00', -2.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-20 00:00:00', 0.971000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-21 00:00:00', 2.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-22 00:00:00', 1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-23 00:00:00', -1.7510000467300415, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-24 00:00:00', -1.03400003910064697, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-25 00:00:00', 1.77300000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-26 00:00:00', 0.781000018119812012, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-27 00:00:00', -2.49499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-28 00:00:00', -4.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-29 00:00:00', -3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-30 00:00:00', -1.09000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-01-31 00:00:00', -4.43499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-01 00:00:00', -2.15599989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-02 00:00:00', -1.72500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-03 00:00:00', -1.39900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-04 00:00:00', 0.683000028133392334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-05 00:00:00', 0.768000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-06 00:00:00', -0.416999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-07 00:00:00', -2.91000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-08 00:00:00', -8.83199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-09 00:00:00', -13.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-10 00:00:00', -6.15100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-11 00:00:00', -8.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-12 00:00:00', -9.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-13 00:00:00', -10.6529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-14 00:00:00', -13.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-15 00:00:00', -10.4079999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-16 00:00:00', -4.33900022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-17 00:00:00', -0.799000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-18 00:00:00', -2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-19 00:00:00', 0.423999994993209839, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-20 00:00:00', 0.119999997317790985, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-21 00:00:00', 5.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-22 00:00:00', 0.986000001430511475, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-23 00:00:00', 3.49000000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-24 00:00:00', 0.458999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-25 00:00:00', 2.17400002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-26 00:00:00', -0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-27 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-02-28 00:00:00', 1.01199996471405029, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-01 00:00:00', -0.796000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-02 00:00:00', 2.41300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-03 00:00:00', 5.1100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-04 00:00:00', -1.00499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-05 00:00:00', 2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-06 00:00:00', 0.802999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-07 00:00:00', 1.25199997425079346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-08 00:00:00', 5.15700006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-09 00:00:00', 4.4850001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-10 00:00:00', 7.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-11 00:00:00', 7.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-12 00:00:00', 2.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-13 00:00:00', 4.68900012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-14 00:00:00', 8.48900032043457031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-15 00:00:00', 11.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-16 00:00:00', 13.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-17 00:00:00', 13.4499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-18 00:00:00', 12.2209997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-19 00:00:00', 15.8739995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-20 00:00:00', 2.37700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-21 00:00:00', 1.40499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-22 00:00:00', 1.47500002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-23 00:00:00', 2.17300009727478027, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-24 00:00:00', 3.58500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-25 00:00:00', 6.92199993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-26 00:00:00', 3.68300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-27 00:00:00', 4.16699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-28 00:00:00', 7.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-29 00:00:00', 6.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-30 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-03-31 00:00:00', 2.87700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-01 00:00:00', 7.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-02 00:00:00', 6.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-03 00:00:00', 0.721000015735626221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-04 00:00:00', 4.75199985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-05 00:00:00', 7.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-06 00:00:00', 8.54300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-07 00:00:00', 3.28200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-08 00:00:00', 10.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-09 00:00:00', 12.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-10 00:00:00', 10.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-11 00:00:00', 9.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-12 00:00:00', 4.39799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-13 00:00:00', 11.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-14 00:00:00', 14.2349996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-15 00:00:00', 7.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-16 00:00:00', 10.5270004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-17 00:00:00', 11.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-18 00:00:00', 11.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-19 00:00:00', 13.4700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-20 00:00:00', 13.1370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-21 00:00:00', 3.82299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-22 00:00:00', 5.32800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-23 00:00:00', 9.40200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-24 00:00:00', 12.0600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-25 00:00:00', 12.2740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-26 00:00:00', 11.7110004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-27 00:00:00', 10.6499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-28 00:00:00', 12.7930002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-29 00:00:00', 10.8229999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-04-30 00:00:00', 13.8409996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-01 00:00:00', 9.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-02 00:00:00', 12.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-03 00:00:00', 12.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-04 00:00:00', 10.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-05 00:00:00', 11.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-06 00:00:00', 10.866999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-07 00:00:00', 8.82600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-08 00:00:00', 11.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-09 00:00:00', 12.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-10 00:00:00', 7.36899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-11 00:00:00', 9.36499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-12 00:00:00', 11.944000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-13 00:00:00', 11.6359996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-14 00:00:00', 14.6470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-15 00:00:00', 15.0670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-16 00:00:00', 10.7309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-17 00:00:00', 7.92500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-18 00:00:00', 11.3690004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-19 00:00:00', 13.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-20 00:00:00', 17.0489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-21 00:00:00', 11.6020002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-22 00:00:00', 11.1960000991821289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-23 00:00:00', 12.1409997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-24 00:00:00', 14.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-25 00:00:00', 18.7329998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-26 00:00:00', 12.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-27 00:00:00', 11.2170000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-28 00:00:00', 13.3599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-29 00:00:00', 15.2790002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-30 00:00:00', 17.3460006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-05-31 00:00:00', 16.6140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-01 00:00:00', 17.2719993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-02 00:00:00', 9.87100028991699219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-03 00:00:00', 9.19900035858154297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-04 00:00:00', 10.2139997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-05 00:00:00', 13.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-06 00:00:00', 10.3839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-07 00:00:00', 11.2469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-08 00:00:00', 10.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-09 00:00:00', 16.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-10 00:00:00', 18.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-11 00:00:00', 18.7469997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-12 00:00:00', 17.7339992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-13 00:00:00', 18.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-14 00:00:00', 16.1830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-15 00:00:00', 17.2439994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-16 00:00:00', 17.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-17 00:00:00', 16.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-18 00:00:00', 18.0799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-19 00:00:00', 19.8349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-20 00:00:00', 21.6439990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-21 00:00:00', 21.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-22 00:00:00', 22.0450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-23 00:00:00', 21.5879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-24 00:00:00', 16.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-25 00:00:00', 15.5480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-26 00:00:00', 19.5779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-27 00:00:00', 20.9130001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-28 00:00:00', 19.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-29 00:00:00', 19.9909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-06-30 00:00:00', 20.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-01 00:00:00', 20.0540008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-02 00:00:00', 21.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-03 00:00:00', 21.3939990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-04 00:00:00', 21.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-05 00:00:00', 19.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-06 00:00:00', 20.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-07 00:00:00', 22.1840000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-08 00:00:00', 23.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-09 00:00:00', 24.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-10 00:00:00', 24.0860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-11 00:00:00', 21.6830005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-12 00:00:00', 19.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-13 00:00:00', 19.5380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-14 00:00:00', 20.6240005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-15 00:00:00', 23.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-16 00:00:00', 28.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-17 00:00:00', 25.0879993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-18 00:00:00', 23.7460002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-19 00:00:00', 22.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-20 00:00:00', 20.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-21 00:00:00', 16.430999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-22 00:00:00', 12.7559995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-23 00:00:00', 19.3969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-24 00:00:00', 20.5680007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-25 00:00:00', 21.1389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-26 00:00:00', 21.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-27 00:00:00', 20.6019992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-28 00:00:00', 20.3819999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-29 00:00:00', 19.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-30 00:00:00', 20.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-07-31 00:00:00', 19.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-01 00:00:00', 21.0939998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-02 00:00:00', 21.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-03 00:00:00', 17.7430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-04 00:00:00', 19.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-05 00:00:00', 20.7940006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-06 00:00:00', 19.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-07 00:00:00', 20.542999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-08 00:00:00', 21.8129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-09 00:00:00', 22.9290008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-10 00:00:00', 21.6989994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-11 00:00:00', 22.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-12 00:00:00', 21.6849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-13 00:00:00', 20.167999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-14 00:00:00', 20.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-15 00:00:00', 21.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-16 00:00:00', 21.8269996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-17 00:00:00', 21.8770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-18 00:00:00', 21.3810005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-19 00:00:00', 22.7959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-20 00:00:00', 23.5419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-21 00:00:00', 25.0030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-22 00:00:00', 24.6749992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-23 00:00:00', 18.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-24 00:00:00', 15.4029998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-25 00:00:00', 16.7800006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-26 00:00:00', 18.5149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-27 00:00:00', 19.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-28 00:00:00', 20.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-29 00:00:00', 20.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-30 00:00:00', 21.0869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-08-31 00:00:00', 22.1329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-01 00:00:00', 21.3040008544921875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-02 00:00:00', 20.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-03 00:00:00', 21.1970005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-04 00:00:00', 21.3640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-05 00:00:00', 20.4750003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-06 00:00:00', 18.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-07 00:00:00', 18.4799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-08 00:00:00', 19.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-09 00:00:00', 19.2789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-10 00:00:00', 18.9710006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-11 00:00:00', 18.4629993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-12 00:00:00', 11.7939996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-13 00:00:00', 10.5229997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-14 00:00:00', 15.1319999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-15 00:00:00', 15.4449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-16 00:00:00', 6.17899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-17 00:00:00', 6.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-18 00:00:00', 8.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-19 00:00:00', 9.66899967193603516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-20 00:00:00', 12.1079998016357422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-21 00:00:00', 13.6730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-22 00:00:00', 12.069000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-23 00:00:00', 11.9569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-24 00:00:00', 13.3100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-25 00:00:00', 12.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-26 00:00:00', 12.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-27 00:00:00', 10.1049995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-28 00:00:00', 10.3400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-29 00:00:00', 11.3339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-09-30 00:00:00', 9.52299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-01 00:00:00', 14.258000373840332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-02 00:00:00', 15.9230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-03 00:00:00', 16.3299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-04 00:00:00', 17.3560009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-05 00:00:00', 16.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-06 00:00:00', 16.0090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-07 00:00:00', 15.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-08 00:00:00', 11.2259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-09 00:00:00', 9.06299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-10 00:00:00', 9.67800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-11 00:00:00', 12.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-12 00:00:00', 14.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-13 00:00:00', 9.79300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-14 00:00:00', 9.45100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-15 00:00:00', 12.6379995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-16 00:00:00', 15.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-17 00:00:00', 14.9200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-18 00:00:00', 14.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-19 00:00:00', 14.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-20 00:00:00', 11.2430000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-21 00:00:00', 6.25799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-22 00:00:00', 5.17399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-23 00:00:00', 5.65799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-24 00:00:00', 6.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-25 00:00:00', 6.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-26 00:00:00', 2.78600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-27 00:00:00', 6.56300020217895508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-28 00:00:00', 4.08599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-29 00:00:00', 3.53699994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-30 00:00:00', 3.44799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-10-31 00:00:00', 8.00300025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-01 00:00:00', 9.18999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-02 00:00:00', 6.83599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-03 00:00:00', 2.69300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-04 00:00:00', 3.89800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-05 00:00:00', 1.24800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-06 00:00:00', 3.35400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-07 00:00:00', 6.41800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-08 00:00:00', 10.0340003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-09 00:00:00', 9.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-10 00:00:00', 9.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-11 00:00:00', 7.3340001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-12 00:00:00', 5.28900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-13 00:00:00', 5.32299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-14 00:00:00', 5.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-15 00:00:00', 4.16800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-16 00:00:00', 4.33099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-17 00:00:00', 5.81599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-18 00:00:00', 4.63100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-19 00:00:00', 3.18300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-20 00:00:00', 1.72800004482269287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-21 00:00:00', 1.11500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-22 00:00:00', 1.45599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-23 00:00:00', 3.44499993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-24 00:00:00', 4.02699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-25 00:00:00', 0.921000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-26 00:00:00', 0.901000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-27 00:00:00', 3.59400010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-28 00:00:00', 4.64099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-29 00:00:00', 4.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-11-30 00:00:00', 3.14700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-01 00:00:00', 2.41000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-02 00:00:00', 3.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-03 00:00:00', 1.34099996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-04 00:00:00', -1.21800005435943604, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-05 00:00:00', -3.62899994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-06 00:00:00', -2.6809999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-07 00:00:00', -1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-08 00:00:00', -0.0329999998211860657, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-09 00:00:00', 2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-10 00:00:00', 1.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-11 00:00:00', 3.18199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-12 00:00:00', 4.21299982070922852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-13 00:00:00', 4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-14 00:00:00', 6.27400016784667969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-15 00:00:00', 1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-16 00:00:00', -4.20300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-17 00:00:00', -2.19899988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-18 00:00:00', -0.0680000036954879761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-19 00:00:00', 1.96500003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-20 00:00:00', 1.67200005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-21 00:00:00', -1.18599998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-22 00:00:00', -3.79399991035461426, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-23 00:00:00', -4.21899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-24 00:00:00', -0.929000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-25 00:00:00', -1.16199994087219238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-26 00:00:00', -2.30200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-27 00:00:00', -3.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-28 00:00:00', -2.9570000171661377, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-29 00:00:00', -1.83899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-30 00:00:00', -0.953999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2010-12-31 00:00:00', -1.25499999523162842, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-01 00:00:00', 0.490000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-02 00:00:00', 0.815999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-03 00:00:00', -1.66900002956390381, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-04 00:00:00', -5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-05 00:00:00', -2.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-06 00:00:00', -4.09299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-07 00:00:00', -5.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-08 00:00:00', -6.19700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-09 00:00:00', -5.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-10 00:00:00', -2.9030001163482666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-11 00:00:00', -6.72399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-12 00:00:00', -6.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-13 00:00:00', -8.93000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-14 00:00:00', -10.8789997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-15 00:00:00', -7.98099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-16 00:00:00', -2.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-17 00:00:00', -6.34600019454956055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-18 00:00:00', -6.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-19 00:00:00', -2.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-20 00:00:00', -5.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-21 00:00:00', -6.70699977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-22 00:00:00', -7.20800018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-23 00:00:00', -6.99900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-24 00:00:00', -4.8880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-25 00:00:00', -3.60800004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-26 00:00:00', -2.36500000953674316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-27 00:00:00', -0.508000016212463379, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-28 00:00:00', -2.125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-29 00:00:00', -2.89899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-30 00:00:00', -1.56200003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-01-31 00:00:00', -1.12100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-01 00:00:00', 0.916999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-02 00:00:00', 1.0549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-03 00:00:00', 1.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-04 00:00:00', -1.46599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-05 00:00:00', -6.46400022506713867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-06 00:00:00', -7.25299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-07 00:00:00', -5.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-08 00:00:00', -6.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-09 00:00:00', -9.48099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-10 00:00:00', -0.0489999987185001373, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-11 00:00:00', -1.22599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-12 00:00:00', -1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-13 00:00:00', -4.65399980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-14 00:00:00', -2.76799988746643066, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-15 00:00:00', -3.03999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-16 00:00:00', -2.55399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-17 00:00:00', -1.93499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-18 00:00:00', -4.53200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-19 00:00:00', -6.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-20 00:00:00', -3.37299990653991699, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-21 00:00:00', -1.13300001621246338, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-22 00:00:00', -2.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-23 00:00:00', -4.91499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-24 00:00:00', -8.67899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-25 00:00:00', -10.616999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-26 00:00:00', -13.9320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-27 00:00:00', -7.1399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-02-28 00:00:00', -8.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-01 00:00:00', -5.70100021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-02 00:00:00', -5.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-03 00:00:00', -7.71000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-04 00:00:00', -9.04199981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-05 00:00:00', -6.77600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-06 00:00:00', -4.26200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-07 00:00:00', -3.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-08 00:00:00', 0.799000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-09 00:00:00', 3.59500002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-10 00:00:00', 4.13100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-11 00:00:00', 5.78499984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-12 00:00:00', 4.80399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-13 00:00:00', 6.86899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-14 00:00:00', 8.95300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-15 00:00:00', 2.13899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-16 00:00:00', 1.67700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-17 00:00:00', -1.32200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-18 00:00:00', 1.19799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-19 00:00:00', -0.893000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-20 00:00:00', 0.804000020027160645, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-21 00:00:00', 2.70600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-22 00:00:00', 3.98399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-23 00:00:00', 5.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-24 00:00:00', 8.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-25 00:00:00', 3.85500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-26 00:00:00', 2.35599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-27 00:00:00', 2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-28 00:00:00', 3.51099991798400879, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-29 00:00:00', 3.64899992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-30 00:00:00', -0.162000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-03-31 00:00:00', 0.800000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-01 00:00:00', 1.34899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-02 00:00:00', 2.2090001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-03 00:00:00', -0.749000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-04 00:00:00', -0.602999985218048096, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-05 00:00:00', 1.94700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-06 00:00:00', 4.76200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-07 00:00:00', 8.46700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-08 00:00:00', 5.04899978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-09 00:00:00', 4.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-10 00:00:00', 7.7369999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-11 00:00:00', 7.71600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-12 00:00:00', 10.9180002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-13 00:00:00', 11.6560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-14 00:00:00', 7.55499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-15 00:00:00', 3.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-16 00:00:00', 5.2649998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-17 00:00:00', 8.45499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-18 00:00:00', 8.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-19 00:00:00', 9.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-20 00:00:00', 10.4930000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-21 00:00:00', 14.6309995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-22 00:00:00', 16.8570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-23 00:00:00', 17.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-24 00:00:00', 18.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-25 00:00:00', 17.8110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-26 00:00:00', 18.0590000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-27 00:00:00', 16.2749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-28 00:00:00', 11.6630001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-29 00:00:00', 9.94499969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-04-30 00:00:00', 14.0179996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-01 00:00:00', 17.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-02 00:00:00', 19.2889995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-03 00:00:00', 19.0259990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-04 00:00:00', 18.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-05 00:00:00', 12.4659996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-06 00:00:00', 8.42800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-07 00:00:00', 11.4879999160766602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-08 00:00:00', 11.2180004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-09 00:00:00', 12.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-10 00:00:00', 8.68500041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-11 00:00:00', 8.05500030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-12 00:00:00', 10.3540000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-13 00:00:00', 15.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-14 00:00:00', 19.2450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-15 00:00:00', 19.8959999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-16 00:00:00', 20.6270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-17 00:00:00', 19.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-18 00:00:00', 14.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-19 00:00:00', 13.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-20 00:00:00', 14.244999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-21 00:00:00', 13.5979995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-22 00:00:00', 15.0419998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-23 00:00:00', 17.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-24 00:00:00', 17.36199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-25 00:00:00', 15.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-26 00:00:00', 14.0190000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-27 00:00:00', 15.3319997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-28 00:00:00', 16.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-29 00:00:00', 14.7100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-30 00:00:00', 16.0499992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-05-31 00:00:00', 13.7340002059936523, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-01 00:00:00', 13.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-02 00:00:00', 14.574000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-03 00:00:00', 16.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-04 00:00:00', 16.0200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-05 00:00:00', 15.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-06 00:00:00', 18.2210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-07 00:00:00', 20.3349990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-08 00:00:00', 20.6639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-09 00:00:00', 20.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-10 00:00:00', 19.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-11 00:00:00', 17.2169990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-12 00:00:00', 15.550999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-13 00:00:00', 18.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-14 00:00:00', 20.23699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-15 00:00:00', 21.3799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-16 00:00:00', 20.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-17 00:00:00', 17.2670001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-18 00:00:00', 19.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-19 00:00:00', 19.7989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-20 00:00:00', 20.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-21 00:00:00', 21.9249992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-22 00:00:00', 21.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-23 00:00:00', 21.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-24 00:00:00', 22.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-25 00:00:00', 17.9619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-26 00:00:00', 17.1210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-27 00:00:00', 20.6429996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-28 00:00:00', 20.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-29 00:00:00', 20.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-06-30 00:00:00', 19.4780006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-01 00:00:00', 19.7350006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-02 00:00:00', 18.8369998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-03 00:00:00', 20.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-04 00:00:00', 22.0849990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-05 00:00:00', 22.6550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-06 00:00:00', 22.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-07 00:00:00', 21.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-08 00:00:00', 22.7360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-09 00:00:00', 22.1369991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-10 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-11 00:00:00', 23.8169994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-12 00:00:00', 25.0359992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-13 00:00:00', 24.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-14 00:00:00', 20.98699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-15 00:00:00', 20.6389999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-16 00:00:00', 20.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-17 00:00:00', 20.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-18 00:00:00', 20.1219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-19 00:00:00', 18.9880008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-20 00:00:00', 20.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-21 00:00:00', 21.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-22 00:00:00', 21.7399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-23 00:00:00', 20.9510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-24 00:00:00', 20.7210006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-25 00:00:00', 20.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-26 00:00:00', 22.9279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-27 00:00:00', 22.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-28 00:00:00', 21.8899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-29 00:00:00', 21.3470001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-30 00:00:00', 19.9850006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-07-31 00:00:00', 21.3020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-01 00:00:00', 23.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-02 00:00:00', 25.2360000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-03 00:00:00', 26.444000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-04 00:00:00', 26.86199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-05 00:00:00', 27.3859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-06 00:00:00', 27.1450004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-07 00:00:00', 25.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-08 00:00:00', 22.6580009460449219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-09 00:00:00', 20.2819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-10 00:00:00', 20.5809993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-11 00:00:00', 22.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-12 00:00:00', 22.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-13 00:00:00', 22.0380001068115234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-14 00:00:00', 22.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-15 00:00:00', 23.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-16 00:00:00', 22.7189998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-17 00:00:00', 21.7560005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-18 00:00:00', 21.667999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-19 00:00:00', 22.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-20 00:00:00', 22.9790000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-21 00:00:00', 23.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-22 00:00:00', 24.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-23 00:00:00', 25.4279994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-24 00:00:00', 24.1529998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-25 00:00:00', 21.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-26 00:00:00', 20.5400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-27 00:00:00', 15.5469999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-28 00:00:00', 15.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-29 00:00:00', 14.4569997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-30 00:00:00', 13.3430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-08-31 00:00:00', 17.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-01 00:00:00', 18.4860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-02 00:00:00', 18.8929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-03 00:00:00', 18.8439998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-04 00:00:00', 20.6329994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-05 00:00:00', 21.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-06 00:00:00', 21.042999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-07 00:00:00', 19.7420005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-08 00:00:00', 19.0930004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-09 00:00:00', 19.9799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-10 00:00:00', 19.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-11 00:00:00', 19.6210002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-12 00:00:00', 20.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-13 00:00:00', 20.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-14 00:00:00', 18.792999267578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-15 00:00:00', 15.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-16 00:00:00', 13.3459997177124023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-17 00:00:00', 15.9940004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-18 00:00:00', 13.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-19 00:00:00', 13.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-20 00:00:00', 13.0760002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-21 00:00:00', 11.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-22 00:00:00', 12.9340000152587891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-23 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-24 00:00:00', 14.9739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-25 00:00:00', 14.8120002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-26 00:00:00', 14.1059999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-27 00:00:00', 14.685999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-28 00:00:00', 11.8839998245239258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-29 00:00:00', 9.09599971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-09-30 00:00:00', 12.5150003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-01 00:00:00', 15.7510004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-02 00:00:00', 18.0470008850097656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-03 00:00:00', 17.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-04 00:00:00', 14.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-05 00:00:00', 8.80799961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-06 00:00:00', 8.72099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-07 00:00:00', 8.38300037384033203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-08 00:00:00', 8.90400028228759766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-09 00:00:00', 9.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-10 00:00:00', 8.33199977874755859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-11 00:00:00', 7.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-12 00:00:00', 6.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-13 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-14 00:00:00', 9.96599960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-15 00:00:00', 10.9270000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-16 00:00:00', 10.1719999313354492, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-17 00:00:00', 9.78299999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-18 00:00:00', 9.56099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-19 00:00:00', 8.319000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-20 00:00:00', 10.2989997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-21 00:00:00', 9.51399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-22 00:00:00', 6.27199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-23 00:00:00', 0.517000019550323486, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-24 00:00:00', 3.35700011253356934, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-25 00:00:00', 4.55800008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-26 00:00:00', 6.12300014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-27 00:00:00', 7.77899980545043945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-28 00:00:00', 1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-29 00:00:00', -0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-30 00:00:00', 2.56299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-10-31 00:00:00', 2.5130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-01 00:00:00', 0.737999975681304932, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-02 00:00:00', 1.29700005054473877, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-03 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-04 00:00:00', -0.0700000002980232239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-05 00:00:00', 2.09100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-06 00:00:00', 3.83100008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-07 00:00:00', 3.62100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-08 00:00:00', -4.46099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-09 00:00:00', -2.56500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-10 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-11 00:00:00', 2.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-12 00:00:00', 2.28800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-13 00:00:00', 3.94099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-14 00:00:00', -0.685000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-15 00:00:00', -2.37400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-16 00:00:00', 0.875999987125396729, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-17 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-18 00:00:00', 0.896000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-19 00:00:00', -0.222000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-20 00:00:00', 2.50799989700317383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-21 00:00:00', 4.06099987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-22 00:00:00', 1.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-23 00:00:00', 2.13400006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-24 00:00:00', -1.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-25 00:00:00', -1.47599995136260986, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-26 00:00:00', -3.81299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-27 00:00:00', -3.88899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-28 00:00:00', -5.07200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-29 00:00:00', -0.898999989032745361, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-11-30 00:00:00', 1.93400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-01 00:00:00', 1.60199999809265137, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-02 00:00:00', -0.635999977588653564, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-03 00:00:00', -3.7219998836517334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-04 00:00:00', -4.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-05 00:00:00', -9.42300033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-06 00:00:00', -9.07100009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-07 00:00:00', -7.07499980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-08 00:00:00', -5.37699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-09 00:00:00', -2.96600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-10 00:00:00', -1.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-11 00:00:00', -0.964999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-12 00:00:00', -7.69099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-13 00:00:00', -4.70599985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-14 00:00:00', -4.25899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-15 00:00:00', -6.12400007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-16 00:00:00', -5.09800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-17 00:00:00', -0.256000012159347534, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-18 00:00:00', -3.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-19 00:00:00', -7.24900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-20 00:00:00', -16.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-21 00:00:00', -16.2530002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-22 00:00:00', -7.54699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-23 00:00:00', -2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-24 00:00:00', -0.938000023365020752, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-25 00:00:00', -0.513000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-26 00:00:00', -2.68499994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-27 00:00:00', -6.05700016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-28 00:00:00', -8.22900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-29 00:00:00', -2.91400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-30 00:00:00', -7.62799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2011-12-31 00:00:00', -6.48199987411499023, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-01 00:00:00', -2.74600005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-02 00:00:00', -3.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-03 00:00:00', -3.22499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-04 00:00:00', -4.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-05 00:00:00', -9.60400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-06 00:00:00', -9.96100044250488281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-07 00:00:00', -7.33699989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-08 00:00:00', -5.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-09 00:00:00', -4.25600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-10 00:00:00', -3.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-11 00:00:00', -4.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-12 00:00:00', -1.46899998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-13 00:00:00', -3.96199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-14 00:00:00', -2.3880000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-15 00:00:00', -7.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-16 00:00:00', -6.98999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-17 00:00:00', -5.05900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-18 00:00:00', -7.55200004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-19 00:00:00', -9.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-20 00:00:00', -9.52999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-21 00:00:00', -5.89799976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-22 00:00:00', -8.93299961090087891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-23 00:00:00', -6.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-24 00:00:00', -4.7350001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-25 00:00:00', -6.26800012588500977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-26 00:00:00', -8.21399974822998047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-27 00:00:00', -4.18599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-28 00:00:00', -3.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-29 00:00:00', -1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-30 00:00:00', -4.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-01-31 00:00:00', -5.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-01 00:00:00', -1.91700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-02 00:00:00', -0.619000017642974854, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-03 00:00:00', -0.773000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-04 00:00:00', -12.2910003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-05 00:00:00', -16.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-06 00:00:00', -13.5489997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-07 00:00:00', -10.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-08 00:00:00', -4.56799983978271484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-09 00:00:00', -4.74599981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-10 00:00:00', -4.58099985122680664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-11 00:00:00', -2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-12 00:00:00', -8.40499973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-13 00:00:00', -11.689000129699707, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-14 00:00:00', -11.5059995651245117, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-15 00:00:00', -8.46199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-16 00:00:00', -5.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-17 00:00:00', -3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-18 00:00:00', -1.68299996852874756, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-19 00:00:00', -0.158999994397163391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-20 00:00:00', -0.810000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-21 00:00:00', -12.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-22 00:00:00', -13.5860004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-23 00:00:00', -10.8710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-24 00:00:00', -7.88700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-25 00:00:00', -4.42999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-26 00:00:00', -1.30299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-27 00:00:00', -3.39100003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-28 00:00:00', -2.58899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-02-29 00:00:00', -2.34299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-01 00:00:00', 0.331999987363815308, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-02 00:00:00', 2.01399993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-03 00:00:00', 1.73000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-04 00:00:00', -1.40400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-05 00:00:00', -4.42899990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-06 00:00:00', -6.52199983596801758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-07 00:00:00', -6.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-08 00:00:00', -4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-09 00:00:00', -5.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-10 00:00:00', -6.04600000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-11 00:00:00', -7.3600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-12 00:00:00', -11.3420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-13 00:00:00', -5.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-14 00:00:00', -0.924000024795532227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-15 00:00:00', 2.51200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-16 00:00:00', 2.48900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-17 00:00:00', 2.84800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-18 00:00:00', -0.150999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-19 00:00:00', -7.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-20 00:00:00', -8.13799953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-21 00:00:00', -2.70799994468688965, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-22 00:00:00', -0.300000011920928955, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-23 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-24 00:00:00', 0.368999987840652466, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-25 00:00:00', -0.0610000006854534149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-26 00:00:00', 0.351000010967254639, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-27 00:00:00', 2.60299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-28 00:00:00', 4.93300008773803711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-29 00:00:00', 2.28600001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-30 00:00:00', 7.87099981307983398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-03-31 00:00:00', 4.75299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-01 00:00:00', 4.53000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-02 00:00:00', 6.0689997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-03 00:00:00', 5.23299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-04 00:00:00', 5.00299978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-05 00:00:00', 7.51900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-06 00:00:00', 6.96899986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-07 00:00:00', 7.09200000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-08 00:00:00', 10.1029996871948242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-09 00:00:00', 5.24300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-10 00:00:00', 8.38099956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-11 00:00:00', 7.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-12 00:00:00', 7.7630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-13 00:00:00', 8.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-14 00:00:00', 10.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-15 00:00:00', 11.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-16 00:00:00', 11.8310003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-17 00:00:00', 11.6260004043579102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-18 00:00:00', 12.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-19 00:00:00', 12.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-20 00:00:00', 9.99300003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-21 00:00:00', 6.16200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-22 00:00:00', 5.10300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-23 00:00:00', 5.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-24 00:00:00', 5.95399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-25 00:00:00', 5.20399999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-26 00:00:00', 6.75500011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-27 00:00:00', 5.06599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-28 00:00:00', 5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-29 00:00:00', 2.45099997520446777, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-04-30 00:00:00', 5.7779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-01 00:00:00', 6.80499982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-02 00:00:00', 5.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-03 00:00:00', 8.71199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-04 00:00:00', 11.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-05 00:00:00', 11.3610000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-06 00:00:00', 10.9519996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-07 00:00:00', 7.87799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-08 00:00:00', 9.93799972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-09 00:00:00', 12.1730003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-10 00:00:00', 9.31499958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-11 00:00:00', 5.59399986267089844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-12 00:00:00', 5.49200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-13 00:00:00', 9.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-14 00:00:00', 10.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-15 00:00:00', 11.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-16 00:00:00', 10.5299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-17 00:00:00', 7.99399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-18 00:00:00', 6.75600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-19 00:00:00', 9.65200042724609375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-20 00:00:00', 10.9670000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-21 00:00:00', 11.625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-22 00:00:00', 11.0410003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-23 00:00:00', 13.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-24 00:00:00', 16.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-25 00:00:00', 10.810999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-26 00:00:00', 7.60900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-27 00:00:00', 12.9560003280639648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-28 00:00:00', 14.9280004501342773, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-29 00:00:00', 14.1350002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-30 00:00:00', 15.0439996719360352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-05-31 00:00:00', 14.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-01 00:00:00', 16.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-02 00:00:00', 17.3209991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-03 00:00:00', 17.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-04 00:00:00', 15.130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-05 00:00:00', 12.180999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-06 00:00:00', 16.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-07 00:00:00', 14.9060001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-08 00:00:00', 15.1470003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-09 00:00:00', 16.8159999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-10 00:00:00', 16.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-11 00:00:00', 16.4920005798339844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-12 00:00:00', 16.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-13 00:00:00', 15.6879997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-14 00:00:00', 17.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-15 00:00:00', 17.6040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-16 00:00:00', 18.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-17 00:00:00', 19.6340007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-18 00:00:00', 19.7119998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-19 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-20 00:00:00', 16.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-21 00:00:00', 15.9239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-22 00:00:00', 12.7049999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-23 00:00:00', 15.0749998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-24 00:00:00', 13.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-26 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-27 00:00:00', 15.1820001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-28 00:00:00', 17.2140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-29 00:00:00', 19.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-06-30 00:00:00', 20.6569995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-01 00:00:00', 21.3069992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-02 00:00:00', 22.6089992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-03 00:00:00', 22.2029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-04 00:00:00', 21.9589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-05 00:00:00', 22.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-06 00:00:00', 22.1200008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-07 00:00:00', 21.3600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-08 00:00:00', 21.0189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-09 00:00:00', 22.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-10 00:00:00', 23.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-11 00:00:00', 23.0109996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-12 00:00:00', 21.73699951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-13 00:00:00', 21.4810009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-14 00:00:00', 20.2240009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-15 00:00:00', 19.5389995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-16 00:00:00', 20.7639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-17 00:00:00', 20.5869998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-18 00:00:00', 19.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-19 00:00:00', 21.0279998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-20 00:00:00', 21.5919990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-21 00:00:00', 22.4109992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-22 00:00:00', 20.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-23 00:00:00', 20.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-24 00:00:00', 18.8969993591308594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-25 00:00:00', 17.7770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-26 00:00:00', 18.3490009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-27 00:00:00', 16.5160007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-28 00:00:00', 17.6509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-29 00:00:00', 19.8640003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-30 00:00:00', 21.0520000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-07-31 00:00:00', 21.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-01 00:00:00', 20.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-02 00:00:00', 20.0830001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-03 00:00:00', 18.6800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-04 00:00:00', 18.5459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-05 00:00:00', 20.6030006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-06 00:00:00', 20.4950008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-07 00:00:00', 21.9449996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-08 00:00:00', 21.2770004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-09 00:00:00', 21.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-10 00:00:00', 20.3110008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-11 00:00:00', 20.2919998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-12 00:00:00', 17.0079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-13 00:00:00', 16.8759994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-14 00:00:00', 20.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-15 00:00:00', 21.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-16 00:00:00', 21.6919994354248047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-17 00:00:00', 22.3549995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-18 00:00:00', 23.3700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-19 00:00:00', 23.4839992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-20 00:00:00', 23.4430007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-21 00:00:00', 24.0480003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-22 00:00:00', 23.5189990997314453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-23 00:00:00', 22.2619991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-24 00:00:00', 17.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-25 00:00:00', 19.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-26 00:00:00', 19.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-27 00:00:00', 18.7409992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-28 00:00:00', 19.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-29 00:00:00', 21.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-30 00:00:00', 21.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-08-31 00:00:00', 21.5960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-01 00:00:00', 20.8859996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-02 00:00:00', 21.1520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-03 00:00:00', 19.4979991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-04 00:00:00', 17.1909999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-05 00:00:00', 15.494999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-06 00:00:00', 17.5510005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-07 00:00:00', 15.1619997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-08 00:00:00', 16.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-09 00:00:00', 18.0100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-10 00:00:00', 20.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-11 00:00:00', 20.0750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-12 00:00:00', 18.3649997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-13 00:00:00', 17.0459995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-14 00:00:00', 15.2200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-15 00:00:00', 15.1269998550415039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-16 00:00:00', 14.2860002517700195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-17 00:00:00', 11.3570003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-18 00:00:00', 12.6239995956420898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-19 00:00:00', 13.5850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-20 00:00:00', 13.1639995574951172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-21 00:00:00', 13.0369997024536133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-22 00:00:00', 13.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-23 00:00:00', 13.435999870300293, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-24 00:00:00', 13.925999641418457, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-25 00:00:00', 12.8420000076293945, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-26 00:00:00', 12.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-27 00:00:00', 14.4040002822875977, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-28 00:00:00', 13.0819997787475586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-29 00:00:00', 10.1180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-09-30 00:00:00', 9.56400012969970703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-01 00:00:00', 11.4320001602172852, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-02 00:00:00', 10.4870004653930664, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-03 00:00:00', 9.71700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-04 00:00:00', 9.13599967956542969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-05 00:00:00', 9.86100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-06 00:00:00', 11.5989999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-07 00:00:00', 12.7799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-08 00:00:00', 12.0260000228881836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-09 00:00:00', 11.4479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-10 00:00:00', 11.8360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-11 00:00:00', 11.8780002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-12 00:00:00', 11.7569999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-13 00:00:00', 12.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-14 00:00:00', 5.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-15 00:00:00', 5.57299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-16 00:00:00', 7.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-17 00:00:00', 6.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-18 00:00:00', 5.90199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-19 00:00:00', 5.26700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-20 00:00:00', 2.65499997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-21 00:00:00', 2.59899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-22 00:00:00', 5.08300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-23 00:00:00', 5.91699981689453125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-24 00:00:00', 7.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-25 00:00:00', 5.60200023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-26 00:00:00', 7.11100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-27 00:00:00', 6.46600008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-28 00:00:00', 9.65600013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-29 00:00:00', 6.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-30 00:00:00', 9.97299957275390625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-10-31 00:00:00', 9.03100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-01 00:00:00', 5.64599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-02 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-03 00:00:00', 5.93200016021728516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-04 00:00:00', 2.05399990081787109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-05 00:00:00', 4.04400014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-06 00:00:00', 5.69799995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-07 00:00:00', 5.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-08 00:00:00', 6.38700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-09 00:00:00', 5.26599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-10 00:00:00', 6.50899982452392578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-11 00:00:00', 7.82899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-12 00:00:00', 3.44600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-13 00:00:00', 1.52799999713897705, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-14 00:00:00', 5.09899997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-15 00:00:00', 4.66499996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-16 00:00:00', 0.272000014781951904, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-17 00:00:00', -0.59299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-18 00:00:00', 0.193000003695487976, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-19 00:00:00', -2.32399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-20 00:00:00', -2.46900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-21 00:00:00', -1.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-22 00:00:00', -0.847999989986419678, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-23 00:00:00', -3.52699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-24 00:00:00', -2.39800000190734863, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-25 00:00:00', 0.174999997019767761, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-26 00:00:00', -2.20600008964538574, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-27 00:00:00', 1.57400000095367432, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-28 00:00:00', -1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-29 00:00:00', -5.28700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-11-30 00:00:00', -1.41400003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-01 00:00:00', 0.326000005006790161, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-02 00:00:00', 0.53200000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-03 00:00:00', 0.860000014305114746, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-04 00:00:00', 2.53900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-05 00:00:00', 3.33500003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-06 00:00:00', 2.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-07 00:00:00', 1.40799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-08 00:00:00', 0.714999973773956299, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-09 00:00:00', 1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-10 00:00:00', -0.21799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-11 00:00:00', -2.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-12 00:00:00', -2.87100005149841309, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-13 00:00:00', -4.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-14 00:00:00', -7.32600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-15 00:00:00', -7.26900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-16 00:00:00', -7.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-17 00:00:00', -3.04699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-18 00:00:00', -7.74399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-19 00:00:00', -6.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-20 00:00:00', -2.99200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-21 00:00:00', 0.90700000524520874, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-22 00:00:00', 4.22300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-23 00:00:00', -0.903999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-24 00:00:00', -2.50900006294250488, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-25 00:00:00', 0.108000002801418304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-26 00:00:00', -4.42399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-27 00:00:00', -6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-28 00:00:00', -11.4739999771118164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-29 00:00:00', -4.19600009918212891, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-30 00:00:00', 0.754999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2012-12-31 00:00:00', -1.82799994945526123, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-01 00:00:00', -12.2320003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-02 00:00:00', -4.45300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-03 00:00:00', -9.31299972534179688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-04 00:00:00', -8.46800041198730469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-05 00:00:00', -3.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-06 00:00:00', -3.00300002098083496, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-07 00:00:00', -1.94599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-08 00:00:00', -1.40199995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-09 00:00:00', -2.52200007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-10 00:00:00', -0.209000006318092346, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-11 00:00:00', -0.086000002920627594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-12 00:00:00', -9.68599987030029297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-13 00:00:00', -5.81500005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-14 00:00:00', -1.83700001239776611, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-15 00:00:00', -7.03900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-16 00:00:00', -9.70199966430664062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-17 00:00:00', -9.31200027465820312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-18 00:00:00', -5.00699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-19 00:00:00', -5.23400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-20 00:00:00', -2.73099994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-21 00:00:00', -1.58399999141693115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-22 00:00:00', -3.71900010108947754, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-23 00:00:00', -2.29699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-24 00:00:00', -0.64999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-25 00:00:00', -1.42799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-26 00:00:00', -0.263999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-27 00:00:00', -0.74299997091293335, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-28 00:00:00', -0.275999993085861206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-29 00:00:00', 0.219999998807907104, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-30 00:00:00', 1.01999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-01-31 00:00:00', -0.888999998569488525, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-01 00:00:00', 0.889999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-02 00:00:00', -0.834999978542327881, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-03 00:00:00', -2.50399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-04 00:00:00', -6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-05 00:00:00', -5.35900020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-06 00:00:00', -1.72200000286102295, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-07 00:00:00', 1.04900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-08 00:00:00', 2.6400001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-09 00:00:00', -2.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-10 00:00:00', -2.23600006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-11 00:00:00', -2.79500007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-12 00:00:00', -2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-13 00:00:00', -1.41700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-14 00:00:00', -0.583999991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-15 00:00:00', -2.19000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-16 00:00:00', -1.97300004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-17 00:00:00', 1.54900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-18 00:00:00', -2.61999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-19 00:00:00', -3.23000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-20 00:00:00', 0.46799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-21 00:00:00', -1.14400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-22 00:00:00', -2.14499998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-23 00:00:00', -1.15699994564056396, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-24 00:00:00', -0.514999985694885254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-25 00:00:00', -0.925999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-26 00:00:00', -3.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-27 00:00:00', -7.9439997673034668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-02-28 00:00:00', -3.03099989891052246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-01 00:00:00', 1.78799998760223389, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-02 00:00:00', 3.19300007820129395, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-03 00:00:00', 2.21399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-04 00:00:00', 2.57200002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-05 00:00:00', 4.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-06 00:00:00', 6.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-07 00:00:00', 0.59299999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-08 00:00:00', -2.0130000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-09 00:00:00', -4.55900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-10 00:00:00', 2.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-11 00:00:00', 3.06699991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-12 00:00:00', 0.874000012874603271, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-13 00:00:00', 0.126000002026557922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-14 00:00:00', 3.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-15 00:00:00', 1.69299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-16 00:00:00', -1.47399997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-17 00:00:00', 0.100000001490116119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-18 00:00:00', 2.4590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-19 00:00:00', 4.55299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-20 00:00:00', 4.03200006484985352, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-21 00:00:00', 2.18400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-22 00:00:00', 2.76600003242492676, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-23 00:00:00', 1.1940000057220459, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-24 00:00:00', 3.43700003623962402, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-25 00:00:00', 5.86800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-26 00:00:00', 1.92299997806549072, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-27 00:00:00', 5.26999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-28 00:00:00', 7.35099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-29 00:00:00', 7.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-30 00:00:00', 8.34099960327148438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-03-31 00:00:00', 2.72000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-01 00:00:00', -3.71499991416931152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-02 00:00:00', -0.104999996721744537, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-03 00:00:00', 2.2650001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-04 00:00:00', 3.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-05 00:00:00', 1.01900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-06 00:00:00', 2.39700007438659668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-07 00:00:00', 5.9590001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-08 00:00:00', 8.74400043487548828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-09 00:00:00', 10.0500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-10 00:00:00', 8.62800025939941406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-11 00:00:00', 7.12699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-12 00:00:00', 8.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-13 00:00:00', 8.45600032806396484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-14 00:00:00', 11.4510002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-15 00:00:00', 3.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-16 00:00:00', 3.48799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-17 00:00:00', 5.22599983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-18 00:00:00', 6.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-19 00:00:00', 6.53700017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-20 00:00:00', 7.78000020980834961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-21 00:00:00', 8.14700031280517578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-22 00:00:00', 12.8430004119873047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-23 00:00:00', 8.80300045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-24 00:00:00', 3.82699990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-25 00:00:00', 2.73300004005432129, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-26 00:00:00', 1.77699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-27 00:00:00', 4.85400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-28 00:00:00', 1.39199995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-29 00:00:00', 0.405999988317489624, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-04-30 00:00:00', 1.43900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-01 00:00:00', 4.59000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-02 00:00:00', 6.6100001335144043, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-03 00:00:00', 5.52500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-04 00:00:00', 8.86699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-05 00:00:00', 8.30900001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-06 00:00:00', 11.2799997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-07 00:00:00', 12.0620002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-08 00:00:00', 11.7829999923706055, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-09 00:00:00', 12.3979997634887695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-10 00:00:00', 13.2309999465942383, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-11 00:00:00', 11.4099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-12 00:00:00', 7.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-13 00:00:00', 8.67599964141845703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-14 00:00:00', 13.4619998931884766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-15 00:00:00', 14.8100004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-16 00:00:00', 16.0289993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-17 00:00:00', 17.4990005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-18 00:00:00', 19.3419990539550781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-19 00:00:00', 11.0310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-20 00:00:00', 12.5699996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-21 00:00:00', 10.4910001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-22 00:00:00', 13.4589996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-23 00:00:00', 15.8680000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-24 00:00:00', 12.0159997940063477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-25 00:00:00', 10.3290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-26 00:00:00', 10.2810001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-27 00:00:00', 8.31700038909912109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-28 00:00:00', 13.6099996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-29 00:00:00', 16.5069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-30 00:00:00', 18.2220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-05-31 00:00:00', 20.0960006713867188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-01 00:00:00', 19.63800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-02 00:00:00', 17.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-03 00:00:00', 16.5209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-04 00:00:00', 16.7740001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-05 00:00:00', 17.2129993438720703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-06 00:00:00', 17.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-07 00:00:00', 19.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-08 00:00:00', 23.4740009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-09 00:00:00', 22.0990009307861328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-10 00:00:00', 20.332000732421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-11 00:00:00', 20.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-12 00:00:00', 20.875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-13 00:00:00', 17.5370006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-14 00:00:00', 15.3260002136230469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-15 00:00:00', 15.9860000610351562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-16 00:00:00', 15.9639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-17 00:00:00', 16.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-18 00:00:00', 19.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-19 00:00:00', 21.1509990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-20 00:00:00', 21.7870006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-21 00:00:00', 22.38800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-22 00:00:00', 23.2980003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-23 00:00:00', 22.7679996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-24 00:00:00', 22.9699993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-25 00:00:00', 23.7849998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-26 00:00:00', 23.1760005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-27 00:00:00', 18.4400005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-28 00:00:00', 14.6929998397827148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-29 00:00:00', 15.2030000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-06-30 00:00:00', 15.4020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-01 00:00:00', 15.699000358581543, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-02 00:00:00', 17.6739997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-03 00:00:00', 21.1900005340576172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-04 00:00:00', 22.8239994049072266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-05 00:00:00', 20.6229991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-06 00:00:00', 18.0170001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-07 00:00:00', 19.1949996948242188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-08 00:00:00', 18.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-09 00:00:00', 15.5670003890991211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-10 00:00:00', 17.2509994506835938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-11 00:00:00', 16.4230003356933594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-12 00:00:00', 20.1849994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-13 00:00:00', 22.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-14 00:00:00', 19.7140007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-15 00:00:00', 20.4610004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-16 00:00:00', 20.9720001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-17 00:00:00', 21.5079994201660156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-18 00:00:00', 23.6690006256103516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-19 00:00:00', 24.3360004425048828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-20 00:00:00', 24.4909992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-21 00:00:00', 22.4360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-22 00:00:00', 20.7259998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-23 00:00:00', 21.8080005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-24 00:00:00', 22.8980007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-25 00:00:00', 22.7450008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-26 00:00:00', 24.7299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-27 00:00:00', 26.3129997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-28 00:00:00', 27.9479999542236328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-29 00:00:00', 28.7859992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-30 00:00:00', 27.8850002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-07-31 00:00:00', 26.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-01 00:00:00', 25.3710002899169922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-02 00:00:00', 25.1490001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-03 00:00:00', 25.0720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-04 00:00:00', 24.1599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-05 00:00:00', 24.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-06 00:00:00', 24.8700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-07 00:00:00', 20.8519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-08 00:00:00', 18.0599994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-09 00:00:00', 20.0580005645751953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-10 00:00:00', 19.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-11 00:00:00', 18.1149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-12 00:00:00', 18.0300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-13 00:00:00', 13.9020004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-14 00:00:00', 18.2479991912841797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-15 00:00:00', 18.8799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-16 00:00:00', 17.2660007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-17 00:00:00', 17.1560001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-18 00:00:00', 18.2250003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-19 00:00:00', 15.6680002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-20 00:00:00', 18.2520008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-21 00:00:00', 18.5890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-22 00:00:00', 20.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-23 00:00:00', 19.6590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-24 00:00:00', 16.6779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-25 00:00:00', 19.5230007171630859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-26 00:00:00', 21.3869991302490234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-27 00:00:00', 20.8020000457763672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-28 00:00:00', 20.7089996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-29 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-30 00:00:00', 17.9160003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-08-31 00:00:00', 17.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-01 00:00:00', 18.0779991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-02 00:00:00', 18.0890007019042969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-03 00:00:00', 18.7310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-04 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-05 00:00:00', 20.7029991149902344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-06 00:00:00', 22.2639999389648438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-07 00:00:00', 21.5550003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-08 00:00:00', 21.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-09 00:00:00', 21.5030002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-10 00:00:00', 21.5310001373291016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-11 00:00:00', 19.7390003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-12 00:00:00', 17.3740005493164062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-13 00:00:00', 16.6159992218017578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-14 00:00:00', 13.7819995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-15 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-16 00:00:00', 12.5769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-17 00:00:00', 15.0249996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-18 00:00:00', 16.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-19 00:00:00', 19.1140003204345703, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-20 00:00:00', 20.3519992828369141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-21 00:00:00', 20.0769996643066406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-22 00:00:00', 18.61199951171875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-23 00:00:00', 18.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-24 00:00:00', 20.1040000915527344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-25 00:00:00', 22.1310005187988281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-26 00:00:00', 21.5949993133544922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-27 00:00:00', 16.1959991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-28 00:00:00', 17.0149993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-29 00:00:00', 16.2549991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-09-30 00:00:00', 16.5090007781982422, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-01 00:00:00', 16.5100002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-02 00:00:00', 16.9370002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-03 00:00:00', 18.0069999694824219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-04 00:00:00', 19.1779994964599609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-05 00:00:00', 19.4969997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-06 00:00:00', 19.9689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-07 00:00:00', 18.4349994659423828, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-08 00:00:00', 16.2310009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-09 00:00:00', 13.0880002975463867, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-10 00:00:00', 9.52099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-11 00:00:00', 9.79800033569335938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-12 00:00:00', 10.4650001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-13 00:00:00', 9.22099971771240234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-14 00:00:00', 10.4729995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-15 00:00:00', 9.27299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-16 00:00:00', 6.9159998893737793, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-17 00:00:00', 8.61800003051757812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-18 00:00:00', 10.6420001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-19 00:00:00', 12.4409999847412109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-20 00:00:00', 13.6219997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-21 00:00:00', 12.7629995346069336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-22 00:00:00', 7.37799978256225586, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-23 00:00:00', 1.65999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-24 00:00:00', 7.07600021362304688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-25 00:00:00', 4.67500019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-26 00:00:00', -1.78900003433227539, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-27 00:00:00', -0.188999995589256287, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-28 00:00:00', 4.2779998779296875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-29 00:00:00', 5.53100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-30 00:00:00', 1.10899996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-10-31 00:00:00', -1.42499995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-01 00:00:00', -1.42100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-02 00:00:00', 0.71399998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-03 00:00:00', 3.25399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-04 00:00:00', 1.69599997997283936, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-05 00:00:00', 2.73399996757507324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-06 00:00:00', 2.61599993705749512, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-07 00:00:00', 1.89900004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-08 00:00:00', 3.34100008010864258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-09 00:00:00', 4.23999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-10 00:00:00', 2.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-11 00:00:00', 2.70199990272521973, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-12 00:00:00', 1.17900002002716064, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-13 00:00:00', 1.92100000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-14 00:00:00', 4.32700014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-15 00:00:00', 6.24200010299682617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-16 00:00:00', 2.94199991226196289, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-17 00:00:00', 3.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-18 00:00:00', 3.00600004196166992, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-19 00:00:00', 3.0840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-20 00:00:00', -0.638000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-21 00:00:00', 0.222000002861022949, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-22 00:00:00', 3.06299996376037598, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-23 00:00:00', 2.62599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-24 00:00:00', 0.128000006079673767, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-25 00:00:00', 1.33000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-26 00:00:00', 0.259000003337860107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-27 00:00:00', 0.646000027656555176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-28 00:00:00', 1.96599996089935303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-29 00:00:00', 1.5549999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-11-30 00:00:00', 3.30500006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-01 00:00:00', 2.44099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-02 00:00:00', -2.43199992179870605, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-03 00:00:00', 1.43200004100799561, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-04 00:00:00', 2.09599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-05 00:00:00', -2.59800004959106445, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-06 00:00:00', 0.224999994039535522, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-07 00:00:00', 0.580999970436096191, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-08 00:00:00', -0.226999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-09 00:00:00', 0.287999987602233887, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-10 00:00:00', 1.6390000581741333, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-11 00:00:00', -2.84299993515014648, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-12 00:00:00', -0.93900001049041748, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-13 00:00:00', 1.89999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-14 00:00:00', 3.98900008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-15 00:00:00', 3.90799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-16 00:00:00', -1.27400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-17 00:00:00', -8.11699962615966797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-18 00:00:00', -9.26299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-19 00:00:00', -5.78800010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-20 00:00:00', -3.35299992561340332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-21 00:00:00', -9.89099979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-22 00:00:00', -9.92099952697753906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-23 00:00:00', -7.57899999618530273, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-24 00:00:00', -10.1160001754760742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-25 00:00:00', -6.50099992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-26 00:00:00', -6.85099983215332031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-27 00:00:00', -10.8290004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-28 00:00:00', -14.4770002365112305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-29 00:00:00', -12.7840003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-30 00:00:00', -12.1709995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2013-12-31 00:00:00', -8.53699970245361328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-01 00:00:00', -5.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-02 00:00:00', -2.59599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-03 00:00:00', -5.96700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-04 00:00:00', -8.86999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-05 00:00:00', -9.77299976348876953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-06 00:00:00', -8.50100040435791016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-07 00:00:00', -5.1810002326965332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-08 00:00:00', -7.47900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-09 00:00:00', -8.99800014495849609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-10 00:00:00', -7.27699995040893555, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-11 00:00:00', -1.21000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-12 00:00:00', 0.566999971866607666, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-13 00:00:00', -4.66200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-14 00:00:00', -1.84599995613098145, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-15 00:00:00', -4.03399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-16 00:00:00', -5.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-17 00:00:00', -2.79900002479553223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-18 00:00:00', -0.39100000262260437, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-19 00:00:00', -0.605000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-20 00:00:00', -1.4309999942779541, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-21 00:00:00', -4.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-22 00:00:00', -4.0149998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-23 00:00:00', -1.95599997043609619, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-24 00:00:00', -1.54100000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-25 00:00:00', -3.66700005531311035, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-26 00:00:00', -0.630999982357025146, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-27 00:00:00', -0.303000003099441528, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-28 00:00:00', 0.629999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-29 00:00:00', 1.02999997138977051, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-30 00:00:00', -1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-01-31 00:00:00', -1.2630000114440918, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-01 00:00:00', -6.69700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-02 00:00:00', -11.366999626159668, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-03 00:00:00', -14.994999885559082, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-04 00:00:00', -14.0220003128051758, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-05 00:00:00', -11.5970001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-06 00:00:00', -9.37399959564208984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-07 00:00:00', -12.5579996109008789, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-08 00:00:00', -9.29300022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-09 00:00:00', -6.35300016403198242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-10 00:00:00', -6.7220001220703125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-11 00:00:00', -6.33599996566772461, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-12 00:00:00', -5.78100013732910156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-13 00:00:00', -6.33300018310546875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-14 00:00:00', -6.10400009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-15 00:00:00', -6.5840001106262207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-16 00:00:00', -0.328999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-17 00:00:00', 2.82500004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-18 00:00:00', -2.31599998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-19 00:00:00', -3.31100010871887207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-20 00:00:00', -3.62700009346008301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-21 00:00:00', -2.36400008201599121, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-22 00:00:00', -1.99699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-23 00:00:00', -5.61100006103515625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-24 00:00:00', -5.92399978637695312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-25 00:00:00', -3.57399988174438477, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-26 00:00:00', -4.80999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-27 00:00:00', -4.17700004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-02-28 00:00:00', -1.77400004863739014, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-01 00:00:00', -1.49699997901916504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-02 00:00:00', -1.19299995899200439, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-03 00:00:00', -3.21199989318847656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-04 00:00:00', -3.15400004386901855, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-05 00:00:00', -0.246000006794929504, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-06 00:00:00', -0.490999996662139893, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-07 00:00:00', -0.528999984264373779, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-08 00:00:00', 0.026000000536441803, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-09 00:00:00', -6.44700002670288086, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-10 00:00:00', -4.73899984359741211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-11 00:00:00', -1.84399998188018799, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-12 00:00:00', 1.8609999418258667, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-13 00:00:00', 2.28399991989135742, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-14 00:00:00', 1.41600000858306885, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-15 00:00:00', -1.26699995994567871, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-16 00:00:00', 0.785000026226043701, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-17 00:00:00', 0.439999997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-18 00:00:00', 1.1799999475479126, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-19 00:00:00', 2.66300010681152344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-20 00:00:00', 1.49399995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-21 00:00:00', 0.583000004291534424, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-22 00:00:00', 0.541999995708465576, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-23 00:00:00', -1.49800002574920654, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-24 00:00:00', -6.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-25 00:00:00', -4.13700008392333984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-26 00:00:00', -2.27500009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-27 00:00:00', -1.23800003528594971, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-28 00:00:00', 0.927999973297119141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-29 00:00:00', 2.74900007247924805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-30 00:00:00', 4.98400020599365234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-03-31 00:00:00', 6.70300006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-01 00:00:00', 5.12900018692016602, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-02 00:00:00', 2.00399994850158691, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-03 00:00:00', 4.62699985504150391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-04 00:00:00', 1.37000000476837158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-05 00:00:00', -0.52499997615814209, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-06 00:00:00', 0.961000025272369385, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-07 00:00:00', -0.248999997973442078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-08 00:00:00', 2.02399992942810059, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-09 00:00:00', 5.47499990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-10 00:00:00', 4.10500001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-11 00:00:00', 4.66800022125244141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-12 00:00:00', 1.02199995517730713, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-13 00:00:00', 2.39599990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-14 00:00:00', 5.91200017929077148, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-15 00:00:00', 8.17800045013427734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-16 00:00:00', 7.01599979400634766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-17 00:00:00', 6.41900014877319336, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-18 00:00:00', 5.76700019836425781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-19 00:00:00', 7.98299980163574219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-20 00:00:00', 7.24499988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-21 00:00:00', 8.86499977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-22 00:00:00', 9.25599956512451172, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-23 00:00:00', 12.0790004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-24 00:00:00', 5.51000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-25 00:00:00', 4.12599992752075195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-26 00:00:00', 7.20200014114379883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-27 00:00:00', 9.98799991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-28 00:00:00', 9.27000045776367188, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-29 00:00:00', 12.2159996032714844, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-04-30 00:00:00', 11.6190004348754883, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-01 00:00:00', 13.8330001831054688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-02 00:00:00', 15.3730001449584961, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-03 00:00:00', 13.6440000534057617, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-04 00:00:00', 12.0850000381469727, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-05 00:00:00', 14.569000244140625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-06 00:00:00', 12.2959995269775391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-07 00:00:00', 13.5450000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-08 00:00:00', 11.6899995803833008, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-09 00:00:00', 11.2040004730224609, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-10 00:00:00', 14.6180000305175781, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-11 00:00:00', 14.0629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-12 00:00:00', 12.0430002212524414, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-13 00:00:00', 9.19099998474121094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-14 00:00:00', 10.6520004272460938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-15 00:00:00', 13.5039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-16 00:00:00', 15.0299997329711914, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-17 00:00:00', 14.1590003967285156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-18 00:00:00', 8.51299953460693359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-19 00:00:00', 9.72700023651123047, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-20 00:00:00', 13.4069995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-21 00:00:00', 11.6370000839233398, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-22 00:00:00', 11.8950004577636719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-23 00:00:00', 12.8400001525878906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-24 00:00:00', 13.6789999008178711, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-25 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-26 00:00:00', 14.9820003509521484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-27 00:00:00', 16.6660003662109375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-28 00:00:00', 17.4689998626708984, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-29 00:00:00', 15.1669998168945312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-30 00:00:00', 8.48700046539306641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-05-31 00:00:00', 10.3920001983642578, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-01 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-02 00:00:00', 13.0780000686645508, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-03 00:00:00', 14.3219995498657227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-04 00:00:00', 15.4639997482299805, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-05 00:00:00', 17.0639991760253906, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-06 00:00:00', 13.1009998321533203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-07 00:00:00', 14.555999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-08 00:00:00', 15.7749996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-09 00:00:00', 16.6459999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-10 00:00:00', 17.1289997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-11 00:00:00', 16.2600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-12 00:00:00', 19.3899993896484375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-13 00:00:00', 21.9459991455078125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-14 00:00:00', 21.1700000762939453, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-15 00:00:00', 15.4239997863769531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-16 00:00:00', 15.7539997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-17 00:00:00', 15.5629997253417969, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-18 00:00:00', 17.0240001678466797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-19 00:00:00', 18.5720005035400391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-20 00:00:00', 19.4120006561279297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-21 00:00:00', 20.2380008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-22 00:00:00', 21.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-23 00:00:00', 21.3180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-24 00:00:00', 21.1270008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-25 00:00:00', 21.3929996490478516, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-26 00:00:00', 21.4939994812011719, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-27 00:00:00', 23.055999755859375, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-28 00:00:00', 23.6149997711181641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-29 00:00:00', 23.0209999084472656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-06-30 00:00:00', 23.7059993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-01 00:00:00', 22.7600002288818359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-02 00:00:00', 19.7280006408691406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-03 00:00:00', 16.9360008239746094, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-04 00:00:00', 16.3770008087158203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-05 00:00:00', 16.3479995727539062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-06 00:00:00', 18.13800048828125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-07 00:00:00', 20.7789993286132812, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-08 00:00:00', 20.8309993743896484, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-09 00:00:00', 21.5750007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-10 00:00:00', 21.5799999237060547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-11 00:00:00', 22.6280002593994141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-12 00:00:00', 21.7759990692138672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-13 00:00:00', 20.8719997406005859, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-14 00:00:00', 21.0319995880126953, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-15 00:00:00', 21.0039997100830078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-16 00:00:00', 19.7900009155273438, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-17 00:00:00', 19.2299995422363281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-18 00:00:00', 19.1410007476806641, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-19 00:00:00', 19.6870002746582031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-20 00:00:00', 21.1609992980957031, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-21 00:00:00', 23.1550006866455078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-22 00:00:00', 25.8339996337890625, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-23 00:00:00', 26.8010005950927734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-24 00:00:00', 22.2609996795654297, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-25 00:00:00', 22.6060009002685547, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-26 00:00:00', 23.2099990844726562, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-27 00:00:00', 25.0049991607666016, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-28 00:00:00', 24.8589992523193359, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-29 00:00:00', 20.6130008697509766, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-30 00:00:00', 19.5569992065429688, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (41, '2014-07-31 00:00:00', 19.8180007934570312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-01-05 00:00:00', 7.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-01-15 00:00:00', 6.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-01-25 00:00:00', 6.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-02-05 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-02-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-02-25 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-03-05 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-03-15 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-03-25 00:00:00', 26.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-04-05 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-04-15 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-04-25 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-05-05 00:00:00', 31.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-05-15 00:00:00', 33.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-05-25 00:00:00', 40.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-06-05 00:00:00', 24.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-06-15 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-06-25 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-07-05 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-07-15 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-07-25 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-08-05 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-08-15 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-08-25 00:00:00', 1.70000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-09-05 00:00:00', 2.18000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-09-15 00:00:00', 2.04999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-09-25 00:00:00', 2.31999993324279785, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-10-05 00:00:00', 3.38000011444091797, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-10-15 00:00:00', 3.68000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-10-25 00:00:00', 3.95000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-11-05 00:00:00', 2.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-11-15 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-11-25 00:00:00', 2.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-12-05 00:00:00', 2.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-12-15 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2017-12-25 00:00:00', 1.79999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-01-05 00:00:00', 4.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-01-15 00:00:00', 5.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-01-25 00:00:00', 5.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-02-05 00:00:00', 6, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-02-15 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-02-25 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-03-05 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-03-15 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-03-25 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-04-05 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-04-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-04-25 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-05-05 00:00:00', 38, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-05-15 00:00:00', 31, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-05-25 00:00:00', 37, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-06-05 00:00:00', 30, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-06-15 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-06-25 00:00:00', 32, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-07-05 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-07-15 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-07-25 00:00:00', 3.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-08-05 00:00:00', 3.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-08-15 00:00:00', 3.29999995231628418, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-08-25 00:00:00', 3, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-09-05 00:00:00', 3.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-09-15 00:00:00', 3.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-09-25 00:00:00', 5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-10-05 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-10-15 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-10-25 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-11-05 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-11-15 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-11-25 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-12-05 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-12-15 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2018-12-25 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-05 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-01-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-05 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-15 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-02-25 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-15 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-03-25 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-05 00:00:00', 68, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-15 00:00:00', 25.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-04-25 00:00:00', 26.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-05 00:00:00', 61, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-15 00:00:00', 77, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-05-25 00:00:00', 65, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-05 00:00:00', 101, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-15 00:00:00', 52, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-06-25 00:00:00', 65, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-05 00:00:00', 48, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-07-15 00:00:00', 72, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-05 00:00:00', 32.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-15 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-08-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-05 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-15 00:00:00', 8.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-09-25 00:00:00', 7.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-05 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-10-25 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-05 00:00:00', 25.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-11-25 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-05 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-15 00:00:00', 14.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2019-12-25 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-01-05 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-01-15 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-01-25 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-02-05 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-02-15 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-02-25 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-03-05 00:00:00', 237, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-03-15 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-03-25 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-04-05 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-04-15 00:00:00', 301, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-04-25 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-05-05 00:00:00', 281, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-05-15 00:00:00', 282, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-05-25 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-06-05 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-06-15 00:00:00', 268, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-06-25 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-07-05 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-07-15 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-07-25 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-08-05 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-08-15 00:00:00', 187, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-08-25 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-09-05 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-09-15 00:00:00', 210, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-09-25 00:00:00', 207, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-10-05 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-10-15 00:00:00', 218, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-10-25 00:00:00', 228, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-11-05 00:00:00', 226, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-11-15 00:00:00', 227, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-11-25 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-12-05 00:00:00', 239, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-12-15 00:00:00', 233, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2014-12-25 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-01-05 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-01-15 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-01-25 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-02-05 00:00:00', 247, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-02-15 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-02-25 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-03-05 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-03-15 00:00:00', 263, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-03-25 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-04-05 00:00:00', 291, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-04-15 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-04-25 00:00:00', 285, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-05-05 00:00:00', 264, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-05-15 00:00:00', 296, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-05-25 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-06-05 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-06-15 00:00:00', 252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-06-25 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-07-05 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-07-15 00:00:00', 211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-07-25 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-08-05 00:00:00', 194, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-08-15 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-08-25 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-09-05 00:00:00', 198, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-09-15 00:00:00', 204, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-09-25 00:00:00', 202, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-10-05 00:00:00', 211, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-10-15 00:00:00', 216, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-10-25 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-11-05 00:00:00', 214, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-11-15 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-11-25 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-12-05 00:00:00', 235, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-12-15 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2015-12-25 00:00:00', 230, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-01-05 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-01-15 00:00:00', 259, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-01-25 00:00:00', 256, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-02-05 00:00:00', 257, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-02-15 00:00:00', 258, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-02-25 00:00:00', 255, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-03-05 00:00:00', 269, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-03-15 00:00:00', 324, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-03-25 00:00:00', 298, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-04-05 00:00:00', 278, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-04-15 00:00:00', 276, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-04-25 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-05-05 00:00:00', 303, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-05-15 00:00:00', 288, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-05-25 00:00:00', 245, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-06-05 00:00:00', 300, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-06-15 00:00:00', 321, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-06-25 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-07-05 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-07-15 00:00:00', 277, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-07-25 00:00:00', 262, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-08-05 00:00:00', 240, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-08-15 00:00:00', 224, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-08-25 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-09-05 00:00:00', 221, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-09-15 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-09-25 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-10-05 00:00:00', 225, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-10-15 00:00:00', 232, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-10-25 00:00:00', 237, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-11-05 00:00:00', 237, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-11-15 00:00:00', 243, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-11-25 00:00:00', 244, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-12-05 00:00:00', 242, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-12-15 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2016-12-25 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-01-05 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-01-15 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-01-25 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-02-05 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-02-15 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-02-25 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-03-05 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-03-15 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-03-25 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-04-05 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-04-15 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-04-25 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-05-05 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-05-15 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-05-25 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-06-05 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-06-15 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-06-25 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-07-05 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-07-15 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-07-25 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-08-05 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-08-15 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-08-25 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-09-05 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-09-15 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-09-25 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-10-05 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-10-15 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-10-25 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-11-05 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-11-15 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-11-25 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-12-05 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-12-15 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (1, '2013-12-25 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-01-05 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-01-15 00:00:00', 158, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-01-25 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-02-05 00:00:00', 156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-02-15 00:00:00', 152, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-02-25 00:00:00', 156, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-03-05 00:00:00', 157, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-03-15 00:00:00', 163, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-03-25 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-04-05 00:00:00', 166, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-04-15 00:00:00', 159, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-04-25 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-05-05 00:00:00', 184, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-05-15 00:00:00', 173, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-05-25 00:00:00', 176, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-06-05 00:00:00', 169, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-06-15 00:00:00', 170, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-06-25 00:00:00', 164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-07-05 00:00:00', 149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-07-15 00:00:00', 132, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-07-25 00:00:00', 118, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-08-05 00:00:00', 107, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-08-15 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-08-25 00:00:00', 106, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-09-05 00:00:00', 111, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-09-15 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-09-25 00:00:00', 109, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-10-05 00:00:00', 119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-10-15 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-10-25 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-11-05 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-11-15 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-11-25 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-12-05 00:00:00', 119, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-12-15 00:00:00', 128, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (3, '2013-12-25 00:00:00', 133, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-01-05 00:00:00', 73, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-01-15 00:00:00', 68, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-01-25 00:00:00', 68, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-02-05 00:00:00', 68, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-02-15 00:00:00', 78, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-02-25 00:00:00', 85, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-03-05 00:00:00', 91, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-03-15 00:00:00', 106, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-03-25 00:00:00', 141, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-04-05 00:00:00', 124, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-04-15 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-04-25 00:00:00', 79, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-05-05 00:00:00', 79, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-05-15 00:00:00', 106, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-05-25 00:00:00', 149, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-06-05 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-06-15 00:00:00', 196, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-06-25 00:00:00', 151, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-07-05 00:00:00', 142, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-07-15 00:00:00', 131, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-07-25 00:00:00', 114, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-08-05 00:00:00', 116, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-08-15 00:00:00', 96, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-08-25 00:00:00', 90, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-09-05 00:00:00', 84, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-09-15 00:00:00', 86, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-09-25 00:00:00', 87, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-10-05 00:00:00', 87, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-10-15 00:00:00', 91, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-10-25 00:00:00', 108, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-11-05 00:00:00', 115, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-11-15 00:00:00', 110, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-11-25 00:00:00', 102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-12-05 00:00:00', 101, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-12-15 00:00:00', 96, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (7, '2013-12-25 00:00:00', 93, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-01-05 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-01-15 00:00:00', 334, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-01-25 00:00:00', 326, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-02-05 00:00:00', 323, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-02-15 00:00:00', 332, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-02-25 00:00:00', 331, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-03-05 00:00:00', 328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-03-15 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-03-25 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-04-05 00:00:00', 320, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-04-15 00:00:00', 329, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-04-25 00:00:00', 343, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-05-05 00:00:00', 322, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-05-15 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-05-25 00:00:00', 342, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-06-05 00:00:00', 417, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-06-15 00:00:00', 406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-06-25 00:00:00', 310, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-07-05 00:00:00', 305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-07-15 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-07-25 00:00:00', 305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-08-05 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-08-15 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-08-25 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-09-05 00:00:00', 321, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-09-15 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-09-25 00:00:00', 307, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-10-05 00:00:00', 304, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-10-15 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-10-25 00:00:00', 307, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-11-05 00:00:00', 307, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-11-15 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-11-25 00:00:00', 306, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-12-05 00:00:00', 307, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-12-15 00:00:00', 312, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (6, '2013-12-25 00:00:00', 316, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-05 00:00:00', 186, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-15 00:00:00', 192, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-01-25 00:00:00', 195, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-05 00:00:00', 206, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-15 00:00:00', 200, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-02-25 00:00:00', 205, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-05 00:00:00', 213, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-15 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-03-25 00:00:00', 234, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-05 00:00:00', 275, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-15 00:00:00', 270, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-04-25 00:00:00', 318, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-05 00:00:00', 313, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-15 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-05-25 00:00:00', 286, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-05 00:00:00', 253, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-15 00:00:00', 279, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-06-25 00:00:00', 284, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-05 00:00:00', 265, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-15 00:00:00', 254, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-07-25 00:00:00', 246, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-05 00:00:00', 241, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-15 00:00:00', 238, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-08-25 00:00:00', 217, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-05 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-15 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-09-25 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-05 00:00:00', 208, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-15 00:00:00', 215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-10-25 00:00:00', 222, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-05 00:00:00', 219, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-15 00:00:00', 220, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-11-25 00:00:00', 223, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-05 00:00:00', 229, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-15 00:00:00', 250, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2013-12-25 00:00:00', 266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-05 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-15 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-03-25 00:00:00', 47.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-05 00:00:00', 55.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-15 00:00:00', 66, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-04-25 00:00:00', 54.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-05 00:00:00', 67.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-15 00:00:00', 79.1999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-05-25 00:00:00', 41, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-05 00:00:00', 43.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-15 00:00:00', 37.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-06-25 00:00:00', 38.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-05 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-15 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-07-25 00:00:00', 9.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-08-05 00:00:00', 2.43000006675720215, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-08-15 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-08-25 00:00:00', 5.76000022888183594, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-09-05 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-09-15 00:00:00', 5.94999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-09-25 00:00:00', 3.98000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-10-05 00:00:00', 4.48000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-10-15 00:00:00', 4.84999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-10-25 00:00:00', 6.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-11-05 00:00:00', 6.34000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-11-15 00:00:00', 6.67999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-11-25 00:00:00', 5.17999982833862305, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-12-05 00:00:00', 9.57999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-12-15 00:00:00', 8.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2014-12-25 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-01-05 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-01-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-01-25 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-02-05 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-02-15 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-02-25 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-03-05 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-03-15 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-03-25 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-04-05 00:00:00', 47.9000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-04-15 00:00:00', 25.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-04-25 00:00:00', 53.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-05-05 00:00:00', 32.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-05-15 00:00:00', 60.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-05-25 00:00:00', 31.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-06-05 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-06-15 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-06-25 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-07-05 00:00:00', 8.65999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-07-15 00:00:00', 5.55000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-07-25 00:00:00', 2.15000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-08-05 00:00:00', 1.85000002384185791, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-08-15 00:00:00', 2.45000004768371582, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-08-25 00:00:00', 3.69000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-09-05 00:00:00', 2.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-09-15 00:00:00', 4.21999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-09-25 00:00:00', 3.1099998950958252, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-10-05 00:00:00', 4.94000005722045898, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-10-15 00:00:00', 5.90999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-10-25 00:00:00', 5.3899998664855957, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-11-05 00:00:00', 5.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-11-15 00:00:00', 7.78999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-11-25 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-12-05 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-12-15 00:00:00', 9.93999958038330078, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2015-12-25 00:00:00', 9.36999988555908203, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-01-05 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-01-15 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-01-25 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-02-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-02-15 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-02-25 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-03-05 00:00:00', 25.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-03-15 00:00:00', 77.8000030517578125, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-03-25 00:00:00', 46.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-04-05 00:00:00', 42.0999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-04-15 00:00:00', 46, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-04-25 00:00:00', 66.4000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-05-05 00:00:00', 58.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-05-15 00:00:00', 46.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-05-25 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-06-05 00:00:00', 54.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-06-15 00:00:00', 81.6999969482421875, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-06-25 00:00:00', 75.5999984741210938, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-07-05 00:00:00', 42, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-07-15 00:00:00', 35, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-07-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-08-05 00:00:00', 8.81000041961669922, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-08-15 00:00:00', 4.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-08-25 00:00:00', 3.50999999046325684, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-09-05 00:00:00', 3.66000008583068848, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-09-15 00:00:00', 4.30999994277954102, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-09-25 00:00:00', 4.09000015258789062, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-10-05 00:00:00', 6.32000017166137695, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-10-15 00:00:00', 7.46999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-10-25 00:00:00', 8.39000034332275391, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-11-05 00:00:00', 7.96999979019165039, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-11-15 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-11-25 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-12-05 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-12-15 00:00:00', 8.73999977111816406, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (2, '2016-12-25 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-01-05 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-01-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-01-25 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-02-05 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-02-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-02-25 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-03-05 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-03-15 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-03-25 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-04-05 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-04-15 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-04-25 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-05-05 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-05-15 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-05-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-06-05 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-06-15 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-06-25 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-07-05 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-07-15 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-07-25 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-08-05 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-08-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-08-25 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-09-05 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-09-15 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-09-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-10-05 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-10-15 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-10-25 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-11-05 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-11-15 00:00:00', 16.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-11-25 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-12-05 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-12-15 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2014-12-25 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-01-05 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-01-15 00:00:00', 10.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-01-25 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-02-05 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-02-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-02-25 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-03-05 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-03-15 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-03-25 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-04-05 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-04-15 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-04-25 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-05-05 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-05-15 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-05-25 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-06-05 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-06-15 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-06-25 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-07-05 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-07-15 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-08-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-08-15 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-08-25 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-09-05 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-09-15 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-09-25 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-10-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-10-15 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-10-25 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-11-05 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-11-15 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-11-25 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-12-05 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-12-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2019-12-25 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-01-05 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-01-15 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-01-25 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-02-05 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-02-15 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-02-25 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-03-05 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-03-15 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-03-25 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-04-05 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-04-15 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-04-25 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-05-05 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-05-15 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-05-25 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-06-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-06-15 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-06-25 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-07-05 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-07-15 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-07-25 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-08-05 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-08-15 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-08-25 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-09-05 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-09-15 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-09-25 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-10-05 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-10-15 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-10-25 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-11-05 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-11-15 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-11-25 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-12-05 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-12-15 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2015-12-25 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-01-05 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-01-15 00:00:00', 9.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-01-25 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-02-05 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-02-15 00:00:00', 8.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-02-25 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-03-05 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-03-15 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-03-25 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-04-05 00:00:00', 12.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-04-15 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-04-25 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-05-05 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-05-15 00:00:00', 16.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-05-25 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-06-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-06-15 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-06-25 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-07-05 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-07-15 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-07-25 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-08-05 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-08-15 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-08-25 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-09-05 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-09-15 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-09-25 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-10-05 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-10-15 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-10-25 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-11-05 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-11-15 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-11-25 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-12-05 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-12-15 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2016-12-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-01-05 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-01-15 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-01-25 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-02-05 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-02-15 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-02-25 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-03-05 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-03-15 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-03-25 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-04-05 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-04-15 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-04-25 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-05-05 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-05-15 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-05-25 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-06-05 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-06-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-06-25 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-07-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-07-15 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-07-25 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-08-05 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-08-15 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-08-25 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-09-05 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-09-15 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-09-25 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-10-05 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-10-15 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-10-25 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-11-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-11-15 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-11-25 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-12-05 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-12-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2017-12-25 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-01-05 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-01-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-01-25 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-02-05 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-02-15 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-02-25 00:00:00', 11.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-03-05 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-03-15 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-03-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-04-05 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-04-15 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-04-25 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-05-05 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-05-15 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-05-25 00:00:00', 16.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-06-05 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-06-15 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-06-25 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-07-05 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-07-15 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-07-25 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-08-05 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-08-15 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-08-25 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-09-05 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-09-15 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-09-25 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-10-05 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-10-15 00:00:00', 18.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-10-25 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-11-05 00:00:00', 15.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-11-15 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-11-25 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-12-05 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-12-15 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (10, '2018-12-25 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-01-05 00:00:00', 10.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-01-15 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-01-25 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-02-05 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-02-15 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-02-25 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-03-05 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-03-15 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-03-25 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-04-05 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-04-15 00:00:00', 15.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-04-25 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-05-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-05-15 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-05-25 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-06-05 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-06-15 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-06-25 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-07-05 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-07-15 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-07-25 00:00:00', 24.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-08-05 00:00:00', 23.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-08-15 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-08-25 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-09-05 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-09-15 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-09-25 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-10-05 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-10-25 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-11-05 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-11-15 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-11-25 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-12-05 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-12-15 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-12-25 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2014-10-15 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-01-05 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-01-15 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-01-25 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-02-05 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-02-15 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-02-25 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-03-05 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-03-15 00:00:00', 12.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-03-25 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-04-05 00:00:00', 15.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-04-15 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-04-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-05-05 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-05-15 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-05-25 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-06-05 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-06-15 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-06-25 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-07-05 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-07-15 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-07-25 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-08-05 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-08-15 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-08-25 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-09-05 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-09-15 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-09-25 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-10-05 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-10-15 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-10-25 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-11-05 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-11-15 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-11-25 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-12-05 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-12-15 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2015-12-25 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-01-05 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-01-15 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-01-25 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-02-05 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-02-15 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-02-25 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-03-05 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-03-15 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-03-25 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-04-05 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-04-15 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-04-25 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-05-05 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-05-15 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-05-25 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-06-05 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-06-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-06-25 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-07-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-07-15 00:00:00', 19.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-07-25 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-08-05 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-08-15 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-08-25 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-09-05 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-09-15 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-09-25 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-10-05 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-10-15 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-10-25 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-11-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-11-15 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-11-25 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-12-05 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-12-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2017-12-25 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-01-05 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-01-15 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-01-25 00:00:00', 9.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-02-05 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-02-15 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-02-25 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-03-05 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-03-15 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-03-25 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-04-05 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-04-15 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-04-25 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-05-05 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-05-15 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-05-25 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-06-05 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-06-15 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-06-25 00:00:00', 22.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-07-05 00:00:00', 23.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-07-15 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-07-25 00:00:00', 25, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-08-05 00:00:00', 24.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-08-15 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-08-25 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-09-05 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-09-15 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-10-05 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-10-15 00:00:00', 18.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-10-25 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-11-05 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-11-15 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-11-25 00:00:00', 12.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-12-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-12-15 00:00:00', 9.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-12-25 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-01-05 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-01-15 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-01-25 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-02-05 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-02-15 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-02-25 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-03-05 00:00:00', 14.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-03-15 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-03-25 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-04-05 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-04-15 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-04-25 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-05-05 00:00:00', 17.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-05-15 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-05-25 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-06-05 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-06-15 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-06-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-07-05 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-07-15 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-08-05 00:00:00', 23.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-08-15 00:00:00', 24.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-08-25 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-09-05 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-09-15 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-09-25 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-10-05 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-10-15 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-10-25 00:00:00', 18.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-11-05 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-11-15 00:00:00', 15.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-11-25 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-12-05 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-12-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2019-12-25 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-01-05 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-01-15 00:00:00', 12, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-01-25 00:00:00', 12.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-02-05 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-02-15 00:00:00', 5.40000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-02-25 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-03-05 00:00:00', 8, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-03-15 00:00:00', 9.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-03-25 00:00:00', 13.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-04-05 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-04-15 00:00:00', 13.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-04-25 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-05-05 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-05-15 00:00:00', 18.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-05-25 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-06-05 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-06-15 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-06-25 00:00:00', 23.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-07-05 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-07-15 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-07-25 00:00:00', 23, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-08-05 00:00:00', 22.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-08-15 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-08-25 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-09-05 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-09-15 00:00:00', 22.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-09-25 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-10-05 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-10-15 00:00:00', 18.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-10-25 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-11-05 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-11-15 00:00:00', 12.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-11-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-12-05 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-12-15 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2016-12-25 00:00:00', 11.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2018-09-25 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-01-05 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-01-15 00:00:00', 7.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-01-25 00:00:00', 7.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-02-05 00:00:00', 8.60000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-02-15 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-02-25 00:00:00', 7.19999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-03-05 00:00:00', 9.39999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-03-15 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-03-25 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-04-05 00:00:00', 17.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-04-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-04-25 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-05-05 00:00:00', 20.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-05-15 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-05-25 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-06-05 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-06-15 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-06-25 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-07-05 00:00:00', 23.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-07-15 00:00:00', 24, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-07-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-08-05 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-08-15 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-08-25 00:00:00', 21.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-09-05 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-09-15 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-09-25 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-10-05 00:00:00', 19.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-10-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-10-25 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-11-05 00:00:00', 14.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-11-15 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-11-25 00:00:00', 13.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-12-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-12-15 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2008-12-25 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-01-05 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-01-15 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-01-25 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-02-05 00:00:00', 10.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-02-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-02-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-03-05 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-03-15 00:00:00', 13, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-03-25 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-04-05 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-04-15 00:00:00', 14.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-04-25 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-05-05 00:00:00', 17.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-05-15 00:00:00', 18.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-05-25 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-06-05 00:00:00', 21.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-06-15 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-06-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-07-05 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-07-15 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-07-25 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-08-05 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-08-15 00:00:00', 21.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-08-25 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-09-05 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-09-15 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-09-25 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-10-05 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-10-15 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-10-25 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-11-05 00:00:00', 16, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-11-15 00:00:00', 14.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-11-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-12-05 00:00:00', 11.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-12-15 00:00:00', 10.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2009-12-25 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-01-05 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-01-15 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-01-25 00:00:00', 10.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-02-05 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-02-15 00:00:00', 9.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-02-25 00:00:00', 11.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-03-05 00:00:00', 10.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-03-15 00:00:00', 12.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-03-25 00:00:00', 12.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-04-05 00:00:00', 14, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-04-15 00:00:00', 15.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-04-25 00:00:00', 17.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-05-05 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-05-15 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-05-25 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-06-05 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-06-15 00:00:00', 22, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-06-25 00:00:00', 23.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-07-05 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-07-15 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-07-25 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-08-05 00:00:00', 21, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-08-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-08-25 00:00:00', 21.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-09-05 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-09-15 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-09-25 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-10-05 00:00:00', 19.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-10-15 00:00:00', 19.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-10-25 00:00:00', 17.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-11-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-11-15 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-11-25 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-12-05 00:00:00', 10.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-12-15 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2010-12-25 00:00:00', 9.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-01-05 00:00:00', 10.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-01-15 00:00:00', 9.80000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-01-25 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-02-05 00:00:00', 11.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-02-15 00:00:00', 11.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-02-25 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-03-05 00:00:00', 11.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-03-15 00:00:00', 11.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-03-25 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-04-05 00:00:00', 13.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-04-15 00:00:00', 15, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-04-25 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-05-05 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-05-15 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-05-25 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-06-05 00:00:00', 20.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-06-15 00:00:00', 20.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-06-25 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-07-05 00:00:00', 20.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-07-15 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-07-25 00:00:00', 20.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-08-05 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-08-15 00:00:00', 21.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-08-25 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-09-05 00:00:00', 20.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-09-15 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-09-25 00:00:00', 19.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-10-05 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-10-15 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-10-25 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-11-05 00:00:00', 16.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-11-15 00:00:00', 15.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-11-25 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-12-05 00:00:00', 15.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-12-15 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2011-12-25 00:00:00', 14.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-01-05 00:00:00', 13.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-01-15 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-01-25 00:00:00', 8.89999961853027344, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-02-05 00:00:00', 6.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-02-15 00:00:00', 5.59999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-02-25 00:00:00', 5.90000009536743164, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-03-05 00:00:00', 6.30000019073486328, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-03-15 00:00:00', 6.09999990463256836, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-03-25 00:00:00', 7.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-04-05 00:00:00', 11, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-04-15 00:00:00', 14.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-04-25 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-05-05 00:00:00', 18.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-05-15 00:00:00', 19.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-05-25 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-06-05 00:00:00', 22.6000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-06-15 00:00:00', 23.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-06-25 00:00:00', 24.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-07-05 00:00:00', 22.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-07-15 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-07-25 00:00:00', 23.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-08-05 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-08-15 00:00:00', 22.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-08-25 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-09-05 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-09-15 00:00:00', 20.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-09-25 00:00:00', 19.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-10-05 00:00:00', 18, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-10-15 00:00:00', 17.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-10-25 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-11-05 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-11-15 00:00:00', 14.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-11-25 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-12-05 00:00:00', 14.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-12-15 00:00:00', 13.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2012-12-25 00:00:00', 10.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-01-05 00:00:00', 8.10000038146972656, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-01-15 00:00:00', 8.69999980926513672, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-01-25 00:00:00', 10, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-02-05 00:00:00', 11.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-02-15 00:00:00', 12.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-02-25 00:00:00', 12.6999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-03-05 00:00:00', 13.3000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-03-15 00:00:00', 13.8000001907348633, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-03-25 00:00:00', 13.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-04-05 00:00:00', 15.1999998092651367, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-04-15 00:00:00', 16.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-04-25 00:00:00', 18.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-05-05 00:00:00', 19, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-05-15 00:00:00', 17.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-05-25 00:00:00', 19.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-06-05 00:00:00', 20.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-06-15 00:00:00', 22.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-06-25 00:00:00', 22.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-07-05 00:00:00', 22.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-07-15 00:00:00', 21.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-07-25 00:00:00', 21.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-08-05 00:00:00', 21.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-08-15 00:00:00', 21.1000003814697266, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-08-25 00:00:00', 20.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-09-05 00:00:00', 20, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-09-15 00:00:00', 19.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-09-25 00:00:00', 18.7000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-10-05 00:00:00', 17.7999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-10-15 00:00:00', 17, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-10-25 00:00:00', 15.8999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-11-05 00:00:00', 16.2999992370605469, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-11-15 00:00:00', 16.5, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-11-25 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-12-05 00:00:00', 16.2000007629394531, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-12-15 00:00:00', 16.3999996185302734, 0);
INSERT INTO fews.timeseriesvaluesandflags VALUES (42, '2013-12-25 00:00:00', 16, 0);


--
-- TOC entry 3791 (class 0 OID 36428)
-- Dependencies: 245
-- Data for Name: timesteps; Type: TABLE DATA; Schema: fews; Owner: postgres
--

INSERT INTO fews.timesteps VALUES (1, 'NETS', 'nonequidistant');


--
-- TOC entry 3792 (class 0 OID 36432)
-- Dependencies: 246
-- Data for Name: users; Type: TABLE DATA; Schema: fews; Owner: postgres
--



--
-- TOC entry 3793 (class 0 OID 36440)
-- Dependencies: 248
-- Data for Name: dump; Type: TABLE DATA; Schema: monitoring; Owner: webapp
--



--
-- TOC entry 3797 (class 0 OID 36449)
-- Dependencies: 252
-- Data for Name: period; Type: TABLE DATA; Schema: ratingcurve; Owner: postgres
--



--
-- TOC entry 3798 (class 0 OID 36453)
-- Dependencies: 253
-- Data for Name: segment; Type: TABLE DATA; Schema: ratingcurve; Owner: postgres
--



--
-- TOC entry 3843 (class 0 OID 0)
-- Dependencies: 205
-- Name: navtree_itemid_seq; Type: SEQUENCE SET; Schema: app; Owner: postgres
--

SELECT pg_catalog.setval('app.navtree_itemid_seq', 12, true);


--
-- TOC entry 3844 (class 0 OID 0)
-- Dependencies: 208
-- Name: role_roleid_seq; Type: SEQUENCE SET; Schema: app; Owner: postgres
--

SELECT pg_catalog.setval('app.role_roleid_seq', 4, true);


--
-- TOC entry 3845 (class 0 OID 0)
-- Dependencies: 212
-- Name: spatialfilter_gid_seq; Type: SEQUENCE SET; Schema: app; Owner: postgres
--

SELECT pg_catalog.setval('app.spatialfilter_gid_seq', 1, true);


--
-- TOC entry 3846 (class 0 OID 0)
-- Dependencies: 213
-- Name: userid_seq; Type: SEQUENCE SET; Schema: app; Owner: postgres
--

SELECT pg_catalog.setval('app.userid_seq', 14, true);


--
-- TOC entry 3847 (class 0 OID 0)
-- Dependencies: 216
-- Name: AggregationPeriods_aggregationperiodkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."AggregationPeriods_aggregationperiodkey_seq"', 1, false);


--
-- TOC entry 3848 (class 0 OID 0)
-- Dependencies: 217
-- Name: FeatureClass_featureclasskey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."FeatureClass_featureclasskey_seq"', 3, true);


--
-- TOC entry 3849 (class 0 OID 0)
-- Dependencies: 218
-- Name: Filters_filterkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."Filters_filterkey_seq"', 1, false);


--
-- TOC entry 3850 (class 0 OID 0)
-- Dependencies: 219
-- Name: Locations_locationkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."Locations_locationkey_seq"', 55, true);


--
-- TOC entry 3851 (class 0 OID 0)
-- Dependencies: 220
-- Name: ModuleInstances_moduleinstancekey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."ModuleInstances_moduleinstancekey_seq"', 1, false);


--
-- TOC entry 3852 (class 0 OID 0)
-- Dependencies: 221
-- Name: ParameterGroups_groupkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."ParameterGroups_groupkey_seq"', 6, true);


--
-- TOC entry 3853 (class 0 OID 0)
-- Dependencies: 222
-- Name: ParametersTable_parameterkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."ParametersTable_parameterkey_seq"', 6, true);


--
-- TOC entry 3854 (class 0 OID 0)
-- Dependencies: 223
-- Name: QualifierSets_qualifiersetkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."QualifierSets_qualifiersetkey_seq"', 1, false);


--
-- TOC entry 3855 (class 0 OID 0)
-- Dependencies: 224
-- Name: Qualifiers_qualifierkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."Qualifiers_qualifierkey_seq"', 1, false);


--
-- TOC entry 3856 (class 0 OID 0)
-- Dependencies: 225
-- Name: TimeSeriesKeys_serieskey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."TimeSeriesKeys_serieskey_seq"', 43, true);


--
-- TOC entry 3857 (class 0 OID 0)
-- Dependencies: 226
-- Name: TimeSteps_timestepkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."TimeSteps_timestepkey_seq"', 1, false);


--
-- TOC entry 3858 (class 0 OID 0)
-- Dependencies: 227
-- Name: Users_userkey_seq; Type: SEQUENCE SET; Schema: fews; Owner: postgres
--

SELECT pg_catalog.setval('fews."Users_userkey_seq"', 1, false);


--
-- TOC entry 3859 (class 0 OID 0)
-- Dependencies: 249
-- Name: dump_id_seq; Type: SEQUENCE SET; Schema: monitoring; Owner: webapp
--

SELECT pg_catalog.setval('monitoring.dump_id_seq', 456233, true);


--
-- TOC entry 3860 (class 0 OID 0)
-- Dependencies: 250
-- Name: Period_periodkey_seq; Type: SEQUENCE SET; Schema: ratingcurve; Owner: postgres
--

SELECT pg_catalog.setval('ratingcurve."Period_periodkey_seq"', 1, false);


--
-- TOC entry 3861 (class 0 OID 0)
-- Dependencies: 251
-- Name: Segment_segmentkey_seq; Type: SEQUENCE SET; Schema: ratingcurve; Owner: postgres
--

SELECT pg_catalog.setval('ratingcurve."Segment_segmentkey_seq"', 1, false);


--
-- TOC entry 3518 (class 2606 OID 36260)
-- Name: navtree pk_navtree; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.navtree
    ADD CONSTRAINT pk_navtree PRIMARY KEY (itemid);


--
-- TOC entry 3528 (class 2606 OID 36264)
-- Name: role_navtree pk_navtree_role; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.role_navtree
    ADD CONSTRAINT pk_navtree_role PRIMARY KEY (roleid, itemid);


--
-- TOC entry 3522 (class 2606 OID 36262)
-- Name: preferences pk_preferences; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.preferences
    ADD CONSTRAINT pk_preferences PRIMARY KEY (type, name);


--
-- TOC entry 3524 (class 2606 OID 36266)
-- Name: role pk_role; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.role
    ADD CONSTRAINT pk_role PRIMARY KEY (roleid);


--
-- TOC entry 3532 (class 2606 OID 36268)
-- Name: user pk_user; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app."user"
    ADD CONSTRAINT pk_user PRIMARY KEY (userid);


--
-- TOC entry 3536 (class 2606 OID 36270)
-- Name: user_spatialfilter pk_user_spatialfilter; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.user_spatialfilter
    ADD CONSTRAINT pk_user_spatialfilter PRIMARY KEY (userid, gid);


--
-- TOC entry 3530 (class 2606 OID 36272)
-- Name: spatialfilter spf_pkey; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.spatialfilter
    ADD CONSTRAINT spf_pkey PRIMARY KEY (gid);


--
-- TOC entry 3520 (class 2606 OID 36274)
-- Name: navtree unique_modulename; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.navtree
    ADD CONSTRAINT unique_modulename UNIQUE (modulename);


--
-- TOC entry 3526 (class 2606 OID 36276)
-- Name: role unique_rolename; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.role
    ADD CONSTRAINT unique_rolename UNIQUE (rolename);


--
-- TOC entry 3534 (class 2606 OID 36278)
-- Name: user unique_username; Type: CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app."user"
    ADD CONSTRAINT unique_username UNIQUE (username);


--
-- TOC entry 3538 (class 2606 OID 36459)
-- Name: aggregationperiods pk_aggregationper; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.aggregationperiods
    ADD CONSTRAINT pk_aggregationper PRIMARY KEY (aggregationperiodkey);


--
-- TOC entry 3542 (class 2606 OID 36461)
-- Name: featureclass pk_featureclass; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.featureclass
    ADD CONSTRAINT pk_featureclass PRIMARY KEY (featureclasskey);


--
-- TOC entry 3544 (class 2606 OID 36463)
-- Name: filters pk_filters; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.filters
    ADD CONSTRAINT pk_filters PRIMARY KEY (filterkey);


--
-- TOC entry 3548 (class 2606 OID 36465)
-- Name: filtertimeserieskeys pk_filtertimeseriesk; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.filtertimeserieskeys
    ADD CONSTRAINT pk_filtertimeseriesk PRIMARY KEY (filterkey, serieskey);


--
-- TOC entry 3550 (class 2606 OID 36467)
-- Name: locations pk_locations; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.locations
    ADD CONSTRAINT pk_locations PRIMARY KEY (locationkey);


--
-- TOC entry 3554 (class 2606 OID 36469)
-- Name: moduleinstances pk_moduleinstances; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.moduleinstances
    ADD CONSTRAINT pk_moduleinstances PRIMARY KEY (moduleinstancekey);


--
-- TOC entry 3558 (class 2606 OID 36471)
-- Name: parametergroups pk_parametergroups; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.parametergroups
    ADD CONSTRAINT pk_parametergroups PRIMARY KEY (groupkey);


--
-- TOC entry 3562 (class 2606 OID 36473)
-- Name: parameterstable pk_parameterstable; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.parameterstable
    ADD CONSTRAINT pk_parameterstable PRIMARY KEY (parameterkey);


--
-- TOC entry 3566 (class 2606 OID 36475)
-- Name: qualifiers pk_qualifiers; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.qualifiers
    ADD CONSTRAINT pk_qualifiers PRIMARY KEY (qualifierkey);


--
-- TOC entry 3570 (class 2606 OID 36477)
-- Name: qualifiersets pk_qualifiersets; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.qualifiersets
    ADD CONSTRAINT pk_qualifiersets PRIMARY KEY (qualifiersetkey);


--
-- TOC entry 3574 (class 2606 OID 36479)
-- Name: samples pk_samples; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.samples
    ADD CONSTRAINT pk_samples PRIMARY KEY (locationkey, datetime);


--
-- TOC entry 3576 (class 2606 OID 36481)
-- Name: timeseriescomments pk_timeseriescomments; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeseriescomments
    ADD CONSTRAINT pk_timeseriescomments PRIMARY KEY (serieskey, datetime);


--
-- TOC entry 3578 (class 2606 OID 36483)
-- Name: timeserieskeys pk_timeserieskeys; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeserieskeys
    ADD CONSTRAINT pk_timeserieskeys PRIMARY KEY (serieskey);


--
-- TOC entry 3582 (class 2606 OID 36485)
-- Name: timeseriesmanualeditshistory pk_timeseriesmanualedits; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeseriesmanualeditshistory
    ADD CONSTRAINT pk_timeseriesmanualedits PRIMARY KEY (serieskey, datetime, editdatetime);


--
-- TOC entry 3584 (class 2606 OID 36487)
-- Name: timeseriesvaluesandflags pk_timeseriesvaluesandflags; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeseriesvaluesandflags
    ADD CONSTRAINT pk_timeseriesvaluesandflags PRIMARY KEY (serieskey, datetime);


--
-- TOC entry 3586 (class 2606 OID 36489)
-- Name: timesteps pk_timesteps; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timesteps
    ADD CONSTRAINT pk_timesteps PRIMARY KEY (timestepkey);


--
-- TOC entry 3590 (class 2606 OID 36491)
-- Name: users pk_users; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.users
    ADD CONSTRAINT pk_users PRIMARY KEY (userkey);


--
-- TOC entry 3540 (class 2606 OID 36493)
-- Name: aggregationperiods uniq_aggregationper_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.aggregationperiods
    ADD CONSTRAINT uniq_aggregationper_id UNIQUE (id);


--
-- TOC entry 3546 (class 2606 OID 36495)
-- Name: filters uniq_filters_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.filters
    ADD CONSTRAINT uniq_filters_id UNIQUE (id);


--
-- TOC entry 3552 (class 2606 OID 36497)
-- Name: locations uniq_locations_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.locations
    ADD CONSTRAINT uniq_locations_id UNIQUE (id);


--
-- TOC entry 3556 (class 2606 OID 36499)
-- Name: moduleinstances uniq_moduleinstances_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.moduleinstances
    ADD CONSTRAINT uniq_moduleinstances_id UNIQUE (id);


--
-- TOC entry 3560 (class 2606 OID 36501)
-- Name: parametergroups uniq_parametergroups_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.parametergroups
    ADD CONSTRAINT uniq_parametergroups_id UNIQUE (id);


--
-- TOC entry 3564 (class 2606 OID 36503)
-- Name: parameterstable uniq_parameterstable_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.parameterstable
    ADD CONSTRAINT uniq_parameterstable_id UNIQUE (id);


--
-- TOC entry 3568 (class 2606 OID 36505)
-- Name: qualifiers uniq_qualifiers_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.qualifiers
    ADD CONSTRAINT uniq_qualifiers_id UNIQUE (id);


--
-- TOC entry 3572 (class 2606 OID 36507)
-- Name: qualifiersets uniq_qualifiersets_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.qualifiersets
    ADD CONSTRAINT uniq_qualifiersets_id UNIQUE (id);


--
-- TOC entry 3580 (class 2606 OID 36509)
-- Name: timeserieskeys uniq_timeserieskey_compound; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeserieskeys
    ADD CONSTRAINT uniq_timeserieskey_compound UNIQUE (locationkey, parameterkey, qualifiersetkey, moduleinstancekey, timestepkey, aggregationperiodkey);


--
-- TOC entry 3588 (class 2606 OID 36511)
-- Name: timesteps uniq_timesteps_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timesteps
    ADD CONSTRAINT uniq_timesteps_id UNIQUE (id);


--
-- TOC entry 3592 (class 2606 OID 36513)
-- Name: users uniq_users_id; Type: CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.users
    ADD CONSTRAINT uniq_users_id UNIQUE (id);


--
-- TOC entry 3594 (class 2606 OID 36515)
-- Name: dump dump_pkey; Type: CONSTRAINT; Schema: monitoring; Owner: webapp
--

ALTER TABLE ONLY monitoring.dump
    ADD CONSTRAINT dump_pkey PRIMARY KEY (id);


--
-- TOC entry 3596 (class 2606 OID 36517)
-- Name: period pk_period; Type: CONSTRAINT; Schema: ratingcurve; Owner: postgres
--

ALTER TABLE ONLY ratingcurve.period
    ADD CONSTRAINT pk_period PRIMARY KEY (periodkey);


--
-- TOC entry 3598 (class 2606 OID 36519)
-- Name: segment pk_segment; Type: CONSTRAINT; Schema: ratingcurve; Owner: postgres
--

ALTER TABLE ONLY ratingcurve.segment
    ADD CONSTRAINT pk_segment PRIMARY KEY (segmentkey);


--
-- TOC entry 3599 (class 2606 OID 36279)
-- Name: preferences fk_gid; Type: FK CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.preferences
    ADD CONSTRAINT fk_gid FOREIGN KEY (gid) REFERENCES app.spatialfilter(gid);


--
-- TOC entry 3605 (class 2606 OID 36294)
-- Name: user_spatialfilter fk_gid; Type: FK CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.user_spatialfilter
    ADD CONSTRAINT fk_gid FOREIGN KEY (gid) REFERENCES app.spatialfilter(gid);


--
-- TOC entry 3602 (class 2606 OID 36299)
-- Name: role_navtree fk_navtree_itemid; Type: FK CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.role_navtree
    ADD CONSTRAINT fk_navtree_itemid FOREIGN KEY (itemid) REFERENCES app.navtree(itemid);


--
-- TOC entry 3603 (class 2606 OID 36304)
-- Name: role_navtree fk_role_roleid; Type: FK CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.role_navtree
    ADD CONSTRAINT fk_role_roleid FOREIGN KEY (roleid) REFERENCES app.role(roleid);


--
-- TOC entry 3600 (class 2606 OID 36284)
-- Name: preferences fk_roleid; Type: FK CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.preferences
    ADD CONSTRAINT fk_roleid FOREIGN KEY (roleid) REFERENCES app.role(roleid);


--
-- TOC entry 3604 (class 2606 OID 36309)
-- Name: user fk_roleid; Type: FK CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app."user"
    ADD CONSTRAINT fk_roleid FOREIGN KEY (roleid) REFERENCES app.role(roleid);


--
-- TOC entry 3601 (class 2606 OID 36289)
-- Name: preferences fk_userid; Type: FK CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.preferences
    ADD CONSTRAINT fk_userid FOREIGN KEY (userid) REFERENCES app."user"(userid);


--
-- TOC entry 3606 (class 2606 OID 36314)
-- Name: user_spatialfilter fk_userid; Type: FK CONSTRAINT; Schema: app; Owner: postgres
--

ALTER TABLE ONLY app.user_spatialfilter
    ADD CONSTRAINT fk_userid FOREIGN KEY (userid) REFERENCES app."user"(userid);


--
-- TOC entry 3607 (class 2606 OID 36520)
-- Name: filtertimeserieskeys fk_filtertimeseriesk_filterkey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.filtertimeserieskeys
    ADD CONSTRAINT fk_filtertimeseriesk_filterkey FOREIGN KEY (filterkey) REFERENCES fews.filters(filterkey);


--
-- TOC entry 3608 (class 2606 OID 36525)
-- Name: filtertimeserieskeys fk_filtertimeseriesk_serieskey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.filtertimeserieskeys
    ADD CONSTRAINT fk_filtertimeseriesk_serieskey FOREIGN KEY (serieskey) REFERENCES fews.timeserieskeys(serieskey);


--
-- TOC entry 3609 (class 2606 OID 36530)
-- Name: locations fk_locationst_srid; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.locations
    ADD CONSTRAINT fk_locationst_srid FOREIGN KEY (srid) REFERENCES public.spatial_ref_sys(srid);


--
-- TOC entry 3610 (class 2606 OID 36535)
-- Name: parameterstable fk_parameterst_featureclasskey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.parameterstable
    ADD CONSTRAINT fk_parameterst_featureclasskey FOREIGN KEY (featureclasskey) REFERENCES fews.featureclass(featureclasskey);


--
-- TOC entry 3611 (class 2606 OID 36540)
-- Name: parameterstable fk_parameterst_groupkey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.parameterstable
    ADD CONSTRAINT fk_parameterst_groupkey FOREIGN KEY (groupkey) REFERENCES fews.parametergroups(groupkey);


--
-- TOC entry 3612 (class 2606 OID 36545)
-- Name: qualifiersets fk_qualifiersets_qualifierkey1; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.qualifiersets
    ADD CONSTRAINT fk_qualifiersets_qualifierkey1 FOREIGN KEY (qualifierkey1) REFERENCES fews.qualifiers(qualifierkey);


--
-- TOC entry 3613 (class 2606 OID 36550)
-- Name: qualifiersets fk_qualifiersets_qualifierkey2; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.qualifiersets
    ADD CONSTRAINT fk_qualifiersets_qualifierkey2 FOREIGN KEY (qualifierkey2) REFERENCES fews.qualifiers(qualifierkey);


--
-- TOC entry 3614 (class 2606 OID 36555)
-- Name: qualifiersets fk_qualifiersets_qualifierkey3; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.qualifiersets
    ADD CONSTRAINT fk_qualifiersets_qualifierkey3 FOREIGN KEY (qualifierkey3) REFERENCES fews.qualifiers(qualifierkey);


--
-- TOC entry 3615 (class 2606 OID 36560)
-- Name: qualifiersets fk_qualifiersets_qualifierkey4; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.qualifiersets
    ADD CONSTRAINT fk_qualifiersets_qualifierkey4 FOREIGN KEY (qualifierkey4) REFERENCES fews.qualifiers(qualifierkey);


--
-- TOC entry 3616 (class 2606 OID 36565)
-- Name: samples fk_samples; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.samples
    ADD CONSTRAINT fk_samples FOREIGN KEY (locationkey) REFERENCES fews.locations(locationkey);


--
-- TOC entry 3617 (class 2606 OID 36570)
-- Name: timeseriescomments fk_timeseriescomments; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeseriescomments
    ADD CONSTRAINT fk_timeseriescomments FOREIGN KEY (serieskey) REFERENCES fews.timeserieskeys(serieskey);


--
-- TOC entry 3618 (class 2606 OID 36575)
-- Name: timeserieskeys fk_timeserieskeys_aggperkey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeserieskeys
    ADD CONSTRAINT fk_timeserieskeys_aggperkey FOREIGN KEY (aggregationperiodkey) REFERENCES fews.aggregationperiods(aggregationperiodkey);


--
-- TOC entry 3619 (class 2606 OID 36580)
-- Name: timeserieskeys fk_timeserieskeys_locationkey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeserieskeys
    ADD CONSTRAINT fk_timeserieskeys_locationkey FOREIGN KEY (locationkey) REFERENCES fews.locations(locationkey);


--
-- TOC entry 3620 (class 2606 OID 36585)
-- Name: timeserieskeys fk_timeserieskeys_modinskey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeserieskeys
    ADD CONSTRAINT fk_timeserieskeys_modinskey FOREIGN KEY (moduleinstancekey) REFERENCES fews.moduleinstances(moduleinstancekey);


--
-- TOC entry 3621 (class 2606 OID 36590)
-- Name: timeserieskeys fk_timeserieskeys_paramkey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeserieskeys
    ADD CONSTRAINT fk_timeserieskeys_paramkey FOREIGN KEY (parameterkey) REFERENCES fews.parameterstable(parameterkey);


--
-- TOC entry 3622 (class 2606 OID 36595)
-- Name: timeserieskeys fk_timeserieskeys_qualsetkey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeserieskeys
    ADD CONSTRAINT fk_timeserieskeys_qualsetkey FOREIGN KEY (qualifiersetkey) REFERENCES fews.qualifiersets(qualifiersetkey);


--
-- TOC entry 3623 (class 2606 OID 36600)
-- Name: timeserieskeys fk_timeserieskeys_timestepkey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeserieskeys
    ADD CONSTRAINT fk_timeserieskeys_timestepkey FOREIGN KEY (timestepkey) REFERENCES fews.timesteps(timestepkey);


--
-- TOC entry 3624 (class 2606 OID 36605)
-- Name: timeseriesmanualeditshistory fk_timeseriesmane_serieskey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeseriesmanualeditshistory
    ADD CONSTRAINT fk_timeseriesmane_serieskey FOREIGN KEY (serieskey) REFERENCES fews.timeserieskeys(serieskey);


--
-- TOC entry 3625 (class 2606 OID 36610)
-- Name: timeseriesmanualeditshistory fk_timeseriesmane_userkey; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeseriesmanualeditshistory
    ADD CONSTRAINT fk_timeseriesmane_userkey FOREIGN KEY (userkey) REFERENCES fews.users(userkey);


--
-- TOC entry 3626 (class 2606 OID 36615)
-- Name: timeseriesvaluesandflags fk_timeseriesvaluesandflags; Type: FK CONSTRAINT; Schema: fews; Owner: postgres
--

ALTER TABLE ONLY fews.timeseriesvaluesandflags
    ADD CONSTRAINT fk_timeseriesvaluesandflags FOREIGN KEY (serieskey) REFERENCES fews.timeserieskeys(serieskey);


--
-- TOC entry 3627 (class 2606 OID 36620)
-- Name: period fk_period_location; Type: FK CONSTRAINT; Schema: ratingcurve; Owner: postgres
--

ALTER TABLE ONLY ratingcurve.period
    ADD CONSTRAINT fk_period_location FOREIGN KEY (locationkey) REFERENCES fews.locations(locationkey);


--
-- TOC entry 3628 (class 2606 OID 36625)
-- Name: segment fk_segment_period; Type: FK CONSTRAINT; Schema: ratingcurve; Owner: postgres
--

ALTER TABLE ONLY ratingcurve.segment
    ADD CONSTRAINT fk_segment_period FOREIGN KEY (periodkey) REFERENCES ratingcurve.period(periodkey);


--
-- TOC entry 3804 (class 0 OID 0)
-- Dependencies: 10
-- Name: SCHEMA app; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA app FROM PUBLIC;
REVOKE ALL ON SCHEMA app FROM postgres;
GRANT ALL ON SCHEMA app TO postgres;
GRANT USAGE ON SCHEMA app TO webapp;


--
-- TOC entry 3805 (class 0 OID 0)
-- Dependencies: 12
-- Name: SCHEMA fews; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA fews FROM PUBLIC;
REVOKE ALL ON SCHEMA fews FROM postgres;
GRANT ALL ON SCHEMA fews TO postgres;
GRANT ALL ON SCHEMA fews TO webapp;


--
-- TOC entry 3806 (class 0 OID 0)
-- Dependencies: 13
-- Name: SCHEMA ratingcurve; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA ratingcurve FROM PUBLIC;
REVOKE ALL ON SCHEMA ratingcurve FROM postgres;
GRANT ALL ON SCHEMA ratingcurve TO postgres;
GRANT ALL ON SCHEMA ratingcurve TO webapp;


--
-- TOC entry 3807 (class 0 OID 0)
-- Dependencies: 206
-- Name: TABLE navtree; Type: ACL; Schema: app; Owner: postgres
--

REVOKE ALL ON TABLE app.navtree FROM PUBLIC;
REVOKE ALL ON TABLE app.navtree FROM postgres;
GRANT ALL ON TABLE app.navtree TO postgres;
GRANT SELECT ON TABLE app.navtree TO webapp;


--
-- TOC entry 3808 (class 0 OID 0)
-- Dependencies: 207
-- Name: TABLE preferences; Type: ACL; Schema: app; Owner: postgres
--

REVOKE ALL ON TABLE app.preferences FROM PUBLIC;
REVOKE ALL ON TABLE app.preferences FROM postgres;
GRANT ALL ON TABLE app.preferences TO postgres;
GRANT SELECT ON TABLE app.preferences TO webapp;


--
-- TOC entry 3809 (class 0 OID 0)
-- Dependencies: 209
-- Name: TABLE role; Type: ACL; Schema: app; Owner: postgres
--

REVOKE ALL ON TABLE app.role FROM PUBLIC;
REVOKE ALL ON TABLE app.role FROM postgres;
GRANT ALL ON TABLE app.role TO postgres;
GRANT SELECT ON TABLE app.role TO webapp;


--
-- TOC entry 3810 (class 0 OID 0)
-- Dependencies: 210
-- Name: TABLE role_navtree; Type: ACL; Schema: app; Owner: postgres
--

REVOKE ALL ON TABLE app.role_navtree FROM PUBLIC;
REVOKE ALL ON TABLE app.role_navtree FROM postgres;
GRANT ALL ON TABLE app.role_navtree TO postgres;
GRANT SELECT ON TABLE app.role_navtree TO webapp;


--
-- TOC entry 3811 (class 0 OID 0)
-- Dependencies: 211
-- Name: TABLE spatialfilter; Type: ACL; Schema: app; Owner: postgres
--

REVOKE ALL ON TABLE app.spatialfilter FROM PUBLIC;
REVOKE ALL ON TABLE app.spatialfilter FROM postgres;
GRANT ALL ON TABLE app.spatialfilter TO postgres;
GRANT SELECT ON TABLE app.spatialfilter TO webapp;


--
-- TOC entry 3813 (class 0 OID 0)
-- Dependencies: 214
-- Name: TABLE "user"; Type: ACL; Schema: app; Owner: postgres
--

REVOKE ALL ON TABLE app."user" FROM PUBLIC;
REVOKE ALL ON TABLE app."user" FROM postgres;
GRANT ALL ON TABLE app."user" TO postgres;
GRANT SELECT ON TABLE app."user" TO webapp;


--
-- TOC entry 3814 (class 0 OID 0)
-- Dependencies: 215
-- Name: TABLE user_spatialfilter; Type: ACL; Schema: app; Owner: postgres
--

REVOKE ALL ON TABLE app.user_spatialfilter FROM PUBLIC;
REVOKE ALL ON TABLE app.user_spatialfilter FROM postgres;
GRANT ALL ON TABLE app.user_spatialfilter TO postgres;
GRANT SELECT ON TABLE app.user_spatialfilter TO webapp;


--
-- TOC entry 3815 (class 0 OID 0)
-- Dependencies: 228
-- Name: TABLE aggregationperiods; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.aggregationperiods FROM PUBLIC;
REVOKE ALL ON TABLE fews.aggregationperiods FROM postgres;
GRANT ALL ON TABLE fews.aggregationperiods TO postgres;
GRANT SELECT ON TABLE fews.aggregationperiods TO webapp;


--
-- TOC entry 3816 (class 0 OID 0)
-- Dependencies: 229
-- Name: TABLE dual; Type: ACL; Schema: fews; Owner: webapp
--

REVOKE ALL ON TABLE fews.dual FROM PUBLIC;
REVOKE ALL ON TABLE fews.dual FROM webapp;
GRANT ALL ON TABLE fews.dual TO webapp;


--
-- TOC entry 3817 (class 0 OID 0)
-- Dependencies: 230
-- Name: TABLE featureclass; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.featureclass FROM PUBLIC;
REVOKE ALL ON TABLE fews.featureclass FROM postgres;
GRANT ALL ON TABLE fews.featureclass TO postgres;
GRANT SELECT ON TABLE fews.featureclass TO webapp;


--
-- TOC entry 3818 (class 0 OID 0)
-- Dependencies: 231
-- Name: TABLE filters; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.filters FROM PUBLIC;
REVOKE ALL ON TABLE fews.filters FROM postgres;
GRANT ALL ON TABLE fews.filters TO postgres;
GRANT SELECT ON TABLE fews.filters TO webapp;


--
-- TOC entry 3819 (class 0 OID 0)
-- Dependencies: 232
-- Name: TABLE filtertimeserieskeys; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.filtertimeserieskeys FROM PUBLIC;
REVOKE ALL ON TABLE fews.filtertimeserieskeys FROM postgres;
GRANT ALL ON TABLE fews.filtertimeserieskeys TO postgres;
GRANT SELECT ON TABLE fews.filtertimeserieskeys TO webapp;


--
-- TOC entry 3823 (class 0 OID 0)
-- Dependencies: 233
-- Name: TABLE locations; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.locations FROM PUBLIC;
REVOKE ALL ON TABLE fews.locations FROM postgres;
GRANT ALL ON TABLE fews.locations TO postgres;
GRANT SELECT ON TABLE fews.locations TO webapp;


--
-- TOC entry 3824 (class 0 OID 0)
-- Dependencies: 234
-- Name: TABLE moduleinstances; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.moduleinstances FROM PUBLIC;
REVOKE ALL ON TABLE fews.moduleinstances FROM postgres;
GRANT ALL ON TABLE fews.moduleinstances TO postgres;
GRANT SELECT ON TABLE fews.moduleinstances TO webapp;


--
-- TOC entry 3825 (class 0 OID 0)
-- Dependencies: 235
-- Name: TABLE parametergroups; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.parametergroups FROM PUBLIC;
REVOKE ALL ON TABLE fews.parametergroups FROM postgres;
GRANT ALL ON TABLE fews.parametergroups TO postgres;
GRANT SELECT ON TABLE fews.parametergroups TO webapp;


--
-- TOC entry 3826 (class 0 OID 0)
-- Dependencies: 236
-- Name: TABLE parameterstable; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.parameterstable FROM PUBLIC;
REVOKE ALL ON TABLE fews.parameterstable FROM postgres;
GRANT ALL ON TABLE fews.parameterstable TO postgres;
GRANT SELECT ON TABLE fews.parameterstable TO webapp;


--
-- TOC entry 3827 (class 0 OID 0)
-- Dependencies: 237
-- Name: TABLE qualifiers; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.qualifiers FROM PUBLIC;
REVOKE ALL ON TABLE fews.qualifiers FROM postgres;
GRANT ALL ON TABLE fews.qualifiers TO postgres;
GRANT SELECT ON TABLE fews.qualifiers TO webapp;


--
-- TOC entry 3828 (class 0 OID 0)
-- Dependencies: 238
-- Name: TABLE qualifiersets; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.qualifiersets FROM PUBLIC;
REVOKE ALL ON TABLE fews.qualifiersets FROM postgres;
GRANT ALL ON TABLE fews.qualifiersets TO postgres;
GRANT SELECT ON TABLE fews.qualifiersets TO webapp;


--
-- TOC entry 3829 (class 0 OID 0)
-- Dependencies: 239
-- Name: TABLE samples; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.samples FROM PUBLIC;
REVOKE ALL ON TABLE fews.samples FROM postgres;
GRANT ALL ON TABLE fews.samples TO postgres;
GRANT SELECT ON TABLE fews.samples TO webapp;


--
-- TOC entry 3830 (class 0 OID 0)
-- Dependencies: 240
-- Name: TABLE stations; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.stations FROM PUBLIC;
REVOKE ALL ON TABLE fews.stations FROM postgres;
GRANT ALL ON TABLE fews.stations TO postgres;
GRANT SELECT ON TABLE fews.stations TO webapp;


--
-- TOC entry 3831 (class 0 OID 0)
-- Dependencies: 241
-- Name: TABLE timeseriescomments; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.timeseriescomments FROM PUBLIC;
REVOKE ALL ON TABLE fews.timeseriescomments FROM postgres;
GRANT ALL ON TABLE fews.timeseriescomments TO postgres;
GRANT SELECT ON TABLE fews.timeseriescomments TO webapp;


--
-- TOC entry 3832 (class 0 OID 0)
-- Dependencies: 242
-- Name: TABLE timeserieskeys; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.timeserieskeys FROM PUBLIC;
REVOKE ALL ON TABLE fews.timeserieskeys FROM postgres;
GRANT ALL ON TABLE fews.timeserieskeys TO postgres;
GRANT SELECT ON TABLE fews.timeserieskeys TO webapp;


--
-- TOC entry 3833 (class 0 OID 0)
-- Dependencies: 243
-- Name: TABLE timeseriesmanualeditshistory; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.timeseriesmanualeditshistory FROM PUBLIC;
REVOKE ALL ON TABLE fews.timeseriesmanualeditshistory FROM postgres;
GRANT ALL ON TABLE fews.timeseriesmanualeditshistory TO postgres;
GRANT SELECT ON TABLE fews.timeseriesmanualeditshistory TO webapp;


--
-- TOC entry 3834 (class 0 OID 0)
-- Dependencies: 244
-- Name: TABLE timeseriesvaluesandflags; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.timeseriesvaluesandflags FROM PUBLIC;
REVOKE ALL ON TABLE fews.timeseriesvaluesandflags FROM postgres;
GRANT ALL ON TABLE fews.timeseriesvaluesandflags TO postgres;
GRANT SELECT ON TABLE fews.timeseriesvaluesandflags TO webapp;


--
-- TOC entry 3835 (class 0 OID 0)
-- Dependencies: 245
-- Name: TABLE timesteps; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.timesteps FROM PUBLIC;
REVOKE ALL ON TABLE fews.timesteps FROM postgres;
GRANT ALL ON TABLE fews.timesteps TO postgres;
GRANT SELECT ON TABLE fews.timesteps TO webapp;


--
-- TOC entry 3836 (class 0 OID 0)
-- Dependencies: 246
-- Name: TABLE users; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.users FROM PUBLIC;
REVOKE ALL ON TABLE fews.users FROM postgres;
GRANT ALL ON TABLE fews.users TO postgres;
GRANT SELECT ON TABLE fews.users TO webapp;


--
-- TOC entry 3837 (class 0 OID 0)
-- Dependencies: 247
-- Name: TABLE wgslocations; Type: ACL; Schema: fews; Owner: postgres
--

REVOKE ALL ON TABLE fews.wgslocations FROM PUBLIC;
REVOKE ALL ON TABLE fews.wgslocations FROM postgres;
GRANT ALL ON TABLE fews.wgslocations TO postgres;
GRANT SELECT ON TABLE fews.wgslocations TO webapp;


--
-- TOC entry 3839 (class 0 OID 0)
-- Dependencies: 252
-- Name: TABLE period; Type: ACL; Schema: ratingcurve; Owner: postgres
--

REVOKE ALL ON TABLE ratingcurve.period FROM PUBLIC;
REVOKE ALL ON TABLE ratingcurve.period FROM postgres;
GRANT ALL ON TABLE ratingcurve.period TO postgres;
GRANT SELECT ON TABLE ratingcurve.period TO webapp;


--
-- TOC entry 3842 (class 0 OID 0)
-- Dependencies: 253
-- Name: TABLE segment; Type: ACL; Schema: ratingcurve; Owner: postgres
--

REVOKE ALL ON TABLE ratingcurve.segment FROM PUBLIC;
REVOKE ALL ON TABLE ratingcurve.segment FROM postgres;
GRANT ALL ON TABLE ratingcurve.segment TO postgres;
GRANT SELECT ON TABLE ratingcurve.segment TO webapp;


-- Completed on 2025-05-28 17:31:32 CEST

--
-- PostgreSQL database dump complete
--

